/* SPDX-License-Identifier: GPL-2.0 */
/*
 * File: if_phonet.h
 *
 * Phonet interface kernel definitions
 *
 * Copyright (C) 2008 Nokia Corporation. All rights reserved.
 */
#ifndef LINUX_IF_PHONET_H
#define LINUX_IF_PHONET_H

#include <uapi/linux/if_phonet.h>

extern const struct header_ops phonet_header_ops;
#endif
