/* SPDX-License-Identifier: (GPL-2.0-only OR MIT) */
/*
 * Copyright (c) 2024 Arm Ltd.
 */

#ifndef _DT_BINDINGS_RST_SUN55I_A523_CCU_H_
#define _DT_BINDINGS_RST_SUN55I_A523_CCU_H_

#define RST_MBUS		0
#define RST_BUS_NSI		1
#define RST_BUS_DE		2
#define RST_BUS_DI		3
#define RST_BUS_G2D		4
#define RST_BUS_SYS		5
#define RST_BUS_GPU		6
#define RST_BUS_CE		7
#define RST_BUS_SYS_CE		8
#define RST_BUS_VE		9
#define RST_BUS_DMA		10
#define RST_BUS_MSGBOX		11
#define RST_BUS_SPINLOCK	12
#define RST_BUS_CPUXTIMER	13
#define RST_BUS_DBG		14
#define RST_BUS_PWM0		15
#define RST_BUS_PWM1		16
#define RST_BUS_DRAM		17
#define RST_BUS_NAND		18
#define RST_BUS_MMC0		19
#define RST_BUS_MMC1		20
#define RST_BUS_MMC2		21
#define RST_BUS_SYSDAP		22
#define RST_BUS_UART0		23
#define RST_BUS_UART1		24
#define RST_BUS_UART2		25
#define RST_BUS_UART3		26
#define RST_BUS_UART4		27
#define RST_BUS_UART5		28
#define RST_BUS_UART6		29
#define RST_BUS_UART7		30
#define RST_BUS_I2C0		31
#define RST_BUS_I2C1		32
#define RST_BUS_I2C2		33
#define RST_BUS_I2C3		34
#define RST_BUS_I2C4		35
#define RST_BUS_I2C5		36
#define RST_BUS_CAN		37
#define RST_BUS_SPI0		38
#define RST_BUS_SPI1		39
#define RST_BUS_SPI2		40
#define RST_BUS_SPIFC		41
#define RST_BUS_EMAC0		42
#define RST_BUS_EMAC1		43
#define RST_BUS_IR_RX		44
#define RST_BUS_IR_TX		45
#define RST_BUS_GPADC0		46
#define RST_BUS_GPADC1		47
#define RST_BUS_THS		48
#define RST_USB_PHY0		49
#define RST_USB_PHY1		50
#define RST_BUS_OHCI0		51
#define RST_BUS_OHCI1		52
#define RST_BUS_EHCI0		53
#define RST_BUS_EHCI1		54
#define RST_BUS_OTG		55
#define RST_BUS_3		56
#define RST_BUS_LRADC		57
#define RST_BUS_PCIE_USB3	58
#define RST_BUS_DISPLAY0_TOP	59
#define RST_BUS_DISPLAY1_TOP	60
#define RST_BUS_HDMI_MAIN	61
#define RST_BUS_HDMI_SUB	62
#define RST_BUS_MIPI_DSI0	63
#define RST_BUS_MIPI_DSI1	64
#define RST_BUS_TCON_LCD0	65
#define RST_BUS_TCON_LCD1	66
#define RST_BUS_TCON_LCD2	67
#define RST_BUS_TCON_TV0	68
#define RST_BUS_TCON_TV1	69
#define RST_BUS_LVDS0		70
#define RST_BUS_LVDS1		71
#define RST_BUS_EDP		72
#define RST_BUS_VIDEO_OUT0	73
#define RST_BUS_VIDEO_OUT1	74
#define RST_BUS_LEDC		75
#define RST_BUS_CSI		76
#define RST_BUS_ISP		77

#endif /* _DT_BINDINGS_RST_SUN55I_A523_CCU_H_ */
