#ifndef __ASM_GENERIC_STRING_H
#define __ASM_GENERIC_STRING_H
/*
 * The kernel provides all required functions in lib/string.c
 *
 * Architectures probably want to provide at least their own optimized
 * memcpy and memset functions though.
 */

#endif /* __ASM_GENERIC_STRING_H */
