/* SPDX-License-Identifier: GPL-2.0 */
#ifndef _DT_BINDINGS_POWER_MT8173_POWER_H
#define _DT_BINDINGS_POWER_MT8173_POWER_H

#define MT8173_POWER_DOMAIN_VDEC	0
#define MT8173_POWER_DOMAIN_VENC	1
#define MT8173_POWER_DOMAIN_ISP		2
#define MT8173_POWER_DOMAIN_MM		3
#define MT8173_POWER_DOMAIN_VENC_LT	4
#define MT8173_POWER_DOMAIN_AUDIO	5
#define MT8173_POWER_DOMAIN_USB		6
#define MT8173_POWER_DOMAIN_MFG_ASYNC	7
#define MT8173_POWER_DOMAIN_MFG_2D	8
#define MT8173_POWER_DOMAIN_MFG		9

#endif /* _DT_BINDINGS_POWER_MT8173_POWER_H */
