/* SPDX-License-Identifier: GPL-2.0 */
#ifndef __DT_MESON_G12A_TOHDMITX_H
#define __DT_MESON_G12A_TOHDMITX_H

#define TOHDMITX_I2S_IN_A	0
#define TOHDMITX_I2S_IN_B	1
#define TOHDMITX_I2S_IN_C	2
#define TOHDMITX_I2S_OUT	3
#define TOHDMITX_SPDIF_IN_A	4
#define TOHDMITX_SPDIF_IN_B	5
#define TOHDMITX_SPDIF_OUT	6

#endif /* __DT_MESON_G12A_TOHDMITX_H */
