/*
 * Automatically generated file; DO NOT EDIT.
 * Linux/x86 7.1.9-zen1 Kernel Configuration
 */
#define CONFIG_RTC_DRV_CROS_EC_MODULE 1
#define CONFIG_AIC79XX_RESET_DELAY_MS 15000
#define CONFIG_REGULATOR_LP3972_MODULE 1
#define CONFIG_SERIAL_8250_RT288X 1
#define CONFIG_VIDEO_PVRUSB2_MODULE 1
#define CONFIG_LIQUIDIO_MODULE 1
#define CONFIG_SND_SOC_INTEL_SOF_REALTEK_COMMON_MODULE 1
#define CONFIG_EDAC_GHES 1
#define CONFIG_NFC_MRVL_MODULE 1
#define CONFIG_IPV6_IOAM6_LWTUNNEL 1
#define CONFIG_WM8350_WATCHDOG_MODULE 1
#define CONFIG_INTEL_SOC_PMIC_MRFLD_MODULE 1
#define CONFIG_PATA_OPTI_MODULE 1
#define CONFIG_SERIAL_8250_RUNTIME_UARTS 32
#define CONFIG_USB_GSPCA_PAC7311_MODULE 1
#define CONFIG_IIO_GTS_HELPER_MODULE 1
#define CONFIG_GENERIC_PHY_MIPI_DPHY 1
#define CONFIG_MFD_IQS62X_MODULE 1
#define CONFIG_SND_SOC_SOF_ACP_PROBES_MODULE 1
#define CONFIG_MAX9611_MODULE 1
#define CONFIG_RTC_DRV_NCT6694_MODULE 1
#define CONFIG_NET_CLS_BPF_MODULE 1
#define CONFIG_STM_PROTO_SYS_T_MODULE 1
#define CONFIG_MTRR 1
#define CONFIG_DHT11_MODULE 1
#define CONFIG_USB_LD_MODULE 1
#define CONFIG_W83627HF_WDT_MODULE 1
#define CONFIG_RTC_DRV_DA9063_MODULE 1
#define CONFIG_ARCH_USES_HIGH_VMA_FLAGS 1
#define CONFIG_LEDS_AS3645A_MODULE 1
#define CONFIG_USB_GSPCA_SQ930X_MODULE 1
#define CONFIG_RFKILL_MODULE 1
#define CONFIG_SPARSEMEM_VMEMMAP_ENABLE 1
#define CONFIG_SERIAL_ALTERA_UART_BAUDRATE 115200
#define CONFIG_NET_DSA_MSCC_SEVILLE_MODULE 1
#define CONFIG_BATTERY_MAX1721X_MODULE 1
#define CONFIG_NET_9P_VIRTIO_MODULE 1
#define CONFIG_USB_COMMON 1
#define CONFIG_SND_SB_COMMON_MODULE 1
#define CONFIG_MTD_MAP_BANK_WIDTH_1 1
#define CONFIG_TABLET_SERIAL_WACOM4_MODULE 1
#define CONFIG_FS_VERITY_BUILTIN_SIGNATURES 1
#define CONFIG_SND_SOC_RT1308_SDW_MODULE 1
#define CONFIG_KVM_X86_MODULE 1
#define CONFIG_SCSI_ENCLOSURE_MODULE 1
#define CONFIG_MODULE_UNLOAD_TAINT_TRACKING 1
#define CONFIG_NFT_FIB_IPV4_MODULE 1
#define CONFIG_QRTR_MODULE 1
#define CONFIG_XEN_512GB 1
#define CONFIG_TULIP_NAPI_HW_MITIGATION 1
#define CONFIG_SND_SOC_TAS6424_MODULE 1
#define CONFIG_NET_ACT_PEDIT_MODULE 1
#define CONFIG_MMC_MODULE 1
#define CONFIG_CROS_EC_MODULE 1
#define CONFIG_CM32181_MODULE 1
#define CONFIG_SND_SOC_RL6347A_MODULE 1
#define CONFIG_GPIOLIB 1
#define CONFIG_USB_DWC2_MODULE 1
#define CONFIG_DVB_LGS8GXX_MODULE 1
#define CONFIG_MFD_TPS6586X 1
#define CONFIG_HYPERV_UTILS_MODULE 1
#define CONFIG_NF_CONNTRACK_EVENTS 1
#define CONFIG_NET_EMATCH_NBYTE_MODULE 1
#define CONFIG_TOUCHSCREEN_AUO_PIXCIR_MODULE 1
#define CONFIG_PARPORT_PC_FIFO 1
#define CONFIG_DM_CACHE_SMQ_MODULE 1
#define CONFIG_IR_SANYO_DECODER_MODULE 1
#define CONFIG_NFS_V3_MODULE 1
#define CONFIG_INPUT_KXTJ9_MODULE 1
#define CONFIG_VIDEO_DEV_MODULE 1
#define CONFIG_USB_GSPCA_OV534_MODULE 1
#define CONFIG_INPUT_XEN_KBDDEV_FRONTEND_MODULE 1
#define CONFIG_ANDROID_BINDER_DEVICES ""
#define CONFIG_DMARD06_MODULE 1
#define CONFIG_AD7923_MODULE 1
#define CONFIG_SENSORS_KBATT_MODULE 1
#define CONFIG_VDPA_MODULE 1
#define CONFIG_SND_SOC_SOF_PROBE_WORK_QUEUE 1
#define CONFIG_NET_VENDOR_MICROSEMI 1
#define CONFIG_TI_ADS1018_MODULE 1
#define CONFIG_SND_EMU10K1_MODULE 1
#define CONFIG_SND_AMD_ASOC_REMBRANDT_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_MASQUERADE_MODULE 1
#define CONFIG_NET_VENDOR_NI 1
#define CONFIG_VL6180_MODULE 1
#define CONFIG_QSEMI_PHY_MODULE 1
#define CONFIG_RFKILL_INPUT 1
#define CONFIG_USB_GSPCA_TOUPTEK_MODULE 1
#define CONFIG_SND_SOC_TAS2552_MODULE 1
#define CONFIG_GENERIC_IRQ_CHIP 1
#define CONFIG_SND_SOC_MT6357_MODULE 1
#define CONFIG_USB_ROLE_SWITCH_MODULE 1
#define CONFIG_ADT7316_MODULE 1
#define CONFIG_SCSI_MYRB_MODULE 1
#define CONFIG_IRQ_BYPASS_MANAGER_MODULE 1
#define CONFIG_REGMAP_SOUNDWIRE_MODULE 1
#define CONFIG_NET_HANDSHAKE 1
#define CONFIG_USER_RETURN_NOTIFIER 1
#define CONFIG_NF_CONNTRACK_OVS 1
#define CONFIG_NETFILTER_XT_TARGET_RATEEST_MODULE 1
#define CONFIG_HTS221_I2C_MODULE 1
#define CONFIG_LIBFDT 1
#define CONFIG_R8169_MODULE 1
#define CONFIG_IWLMVM_MODULE 1
#define CONFIG_ATH10K_CE 1
#define CONFIG_RDS_TCP_MODULE 1
#define CONFIG_RCU_DOUBLE_CHECK_CB_TIME 1
#define CONFIG_WCN36XX_DEBUGFS 1
#define CONFIG_NFC_PN533_I2C_MODULE 1
#define CONFIG_PAGE_SHIFT 12
#define CONFIG_NOA1305_MODULE 1
#define CONFIG_NLS_ASCII 1
#define CONFIG_UIO_HV_GENERIC_MODULE 1
#define CONFIG_SND_ES1968_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_TIME_MODULE 1
#define CONFIG_SND_VXPOCKET_MODULE 1
#define CONFIG_USB_F_UAC1_LEGACY_MODULE 1
#define CONFIG_BATTERY_INTEL_DC_TI_MODULE 1
#define CONFIG_SATA_SVW_MODULE 1
#define CONFIG_NFS_COMMON 1
#define CONFIG_MMA9551_CORE_MODULE 1
#define CONFIG_PPPOATM_MODULE 1
#define CONFIG_SENSORS_HP_WMI_MODULE 1
#define CONFIG_WL12XX_MODULE 1
#define CONFIG_CGROUP_NET_CLASSID 1
#define CONFIG_NET_DSA_TAG_EDSA_MODULE 1
#define CONFIG_VIDEO_OV2735_MODULE 1
#define CONFIG_LOGIG940_FF 1
#define CONFIG_DVB_ISL6423_MODULE 1
#define CONFIG_SENSORS_MAX6697_MODULE 1
#define CONFIG_INPUT_TWL4030_PWRBUTTON_MODULE 1
#define CONFIG_TOUCHSCREEN_MC13783_MODULE 1
#define CONFIG_IKCONFIG 1
#define CONFIG_TREE_RCU 1
#define CONFIG_XEN_SYMS 1
#define CONFIG_LRU_GEN_WALKS_MMU 1
#define CONFIG_SYSVIPC_COMPAT 1
#define CONFIG_USB_ISP1760_HCD 1
#define CONFIG_KEYBOARD_CHARLIEPLEX_MODULE 1
#define CONFIG_CHARGER_MAX8998_MODULE 1
#define CONFIG_CRYPTO_CRYPTD_MODULE 1
#define CONFIG_VIDEO_SAA711X_MODULE 1
#define CONFIG_INFINIBAND_USER_MAD_MODULE 1
#define CONFIG_SPI_INTEL_MODULE 1
#define CONFIG_VIDEO_MT9M111_MODULE 1
#define CONFIG_CRYPTO_ECC 1
#define CONFIG_BMC150_ACCEL_MODULE 1
#define CONFIG_NET_DSA_KS8995_MODULE 1
#define CONFIG_CRC_CCITT 1
#define CONFIG_FUNCTION_TRACE_ARGS 1
#define CONFIG_USB_NET_AX8817X_MODULE 1
#define CONFIG_SYSTEM_BLACKLIST_HASH_LIST ""
#define CONFIG_PANASONIC_LAPTOP_MODULE 1
#define CONFIG_INFINIBAND_QEDR_MODULE 1
#define CONFIG_NLS_CODEPAGE_437 1
#define CONFIG_SENSORS_GL518SM_MODULE 1
#define CONFIG_RMI4_F03_SERIO_MODULE 1
#define CONFIG_X9250_MODULE 1
#define CONFIG_MMC5633_MODULE 1
#define CONFIG_ALIENWARE_WMI_LEGACY 1
#define CONFIG_SND_SOC_SOF_PCI_MODULE 1
#define CONFIG_ISL76682_MODULE 1
#define CONFIG_CRYPTO_GCM_MODULE 1
#define CONFIG_ICE_SWITCHDEV 1
#define CONFIG_CRYPTO_WP512_MODULE 1
#define CONFIG_INTEL_OAKTRAIL_MODULE 1
#define CONFIG_ARCH_USE_BUILTIN_BSWAP 1
#define CONFIG_SND_SOC_MAX98396_MODULE 1
#define CONFIG_X86_REQUIRED_FEATURE_CMOV 1
#define CONFIG_VEML6040_MODULE 1
#define CONFIG_SND_SOC_PCM1789_I2C_MODULE 1
#define CONFIG_SBITMAP 1
#define CONFIG_USB_SERIAL_AIRCABLE_MODULE 1
#define CONFIG_USB_NET_CDCETHER_MODULE 1
#define CONFIG_ATH11K_DEBUG 1
#define CONFIG_NET_NCSI 1
#define CONFIG_LRU_CACHE_MODULE 1
#define CONFIG_CC_HAS_ASSUME 1
#define CONFIG_SND_XEN_FRONTEND_MODULE 1
#define CONFIG_AS_IS_GNU 1
#define CONFIG_BACKLIGHT_APPLE_MODULE 1
#define CONFIG_EARLY_PRINTK_USB_XDBC 1
#define CONFIG_STACKPROTECTOR_STRONG 1
#define CONFIG_RTW88_MODULE 1
#define CONFIG_IR_RC6_DECODER_MODULE 1
#define CONFIG_ENCRYPTED_KEYS_MODULE 1
#define CONFIG_DVB_USB_UMT_010_MODULE 1
#define CONFIG_USB_EZUSB_FX2_MODULE 1
#define CONFIG_IIO_TRIGGER 1
#define CONFIG_USB_XHCI_PCI_RENESAS_MODULE 1
#define CONFIG_MCTP_TRANSPORT_I2C_MODULE 1
#define CONFIG_EXPORTFS_BLOCK_OPS 1
#define CONFIG_EDAC_SBRIDGE_MODULE 1
#define CONFIG_TERANETICS_PHY_MODULE 1
#define CONFIG_V4L2_FWNODE_MODULE 1
#define CONFIG_SENSORS_INA209_MODULE 1
#define CONFIG_INIT_STACK_ALL_ZERO 1
#define CONFIG_SENSORS_DELTA_AHE50DC_FAN_MODULE 1
#define CONFIG_MFD_INTEL_LPSS_ACPI_MODULE 1
#define CONFIG_USB_HCD_BCMA_MODULE 1
#define CONFIG_ACPI_FAN 1
#define CONFIG_SND_SOC_ADAU1373_MODULE 1
#define CONFIG_HID_STEAM_MODULE 1
#define CONFIG_RANDSTRUCT_NONE 1
#define CONFIG_INTEL_SDSI_MODULE 1
#define CONFIG_HTS221_MODULE 1
#define CONFIG_RTC_I2C_AND_SPI 1
#define CONFIG_RADIO_SHARK2_MODULE 1
#define CONFIG_CMA_SIZE_SEL_MBYTES 1
#define CONFIG_INTEL_IOMMU_PERF_EVENTS 1
#define CONFIG_ROMFS_ON_BLOCK 1
#define CONFIG_TMPFS 1
#define CONFIG_FUNCTION_ALIGNMENT_4B 1
#define CONFIG_TINYDRM_MI0283QT_MODULE 1
#define CONFIG_RAVE_SP_WATCHDOG_MODULE 1
#define CONFIG_CHARGER_MP2629_MODULE 1
#define CONFIG_PMBUS_MODULE 1
#define CONFIG_NETFILTER_NETLINK_MODULE 1
#define CONFIG_DM_MIRROR_MODULE 1
#define CONFIG_RTW89_8852BT_MODULE 1
#define CONFIG_FPGA_MGR_LATTICE_SYSCONFIG_SPI_MODULE 1
#define CONFIG_VIDEO_OV02A10_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_IRTOUCH 1
#define CONFIG_INFINIBAND_ISER_MODULE 1
#define CONFIG_DRM_I915_PREEMPT_TIMEOUT_COMPUTE 7500
#define CONFIG_BACKLIGHT_AAT2870_MODULE 1
#define CONFIG_VIDEO_OV02E10_MODULE 1
#define CONFIG_CARL9170_MODULE 1
#define CONFIG_IPV6 1
#define CONFIG_RTC_DRV_FM3130_MODULE 1
#define CONFIG_MCTP_SERIAL_MODULE 1
#define CONFIG_SCSI_DMA 1
#define CONFIG_LIDAR_LITE_V2_MODULE 1
#define CONFIG_SIGNALFD 1
#define CONFIG_SENSORS_INTEL_M10_BMC_HWMON_MODULE 1
#define CONFIG_PCMCIA_XIRC2PS_MODULE 1
#define CONFIG_RTC_DRV_M48T59_MODULE 1
#define CONFIG_DVB_DDBRIDGE_MODULE 1
#define CONFIG_HID_ORTEK_MODULE 1
#define CONFIG_USB_PWC_INPUT_EVDEV 1
#define CONFIG_NET_VENDOR_MUCSE 1
#define CONFIG_MP2629_ADC_MODULE 1
#define CONFIG_ASYNC_RAID6_RECOV_MODULE 1
#define CONFIG_ANON_VMA_NAME 1
#define CONFIG_VIDEO_GC05A2_MODULE 1
#define CONFIG_MLX5_SF_MANAGER 1
#define CONFIG_CPU_FREQ_GOV_PERFORMANCE 1
#define CONFIG_F2FS_FS_LZORLE 1
#define CONFIG_SND_HDA_CODEC_HDMI_NVIDIA_MCP_MODULE 1
#define CONFIG_CHARGER_LT3651_MODULE 1
#define CONFIG_DEBUG_BUGVERBOSE_DETAILED 1
#define CONFIG_SND_SOC_WM8782_MODULE 1
#define CONFIG_USB_G_MULTI_RNDIS 1
#define CONFIG_MFD_88PM860X 1
#define CONFIG_KVM_AMD_MODULE 1
#define CONFIG_HAVE_KVM_PFNCACHE 1
#define CONFIG_MMC_CB710_MODULE 1
#define CONFIG_NFT_TPROXY_MODULE 1
#define CONFIG_DAMON_LRU_SORT 1
#define CONFIG_OVERLAY_FS_REDIRECT_DIR 1
#define CONFIG_MFD_ARIZONA_SPI_MODULE 1
#define CONFIG_INFINIBAND_RTRS_SERVER_MODULE 1
#define CONFIG_SENSORS_WM831X_MODULE 1
#define CONFIG_MFD_TPS65910 1
#define CONFIG_NET_VENDOR_MICREL 1
#define CONFIG_SND_SOC_ACPI_AMD_SDCA_QUIRKS 1
#define CONFIG_TI_ADC0832_MODULE 1
#define CONFIG_XEN_HAVE_PVMMU 1
#define CONFIG_RT2X00_LIB_DEBUGFS 1
#define CONFIG_AD7746_MODULE 1
#define CONFIG_MTD_MAP_BANK_WIDTH_2 1
#define CONFIG_DEFAULT_NET_SCH "fq_codel"
#define CONFIG_GPIO_F7188X_MODULE 1
#define CONFIG_NET_VENDOR_ASIX 1
#define CONFIG_SND_SST_ATOM_HIFI2_PLATFORM_MODULE 1
#define CONFIG_SND_HDA_INTEL_MODULE 1
#define CONFIG_SXGBE_ETH_MODULE 1
#define CONFIG_SND_PORTMAN2X4_MODULE 1
#define CONFIG_DELL_RBTN_MODULE 1
#define CONFIG_PERF_EVENTS_INTEL_UNCORE_MODULE 1
#define CONFIG_SND_SOC_XILINX_AUDIO_FORMATTER_MODULE 1
#define CONFIG_SND_SOC_RT700_MODULE 1
#define CONFIG_KVM_GUEST 1
#define CONFIG_MFD_RT5120_MODULE 1
#define CONFIG_CAN_PEAK_PCMCIA_MODULE 1
#define CONFIG_SND_SOC_TLV320AIC31XX_MODULE 1
#define CONFIG_ATH11K_DEBUGFS 1
#define CONFIG_SCSI_BUSLOGIC_MODULE 1
#define CONFIG_REGULATOR_AS3711_MODULE 1
#define CONFIG_UNWINDER_ORC 1
#define CONFIG_MTD_NAND_ECC_MXIC 1
#define CONFIG_ACPI_HED 1
#define CONFIG_USB_DWC3_MODULE 1
#define CONFIG_HID_GOODIX_SPI_MODULE 1
#define CONFIG_SND_SOC_PEB2466_MODULE 1
#define CONFIG_BRIDGE_EBT_IP6_MODULE 1
#define CONFIG_MFD_UPBOARD_FPGA_MODULE 1
#define CONFIG_HAVE_UID16 1
#define CONFIG_DEVFREQ_GOV_POWERSAVE_MODULE 1
#define CONFIG_DEFXX_MODULE 1
#define CONFIG_ARCH_SUPPORTS_DEBUG_PAGEALLOC 1
#define CONFIG_NFS_V2_MODULE 1
#define CONFIG_VIDEO_AR0521_MODULE 1
#define CONFIG_UHID_MODULE 1
#define CONFIG_LEDS_LM355x_MODULE 1
#define CONFIG_HID_RAZER_MODULE 1
#define CONFIG_NFC_MRVL_UART_MODULE 1
#define CONFIG_SECURITY_NETWORK 1
#define CONFIG_DWC_XLGMAC_MODULE 1
#define CONFIG_CRYPTO_DRBG 1
#define CONFIG_SENSORS_RM3100_I2C_MODULE 1
#define CONFIG_HOTPLUG_SMT 1
#define CONFIG_FB_DEVICE 1
#define CONFIG_X86_REQUIRED_FEATURE_FXSR 1
#define CONFIG_IPE_PROP_DM_VERITY 1
#define CONFIG_NET_IPIP_MODULE 1
#define CONFIG_WDTPCI_MODULE 1
#define CONFIG_MTK_NET_PHYLIB_MODULE 1
#define CONFIG_AIO 1
#define CONFIG_HID_SPEEDLINK_MODULE 1
#define CONFIG_DRM_AMDGPU_USERPTR 1
#define CONFIG_RMNET_MODULE 1
#define CONFIG_NET_SCH_DUALPI2_MODULE 1
#define CONFIG_HP03_MODULE 1
#define CONFIG_DRM_AMDGPU_SI 1
#define CONFIG_RADIO_TEF6862_MODULE 1
#define CONFIG_PERF_GUEST_MEDIATED_PMU 1
#define CONFIG_RTC_DRV_PALMAS_MODULE 1
#define CONFIG_EXTCON_USBC_CROS_EC_MODULE 1
#define CONFIG_INV_MPU6050_IIO_MODULE 1
#define CONFIG_GENERIC_IRQ_SHOW 1
#define CONFIG_SENSORS_INSPUR_IPSPS_MODULE 1
#define CONFIG_DRM_AMD_ISP 1
#define CONFIG_PATA_EFAR_MODULE 1
#define CONFIG_SCSI_DH_RDAC_MODULE 1
#define CONFIG_JFFS2_FS_SECURITY 1
#define CONFIG_BLOCK_LEGACY_AUTOLOAD 1
#define CONFIG_GPIB_INES_MODULE 1
#define CONFIG_VIDEO_GC2145_MODULE 1
#define CONFIG_HP_WATCHDOG_MODULE 1
#define CONFIG_PCI_SW_SWITCHTEC_MODULE 1
#define CONFIG_UIO_NETX_MODULE 1
#define CONFIG_NET_SCH_SKBPRIO_MODULE 1
#define CONFIG_CRYPTO_ARIA_AESNI_AVX2_X86_64_MODULE 1
#define CONFIG_DWMAC_GENERIC_MODULE 1
#define CONFIG_SECURITY_TOMOYO_MAX_ACCEPT_ENTRY 2048
#define CONFIG_MPU3050_I2C_MODULE 1
#define CONFIG_VIDEO_TDA7432_MODULE 1
#define CONFIG_MAX22007_MODULE 1
#define CONFIG_XILINX_WATCHDOG_MODULE 1
#define CONFIG_NETFS_SUPPORT_MODULE 1
#define CONFIG_ACPI_HOTPLUG_MEMORY 1
#define CONFIG_CAN_KVASER_USB_MODULE 1
#define CONFIG_MTD_RAW_NAND_MODULE 1
#define CONFIG_TI_ADC128S052_MODULE 1
#define CONFIG_HID_WINWING_MODULE 1
#define CONFIG_INTEL_SCU_PLATFORM_MODULE 1
#define CONFIG_GPIO_DWAPB_MODULE 1
#define CONFIG_PCI_PWRCTRL_MODULE 1
#define CONFIG_RPCSEC_GSS_KRB5_MODULE 1
#define CONFIG_AD3530R_MODULE 1
#define CONFIG_INPUT_POWERMATE_MODULE 1
#define CONFIG_DP83848_PHY_MODULE 1
#define CONFIG_WDAT_WDT_MODULE 1
#define CONFIG_GPIO_QIXIS_FPGA_MODULE 1
#define CONFIG_VIDEO_CX25821_ALSA_MODULE 1
#define CONFIG_PCI_PASID 1
#define CONFIG_NET_DSA_MICROCHIP_KSZ_PTP 1
#define CONFIG_WL1251_SDIO_MODULE 1
#define CONFIG_WIL6210_TRACING 1
#define CONFIG_BACKLIGHT_ADP8860_MODULE 1
#define CONFIG_F2FS_FS_MODULE 1
#define CONFIG_SND_DMA_SGBUF 1
#define CONFIG_IP_VS_MH_TAB_INDEX 12
#define CONFIG_CRYPTO_KPP 1
#define CONFIG_GENERIC_STRNLEN_USER 1
#define CONFIG_NET_FOU_MODULE 1
#define CONFIG_CHROMEOS_PSTORE_MODULE 1
#define CONFIG_SND_SOC_SDCA_CLASS_FUNCTION_MODULE 1
#define CONFIG_VIDEO_DW9714_MODULE 1
#define CONFIG_ADIN1100_PHY_MODULE 1
#define CONFIG_GOOGLE_MEMCONSOLE_MODULE 1
#define CONFIG_SND_LAYLA20_MODULE 1
#define CONFIG_BLK_SED_OPAL 1
#define CONFIG_PGTABLE_LEVELS 5
#define CONFIG_QFMT_V2_MODULE 1
#define CONFIG_CRYPTO_ECB 1
#define CONFIG_DRM_AST_MODULE 1
#define CONFIG_THINKPAD_ACPI_MODULE 1
#define CONFIG_NET_VENDOR_MICROSOFT 1
#define CONFIG_SND_SOC_SDCA_CLASS_MODULE 1
#define CONFIG_IDLE_PAGE_TRACKING 1
#define CONFIG_DRM_I915_DP_TUNNEL 1
#define CONFIG_B44_MODULE 1
#define CONFIG_BT_BNEP_MODULE 1
#define CONFIG_KEYBOARD_XTKBD_MODULE 1
#define CONFIG_SECURITY_LOADPIN 1
#define CONFIG_MFD_QNAP_MCU_MODULE 1
#define CONFIG_REGMAP 1
#define CONFIG_SLAB_OBJ_EXT 1
#define CONFIG_BT_HCIBPA10X_MODULE 1
#define CONFIG_SENSORS_MAX1619_MODULE 1
#define CONFIG_PCI_ATS 1
#define CONFIG_SCSI_SYM53C8XX_MAX_TAGS 64
#define CONFIG_NET_VENDOR_8390 1
#define CONFIG_LEDS_SPI_BYTE_MODULE 1
#define CONFIG_NLS_MAC_ROMANIAN_MODULE 1
#define CONFIG_USB_NET_GL620A_MODULE 1
#define CONFIG_DVB_ZL10039_MODULE 1
#define CONFIG_LED_TRIGGER_PHY 1
#define CONFIG_HAVE_KVM_ARCH_GMEM_PREPARE 1
#define CONFIG_DRM_FBDEV_EMULATION 1
#define CONFIG_DRM_ANALOGIX_DP_MODULE 1
#define CONFIG_USER_NS 1
#define CONFIG_RT73USB_MODULE 1
#define CONFIG_NFSD_V4_2_INTER_SSC 1
#define CONFIG_TOUCHSCREEN_CY8CTMA140_MODULE 1
#define CONFIG_XEN_GRANT_DMA_ALLOC 1
#define CONFIG_HWMON_VID_MODULE 1
#define CONFIG_MWL8K_MODULE 1
#define CONFIG_RTW89_MODULE 1
#define CONFIG_MITIGATION_SPECTRE_BHI 1
#define CONFIG_MODULE_DEBUGFS 1
#define CONFIG_MITIGATION_SLS 1
#define CONFIG_X86_BOOTPARAM_MEMORY_CORRUPTION_CHECK 1
#define CONFIG_LEDS_LM3601X_MODULE 1
#define CONFIG_SECURITY_YAMA 1
#define CONFIG_VIDEO_SONY_BTF_MPX_MODULE 1
#define CONFIG_USB_GOKU_MODULE 1
#define CONFIG_RTW88_8822BE_MODULE 1
#define CONFIG_ARCH_HAS_ADD_PAGES 1
#define CONFIG_SND_SOC_ADAU1372_MODULE 1
#define CONFIG_DRM_PANIC_SCREEN "qr_code"
#define CONFIG_ACPI_AC 1
#define CONFIG_USB_SERIAL_OPTION_MODULE 1
#define CONFIG_SCD30_SERIAL_MODULE 1
#define CONFIG_IEEE802154_ATUSB_MODULE 1
#define CONFIG_NVME_AUTH_MODULE 1
#define CONFIG_CRYPTO_DEV_QAT_C62XVF_MODULE 1
#define CONFIG_EROFS_FS_POSIX_ACL 1
#define CONFIG_SND_AU8810_MODULE 1
#define CONFIG_ARCH_HAS_MEMBARRIER_SYNC_CORE 1
#define CONFIG_RTASE_MODULE 1
#define CONFIG_SND_SOC_RT5616_MODULE 1
#define CONFIG_USB_RTL8152_MODULE 1
#define CONFIG_KVM_ELIDE_TLB_FLUSH_IF_YOUNG 1
#define CONFIG_PREFIX_SYMBOLS 1
#define CONFIG_AD799X_MODULE 1
#define CONFIG_TOUCHSCREEN_ADC_MODULE 1
#define CONFIG_VIDEO_OV8856_MODULE 1
#define CONFIG_GAMEPORT_FM801_MODULE 1
#define CONFIG_I2C_CP2615_MODULE 1
#define CONFIG_W1_SLAVE_DS28E04_MODULE 1
#define CONFIG_MMC_MTK_MODULE 1
#define CONFIG_REGULATOR_MAX8660_MODULE 1
#define CONFIG_HAVE_C_RECORDMCOUNT 1
#define CONFIG_MAX44000_MODULE 1
#define CONFIG_NET_VENDOR_VIA 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_RT5663_MODULE 1
#define CONFIG_NF_TABLES_IPV4 1
#define CONFIG_MAC80211_STA_HASH_MAX_SIZE 0
#define CONFIG_DEBUG_WX 1
#define CONFIG_TICK_ONESHOT 1
#define CONFIG_INET_ESP_MODULE 1
#define CONFIG_USB_SERIAL_SAFE_MODULE 1
#define CONFIG_NFC_NXP_NCI_I2C_MODULE 1
#define CONFIG_INFINIBAND_MODULE 1
#define CONFIG_AK09911_MODULE 1
#define CONFIG_VIDEO_TW9903_MODULE 1
#define CONFIG_ARCH_WANT_HUGE_PMD_SHARE 1
#define CONFIG_MFD_MC13XXX_SPI_MODULE 1
#define CONFIG_RSI_USB_MODULE 1
#define CONFIG_RSI_COEX 1
#define CONFIG_DRM 1
#define CONFIG_HAVE_KERNEL_LZMA 1
#define CONFIG_BCMA_POSSIBLE 1
#define CONFIG_NF_REJECT_IPV6_MODULE 1
#define CONFIG_X86_DISABLED_FEATURE_CYRIX_ARR 1
#define CONFIG_VIDEO_OV8865_MODULE 1
#define CONFIG_NTB_AMD_MODULE 1
#define CONFIG_NFC_MODULE 1
#define CONFIG_NFSD_V4_SECURITY_LABEL 1
#define CONFIG_MLXSW_MINIMAL_MODULE 1
#define CONFIG_PWM_LPSS_MODULE 1
#define CONFIG_STMMAC_LIBPCI_MODULE 1
#define CONFIG_LENOVO_WMI_TUNING_MODULE 1
#define CONFIG_HUGETLB_PAGE_OPTIMIZE_VMEMMAP 1
#define CONFIG_MFD_TPS6594_MODULE 1
#define CONFIG_CRYPTO_LIB_CHACHA_ARCH 1
#define CONFIG_MT76_USB_MODULE 1
#define CONFIG_TCG_TPM 1
#define CONFIG_SILICOM_PLATFORM_MODULE 1
#define CONFIG_USB_ISIGHTFW_MODULE 1
#define CONFIG_SND_SOC_AMD_ACP_I2S_MODULE 1
#define CONFIG_PCIE_DW_PLAT 1
#define CONFIG_CRYPTO_DEV_PADLOCK_AES_MODULE 1
#define CONFIG_NET_DSA_TAG_DSA_COMMON_MODULE 1
#define CONFIG_BMI270_MODULE 1
#define CONFIG_AD5380_MODULE 1
#define CONFIG_STMMAC_ETH_MODULE 1
#define CONFIG_USB_YUREX_MODULE 1
#define CONFIG_USB_IPHETH_MODULE 1
#define CONFIG_USB_GSPCA_PAC7302_MODULE 1
#define CONFIG_NET_VENDOR_VERTEXCOM 1
#define CONFIG_LCD_LTV350QV_MODULE 1
#define CONFIG_IIO_TIGHTLOOP_TRIGGER_MODULE 1
#define CONFIG_BLK_DEV_MD_MODULE 1
#define CONFIG_NET_DSA_TAG_QCA_MODULE 1
#define CONFIG_MEMSTICK_R592_MODULE 1
#define CONFIG_VFIO_PCI_MODULE 1
#define CONFIG_TEHUTI_MODULE 1
#define CONFIG_SND_PCM_IEC958 1
#define CONFIG_TOUCHSCREEN_TSC_SERIO_MODULE 1
#define CONFIG_PINCTRL_EMMITSBURG_MODULE 1
#define CONFIG_CPUMASK_OFFSTACK 1
#define CONFIG_SENSORS_ADM1177_MODULE 1
#define CONFIG_JFS_STATISTICS 1
#define CONFIG_USB_CONFIGFS_F_UAC2 1
#define CONFIG_I2C_ALGOPCA_MODULE 1
#define CONFIG_IPW2200_PROMISCUOUS 1
#define CONFIG_BATTERY_BQ27XXX_I2C_MODULE 1
#define CONFIG_ISCSI_TCP_MODULE 1
#define CONFIG_X86_DISABLED_FEATURE_LAM 1
#define CONFIG_MCP4725_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_TRACE_MODULE 1
#define CONFIG_USB_SERIAL_GENERIC 1
#define CONFIG_DMIID 1
#define CONFIG_NFC_DIGITAL_MODULE 1
#define CONFIG_MLX5_SF 1
#define CONFIG_DM9051_MODULE 1
#define CONFIG_COMMON_CLK_TPS68470_MODULE 1
#define CONFIG_BRIDGE_EBT_NFLOG_MODULE 1
#define CONFIG_INFINIBAND_MTHCA_MODULE 1
#define CONFIG_HID_SIGMAMICRO_MODULE 1
#define CONFIG_NF_DUP_IPV4_MODULE 1
#define CONFIG_IR_IMON_RAW_MODULE 1
#define CONFIG_SURFACE_3_POWER_OPREGION_MODULE 1
#define CONFIG_SND_SOC_PCM3168A_I2C_MODULE 1
#define CONFIG_SCSI_AACRAID_MODULE 1
#define CONFIG_REGULATOR_MC13783_MODULE 1
#define CONFIG_CAN_IFI_CANFD_MODULE 1
#define CONFIG_BRIDGE_EBT_SNAT_MODULE 1
#define CONFIG_USB_GPIO_VBUS_MODULE 1
#define CONFIG_RELAY 1
#define CONFIG_HAVE_KPROBES_ON_FTRACE 1
#define CONFIG_CPUSETS 1
#define CONFIG_DRM_NOUVEAU_MODULE 1
#define CONFIG_VF610_ADC_MODULE 1
#define CONFIG_AD4130_MODULE 1
#define CONFIG_USB_KC2190 1
#define CONFIG_SND_HDA_CODEC_VIA_MODULE 1
#define CONFIG_I2C_ISCH_MODULE 1
#define CONFIG_NFP_APP_ABM_NIC 1
#define CONFIG_CPU_FREQ_STAT 1
#define CONFIG_LOOPBACK_TARGET_MODULE 1
#define CONFIG_SCSI_MVSAS_MODULE 1
#define CONFIG_AL3000A_MODULE 1
#define CONFIG_MLX5_INFINIBAND_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_CLASSIFY_MODULE 1
#define CONFIG_LXT_PHY_MODULE 1
#define CONFIG_NET_VENDOR_DAVICOM 1
#define CONFIG_SENSORS_LM3533_MODULE 1
#define CONFIG_NVME_TARGET_AUTH 1
#define CONFIG_INTEL_VSC_MODULE 1
#define CONFIG_NFS_V3_ACL 1
#define CONFIG_DVB_SMIPCIE_MODULE 1
#define CONFIG_MTD_NAND_ECC_SW_HAMMING_SMC 1
#define CONFIG_X86_USER_SHADOW_STACK 1
#define CONFIG_TOUCHSCREEN_WM9712 1
#define CONFIG_CRC_T10DIF 1
#define CONFIG_GPIO_SIOX_MODULE 1
#define CONFIG_ATA_BMDMA 1
#define CONFIG_USB_TMC_MODULE 1
#define CONFIG_PPPOE_HASH_BITS_4 1
#define CONFIG_BCMA_HOST_PCI 1
#define CONFIG_QCA83XX_PHY_MODULE 1
#define CONFIG_SECURITY_LANDLOCK 1
#define CONFIG_NET_DSA_TAG_DSA_MODULE 1
#define CONFIG_REGULATOR_MT6370_MODULE 1
#define CONFIG_X509_CERTIFICATE_PARSER 1
#define CONFIG_EDAC_I5100_MODULE 1
#define CONFIG_REGULATOR_DA903X_MODULE 1
#define CONFIG_MAC80211_RC_DEFAULT "minstrel_ht"
#define CONFIG_MCP41010_MODULE 1
#define CONFIG_HID_CYPRESS_MODULE 1
#define CONFIG_MLX4_INFINIBAND_MODULE 1
#define CONFIG_RICHTEK_RTQ6056_MODULE 1
#define CONFIG_BT_HCIDTL1_MODULE 1
#define CONFIG_ATH9K_HWRNG 1
#define CONFIG_DP83822_PHY_MODULE 1
#define CONFIG_SKGE_GENESIS 1
#define CONFIG_EVENTFD 1
#define CONFIG_SND_SOC_WM8903_MODULE 1
#define CONFIG_NFC_NCI_SPI_MODULE 1
#define CONFIG_GENERIC_CPU_VULNERABILITIES 1
#define CONFIG_REGULATOR_DA9210_MODULE 1
#define CONFIG_KEYBOARD_QT2160_MODULE 1
#define CONFIG_X86_PCC_CPUFREQ_MODULE 1
#define CONFIG_BACKLIGHT_LM3630A_MODULE 1
#define CONFIG_SENSORS_MAX31730_MODULE 1
#define CONFIG_KEYBOARD_STOWAWAY_MODULE 1
#define CONFIG_TCG_SVSM_MODULE 1
#define CONFIG_FXAS21002C_MODULE 1
#define CONFIG_SYSTEM_BLACKLIST_KEYRING 1
#define CONFIG_SMI330_MODULE 1
#define CONFIG_I2C_MUX_GPIO_MODULE 1
#define CONFIG_SENSORS_GPD_MODULE 1
#define CONFIG_NFSD_V4 1
#define CONFIG_NUMA 1
#define CONFIG_VIDEO_HEXIUM_GEMINI_MODULE 1
#define CONFIG_SND_SOC_I2C_AND_SPI_MODULE 1
#define CONFIG_HID_VIVALDI_COMMON_MODULE 1
#define CONFIG_CHARGER_MT6360_MODULE 1
#define CONFIG_NET_SHAPER 1
#define CONFIG_SND_SOC_PCM1754_MODULE 1
#define CONFIG_INTEL_RAPL_TPMI_MODULE 1
#define CONFIG_XEN_SCSI_BACKEND_MODULE 1
#define CONFIG_ZLIB_DEFLATE 1
#define CONFIG_ADT7316_I2C_MODULE 1
#define CONFIG_BNXT_HWMON 1
#define CONFIG_CHARGER_WILCO_MODULE 1
#define CONFIG_USB_NET_DM9601_MODULE 1
#define CONFIG_SCSI_ARCMSR_MODULE 1
#define CONFIG_LEDS_INTEL_SS4200_MODULE 1
#define CONFIG_WLCORE_MODULE 1
#define CONFIG_IP_NF_NAT_MODULE 1
#define CONFIG_B43_PHY_HT 1
#define CONFIG_ICE_HWTS 1
#define CONFIG_PNP 1
#define CONFIG_SATA_AHCI 1
#define CONFIG_REGULATOR_MC13XXX_CORE_MODULE 1
#define CONFIG_LENOVO_WMI_CAMERA_MODULE 1
#define CONFIG_HID_SONY_MODULE 1
#define CONFIG_CRYPTO_PCRYPT_MODULE 1
#define CONFIG_MITIGATION_L1TF 1
#define CONFIG_NET_VENDOR_CHELSIO 1
#define CONFIG_SND_HDA_CODEC_CMEDIA_MODULE 1
#define CONFIG_PHANTOM_MODULE 1
#define CONFIG_TQMX86_WDT_MODULE 1
#define CONFIG_NF_DEFRAG_IPV6_MODULE 1
#define CONFIG_SENSORS_ADP1050_MODULE 1
#define CONFIG_ACPI_DPTF 1
#define CONFIG_PCI_NPEM 1
#define CONFIG_PATA_PARPORT_BPCK_MODULE 1
#define CONFIG_SND_SOC_ADAU17X1_MODULE 1
#define CONFIG_SND_SOC_SSM2518_MODULE 1
#define CONFIG_NTB_INTEL_MODULE 1
#define CONFIG_SERIAL_SC16IS7XX_SPI_MODULE 1
#define CONFIG_SND_SOC_MAX98390_MODULE 1
#define CONFIG_MITIGATION_SSB 1
#define CONFIG_TOUCHSCREEN_BU21029_MODULE 1
#define CONFIG_SECURITY_SAFESETID 1
#define CONFIG_ZSMALLOC 1
#define CONFIG_CRYPTO_RNG 1
#define CONFIG_SND_SOC_SOF_ALDERLAKE_MODULE 1
#define CONFIG_MFD_WM8400 1
#define CONFIG_HID_SENSOR_ALS_MODULE 1
#define CONFIG_TCP_CONG_DCTCP_MODULE 1
#define CONFIG_CHARGER_88PM860X_MODULE 1
#define CONFIG_NLMON_MODULE 1
#define CONFIG_SND_SOC_TAS2783_SDW_MODULE 1
#define CONFIG_FILE_LOCKING 1
#define CONFIG_EDAC_IMH_MODULE 1
#define CONFIG_LEDS_88PM860X_MODULE 1
#define CONFIG_TCG_TIS_ST33ZP24_SPI_MODULE 1
#define CONFIG_USB_U_AUDIO_MODULE 1
#define CONFIG_NOUVEAU_DEBUG 5
#define CONFIG_MAG3110_MODULE 1
#define CONFIG_PATA_IT8213_MODULE 1
#define CONFIG_SND_SOC_TFA989X_MODULE 1
#define CONFIG_I2C_AMD756_MODULE 1
#define CONFIG_SND_SOC_INTEL_SOF_BOARD_HELPERS_MODULE 1
#define CONFIG_PATA_SIS_MODULE 1
#define CONFIG_RTC_DRV_ABEOZ9_MODULE 1
#define CONFIG_CRYPTO_HMAC 1
#define CONFIG_TEE_MODULE 1
#define CONFIG_ADXL355_I2C_MODULE 1
#define CONFIG_DMA_VIRTUAL_CHANNELS 1
#define CONFIG_DRM_PANEL_ILITEK_ILI9341_MODULE 1
#define CONFIG_REGULATOR_ATC260X_MODULE 1
#define CONFIG_SCSI_INITIO_MODULE 1
#define CONFIG_REGULATOR_FIXED_VOLTAGE_MODULE 1
#define CONFIG_GP_PCI1XXXX_MODULE 1
#define CONFIG_GPIO_VIRTIO_MODULE 1
#define CONFIG_PGTABLE_HAS_HUGE_LEAVES 1
#define CONFIG_TI_DAC082S085_MODULE 1
#define CONFIG_FS_ENCRYPTION_ALGS 1
#define CONFIG_TOUCHSCREEN_CYTTSP5_MODULE 1
#define CONFIG_AD7766_MODULE 1
#define CONFIG_CRYPTO_USER_API_SKCIPHER_MODULE 1
#define CONFIG_SND_SOC_TLV320AIC32X4_SPI_MODULE 1
#define CONFIG_CRYPTO_FCRYPT_MODULE 1
#define CONFIG_RTC_INTF_DEV_UIE_EMUL 1
#define CONFIG_CROS_EC_SENSORHUB_MODULE 1
#define CONFIG_SND_SOC_ACPI_INTEL_MATCH_MODULE 1
#define CONFIG_IEEE802154_CC2520_MODULE 1
#define CONFIG_CRYPTO_AES 1
#define CONFIG_SND_HDA_PREALLOC_SIZE 0
#define CONFIG_MFD_ARIZONA_I2C_MODULE 1
#define CONFIG_USB_XUSBATM_MODULE 1
#define CONFIG_PAGE_SIZE_4KB 1
#define CONFIG_CAN_EMS_PCI_MODULE 1
#define CONFIG_GPIO_SCH_MODULE 1
#define CONFIG_I2C_CHARDEV_MODULE 1
#define CONFIG_BCM_NET_PHYPTP_MODULE 1
#define CONFIG_SENSORS_MAX31760_MODULE 1
#define CONFIG_STM_PROTO_BASIC_MODULE 1
#define CONFIG_VIDEO_VIM2M_MODULE 1
#define CONFIG_AF_UNIX_OOB 1
#define CONFIG_QCOM_NET_PHYLIB_MODULE 1
#define CONFIG_REGULATOR_LP3971_MODULE 1
#define CONFIG_SERIAL_RP2_NR_UARTS 32
#define CONFIG_MMC_SPI_MODULE 1
#define CONFIG_INPUT_JOYDEV_MODULE 1
#define CONFIG_ENCX24J600_MODULE 1
#define CONFIG_DVB_MN88472_MODULE 1
#define CONFIG_PCIE_DW_DEBUGFS 1
#define CONFIG_CRYPTO_DEV_CCP_DD_MODULE 1
#define CONFIG_DMI 1
#define CONFIG_HAVE_DYNAMIC_FTRACE 1
#define CONFIG_SECURITY_APPARMOR_EXPORT_BINARY 1
#define CONFIG_AFS_FS_MODULE 1
#define CONFIG_BT_VIRTIO_MODULE 1
#define CONFIG_ARCH_SUPPORTS_CRASH_DUMP 1
#define CONFIG_VIRTIO_CONSOLE 1
#define CONFIG_DRM_I915_PREEMPT_TIMEOUT 640
#define CONFIG_MDIO_I2C_MODULE 1
#define CONFIG_PATA_ATP867X_MODULE 1
#define CONFIG_CC_HAS_SLS 1
#define CONFIG_VIDEO_OV13858_MODULE 1
#define CONFIG_IPW2200_MODULE 1
#define CONFIG_SMC_MODULE 1
#define CONFIG_ITG3200_MODULE 1
#define CONFIG_IDPF_MODULE 1
#define CONFIG_RPMSG_WWAN_CTRL_MODULE 1
#define CONFIG_DVB_OR51211_MODULE 1
#define CONFIG_RTC_DRV_MAX6916_MODULE 1
#define CONFIG_CHARGER_BQ2415X_MODULE 1
#define CONFIG_NET_VENDOR_SUN 1
#define CONFIG_SENSORS_MAX127_MODULE 1
#define CONFIG_STK8312_MODULE 1
#define CONFIG_NET_IFE_SKBTCINDEX_MODULE 1
#define CONFIG_USB_SERIAL_UPD78F0730_MODULE 1
#define CONFIG_HID_ROCCAT_MODULE 1
#define CONFIG_MAX34408_MODULE 1
#define CONFIG_CRYPTO_TWOFISH_X86_64_MODULE 1
#define CONFIG_ATH10K_DEBUGFS 1
#define CONFIG_BOOTPARAM_SOFTLOCKUP_PANIC 0
#define CONFIG_TCM_PSCSI_MODULE 1
#define CONFIG_HID_KYSONA_MODULE 1
#define CONFIG_PATA_PARPORT_EPIA_MODULE 1
#define CONFIG_IP6_NF_TARGET_SYNPROXY_MODULE 1
#define CONFIG_VIDEO_OV5647_MODULE 1
#define CONFIG_NET_SCH_HFSC_MODULE 1
#define CONFIG_PD6729_MODULE 1
#define CONFIG_SENSORS_DRIVETEMP_MODULE 1
#define CONFIG_IDEAPAD_LAPTOP_MODULE 1
#define CONFIG_GENERIC_MSI_IRQ 1
#define CONFIG_FB_SYS_COPYAREA 1
#define CONFIG_POWER_SUPPLY 1
#define CONFIG_HAVE_MOD_ARCH_SPECIFIC 1
#define CONFIG_ROCKER_MODULE 1
#define CONFIG_CROS_TYPEC_SWITCH_MODULE 1
#define CONFIG_FPGA_DFL_EMIF_MODULE 1
#define CONFIG_WLAN_VENDOR_ATMEL 1
#define CONFIG_DEVTMPFS 1
#define CONFIG_HAVE_DYNAMIC_FTRACE_WITH_JMP 1
#define CONFIG_SURFACE_PLATFORMS 1
#define CONFIG_HAVE_DEBUG_KMEMLEAK 1
#define CONFIG_NET_VENDOR_CORTINA 1
#define CONFIG_BLK_DEV_BSG 1
#define CONFIG_MEDIA_PCI_SUPPORT 1
#define CONFIG_PCMCIA_QLOGIC_MODULE 1
#define CONFIG_AT803X_PHY_MODULE 1
#define CONFIG_MACVTAP_MODULE 1
#define CONFIG_IPE_PROP_FS_VERITY 1
#define CONFIG_IPV6_FOU_MODULE 1
#define CONFIG_DRM_DISPLAY_HDMI_HELPER 1
#define CONFIG_NETFILTER_XT_MATCH_PHYSDEV_MODULE 1
#define CONFIG_USB_ANNOUNCE_NEW_DEVICES 1
#define CONFIG_USB_NET_QMI_WWAN_MODULE 1
#define CONFIG_RT2800PCI_RT53XX 1
#define CONFIG_SND_SOC_TSCS454_MODULE 1
#define CONFIG_SND_SOC_SOF_HDA_PROBES_MODULE 1
#define CONFIG_USB_USBNET_MODULE 1
#define CONFIG_INPUT_EVDEV 1
#define CONFIG_IPV6_ROUTE_INFO 1
#define CONFIG_TI_ADS1015_MODULE 1
#define CONFIG_HZ_1000 1
#define CONFIG_MOST_VIDEO_MODULE 1
#define CONFIG_HUGETLBFS 1
#define CONFIG_SCTP_DEFAULT_COOKIE_HMAC_SHA256 1
#define CONFIG_INTEGRITY_PLATFORM_KEYRING 1
#define CONFIG_EDAC_I7300_MODULE 1
#define CONFIG_CIFS_XATTR 1
#define CONFIG_MHI_BUS_MODULE 1
#define CONFIG_MLX5_CORE_EN_DCB 1
#define CONFIG_ZRAM_BACKEND_842 1
#define CONFIG_SENSORS_NPCM7XX_MODULE 1
#define CONFIG_TOUCHSCREEN_WM9713 1
#define CONFIG_PATA_SERVERWORKS_MODULE 1
#define CONFIG_FAT_DEFAULT_UTF8 1
#define CONFIG_SND_SOC_TS3A227E_MODULE 1
#define CONFIG_USB_NET_RNDIS_HOST_MODULE 1
#define CONFIG_TCG_TIS_ST33ZP24_MODULE 1
#define CONFIG_SSB_PCMCIAHOST 1
#define CONFIG_NETWORK_FILESYSTEMS 1
#define CONFIG_PATA_SIL680_MODULE 1
#define CONFIG_MISC_RTSX_PCI_MODULE 1
#define CONFIG_XFS_QUOTA 1
#define CONFIG_REGULATOR_SKY81452_MODULE 1
#define CONFIG_TELCLOCK_MODULE 1
#define CONFIG_AMD_3D_VCACHE 1
#define CONFIG_INTEL_IDXD_SVM 1
#define CONFIG_RTW88_8814AE_MODULE 1
#define CONFIG_CRYPTO_DEV_SP_PSP 1
#define CONFIG_SND_OXFW_MODULE 1
#define CONFIG_COMPACT_UNEVICTABLE_DEFAULT 0
#define CONFIG_NFC_ST_NCI_SPI_MODULE 1
#define CONFIG_ARCH_HAS_DEBUG_WX 1
#define CONFIG_VIDEO_HI556_MODULE 1
#define CONFIG_NET_EGRESS 1
#define CONFIG_SND_USB_CAIAQ_MODULE 1
#define CONFIG_MLX5_SW_STEERING 1
#define CONFIG_W1_MASTER_DS2490_MODULE 1
#define CONFIG_USB_XHCI_PLATFORM_MODULE 1
#define CONFIG_SND_SOC_TLV320AIC32X4_I2C_MODULE 1
#define CONFIG_CROSS_MEMORY_ATTACH 1
#define CONFIG_LD_ORPHAN_WARN 1
#define CONFIG_EROFS_FS_BACKED_BY_FILE 1
#define CONFIG_USB_SERIAL_CH341_MODULE 1
#define CONFIG_NVMEM_QNAP_MCU_EEPROM_MODULE 1
#define CONFIG_YENTA_TI 1
#define CONFIG_REGULATOR_DA9211_MODULE 1
#define CONFIG_INET_TCP_DIAG_MODULE 1
#define CONFIG_DRM_EXEC_MODULE 1
#define CONFIG_KEYBOARD_ATKBD 1
#define CONFIG_SENSORS_ASC7621_MODULE 1
#define CONFIG_MXC6255_MODULE 1
#define CONFIG_TMP006_MODULE 1
#define CONFIG_HID_NTRIG_MODULE 1
#define CONFIG_ARCH_WANT_LD_ORPHAN_WARN 1
#define CONFIG_EROFS_FS_MODULE 1
#define CONFIG_VIDEO_SAA7164_MODULE 1
#define CONFIG_RTC_DRV_STK17TA8_MODULE 1
#define CONFIG_SENSORS_QNAP_MCU_HWMON_MODULE 1
#define CONFIG_USB_NET_CDC_SUBSET_ENABLE_MODULE 1
#define CONFIG_NF_CONNTRACK_TFTP_MODULE 1
#define CONFIG_AD7606_MODULE 1
#define CONFIG_MFD_INTEL_QUARK_I2C_GPIO_MODULE 1
#define CONFIG_VIDEO_T4KA3_MODULE 1
#define CONFIG_XEN_PRIVCMD_MODULE 1
#define CONFIG_SND_SOC_TLV320AIC23_SPI_MODULE 1
#define CONFIG_PARAVIRT_TIME_ACCOUNTING 1
#define CONFIG_I2C_NVIDIA_GPU_MODULE 1
#define CONFIG_OBJAGG_MODULE 1
#define CONFIG_SND_GINA20_MODULE 1
#define CONFIG_DVB_BUDGET_CORE_MODULE 1
#define CONFIG_BLK_DEV_INTEGRITY 1
#define CONFIG_EDAC_I5400_MODULE 1
#define CONFIG_USB_CDNS3_GADGET 1
#define CONFIG_USB_G_HID_MODULE 1
#define CONFIG_PPPOL2TP_MODULE 1
#define CONFIG_ACPI_DEBUG 1
#define CONFIG_IOMMU_SVA 1
#define CONFIG_BACKLIGHT_ARCXCNN_MODULE 1
#define CONFIG_SENSORS_DPS920AB_MODULE 1
#define CONFIG_EXTCON_LC824206XA_MODULE 1
#define CONFIG_SENSORS_IR38064_REGULATOR 1
#define CONFIG_X86_MCE_INJECT_MODULE 1
#define CONFIG_VIDEO 1
#define CONFIG_VIDEO_MT9M114_MODULE 1
#define CONFIG_VIDEO_GC0310_MODULE 1
#define CONFIG_SND_SOC_CS42L73_MODULE 1
#define CONFIG_THERMAL_GOV_BANG_BANG 1
#define CONFIG_VGA_CONSOLE 1
#define CONFIG_ALIM7101_WDT_MODULE 1
#define CONFIG_PSTORE_ZONE_MODULE 1
#define CONFIG_RADIO_SAA7706H_MODULE 1
#define CONFIG_XEN_PRIVCMD_EVENTFD 1
#define CONFIG_MFD_SI476X_CORE_MODULE 1
#define CONFIG_NET_ACT_CONNMARK_MODULE 1
#define CONFIG_GENERIC_EARLY_IOREMAP 1
#define CONFIG_SND_SOC_MAX98363_MODULE 1
#define CONFIG_USB_SL811_CS_MODULE 1
#define CONFIG_TOUCHSCREEN_TSC2005_MODULE 1
#define CONFIG_SND_SOC_PCM5102A_MODULE 1
#define CONFIG_RTL8821AE_MODULE 1
#define CONFIG_SND_SOC_ADAU7118_MODULE 1
#define CONFIG_BINDGEN_VERSION_TEXT "bindgen 0.72.1"
#define CONFIG_BT_RFCOMM_MODULE 1
#define CONFIG_USB_ROLES_INTEL_XHCI_MODULE 1
#define CONFIG_XFRM_ESP_MODULE 1
#define CONFIG_MITIGATION_MDS 1
#define CONFIG_XEN_NETDEV_BACKEND_MODULE 1
#define CONFIG_CACHEFILES_ONDEMAND 1
#define CONFIG_MAXSMP 1
#define CONFIG_PATA_OPTIDMA_MODULE 1
#define CONFIG_REGULATOR_BCM590XX_MODULE 1
#define CONFIG_USB_CDC_COMPOSITE_MODULE 1
#define CONFIG_USB_EXTRON_DA_HD_4K_PLUS_CEC_MODULE 1
#define CONFIG_SND_SOC_CS42L42_SDW_MODULE 1
#define CONFIG_AMD_XGBE_DCB 1
#define CONFIG_BACKLIGHT_CGBC_MODULE 1
#define CONFIG_DASHARO_ACPI_MODULE 1
#define CONFIG_KEYBOARD_TM2_TOUCHKEY_MODULE 1
#define CONFIG_ARCH_SUPPORTS_PAGE_TABLE_CHECK 1
#define CONFIG_TRACE_SYSCALL_BUF_SIZE_DEFAULT 63
#define CONFIG_RTL8188EE_MODULE 1
#define CONFIG_CXL_SUSPEND 1
#define CONFIG_ZRAM_BACKEND_LZ4HC 1
#define CONFIG_CAN_SLCAN_MODULE 1
#define CONFIG_USB_GSPCA_NW80X_MODULE 1
#define CONFIG_SND_USB_CAIAQ_INPUT 1
#define CONFIG_RT2800USB_RT35XX 1
#define CONFIG_I2C_ALI15X3_MODULE 1
#define CONFIG_JOYSTICK_MAGELLAN_MODULE 1
#define CONFIG_WINMATE_FM07_KEYS_MODULE 1
#define CONFIG_GPIB_NI_USB_MODULE 1
#define CONFIG_SPEAKUP_SYNTH_SOFT_MODULE 1
#define CONFIG_SND_SOC_NAU8825_MODULE 1
#define CONFIG_IP_NF_MATCH_ECN_MODULE 1
#define CONFIG_ACPI_SYSTEM_POWER_STATES_SUPPORT 1
#define CONFIG_REGULATOR_MT6331_MODULE 1
#define CONFIG_DVB_B2C2_FLEXCOP_PCI_MODULE 1
#define CONFIG_SND_USB_VARIAX_MODULE 1
#define CONFIG_SERIAL_DEV_BUS 1
#define CONFIG_USB_RTL8150_MODULE 1
#define CONFIG_XEN_GRANT_DEV_ALLOC_MODULE 1
#define CONFIG_L2TP_MODULE 1
#define CONFIG_COMPAT_BINFMT_ELF 1
#define CONFIG_WWAN_DEBUGFS 1
#define CONFIG_CAN_ESD_USB_MODULE 1
#define CONFIG_GPIB_NI_PCI_ISA_MODULE 1
#define CONFIG_X86_DISABLED_FEATURE_VME 1
#define CONFIG_USB_SEVSEG_MODULE 1
#define CONFIG_TOUCHSCREEN_CY8CTMG110_MODULE 1
#define CONFIG_NETFILTER_XT_SET_MODULE 1
#define CONFIG_NF_TABLES_IPV6 1
#define CONFIG_UIO_MF624_MODULE 1
#define CONFIG_BSD_PROCESS_ACCT 1
#define CONFIG_GAMEPORT_EMU10K1_MODULE 1
#define CONFIG_AMD_SECURE_AVIC 1
#define CONFIG_SND_SEQ_MIDI_MODULE 1
#define CONFIG_SCSI_STEX_MODULE 1
#define CONFIG_DVB_MN88473_MODULE 1
#define CONFIG_INPUT_FF_MEMLESS_MODULE 1
#define CONFIG_XZ_DEC_SPARC 1
#define CONFIG_TYPEC_ANX7411_MODULE 1
#define CONFIG_VIDEO_OV64A40_MODULE 1
#define CONFIG_RXGK 1
#define CONFIG_B43_LEDS 1
#define CONFIG_SND_SOC_TAS2781_COMLIB_MODULE 1
#define CONFIG_NF_REJECT_IPV4_MODULE 1
#define CONFIG_MEMSTICK_MODULE 1
#define CONFIG_TOUCHSCREEN_TSC2007_IIO 1
#define CONFIG_MWIFIEX_PCIE_MODULE 1
#define CONFIG_TOUCHSCREEN_MAX11801_MODULE 1
#define CONFIG_W1_SLAVE_DS28E17_MODULE 1
#define CONFIG_LEDS_TRIGGER_INPUT_EVENTS_MODULE 1
#define CONFIG_SND_SOC_AK4642_MODULE 1
#define CONFIG_SERIAL_8250_EXTENDED 1
#define CONFIG_LEDS_SIEMENS_SIMATIC_IPC_F7188X_MODULE 1
#define CONFIG_SND_SOC_PCM3168A_SPI_MODULE 1
#define CONFIG_PCMCIA_AHA152X_MODULE 1
#define CONFIG_KVM_COMPAT 1
#define CONFIG_SYSTEM_BLACKLIST_AUTH_UPDATE 1
#define CONFIG_AMD_PMF_MODULE 1
#define CONFIG_CC_HAS_NO_PROFILE_FN_ATTR 1
#define CONFIG_X86_64_ACPI_NUMA 1
#define CONFIG_GPIO_BY_PINCTRL_MODULE 1
#define CONFIG_SND_SOC_ADAU1372_I2C_MODULE 1
#define CONFIG_MDIO_CAVIUM_MODULE 1
#define CONFIG_SND_SOC_SOF_ACPI_MODULE 1
#define CONFIG_SND_SOC_TPA6130A2_MODULE 1
#define CONFIG_SENSORS_EMC1403_MODULE 1
#define CONFIG_USB_U_SERIAL_MODULE 1
#define CONFIG_ACPI_SPCR_TABLE 1
#define CONFIG_MMC_CRYPTO 1
#define CONFIG_NET_DSA_MV88E6060_MODULE 1
#define CONFIG_MODULE_COMPRESS 1
#define CONFIG_CGROUP_MISC 1
#define CONFIG_RCU_FANOUT 64
#define CONFIG_NATSEMI_MODULE 1
#define CONFIG_NET_IPVTI_MODULE 1
#define CONFIG_GENERIC_IOMAP 1
#define CONFIG_LEDS_SIEMENS_SIMATIC_IPC_ELKHARTLAKE_MODULE 1
#define CONFIG_SND_X86 1
#define CONFIG_KXSD9_SPI_MODULE 1
#define CONFIG_TYPEC_WUSB3801_MODULE 1
#define CONFIG_I2C_VIPERBOARD_MODULE 1
#define CONFIG_REGULATOR_USERSPACE_CONSUMER_MODULE 1
#define CONFIG_LTR390_MODULE 1
#define CONFIG_MMA7660_MODULE 1
#define CONFIG_MPRLS0025PA_MODULE 1
#define CONFIG_MISC_RTSX_USB_MODULE 1
#define CONFIG_BYTCRC_PMIC_OPREGION 1
#define CONFIG_TI_DAC5571_MODULE 1
#define CONFIG_DVB_MB86A20S_MODULE 1
#define CONFIG_ADXL380_SPI_MODULE 1
#define CONFIG_USB_ISP116X_HCD_MODULE 1
#define CONFIG_OCTEON_EP_MODULE 1
#define CONFIG_LIBERTAS_USB_MODULE 1
#define CONFIG_RCU_CPU_STALL_TIMEOUT 60
#define CONFIG_NF_DUP_IPV6_MODULE 1
#define CONFIG_PMIC_ADP5520 1
#define CONFIG_IP_MROUTE_COMMON 1
#define CONFIG_USB_GADGET_TARGET_MODULE 1
#define CONFIG_USB_EHCI_HCD 1
#define CONFIG_TOUCHSCREEN_USB_EASYTOUCH 1
#define CONFIG_RTL8192DU_MODULE 1
#define CONFIG_IRQ_REMAP 1
#define CONFIG_PHY_QCOM_USB_HSIC_MODULE 1
#define CONFIG_SND_SOC_AMD_ACP_LEGACY_COMMON_MODULE 1
#define CONFIG_XILINX_EMACLITE_MODULE 1
#define CONFIG_STRICT_KERNEL_RWX 1
#define CONFIG_MMC_SDHCI_UHS2_MODULE 1
#define CONFIG_EDD_MODULE 1
#define CONFIG_MAX5821_MODULE 1
#define CONFIG_INFINIBAND_ON_DEMAND_PAGING 1
#define CONFIG_USB_CONFIGFS_OBEX 1
#define CONFIG_USB_SERIAL_QUALCOMM_MODULE 1
#define CONFIG_GENERIC_CLOCKEVENTS_MIN_ADJUST 1
#define CONFIG_RTW88_SDIO_MODULE 1
#define CONFIG_LZO_COMPRESS 1
#define CONFIG_SPARSEMEM_VMEMMAP 1
#define CONFIG_LEDS_CROS_EC_MODULE 1
#define CONFIG_MEDIA_TUNER_MT2266_MODULE 1
#define CONFIG_I2C_NFORCE2_MODULE 1
#define CONFIG_KFENCE_DEFERRABLE 1
#define CONFIG_CRYPTO_STREEBOG_MODULE 1
#define CONFIG_HID_SUPPORT 1
#define CONFIG_CXL_PMEM_MODULE 1
#define CONFIG_USB_CDC_PHONET_MODULE 1
#define CONFIG_CRYPTO_DEV_CHELSIO_MODULE 1
#define CONFIG_IP_NF_ARPFILTER_MODULE 1
#define CONFIG_MACB_MODULE 1
#define CONFIG_EXTCON_MAX77693_MODULE 1
#define CONFIG_ARCH_WANT_HUGETLB_VMEMMAP_PREINIT 1
#define CONFIG_GPIO_ICH_MODULE 1
#define CONFIG_HID_SMARTJOYPLUS_MODULE 1
#define CONFIG_I2C_CCGX_UCSI 1
#define CONFIG_ASYNC_PQ_MODULE 1
#define CONFIG_HX711_MODULE 1
#define CONFIG_VFAT_FS_MODULE 1
#define CONFIG_LCD_CLASS_DEVICE_MODULE 1
#define CONFIG_NET_VENDOR_ROCKER 1
#define CONFIG_FONT_8x8 1
#define CONFIG_EFIVAR_FS 1
#define CONFIG_SND_SOC_WCD_MBHC_MODULE 1
#define CONFIG_HOTPLUG_CORE_SYNC_FULL 1
#define CONFIG_NFC_MICROREAD_I2C_MODULE 1
#define CONFIG_UBIFS_FS_XATTR 1
#define CONFIG_SECURITY_DMESG_RESTRICT 1
#define CONFIG_INSPUR_PLATFORM_PROFILE_MODULE 1
#define CONFIG_LEDS_GPIO_MODULE 1
#define CONFIG_CHELSIO_T1_1G 1
#define CONFIG_AD4080_MODULE 1
#define CONFIG_DVB_HOPPER_MODULE 1
#define CONFIG_CRYPTO_DEFLATE_MODULE 1
#define CONFIG_LTR501_MODULE 1
#define CONFIG_E100_MODULE 1
#define CONFIG_MACSEC_MODULE 1
#define CONFIG_IP_ROUTE_MULTIPATH 1
#define CONFIG_MFD_RT4831_MODULE 1
#define CONFIG_KFENCE_STRESS_TEST_FAULTS 0
#define CONFIG_SND_SOC_RT5663_MODULE 1
#define CONFIG_WLAN_VENDOR_ADMTEK 1
#define CONFIG_TIME_NS 1
#define CONFIG_TMP007_MODULE 1
#define CONFIG_QEDI_MODULE 1
#define CONFIG_UCS2_STRING 1
#define CONFIG_DM_MULTIPATH_QL_MODULE 1
#define CONFIG_MHP_DEFAULT_ONLINE_TYPE_ONLINE_AUTO 1
#define CONFIG_REGULATOR_PF9453_MODULE 1
#define CONFIG_SND_SOC_PCM6240_MODULE 1
#define CONFIG_FUNCTION_PADDING_BYTES 16
#define CONFIG_MFD_ATC260X_I2C_MODULE 1
#define CONFIG_MAGIC_SYSRQ_DEFAULT_ENABLE 0x0
#define CONFIG_VIDEO_MT9M001_MODULE 1
#define CONFIG_PACKET 1
#define CONFIG_LEDS_TRIGGER_TRANSIENT_MODULE 1
#define CONFIG_VGA_ARB_MAX_GPUS 10
#define CONFIG_KVM_GENERIC_PRE_FAULT_MEMORY 1
#define CONFIG_VF610_DAC_MODULE 1
#define CONFIG_NO_HZ_COMMON 1
#define CONFIG_SND_FIREFACE_MODULE 1
#define CONFIG_USB_SERIAL_METRO_MODULE 1
#define CONFIG_USB_LJCA_MODULE 1
#define CONFIG_SCSI_ESAS2R_MODULE 1
#define CONFIG_MEMTEST 1
#define CONFIG_6LOWPAN_GHC_EXT_HDR_HOP_MODULE 1
#define CONFIG_IIO_HRTIMER_TRIGGER_MODULE 1
#define CONFIG_DRM_VIRTIO_GPU_MODULE 1
#define CONFIG_MFD_TPS65086_MODULE 1
#define CONFIG_USB_SERIAL_MXUPORT_MODULE 1
#define CONFIG_USB_STORAGE_SDDR55_MODULE 1
#define CONFIG_CC_HAS_SANE_FUNCTION_ALIGNMENT 1
#define CONFIG_SENSORS_LM95234_MODULE 1
#define CONFIG_CC_HAS_MARCH_NATIVE 1
#define CONFIG_SND_PCM_OSS_PLUGINS 1
#define CONFIG_I8253_LOCK 1
#define CONFIG_STACKDEPOT_MAX_FRAMES 64
#define CONFIG_BRIDGE_EBT_ARP_MODULE 1
#define CONFIG_SND_SERIAL_U16550_MODULE 1
#define CONFIG_FPGA_DFL_PCI_MODULE 1
#define CONFIG_REGULATOR_MAX20086_MODULE 1
#define CONFIG_PTP_1588_CLOCK_KVM_MODULE 1
#define CONFIG_QFMT_V1_MODULE 1
#define CONFIG_FB_CFB_FILLRECT 1
#define CONFIG_TINYDRM_SHARP_MEMORY_MODULE 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_RT286_MODULE 1
#define CONFIG_BRIDGE_EBT_T_NAT_MODULE 1
#define CONFIG_NF_DEFRAG_IPV4_MODULE 1
#define CONFIG_FAIR_GROUP_SCHED 1
#define CONFIG_LEDS_MC13783_MODULE 1
#define CONFIG_ZSTD_DECOMPRESS 1
#define CONFIG_NETFILTER_ADVANCED 1
#define CONFIG_FAT_FS_MODULE 1
#define CONFIG_USB_CONFIGFS_NCM 1
#define CONFIG_DRM_PANIC_FOREGROUND_COLOR 0xffffff
#define CONFIG_REGULATOR_MAX77503_MODULE 1
#define CONFIG_WM831X_POWER_MODULE 1
#define CONFIG_TOUCHSCREEN_TSC2004_MODULE 1
#define CONFIG_SND_SOC_RT274_MODULE 1
#define CONFIG_VDPA_USER_MODULE 1
#define CONFIG_INTEL_PMT_DISCOVERY_MODULE 1
#define CONFIG_NVME_MULTIPATH 1
#define CONFIG_B43LEGACY_DMA_AND_PIO_MODE 1
#define CONFIG_PSTORE_DEFAULT_KMSG_BYTES 10240
#define CONFIG_VIDEO_CX231XX_RC 1
#define CONFIG_X86_PMEM_LEGACY_MODULE 1
#define CONFIG_IP6_NF_TARGET_REJECT_MODULE 1
#define CONFIG_SND_SOC_LPASS_MACRO_COMMON_MODULE 1
#define CONFIG_AIC79XX_CMDS_PER_DEVICE 32
#define CONFIG_MLX5_BRIDGE 1
#define CONFIG_IOMMU_PT_AMDV1 1
#define CONFIG_RTW89_8852BTE_MODULE 1
#define CONFIG_GENERIC_TIME_VSYSCALL 1
#define CONFIG_MMU_GATHER_RCU_TABLE_FREE 1
#define CONFIG_ARCH_SUPPORTS_PER_VMA_LOCK 1
#define CONFIG_AS73211_MODULE 1
#define CONFIG_SND_HDA_CODEC_ALC680_MODULE 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_PCM3168A_MODULE 1
#define CONFIG_SND_CS46XX_NEW_DSP 1
#define CONFIG_BT_HCIBLUECARD_MODULE 1
#define CONFIG_THERMAL_CORE_TESTING_MODULE 1
#define CONFIG_DVB_AS102_FE_MODULE 1
#define CONFIG_SND_SOC_AMD_ACP5x_MODULE 1
#define CONFIG_IR_IMON_DECODER_MODULE 1
#define CONFIG_OVERLAY_FS_METACOPY 1
#define CONFIG_DLN2_ADC_MODULE 1
#define CONFIG_DS1682_MODULE 1
#define CONFIG_NR_CPUS 8192
#define CONFIG_DRM_ST7920_MODULE 1
#define CONFIG_V4L2_CCI_MODULE 1
#define CONFIG_PATA_PARPORT_KTTI_MODULE 1
#define CONFIG_ARCH_HIBERNATION_POSSIBLE 1
#define CONFIG_HID_ACCUTOUCH_MODULE 1
#define CONFIG_NET_DSA_TAG_YT921X_MODULE 1
#define CONFIG_X86_REQUIRED_FEATURE_MSR 1
#define CONFIG_TOUCHSCREEN_USB_E2I 1
#define CONFIG_HAVE_FUNCTION_TRACER 1
#define CONFIG_ASYNC_MEMCPY_MODULE 1
#define CONFIG_MLXSW_PCI_MODULE 1
#define CONFIG_SPI_OC_TINY_MODULE 1
#define CONFIG_SND_SOC_NAU8824_MODULE 1
#define CONFIG_GPIO_MAX7301_MODULE 1
#define CONFIG_SX9500_MODULE 1
#define CONFIG_LOG_BUF_SHIFT 17
#define CONFIG_REGULATOR_MT6332_MODULE 1
#define CONFIG_LEDS_TRIGGER_DEFAULT_ON_MODULE 1
#define CONFIG_IPV6_OPTIMISTIC_DAD 1
#define CONFIG_SND_SOC_MAX98927_MODULE 1
#define CONFIG_FB_EFI 1
#define CONFIG_AUDIT 1
#define CONFIG_SQUASHFS_XATTR 1
#define CONFIG_BH1745_MODULE 1
#define CONFIG_NET_9P_MODULE 1
#define CONFIG_BATTERY_DA9052_MODULE 1
#define CONFIG_SECURITY_SMACK_APPEND_SIGNALS 1
#define CONFIG_USB_F_MIDI_MODULE 1
#define CONFIG_BT_HCIBTUSB_MODULE 1
#define CONFIG_XEN_ACPI 1
#define CONFIG_GPIO_DA9052_MODULE 1
#define CONFIG_DRM_XE_JOB_TIMEOUT_MAX 10000
#define CONFIG_USB_HUB_USB251XB_MODULE 1
#define CONFIG_SND_SOC_SOF_CANNONLAKE_MODULE 1
#define CONFIG_TCP_CONG_SCALABLE_MODULE 1
#define CONFIG_INTEL_QUICKSPI_MODULE 1
#define CONFIG_SND_SEQ_DEVICE_MODULE 1
#define CONFIG_VEML3235_MODULE 1
#define CONFIG_DVB_DRX39XYJ_MODULE 1
#define CONFIG_RTW88_USB_MODULE 1
#define CONFIG_SND_SOC_CROS_EC_CODEC_MODULE 1
#define CONFIG_MOUSE_CYAPA_MODULE 1
#define CONFIG_VIDEO_TW9906_MODULE 1
#define CONFIG_REGULATOR_MT6323_MODULE 1
#define CONFIG_BLK_DEV_ZONED_LOOP_MODULE 1
#define CONFIG_AD3552R_HS_MODULE 1
#define CONFIG_QED_MODULE 1
#define CONFIG_DAMON_RECLAIM 1
#define CONFIG_SDP500_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_CONNTRACK_MODULE 1
#define CONFIG_NF_SOCKET_IPV4_MODULE 1
#define CONFIG_CRYPTO_ARIA_AESNI_AVX_X86_64_MODULE 1
#define CONFIG_CAN_DEV_MODULE 1
#define CONFIG_SND_SEQ_HRTIMER_DEFAULT 1
#define CONFIG_MSE102X_MODULE 1
#define CONFIG_HW_RANDOM_INTEL_MODULE 1
#define CONFIG_NVME_TCP_TLS 1
#define CONFIG_COMPAT_NETLINK_MESSAGES 1
#define CONFIG_JOYSTICK_TWIDJOY_MODULE 1
#define CONFIG_USB_ATM_MODULE 1
#define CONFIG_REGULATOR_AXP20X_MODULE 1
#define CONFIG_USB_DWC3_GOOGLE_MODULE 1
#define CONFIG_VSOCKETS_DIAG_MODULE 1
#define CONFIG_USB_LED_TRIG 1
#define CONFIG_NET_SCH_GRED_MODULE 1
#define CONFIG_DM_MULTIPATH_MODULE 1
#define CONFIG_AFE4403_MODULE 1
#define CONFIG_SND_SOC_AMD_YC_MACH_MODULE 1
#define CONFIG_KVM_INTEL_MODULE 1
#define CONFIG_CAN_J1939_MODULE 1
#define CONFIG_RDS_RDMA_MODULE 1
#define CONFIG_EVENT_TRACING 1
#define CONFIG_KRETPROBES 1
#define CONFIG_BCM_NET_PHYLIB_MODULE 1
#define CONFIG_PAGE_POISONING 1
#define CONFIG_BACKLIGHT_AS3711_MODULE 1
#define CONFIG_DVB_USB_CE6230_MODULE 1
#define CONFIG_ARCH_HAS_USER_SHADOW_STACK 1
#define CONFIG_PATA_CMD640_PCI_MODULE 1
#define CONFIG_SERIAL_8250_SHARE_IRQ 1
#define CONFIG_MLX5_HW_STEERING 1
#define CONFIG_NETFS_DEBUG 1
#define CONFIG_LOCKD_MODULE 1
#define CONFIG_USB_SERIAL_CYPRESS_M8_MODULE 1
#define CONFIG_6LOWPAN_GHC_UDP_MODULE 1
#define CONFIG_RPMSG_CTRL_MODULE 1
#define CONFIG_USB_CONFIGFS_F_UAC1 1
#define CONFIG_HID_CREATIVE_SB0540_MODULE 1
#define CONFIG_BPF_LSM 1
#define CONFIG_BACKLIGHT_RT4831_MODULE 1
#define CONFIG_NVME_TARGET_RDMA_MODULE 1
#define CONFIG_IP_ROUTE_VERBOSE 1
#define CONFIG_COMPACTION 1
#define CONFIG_SND_HDA_CODEC_ALC861VD_MODULE 1
#define CONFIG_REGULATOR_RT4801_MODULE 1
#define CONFIG_PINCTRL_ALDERLAKE_MODULE 1
#define CONFIG_FB_CFB_IMAGEBLIT 1
#define CONFIG_PATA_SCH_MODULE 1
#define CONFIG_SCSI_BFA_FC_MODULE 1
#define CONFIG_HWPOISON_INJECT_MODULE 1
#define CONFIG_BRANCH_PROFILE_NONE 1
#define CONFIG_SND_SOC_NTP8918_MODULE 1
#define CONFIG_VIDEOBUF2_VMALLOC_MODULE 1
#define CONFIG_BRIDGE_EBT_IP_MODULE 1
#define CONFIG_INPUT 1
#define CONFIG_BIG_KEYS 1
#define CONFIG_SENSORS_OCC_P8_I2C_MODULE 1
#define CONFIG_LEDS_UPBOARD_MODULE 1
#define CONFIG_TI_ADS131E08_MODULE 1
#define CONFIG_WLAN_VENDOR_RSI 1
#define CONFIG_SND_SOC_RT711_MODULE 1
#define CONFIG_USB_MAX3420_UDC_MODULE 1
#define CONFIG_USB_NET_PLUSB_MODULE 1
#define CONFIG_NFT_LOG_MODULE 1
#define CONFIG_HAVE_MMIOTRACE_SUPPORT 1
#define CONFIG_GENWQE_PLATFORM_ERROR_RECOVERY 0
#define CONFIG_NTFS_DEBUG 1
#define CONFIG_RADIO_ADAPTERS_MODULE 1
#define CONFIG_HAVE_OBJTOOL_MCOUNT 1
#define CONFIG_SND_SOC_MT6358_MODULE 1
#define CONFIG_SMPRO_MISC_MODULE 1
#define CONFIG_BRIDGE_EBT_REDIRECT_MODULE 1
#define CONFIG_FPGA_BRIDGE_MODULE 1
#define CONFIG_TCG_TPM2_HMAC 1
#define CONFIG_ROHM_BM1390_MODULE 1
#define CONFIG_FUTEX_PRIVATE_HASH 1
#define CONFIG_FUEL_GAUGE_MM8013_MODULE 1
#define CONFIG_VXLAN_MODULE 1
#define CONFIG_RXKAD 1
#define CONFIG_SONY_FF 1
#define CONFIG_MS5611_I2C_MODULE 1
#define CONFIG_CAN_M_CAN_PCI_MODULE 1
#define CONFIG_RTW88_8723DE_MODULE 1
#define CONFIG_DEV_COREDUMP 1
#define CONFIG_SLAB_MERGE_DEFAULT 1
#define CONFIG_XEN 1
#define CONFIG_DVB_USB_MODULE 1
#define CONFIG_FB_DMAMEM_HELPERS_DEFERRED 1
#define CONFIG_BATMAN_ADV_BATMAN_V 1
#define CONFIG_QAT_VFIO_PCI_MODULE 1
#define CONFIG_TYPEC_MUX_PTN36502_MODULE 1
#define CONFIG_USB_MIDI_GADGET_MODULE 1
#define CONFIG_DVB_B2C2_FLEXCOP_MODULE 1
#define CONFIG_SND_SOC_WM8998_MODULE 1
#define CONFIG_GPIO_PCF857X_MODULE 1
#define CONFIG_SND_SOC_RT5575_MODULE 1
#define CONFIG_INTEL_MEI_CSC_MODULE 1
#define CONFIG_FUNCTION_ERROR_INJECTION 1
#define CONFIG_TABLET_USB_HANWANG_MODULE 1
#define CONFIG_E1000_MODULE 1
#define CONFIG_FRAMEBUFFER_CONSOLE 1
#define CONFIG_SND_INDIGO_MODULE 1
#define CONFIG_SND_SOC_AMD_ACP6x_MODULE 1
#define CONFIG_SND_SOC_RT5660_MODULE 1
#define CONFIG_ADT7316_SPI_MODULE 1
#define CONFIG_ARCH_HAS_GENERIC_CRASHKERNEL_RESERVATION 1
#define CONFIG_GPIO_LP873X_MODULE 1
#define CONFIG_RADIO_SI476X_MODULE 1
#define CONFIG_REGULATOR_TPS6507X_MODULE 1
#define CONFIG_SND_SOC_AW88166_MODULE 1
#define CONFIG_MTD_NAND_ECC_SW_BCH 1
#define CONFIG_JOYSTICK_XPAD_FF 1
#define CONFIG_CRYPTO_ENGINE_MODULE 1
#define CONFIG_COUNTER_MODULE 1
#define CONFIG_POLYNOMIAL_MODULE 1
#define CONFIG_BLK_ICQ 1
#define CONFIG_MPL115_MODULE 1
#define CONFIG_NF_CONNTRACK_MARK 1
#define CONFIG_VFIO_PCI_VGA 1
#define CONFIG_RTC_DRV_MSM6242_MODULE 1
#define CONFIG_HAVE_GCC_PLUGINS 1
#define CONFIG_USB_NET_SMSC95XX_MODULE 1
#define CONFIG_SENSORS_NCT6683_MODULE 1
#define CONFIG_PATA_ARTOP_MODULE 1
#define CONFIG_FUSION_LAN_MODULE 1
#define CONFIG_MEMSTICK_TIFM_MS_MODULE 1
#define CONFIG_DRM_VMWGFX_MKSSTATS 1
#define CONFIG_DVB_AF9033_MODULE 1
#define CONFIG_SND_DESIGNWARE_PCM 1
#define CONFIG_NO_HZ 1
#define CONFIG_VIDEO_GO7007_USB_MODULE 1
#define CONFIG_IQS624_POS_MODULE 1
#define CONFIG_DP83869_PHY_MODULE 1
#define CONFIG_TPL0102_MODULE 1
#define CONFIG_LIBIE_FWLOG_MODULE 1
#define CONFIG_GPIO_PALMAS_MODULE 1
#define CONFIG_PWM_CLK_MODULE 1
#define CONFIG_SENSORS_LT3074_MODULE 1
#define CONFIG_CEPH_FSCACHE 1
#define CONFIG_INPUT_GPIO_DECODER_MODULE 1
#define CONFIG_RING_BUFFER 1
#define CONFIG_W1_MASTER_GPIO_MODULE 1
#define CONFIG_I2C_MUX_PCA954x_MODULE 1
#define CONFIG_ATH12K_DEBUG 1
#define CONFIG_NET_DSA_TAG_MTK_MODULE 1
#define CONFIG_I2C_SIS96X_MODULE 1
#define CONFIG_D3323AA_MODULE 1
#define CONFIG_USB_HSIC_USB4604_MODULE 1
#define CONFIG_TOUCHSCREEN_TSC2007_MODULE 1
#define CONFIG_DM_SNAPSHOT_MODULE 1
#define CONFIG_MCP4821_MODULE 1
#define CONFIG_USB_SERIAL_IUU_MODULE 1
#define CONFIG_EDAC_E752X_MODULE 1
#define CONFIG_SENSORS_YOGAFAN_MODULE 1
#define CONFIG_NET_PKTGEN_MODULE 1
#define CONFIG_LLC_MODULE 1
#define CONFIG_VIDEO_AU0828_MODULE 1
#define CONFIG_DYNAMIC_FTRACE_WITH_REGS 1
#define CONFIG_LEDS_LM36274_MODULE 1
#define CONFIG_MFD_SYSCON 1
#define CONFIG_REGULATOR_PCAP_MODULE 1
#define CONFIG_VIDEO_STK1160_MODULE 1
#define CONFIG_USB_CYTHERM_MODULE 1
#define CONFIG_SENSORS_GPIO_FAN_MODULE 1
#define CONFIG_INPUT_PCF8574_MODULE 1
#define CONFIG_GPIOLIB_FASTPATH_LIMIT 512
#define CONFIG_MAC80211_LEDS 1
#define CONFIG_EXTCON_FSA9480_MODULE 1
#define CONFIG_SCHED_MC_PRIO 1
#define CONFIG_USB_NET_AQC111_MODULE 1
#define CONFIG_NFC_ST_NCI_I2C_MODULE 1
#define CONFIG_EZX_PCAP 1
#define CONFIG_SECURITY_SELINUX_BOOTPARAM 1
#define CONFIG_JFS_SECURITY 1
#define CONFIG_PCIPCWATCHDOG_MODULE 1
#define CONFIG_NFC_MRVL_USB_MODULE 1
#define CONFIG_XEN_MCE_LOG 1
#define CONFIG_RT2800USB_MODULE 1
#define CONFIG_BT_BNEP_PROTO_FILTER 1
#define CONFIG_RESET_CONTROLLER 1
#define CONFIG_SND_SOC_SOF_GEMINILAKE_MODULE 1
#define CONFIG_ARCH_SUPPORTS_HUGETLBFS 1
#define CONFIG_RTC_DRV_M41T80_WDT 1
#define CONFIG_VIDEO_MEM2MEM_DEINTERLACE_MODULE 1
#define CONFIG_SURFACE_AGGREGATOR_HUB_MODULE 1
#define CONFIG_RTC_DRV_MCP795_MODULE 1
#define CONFIG_CRYPTO_SM4_AESNI_AVX_X86_64_MODULE 1
#define CONFIG_PID_NS 1
#define CONFIG_DRM_GPUVM_MODULE 1
#define CONFIG_GPIO_MAX7300_MODULE 1
#define CONFIG_NVME_HWMON 1
#define CONFIG_IP6_NF_TARGET_NPT_MODULE 1
#define CONFIG_LEDS_RT8515_MODULE 1
#define CONFIG_MB1232_MODULE 1
#define CONFIG_NET_DSA_MICROCHIP_KSZ8863_SMI_MODULE 1
#define CONFIG_TINYDRM_ILI9163_MODULE 1
#define CONFIG_ASUS_ARMOURY_MODULE 1
#define CONFIG_HAVE_KVM_DIRTY_RING 1
#define CONFIG_ROHM_BU27034_MODULE 1
#define CONFIG_AS3935_MODULE 1
#define CONFIG_CGROUP_PERF 1
#define CONFIG_INET6_ESP_OFFLOAD_MODULE 1
#define CONFIG_L2TP_ETH_MODULE 1
#define CONFIG_IGC_LEDS 1
#define CONFIG_VIDEO_MSP3400_MODULE 1
#define CONFIG_USB_PWC_MODULE 1
#define CONFIG_HARDIRQS_SW_RESEND 1
#define CONFIG_IIO_CONSUMERS_PER_TRIGGER 2
#define CONFIG_FRAMEBUFFER_CONSOLE_ROTATION 1
#define CONFIG_BNX2X_MODULE 1
#define CONFIG_SND_SOC_NAU8810_MODULE 1
#define CONFIG_ARCH_HAVE_NMI_SAFE_CMPXCHG 1
#define CONFIG_SSIF_IPMI_BMC_MODULE 1
#define CONFIG_AW96103_MODULE 1
#define CONFIG_NETFILTER_NETLINK_GLUE_CT 1
#define CONFIG_SENSORS_XDPE122_MODULE 1
#define CONFIG_SERIAL_8250_FINTEK 1
#define CONFIG_ENIC_MODULE 1
#define CONFIG_SCSI_MPT2SAS_MAX_SGE 128
#define CONFIG_FREEZER 1
#define CONFIG_RFD77402_MODULE 1
#define CONFIG_XEN_GNTDEV_DMABUF 1
#define CONFIG_INFINIBAND_USER_MEM 1
#define CONFIG_PINCTRL_CS47L35 1
#define CONFIG_SND_SOC_SSM2602_MODULE 1
#define CONFIG_DVB_USB_V2_MODULE 1
#define CONFIG_AMD_PTDMA_MODULE 1
#define CONFIG_MYRI10GE_MODULE 1
#define CONFIG_SND_SOC_SOF_INTEL_SOUNDWIRE_LINK_BASELINE_MODULE 1
#define CONFIG_VM_EVENT_COUNTERS 1
#define CONFIG_SQUASHFS_CHOICE_DECOMP_BY_MOUNT 1
#define CONFIG_PAGE_SIZE_LESS_THAN_64KB 1
#define CONFIG_VLAN_8021Q_MODULE 1
#define CONFIG_HID_HAPTIC 1
#define CONFIG_AQTION_MODULE 1
#define CONFIG_ASSOCIATIVE_ARRAY 1
#define CONFIG_PNFS_FILE_LAYOUT_MODULE 1
#define CONFIG_RTL8723_COMMON_MODULE 1
#define CONFIG_AXP288_ADC_MODULE 1
#define CONFIG_SI7005_MODULE 1
#define CONFIG_JOYSTICK_SPACEBALL_MODULE 1
#define CONFIG_EFI_EARLYCON 1
#define CONFIG_GPIOLIB_LEGACY 1
#define CONFIG_MINIX_SUBPARTITION 1
#define CONFIG_IPE_PROP_DM_VERITY_SIGNATURE 1
#define CONFIG_LEDS_MLXCPLD_MODULE 1
#define CONFIG_EXT4_FS_SECURITY 1
#define CONFIG_SENSORS_SHT3x_MODULE 1
#define CONFIG_BRCMFMAC_USB 1
#define CONFIG_SUNRPC_SWAP 1
#define CONFIG_XFS_SUPPORT_V4 1
#define CONFIG_TOUCHSCREEN_USB_DMC_TSC10 1
#define CONFIG_BRIDGE_EBT_VLAN_MODULE 1
#define CONFIG_SENSORS_G760A_MODULE 1
#define CONFIG_CRASH_RESERVE 1
#define CONFIG_SND_VIRTUOSO_MODULE 1
#define CONFIG_ATH_COMMON_MODULE 1
#define CONFIG_AD7816_MODULE 1
#define CONFIG_UACCE_MODULE 1
#define CONFIG_BLK_DEV 1
#define CONFIG_CRYPTO_SIG 1
#define CONFIG_RT61PCI_MODULE 1
#define CONFIG_OXP_EC_MODULE 1
#define CONFIG_SND_SOC_PCM179X_SPI_MODULE 1
#define CONFIG_EFI_COCO_SECRET 1
#define CONFIG_DRM_BUDDY_MODULE 1
#define CONFIG_MAX8925_POWER_MODULE 1
#define CONFIG_POWER_SEQUENCING_MODULE 1
#define CONFIG_BT_HCIBTUSB_POLL_SYNC 1
#define CONFIG_GPIO_DS4520_MODULE 1
#define CONFIG_USB_SERIAL_PL2303_MODULE 1
#define CONFIG_TOUCHSCREEN_MSG2638_MODULE 1
#define CONFIG_TYPEC_MT6360_MODULE 1
#define CONFIG_9P_FSCACHE 1
#define CONFIG_AD5449_MODULE 1
#define CONFIG_HID_SENSOR_PROX_MODULE 1
#define CONFIG_CGROUP_PIDS 1
#define CONFIG_DRM_ACCEL_AMDXDNA_MODULE 1
#define CONFIG_X86_UMIP 1
#define CONFIG_VIDEO_CX88_MODULE 1
#define CONFIG_RMI4_F30 1
#define CONFIG_SND_HDA_INTEL_HDMI_SILENT_STREAM 1
#define CONFIG_PWM_IQS620A_MODULE 1
#define CONFIG_NVDIMM_KEYS 1
#define CONFIG_SENSORS_IBMAEM_MODULE 1
#define CONFIG_SENSORS_W83L786NG_MODULE 1
#define CONFIG_SOCK_VALIDATE_XMIT 1
#define CONFIG_LIBETH_XDP_MODULE 1
#define CONFIG_NFC_S3FWRN5_MODULE 1
#define CONFIG_CRYPTO_LIB_AES_CBC_MACS 1
#define CONFIG_DVB_USB_AZ6007_MODULE 1
#define CONFIG_INTEGRITY_ASYMMETRIC_KEYS 1
#define CONFIG_INSTRUCTION_DECODER 1
#define CONFIG_INPUT_AD714X_I2C_MODULE 1
#define CONFIG_REGULATOR_RT8092_MODULE 1
#define CONFIG_INET6_ESP_MODULE 1
#define CONFIG_HPWDT_NMI_DECODING 1
#define CONFIG_FCOE_FNIC_MODULE 1
#define CONFIG_FPROBE 1
#define CONFIG_CAN_GW_MODULE 1
#define CONFIG_NF_CONNTRACK_SIP_MODULE 1
#define CONFIG_RTW89_8852AU_MODULE 1
#define CONFIG_NET_RX_BUSY_POLL 1
#define CONFIG_PHYSICAL_START 0x1000000
#define CONFIG_PT_RECLAIM 1
#define CONFIG_INPUT_ATI_REMOTE2_MODULE 1
#define CONFIG_EDAC 1
#define CONFIG_USB_CHIPIDEA_HOST 1
#define CONFIG_ARCH_WANTS_CLOCKSOURCE_READ_INLINE 1
#define CONFIG_PAHOLE_VERSION 131
#define CONFIG_HTS221_SPI_MODULE 1
#define CONFIG_SPI_AXI_SPI_ENGINE_MODULE 1
#define CONFIG_LEDS_DAC124S085_MODULE 1
#define CONFIG_SND_MPU401_MODULE 1
#define CONFIG_PKCS7_MESSAGE_PARSER 1
#define CONFIG_HAVE_UNWIND_USER_FP 1
#define CONFIG_REGMAP_SLIMBUS_MODULE 1
#define CONFIG_LRU_GEN_ENABLED 1
#define CONFIG_ADXL355_MODULE 1
#define CONFIG_TOUCHSCREEN_SILEAD_MODULE 1
#define CONFIG_PTP_1588_CLOCK_IDT82P33_MODULE 1
#define CONFIG_TOUCHSCREEN_GOODIX_BERLIN_SPI_MODULE 1
#define CONFIG_PWM_CRC 1
#define CONFIG_B43LEGACY_PCICORE_AUTOSELECT 1
#define CONFIG_USB_CONFIGFS_PHONET 1
#define CONFIG_LCD_AMS369FG06_MODULE 1
#define CONFIG_MEDIA_SUPPORT_MODULE 1
#define CONFIG_MOUSE_PS2_LOGIPS2PP 1
#define CONFIG_I2C_DESIGNWARE_PLATFORM 1
#define CONFIG_SENSORS_TSL2550_MODULE 1
#define CONFIG_CC_HAS_ENTRY_PADDING 1
#define CONFIG_NET_VENDOR_SMSC 1
#define CONFIG_MITIGATION_RETBLEED 1
#define CONFIG_TRACE_CLOCK 1
#define CONFIG_R6040_MODULE 1
#define CONFIG_TCG_TIS_I2C_INFINEON_MODULE 1
#define CONFIG_MGBE_MODULE 1
#define CONFIG_HAVE_KVM_IRQ_BYPASS_MODULE 1
#define CONFIG_EXTCON_SM5502_MODULE 1
#define CONFIG_ACPI_BUTTON 1
#define CONFIG_USB_SERIAL_TI_MODULE 1
#define CONFIG_FPGA_MGR_XILINX_CORE_MODULE 1
#define CONFIG_CAVIUM_PTP_MODULE 1
#define CONFIG_BATTERY_MAX1720X_MODULE 1
#define CONFIG_NOZOMI_MODULE 1
#define CONFIG_VIDEO_GC0308_MODULE 1
#define CONFIG_DELL_WMI_LED_MODULE 1
#define CONFIG_RTC_INTF_SYSFS 1
#define CONFIG_MOUSE_PS2_FOCALTECH 1
#define CONFIG_PATA_HPT3X3_MODULE 1
#define CONFIG_FB_NOTIFY 1
#define CONFIG_QUOTA 1
#define CONFIG_VIA_RHINE_MODULE 1
#define CONFIG_ACPI_PRMT 1
#define CONFIG_RCU_LAZY 1
#define CONFIG_BACKLIGHT_SKY81452_MODULE 1
#define CONFIG_TCG_TIS_I2C_CR50_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_TCPMSS_MODULE 1
#define CONFIG_NFT_TUNNEL_MODULE 1
#define CONFIG_ADMV4420_MODULE 1
#define CONFIG_ACPI_TABLE_UPGRADE 1
#define CONFIG_SENSORS_LTC4282_MODULE 1
#define CONFIG_SND_SOC_TLV320AIC3X_I2C_MODULE 1
#define CONFIG_DVB_L64781_MODULE 1
#define CONFIG_MT7663U_MODULE 1
#define CONFIG_TASKS_RCU_GENERIC 1
#define CONFIG_PATA_PARPORT_BPCK6_MODULE 1
#define CONFIG_CRYPTO_SHA1 1
#define CONFIG_IP_SET_HASH_IPPORT_MODULE 1
#define CONFIG_PREEMPT_NOTIFIERS 1
#define CONFIG_VIDEO_S5K3M5_MODULE 1
#define CONFIG_UBIFS_FS_SECURITY 1
#define CONFIG_INTEL_BXTWC_PMIC_TMU_MODULE 1
#define CONFIG_MFD_MAX7360_MODULE 1
#define CONFIG_NFC_MRVL_SPI_MODULE 1
#define CONFIG_VIDEO_VP27SMPX_MODULE 1
#define CONFIG_SND_SOC_ES83XX_DSM_COMMON_MODULE 1
#define CONFIG_SND_VIRTIO_MODULE 1
#define CONFIG_NFT_DUP_IPV6_MODULE 1
#define CONFIG_FS_VERITY 1
#define CONFIG_X86_PLATFORM_DRIVERS_UNIWILL 1
#define CONFIG_RC_ATI_REMOTE_MODULE 1
#define CONFIG_PATA_ACPI_MODULE 1
#define CONFIG_SMC_DIAG_MODULE 1
#define CONFIG_JOYSTICK_PXRC_MODULE 1
#define CONFIG_CONTEXT_TRACKING 1
#define CONFIG_USB_CHAOSKEY_MODULE 1
#define CONFIG_AMD_HSMP_ACPI_MODULE 1
#define CONFIG_AGP_AMD64_MODULE 1
#define CONFIG_NI_XGE_MANAGEMENT_ENET_MODULE 1
#define CONFIG_CPU_IDLE_GOV_TEO 1
#define CONFIG_SND_SOC_RT721_SDCA_SDW_MODULE 1
#define CONFIG_ULI526X_MODULE 1
#define CONFIG_DEVTMPFS_SAFE 1
#define CONFIG_NET_EMATCH_U32_MODULE 1
#define CONFIG_MEDIA_CEC_RC 1
#define CONFIG_USB_SERIAL_CYBERJACK_MODULE 1
#define CONFIG_GPIB_CEC_PCI_MODULE 1
#define CONFIG_USB_XHCI_SIDEBAND 1
#define CONFIG_TOUCHSCREEN_SIS_I2C_MODULE 1
#define CONFIG_VIDEO_UPD64083_MODULE 1
#define CONFIG_AL3320A_MODULE 1
#define CONFIG_DVB_LGDT3305_MODULE 1
#define CONFIG_NET_VENDOR_SEEQ 1
#define CONFIG_IP6_NF_MANGLE_MODULE 1
#define CONFIG_GPIO_MAX732X_MODULE 1
#define CONFIG_PARAVIRT_CLOCK 1
#define CONFIG_LEDS_PCA955X_GPIO 1
#define CONFIG_PAGE_IDLE_FLAG 1
#define CONFIG_CRYPTO_LZ4HC_MODULE 1
#define CONFIG_VHBA_MODULE 1
#define CONFIG_GPIO_TPS65912_MODULE 1
#define CONFIG_TASK_IO_ACCOUNTING 1
#define CONFIG_PSTORE_BLK_KMSG_SIZE 64
#define CONFIG_WLAN 1
#define CONFIG_PTP_DFL_TOD_MODULE 1
#define CONFIG_MITIGATION_TAA 1
#define CONFIG_INET6_AH_MODULE 1
#define CONFIG_MOUSE_PS2_SYNAPTICS_SMBUS 1
#define CONFIG_IEEE802154_6LOWPAN_MODULE 1
#define CONFIG_NET_DSA_TAG_AR9331_MODULE 1
#define CONFIG_TOUCHSCREEN_TSC200X_CORE_MODULE 1
#define CONFIG_DRM_PANEL_ORIENTATION_QUIRKS 1
#define CONFIG_ATH10K_USB_MODULE 1
#define CONFIG_EEPROM_M24LR_MODULE 1
#define CONFIG_CPU_SUP_CENTAUR 1
#define CONFIG_I2C_VIA_MODULE 1
#define CONFIG_SOFTLOCKUP_DETECTOR 1
#define CONFIG_MPRLS0025PA_SPI_MODULE 1
#define CONFIG_BT_HCIUART_BCSP 1
#define CONFIG_ASUS_TF103C_DOCK_MODULE 1
#define CONFIG_WLAN_VENDOR_INTERSIL 1
#define CONFIG_ISL29501_MODULE 1
#define CONFIG_USB4_MODULE 1
#define CONFIG_MS5637_MODULE 1
#define CONFIG_IP_NF_TARGET_TTL_MODULE 1
#define CONFIG_COMMON_CLK_PWM_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_NFQUEUE_MODULE 1
#define CONFIG_KVM_GENERIC_HARDWARE_ENABLING 1
#define CONFIG_SND_HDA_CODEC_ALC268_MODULE 1
#define CONFIG_CHARGER_MAX77705_MODULE 1
#define CONFIG_NETFILTER_XTABLES_LEGACY 1
#define CONFIG_DVB_SP2_MODULE 1
#define CONFIG_SENSORS_NCT7802_MODULE 1
#define CONFIG_SPI_ZYNQMP_GQSPI_MODULE 1
#define CONFIG_REGULATOR_ISL9305_MODULE 1
#define CONFIG_X86_DECODER_SELFTEST 1
#define CONFIG_DVB_AU8522_MODULE 1
#define CONFIG_RTL8192CE_MODULE 1
#define CONFIG_SFC_SRIOV 1
#define CONFIG_IR_FINTEK_MODULE 1
#define CONFIG_DVB_CXD2820R_MODULE 1
#define CONFIG_SENSORS_MP29502_MODULE 1
#define CONFIG_NF_SOCKET_IPV6_MODULE 1
#define CONFIG_KEYBOARD_PINEPHONE_MODULE 1
#define CONFIG_PCIE_DW_HOST 1
#define CONFIG_ARCH_WANT_COMPAT_IPC_PARSE_VERSION 1
#define CONFIG_IWLMLD_MODULE 1
#define CONFIG_USB_MON_MODULE 1
#define CONFIG_SND_SONICVIBES_MODULE 1
#define CONFIG_EXTCON_GPIO_MODULE 1
#define CONFIG_TIPC_DIAG_MODULE 1
#define CONFIG_INTEL_IFS_MODULE 1
#define CONFIG_DAVICOM_PHY_MODULE 1
#define CONFIG_DRM_I915_FENCE_TIMEOUT 10000
#define CONFIG_INET6_XFRM_TUNNEL_MODULE 1
#define CONFIG_TSNEP_MODULE 1
#define CONFIG_NETWORK_SECMARK 1
#define CONFIG_MFD_DLN2_MODULE 1
#define CONFIG_SENSORS_SY7636A_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_NEXIO 1
#define CONFIG_AMD_PMC_MODULE 1
#define CONFIG_BLK_DEV_IO_TRACE 1
#define CONFIG_SND_TRIDENT_MODULE 1
#define CONFIG_SND_OSSEMUL 1
#define CONFIG_SND_SOC_AK4458_MODULE 1
#define CONFIG_HAVE_KLP_BUILD 1
#define CONFIG_HW_RANDOM_BA431_MODULE 1
#define CONFIG_MLXSW_CORE_MODULE 1
#define CONFIG_SND_CMIPCI_MODULE 1
#define CONFIG_PCCARD_NONSTATIC 1
#define CONFIG_CRYPTO_ECDSA 1
#define CONFIG_COMMON_CLK_SI544_MODULE 1
#define CONFIG_DVB_DUMMY_FE_MODULE 1
#define CONFIG_KVM_MODULE 1
#define CONFIG_NFT_FLOW_OFFLOAD_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_CONNLIMIT_MODULE 1
#define CONFIG_DEFAULT_MMAP_MIN_ADDR 65536
#define CONFIG_SENSORS_LM95241_MODULE 1
#define CONFIG_NLS_CODEPAGE_936_MODULE 1
#define CONFIG_SEN0322_MODULE 1
#define CONFIG_GPIO_PCA953X_MODULE 1
#define CONFIG_CRYPTO_CMAC_MODULE 1
#define CONFIG_TRANSPARENT_HUGEPAGE 1
#define CONFIG_AIC7XXX_REG_PRETTY_PRINT 1
#define CONFIG_BT_MSFTEXT 1
#define CONFIG_REGULATOR_RT4803_MODULE 1
#define CONFIG_AD4170_4_MODULE 1
#define CONFIG_TYPEC_RT1711H_MODULE 1
#define CONFIG_WLAN_VENDOR_BROADCOM 1
#define CONFIG_NET_SCH_MULTIQ_MODULE 1
#define CONFIG_TOUCHSCREEN_ZET6223_MODULE 1
#define CONFIG_TOUCHSCREEN_HYNITRON_CSTXXX_MODULE 1
#define CONFIG_BPF_JIT_DEFAULT_ON 1
#define CONFIG_LEDS_LT3593_MODULE 1
#define CONFIG_SERIAL_8250_EXAR_MODULE 1
#define CONFIG_SPI_DW_DMA 1
#define CONFIG_QLCNIC_SRIOV 1
#define CONFIG_ZRAM_WRITEBACK 1
#define CONFIG_NFS_V4_MODULE 1
#define CONFIG_INTEL_ISHTP_ECLITE_MODULE 1
#define CONFIG_DVB_TUNER_ITD1000_MODULE 1
#define CONFIG_SND_SOC_ES7134_MODULE 1
#define CONFIG_NET_NSH_MODULE 1
#define CONFIG_VIDEO_OV4689_MODULE 1
#define CONFIG_HID_GOOGLE_STADIA_FF_MODULE 1
#define CONFIG_HID_LCPOWER_MODULE 1
#define CONFIG_F2FS_FS_SECURITY 1
#define CONFIG_SND_AC97_CODEC_MODULE 1
#define CONFIG_GENEVE_MODULE 1
#define CONFIG_DVB_NXT6000_MODULE 1
#define CONFIG_BLK_DEV_NBD_MODULE 1
#define CONFIG_HID_SENSOR_CUSTOM_SENSOR_MODULE 1
#define CONFIG_ATH9K_WOW 1
#define CONFIG_IIO_ST_GYRO_SPI_3AXIS_MODULE 1
#define CONFIG_KFENCE_NUM_OBJECTS 255
#define CONFIG_IP_SET_HASH_NET_MODULE 1
#define CONFIG_ZPA2326_SPI_MODULE 1
#define CONFIG_I2C_ISMT_MODULE 1
#define CONFIG_KCMP 1
#define CONFIG_RTC_DRV_DS1742_MODULE 1
#define CONFIG_DRM_NOUVEAU_CH7006_MODULE 1
#define CONFIG_SENSORS_ACPI_POWER_MODULE 1
#define CONFIG_XFRM_ALGO_MODULE 1
#define CONFIG_SD_ADC_MODULATOR_MODULE 1
#define CONFIG_NET_VENDOR_STMICRO 1
#define CONFIG_VIDEO_INTEL_IPU6_MODULE 1
#define CONFIG_IPWIRELESS_MODULE 1
#define CONFIG_AX88796B_PHY_MODULE 1
#define CONFIG_EDAC_SKX_MODULE 1
#define CONFIG_AMD_NB 1
#define CONFIG_MUX_CORE 1
#define CONFIG_PWM_LPSS_PCI_MODULE 1
#define CONFIG_IPU_BRIDGE_MODULE 1
#define CONFIG_LEDS_TRIGGER_TTY_MODULE 1
#define CONFIG_BUILD_SALT ""
#define CONFIG_LG_LAPTOP_MODULE 1
#define CONFIG_MFD_CS47L35 1
#define CONFIG_ATH9K_COMMON_SPECTRAL 1
#define CONFIG_SND_BT87X_MODULE 1
#define CONFIG_DRM_XE_PREEMPT_TIMEOUT 640000
#define CONFIG_PERF_EVENTS_AMD_POWER_MODULE 1
#define CONFIG_HID_NINTENDO_MODULE 1
#define CONFIG_X86_INTERNODE_CACHE_SHIFT 6
#define CONFIG_SND_HDA_CODEC_CIRRUS_MODULE 1
#define CONFIG_BH1780_MODULE 1
#define CONFIG_GPIO_EXAR_MODULE 1
#define CONFIG_DUMMY_CONSOLE_ROWS 25
#define CONFIG_GPIO_VX855_MODULE 1
#define CONFIG_NVME_FABRICS_MODULE 1
#define CONFIG_FUNCTION_TRACER 1
#define CONFIG_SURFACE_AGGREGATOR_TABLET_SWITCH_MODULE 1
#define CONFIG_KEYBOARD_TCA8418_MODULE 1
#define CONFIG_MEDIA_CONTROLLER_DVB 1
#define CONFIG_AD5272_MODULE 1
#define CONFIG_DM_DEBUG 1
#define CONFIG_MODPROBE_PATH "/sbin/modprobe"
#define CONFIG_MLXSW_CORE_HWMON 1
#define CONFIG_RTL8187_MODULE 1
#define CONFIG_HID_MEGAWORLD_FF_MODULE 1
#define CONFIG_MCB_LPC_MODULE 1
#define CONFIG_POSIX_MQUEUE 1
#define CONFIG_NV_TCO_MODULE 1
#define CONFIG_SENSORS_POWR1220_MODULE 1
#define CONFIG_I2C_EMEV2_MODULE 1
#define CONFIG_TEXTSEARCH_FSM_MODULE 1
#define CONFIG_VHOST_SCSI_MODULE 1
#define CONFIG_PSTORE_BLK_MODULE 1
#define CONFIG_NFSD_SCSILAYOUT 1
#define CONFIG_RMI4_SMB_MODULE 1
#define CONFIG_AMD_ATL_MODULE 1
#define CONFIG_POWER_RESET_ATC260X_MODULE 1
#define CONFIG_MQ_IOSCHED_DEADLINE 1
#define CONFIG_HAVE_KVM_ARCH_GMEM_INVALIDATE 1
#define CONFIG_HAVE_CLK 1
#define CONFIG_USB_SERIAL_SIERRAWIRELESS_MODULE 1
#define CONFIG_MAC_PARTITION 1
#define CONFIG_SECURITY_APPARMOR_HASH 1
#define CONFIG_SND_SOC_SIMPLE_AMPLIFIER_MODULE 1
#define CONFIG_DRM_AMD_SECURE_DISPLAY 1
#define CONFIG_ARCH_SUPPORTS_RT 1
#define CONFIG_BATTERY_DA9030_MODULE 1
#define CONFIG_DEBUG_FS 1
#define CONFIG_MEDIA_CEC_SUPPORT 1
#define CONFIG_SND_SOC_RT5677_MODULE 1
#define CONFIG_CROS_KBD_LED_BACKLIGHT_MODULE 1
#define CONFIG_RTC_DRV_DS1307_MODULE 1
#define CONFIG_PPTP_MODULE 1
#define CONFIG_INTEL_MEI_TXE_MODULE 1
#define CONFIG_FUTEX 1
#define CONFIG_DM_VDO_MODULE 1
#define CONFIG_USB_ETH_EEM 1
#define CONFIG_HID_GLORIOUS_MODULE 1
#define CONFIG_TSYS01_MODULE 1
#define CONFIG_TOUCHSCREEN_WACOM_W8001_MODULE 1
#define CONFIG_IP_SET_MAX 256
#define CONFIG_ASYNC_CORE_MODULE 1
#define CONFIG_ADXL345_I2C_MODULE 1
#define CONFIG_CRYPTO_SM4_MODULE 1
#define CONFIG_RTW88_DEBUG 1
#define CONFIG_ADIS16475_MODULE 1
#define CONFIG_SND_SOC_MAX98504_MODULE 1
#define CONFIG_ATALK_MODULE 1
#define CONFIG_NF_TABLES_INET 1
#define CONFIG_TCM_USER2_MODULE 1
#define CONFIG_VIDEO_TDA9840_MODULE 1
#define CONFIG_NEED_PER_CPU_EMBED_FIRST_CHUNK 1
#define CONFIG_RTC_DRV_TPS65910_MODULE 1
#define CONFIG_SND_SOC_ZL38060_MODULE 1
#define CONFIG_JOYSTICK_XPAD_LEDS 1
#define CONFIG_RTC_DRV_DS1685 1
#define CONFIG_USB_LCD_MODULE 1
#define CONFIG_NTB_MSI 1
#define CONFIG_CM3232_MODULE 1
#define CONFIG_ARCH_HAS_CURRENT_STACK_POINTER 1
#define CONFIG_SENSORS_CHIPCAP2_MODULE 1
#define CONFIG_FB_SYSMEM_HELPERS 1
#define CONFIG_REGULATOR_LP8755_MODULE 1
#define CONFIG_MAX63XX_WATCHDOG_MODULE 1
#define CONFIG_SERIAL_8250_PNP 1
#define CONFIG_USBIP_VHCI_NR_HCS 1
#define CONFIG_SND_SOC_AMD_ACP_PCI_MODULE 1
#define CONFIG_UNIWILL_LAPTOP_MODULE 1
#define CONFIG_PCMCIA_SYM53C500_MODULE 1
#define CONFIG_DELL_WMI_DDV_MODULE 1
#define CONFIG_BE2NET_LANCER 1
#define CONFIG_AD2S90_MODULE 1
#define CONFIG_USB_ETH_RNDIS 1
#define CONFIG_ADIS16460_MODULE 1
#define CONFIG_HAVE_FUNCTION_ERROR_INJECTION 1
#define CONFIG_CAN_CTUCANFD_PCI_MODULE 1
#define CONFIG_RADIO_SHARK_MODULE 1
#define CONFIG_LEDS_BD2606MVV_MODULE 1
#define CONFIG_XILINX_XADC_MODULE 1
#define CONFIG_PINCTRL_DENVERTON_MODULE 1
#define CONFIG_TOUCHSCREEN_PIXCIR_MODULE 1
#define CONFIG_SND_SOC_CX2072X_MODULE 1
#define CONFIG_JOYSTICK_SENSEHAT_MODULE 1
#define CONFIG_SENSORS_MAX1668_MODULE 1
#define CONFIG_MEGARAID_MM_MODULE 1
#define CONFIG_SND_SOC_ADAU7118_I2C_MODULE 1
#define CONFIG_ROHM_BD79124_MODULE 1
#define CONFIG_HAS_DMA 1
#define CONFIG_FB_VESA 1
#define CONFIG_SOFTIRQ_ON_OWN_STACK 1
#define CONFIG_OPT3001_MODULE 1
#define CONFIG_SENSORS_TDA38640_MODULE 1
#define CONFIG_SND_MONA_MODULE 1
#define CONFIG_W1_SLAVE_DS2413_MODULE 1
#define CONFIG_MLX4_EN_MODULE 1
#define CONFIG_ARCH_WANT_BATCHED_UNMAP_TLB_FLUSH 1
#define CONFIG_SX9324_MODULE 1
#define CONFIG_LENOVO_WMI_EVENTS_MODULE 1
#define CONFIG_DRM_XEN_FRONTEND_MODULE 1
#define CONFIG_USE_X86_SEG_SUPPORT 1
#define CONFIG_CRYPTO_USER_API_MODULE 1
#define CONFIG_AUDITSYSCALL 1
#define CONFIG_REGULATOR_MAX8907_MODULE 1
#define CONFIG_SND_SOC_AMD_ST_ES8336_MACH_MODULE 1
#define CONFIG_STACKDEPOT 1
#define CONFIG_CHARGER_LTC4162L_MODULE 1
#define CONFIG_IP_SET_BITMAP_IPMAC_MODULE 1
#define CONFIG_SND_HDA_CODEC_ALC269_MODULE 1
#define CONFIG_SND_SOC_TLV320AIC3X_MODULE 1
#define CONFIG_KEBA_LAN9252_MODULE 1
#define CONFIG_PHY_PXA_28NM_HSIC_MODULE 1
#define CONFIG_USB_USS720_MODULE 1
#define CONFIG_PTP_1588_CLOCK_OCP_MODULE 1
#define CONFIG_INFINIBAND_IONIC_MODULE 1
#define CONFIG_ARCH_HAS_ACPI_TABLE_UPGRADE 1
#define CONFIG_MAX11100_MODULE 1
#define CONFIG_USB_CDNS_SUPPORT_MODULE 1
#define CONFIG_TOUCHSCREEN_TOUCHIT213_MODULE 1
#define CONFIG_GENERIC_BUG 1
#define CONFIG_XFS_MEMORY_BUFS 1
#define CONFIG_TEE_DMABUF_HEAPS 1
#define CONFIG_IP_VS_MODULE 1
#define CONFIG_SND_LOLA_MODULE 1
#define CONFIG_MOUSE_ELAN_I2C_I2C 1
#define CONFIG_USB_WDM_MODULE 1
#define CONFIG_TCP_CONG_ILLINOIS_MODULE 1
#define CONFIG_CXL_ATL 1
#define CONFIG_GPIO_PISOSR_MODULE 1
#define CONFIG_BT_RFCOMM_TTY 1
#define CONFIG_BT_ATH3K_MODULE 1
#define CONFIG_AD3552R_MODULE 1
#define CONFIG_VFIO_DEBUGFS 1
#define CONFIG_USBIP_CORE_MODULE 1
#define CONFIG_UNION_FIND 1
#define CONFIG_BRCMUTIL_MODULE 1
#define CONFIG_BTRFS_FS 1
#define CONFIG_KVFREE_RCU_BATCHED 1
#define CONFIG_HID_HUAWEI_MODULE 1
#define CONFIG_SND_HDA_CODEC_REALTEK_MODULE 1
#define CONFIG_DRM_I915_GVT 1
#define CONFIG_MFD_INTEL_PMC_BXT_MODULE 1
#define CONFIG_IP_VS_IPV6 1
#define CONFIG_REGULATOR_TPS65910_MODULE 1
#define CONFIG_CPU_FREQ_GOV_COMMON 1
#define CONFIG_PPP_MPPE_MODULE 1
#define CONFIG_SCSI_QLA_FC_MODULE 1
#define CONFIG_HAVE_ALIGNED_STRUCT_PAGE 1
#define CONFIG_THUNDER_NIC_VF_MODULE 1
#define CONFIG_CB710_CORE_MODULE 1
#define CONFIG_FUSE_IO_URING 1
#define CONFIG_SCHED_OMIT_FRAME_POINTER 1
#define CONFIG_CEPH_LIB_MODULE 1
#define CONFIG_LEGACY_DIRECT_IO 1
#define CONFIG_BATMAN_ADV_MCAST 1
#define CONFIG_LOCK_SPIN_ON_OWNER 1
#define CONFIG_HAVE_PERF_USER_STACK_DUMP 1
#define CONFIG_SENSORS_ASB100_MODULE 1
#define CONFIG_GPIO_IDIO_16_MODULE 1
#define CONFIG_NVME_CORE_MODULE 1
#define CONFIG_NVME_VERBOSE_ERRORS 1
#define CONFIG_GPIB_MODULE 1
#define CONFIG_AMD_PHY_MODULE 1
#define CONFIG_USB_PCI_AMD 1
#define CONFIG_VIDEO_OV13B10_MODULE 1
#define CONFIG_SENSORS_AXI_FAN_CONTROL_MODULE 1
#define CONFIG_NF_CT_NETLINK_TIMEOUT_MODULE 1
#define CONFIG_OPTPROBES 1
#define CONFIG_B43LEGACY_DMA 1
#define CONFIG_SKB_EXTENSIONS 1
#define CONFIG_HUGETLB_PAGE 1
#define CONFIG_DEBUG_RODATA_TEST 1
#define CONFIG_SND_SOC_TAS5805M_MODULE 1
#define CONFIG_HMEM_REPORTING 1
#define CONFIG_SND_SOC_ES8328_SPI_MODULE 1
#define CONFIG_SND_SOC_MAX98088_MODULE 1
#define CONFIG_XFRM_INTERFACE_MODULE 1
#define CONFIG_HAVE_ARCH_RANDOMIZE_KSTACK_OFFSET 1
#define CONFIG_LEDS_LP8788_MODULE 1
#define CONFIG_SERIAL_CORE 1
#define CONFIG_SND_SOC_WM8580_MODULE 1
#define CONFIG_DVB_USB_GP8PSK_MODULE 1
#define CONFIG_HOTPLUG_PCI_PCIE 1
#define CONFIG_NFS_USE_KERNEL_DNS 1
#define CONFIG_MLX_WDT_MODULE 1
#define CONFIG_SPI_LOOPBACK_TEST_MODULE 1
#define CONFIG_USB_OXU210HP_HCD_MODULE 1
#define CONFIG_NO_HZ_FULL 1
#define CONFIG_PINCTRL_CS47L15 1
#define CONFIG_CAN_SOFTING_CS_MODULE 1
#define CONFIG_SENSORS_MP5023_MODULE 1
#define CONFIG_SND_SOC_SDCA_OPTIONAL_MODULE 1
#define CONFIG_DRM_I915_CAPTURE_ERROR 1
#define CONFIG_TAHVO_USB_MODULE 1
#define CONFIG_SND_SOC_CS35L45_I2C_MODULE 1
#define CONFIG_LEDS_TRIGGERS 1
#define CONFIG_NET_SCH_TBF_MODULE 1
#define CONFIG_SECURITY_NETWORK_XFRM 1
#define CONFIG_BRCMSMAC_MODULE 1
#define CONFIG_CAN_MCP251X_MODULE 1
#define CONFIG_UBIFS_FS_LZO 1
#define CONFIG_SND_SOC_WM8731_MODULE 1
#define CONFIG_SENSORS_LTC2945_MODULE 1
#define CONFIG_INTEL_TDX_GUEST 1
#define CONFIG_EROFS_FS_ZIP_ACCEL 1
#define CONFIG_INTEL_ISH_HID_MODULE 1
#define CONFIG_TI_ADS1119_MODULE 1
#define CONFIG_MLX5_CORE_MODULE 1
#define CONFIG_GENERIC_IRQ_STAT_SNAPSHOT 1
#define CONFIG_NET_KEY_MODULE 1
#define CONFIG_REMOTE_TARGET_MODULE 1
#define CONFIG_SERIAL_MCTRL_GPIO 1
#define CONFIG_ZIIRAVE_WATCHDOG_MODULE 1
#define CONFIG_SND_SOC_SIGMADSP_I2C_MODULE 1
#define CONFIG_NET_DSA_TAG_HELLCREEK_MODULE 1
#define CONFIG_THERMAL_GOV_POWER_ALLOCATOR 1
#define CONFIG_SERIO_PARKBD_MODULE 1
#define CONFIG_USB_GSPCA_ZC3XX_MODULE 1
#define CONFIG_MMC_TOSHIBA_PCI_MODULE 1
#define CONFIG_X86_MSR 1
#define CONFIG_CRYPTO_CCM_MODULE 1
#define CONFIG_SATA_PROMISE_MODULE 1
#define CONFIG_SCSI_INIA100_MODULE 1
#define CONFIG_VIDEO_INTEL_IPU7_MODULE 1
#define CONFIG_QLCNIC_MODULE 1
#define CONFIG_EROFS_FS_ZIP_DEFLATE 1
#define CONFIG_IP_VS_NQ_MODULE 1
#define CONFIG_PRESTERA_PCI_MODULE 1
#define CONFIG_CODA_FS_MODULE 1
#define CONFIG_SPEAKUP_SYNTH_AUDPTR_MODULE 1
#define CONFIG_KEYBOARD_IQS62X_MODULE 1
#define CONFIG_XEN_DEV_EVTCHN_MODULE 1
#define CONFIG_DWC_XLGMAC_PCI_MODULE 1
#define CONFIG_INTEL_CHTWC_INT33FE_MODULE 1
#define CONFIG_SND_RAWMIDI_MODULE 1
#define CONFIG_JOYSTICK_SIDEWINDER_MODULE 1
#define CONFIG_SND_SOC_INTEL_SOF_PCM512x_MACH_MODULE 1
#define CONFIG_GENERIC_GETTIMEOFDAY 1
#define CONFIG_TOUCHSCREEN_WM9705 1
#define CONFIG_ARCH_SUPPORTS_KEXEC_JUMP 1
#define CONFIG_IP_SET_HASH_IPMARK_MODULE 1
#define CONFIG_IIO_CROS_EC_SENSORS_MODULE 1
#define CONFIG_PINCTRL_JASPERLAKE_MODULE 1
#define CONFIG_FW_UPLOAD 1
#define CONFIG_HAVE_KVM_NO_POLL 1
#define CONFIG_ATM_SOLOS_MODULE 1
#define CONFIG_QEDE_MODULE 1
#define CONFIG_SND_USB 1
#define CONFIG_NET_DSA_SJA1105_PTP 1
#define CONFIG_NET_ACT_CT_MODULE 1
#define CONFIG_INTEL_PMC_SSRAM_TELEMETRY_MODULE 1
#define CONFIG_VIDEO_CX18_ALSA_MODULE 1
#define CONFIG_USB_GSPCA_TV8532_MODULE 1
#define CONFIG_DPTF_POWER_MODULE 1
#define CONFIG_DVB_USB_RTL28XXU_MODULE 1
#define CONFIG_ARCH_MIGHT_HAVE_ACPI_PDC 1
#define CONFIG_PCS_XPCS_MODULE 1
#define CONFIG_CAN_C_CAN_MODULE 1
#define CONFIG_SND_SOC_INTEL_SOF_DA7219_MACH_MODULE 1
#define CONFIG_ND_CLAIM 1
#define CONFIG_BRCMFMAC_PROTO_MSGBUF 1
#define CONFIG_GPIO_CDEV_V1 1
#define CONFIG_SYN_COOKIES 1
#define CONFIG_SND_SOC_SIGMADSP_MODULE 1
#define CONFIG_INFINIBAND_IPOIB_CM 1
#define CONFIG_ARCH_HAS_FORTIFY_SOURCE 1
#define CONFIG_DRM_PANIC_SCREEN_QR_VERSION 40
#define CONFIG_MT7663S_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_SCTP_MODULE 1
#define CONFIG_HID_GEMBIRD_MODULE 1
#define CONFIG_NF_FLOW_TABLE_MODULE 1
#define CONFIG_CRYPTO_SHA3 1
#define CONFIG_NFC_SIM_MODULE 1
#define CONFIG_SND_PCMTEST_MODULE 1
#define CONFIG_NET_VENDOR_QUALCOMM 1
#define CONFIG_STACKTRACE_SUPPORT 1
#define CONFIG_WIRELESS_EXT 1
#define CONFIG_JOYSTICK_ADC_MODULE 1
#define CONFIG_SND_SOC_HDA_MODULE 1
#define CONFIG_CRYPTO_LIB_AES_ARCH 1
#define CONFIG_NFT_DUP_IPV4_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_CONNMARK_MODULE 1
#define CONFIG_PCIEASPM_DEFAULT 1
#define CONFIG_USB_EHSET_TEST_FIXTURE_MODULE 1
#define CONFIG_FPGA_MODULE 1
#define CONFIG_SND_MODULE 1
#define CONFIG_SENSORS_W83627EHF_MODULE 1
#define CONFIG_SENSORS_IR38064_MODULE 1
#define CONFIG_MEGARAID_LEGACY_MODULE 1
#define CONFIG_MD_LINEAR_MODULE 1
#define CONFIG_SND_SOC_INTEL_HDA_DSP_COMMON_MODULE 1
#define CONFIG_CRYPTO_AEAD_MODULE 1
#define CONFIG_IEEE802154_MRF24J40_MODULE 1
#define CONFIG_BCMGENET_MODULE 1
#define CONFIG_MAX31856_MODULE 1
#define CONFIG_CHARGER_RT9471_MODULE 1
#define CONFIG_ACPI_QUICKSTART_MODULE 1
#define CONFIG_BLK_DEV_THROTTLING 1
#define CONFIG_PDS_VFIO_PCI_MODULE 1
#define CONFIG_NET_DSA_TAG_LAN9303_MODULE 1
#define CONFIG_CHTCRC_PMIC_OPREGION 1
#define CONFIG_SND_SOC_ADAU_UTILS_MODULE 1
#define CONFIG_SECTION_MISMATCH_WARN_ONLY 1
#define CONFIG_ASYNC_XOR_MODULE 1
#define CONFIG_INTEL_IOMMU 1
#define CONFIG_PROC_CHILDREN 1
#define CONFIG_INET_MPTCP_DIAG_MODULE 1
#define CONFIG_FPGA_DFL_AFU_MODULE 1
#define CONFIG_DRM_DISPLAY_HDCP_HELPER 1
#define CONFIG_CC_IS_GCC 1
#define CONFIG_SQUASHFS_FILE_DIRECT 1
#define CONFIG_GPIO_TPS65910 1
#define CONFIG_SND_SOC_INTEL_SOF_NAU8825_MACH_MODULE 1
#define CONFIG_VSOCKETS_LOOPBACK_MODULE 1
#define CONFIG_MPL115_SPI_MODULE 1
#define CONFIG_KEYBOARD_SUNKBD_MODULE 1
#define CONFIG_VIDEO_MXB_MODULE 1
#define CONFIG_BLK_DEV_UBLK_MODULE 1
#define CONFIG_ARCH_HAS_SYNC_CORE_BEFORE_USERMODE 1
#define CONFIG_CARDBUS 1
#define CONFIG_RTW89_DEBUGFS 1
#define CONFIG_SENSORS_IIO_HWMON_MODULE 1
#define CONFIG_HAVE_CMPXCHG_LOCAL 1
#define CONFIG_JOYSTICK_COBRA_MODULE 1
#define CONFIG_HID_APPLETB_BL_MODULE 1
#define CONFIG_INITRAMFS_PRESERVE_MTIME 1
#define CONFIG_DELL_LAPTOP_MODULE 1
#define CONFIG_X86_HV_CALLBACK_VECTOR 1
#define CONFIG_MLXREG_IO_MODULE 1
#define CONFIG_BLK_DEV_3W_XXXX_RAID_MODULE 1
#define CONFIG_X86_X2APIC 1
#define CONFIG_FPGA_MGR_ALTERA_PS_SPI_MODULE 1
#define CONFIG_ADIS16260_MODULE 1
#define CONFIG_RPMB_MODULE 1
#define CONFIG_IPV6_ROUTER_PREF 1
#define CONFIG_CGROUP_SCHED 1
#define CONFIG_DMA_ENGINE 1
#define CONFIG_VIRTIO_DEBUG 1
#define CONFIG_FPGA_REGION_MODULE 1
#define CONFIG_DA280_MODULE 1
#define CONFIG_AMD_ISP_PLATFORM_MODULE 1
#define CONFIG_SENSORS_RM3100_SPI_MODULE 1
#define CONFIG_XEN_WDT_MODULE 1
#define CONFIG_MAX44009_MODULE 1
#define CONFIG_SND_VIA82XX_MODULE 1
#define CONFIG_DVB_TDA10048_MODULE 1
#define CONFIG_SENSIRION_SGP30_MODULE 1
#define CONFIG_EARLY_PRINTK 1
#define CONFIG_F2FS_FS_COMPRESSION 1
#define CONFIG_IP_SET_HASH_MAC_MODULE 1
#define CONFIG_MFD_CS47L85 1
#define CONFIG_NET_DSA_LOOP_MODULE 1
#define CONFIG_CRYPTO_CRC32C 1
#define CONFIG_PM_STD_PARTITION ""
#define CONFIG_MOUSE_PS2_ELANTECH_SMBUS 1
#define CONFIG_L2TP_IP_MODULE 1
#define CONFIG_WATCHDOG_PRETIMEOUT_DEFAULT_GOV_PANIC 1
#define CONFIG_DM_ZONED_MODULE 1
#define CONFIG_SND_INDIGODJ_MODULE 1
#define CONFIG_CHARGER_SBS_MODULE 1
#define CONFIG_RD_BZIP2 1
#define CONFIG_SCSI_3W_9XXX_MODULE 1
#define CONFIG_AD5446_I2C_MODULE 1
#define CONFIG_WILCO_EC_TELEMETRY_MODULE 1
#define CONFIG_NLS_CODEPAGE_1250_MODULE 1
#define CONFIG_GPIO_IT87_MODULE 1
#define CONFIG_MEDIA_TUNER_MAX2165_MODULE 1
#define CONFIG_DVB_LNBP22_MODULE 1
#define CONFIG_ECRYPT_FS_MODULE 1
#define CONFIG_DRM_RAS 1
#define CONFIG_FRAMEBUFFER_CONSOLE_DEFERRED_TAKEOVER 1
#define CONFIG_PHYS_ADDR_T_64BIT 1
#define CONFIG_USB_F_NCM_MODULE 1
#define CONFIG_UVC_COMMON_MODULE 1
#define CONFIG_HAVE_FUNCTION_GRAPH_TRACER 1
#define CONFIG_BPF_UNPRIV_DEFAULT_OFF 1
#define CONFIG_USB_GSPCA_OV534_9_MODULE 1
#define CONFIG_SERIAL_8250_MID_MODULE 1
#define CONFIG_MFD_TPS6594_I2C_MODULE 1
#define CONFIG_SCSI_IPR_TRACE 1
#define CONFIG_CGROUP_BPF 1
#define CONFIG_ANDROID_BINDER_IPC_RUST 1
#define CONFIG_MT76_LEDS 1
#define CONFIG_IIO_ST_LSM9DS0_SPI_MODULE 1
#define CONFIG_BT_AOSPEXT 1
#define CONFIG_NET_SCH_CBS_MODULE 1
#define CONFIG_INFINIBAND_ERDMA_MODULE 1
#define CONFIG_SND_SOC_TDA7419_MODULE 1
#define CONFIG_HIDRAW 1
#define CONFIG_X86_MCE 1
#define CONFIG_MSPRO_BLOCK_MODULE 1
#define CONFIG_ADP810_MODULE 1
#define CONFIG_DVB_USB_AF9005_REMOTE_MODULE 1
#define CONFIG_CRYPTO_DES_MODULE 1
#define CONFIG_SMI330_SPI_MODULE 1
#define CONFIG_IR_NEC_DECODER_MODULE 1
#define CONFIG_LOCK_DEBUGGING_SUPPORT 1
#define CONFIG_VIDEOBUF2_DMA_CONTIG_MODULE 1
#define CONFIG_ATH10K_PCI_MODULE 1
#define CONFIG_MCTP 1
#define CONFIG_SBC_EPX_C3_WATCHDOG_MODULE 1
#define CONFIG_SCSI_ISCSI_ATTRS_MODULE 1
#define CONFIG_SECURITY_SELINUX_SID2STR_CACHE_SIZE 256
#define CONFIG_TWL6030_GPADC_MODULE 1
#define CONFIG_SERIAL_UARTLITE_NR_UARTS 1
#define CONFIG_P54_LEDS 1
#define CONFIG_BUG 1
#define CONFIG_USB_EG20T_MODULE 1
#define CONFIG_JFFS2_RTIME 1
#define CONFIG_DVB_AU8522_V4L_MODULE 1
#define CONFIG_QCOM_TZMEM_MODE_GENERIC 1
#define CONFIG_IPVTAP_MODULE 1
#define CONFIG_SPI_LM70_LLP_MODULE 1
#define CONFIG_SND_SOC_INTEL_SOF_WM8804_MACH_MODULE 1
#define CONFIG_VIDEO_MT9P031_MODULE 1
#define CONFIG_M62332_MODULE 1
#define CONFIG_MEMORY 1
#define CONFIG_GDB_SCRIPTS 1
#define CONFIG_SENSORS_ABITUGURU_MODULE 1
#define CONFIG_TTPCI_EEPROM_MODULE 1
#define CONFIG_SND_SOC_RT715_MODULE 1
#define CONFIG_NET_VENDOR_SYNOPSYS 1
#define CONFIG_ARCH_HAS_GCOV_PROFILE_ALL 1
#define CONFIG_DMARD09_MODULE 1
#define CONFIG_AF_KCM_MODULE 1
#define CONFIG_SND_SYNTH_EMUX_MODULE 1
#define CONFIG_INPUT_MMA8450_MODULE 1
#define CONFIG_INTEL_RST_MODULE 1
#define CONFIG_MFD_MAX8907_MODULE 1
#define CONFIG_SENSORS_XDPE1A2G7B_MODULE 1
#define CONFIG_SND_SOC_INTEL_SOF_SSP_AMP_MACH_MODULE 1
#define CONFIG_PATA_RADISYS_MODULE 1
#define CONFIG_NFC_SHDLC 1
#define CONFIG_XZ_DEC_BCJ 1
#define CONFIG_USB_SERIAL_OTI6858_MODULE 1
#define CONFIG_QRTR_TUN_MODULE 1
#define CONFIG_DRM_KMS_HELPER 1
#define CONFIG_MOUSE_PS2_BYD 1
#define CONFIG_CHELSIO_T4_DCB 1
#define CONFIG_SND_SOC_HDAC_HDA_MODULE 1
#define CONFIG_SENSORS_DA9055_MODULE 1
#define CONFIG_TCS3472_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_TCPOPTSTRIP_MODULE 1
#define CONFIG_HAVE_ARCH_USERFAULTFD_WP 1
#define CONFIG_FB_SYSMEM_FOPS 1
#define CONFIG_X86_MCE_INTEL 1
#define CONFIG_SND_SOC_SOF_INTEL_CNL_MODULE 1
#define CONFIG_PAGE_REPORTING 1
#define CONFIG_MOUSE_PS2_TRACKPOINT 1
#define CONFIG_SCHED_HRTICK 1
#define CONFIG_TRACING_SUPPORT 1
#define CONFIG_INFINIBAND_BNXT_RE_MODULE 1
#define CONFIG_WILCO_EC_EVENTS_MODULE 1
#define CONFIG_IOMMU_MM_DATA 1
#define CONFIG_MPLS 1
#define CONFIG_SERIAL_SC16IS7XX_I2C_MODULE 1
#define CONFIG_STACK_TRACER 1
#define CONFIG_SND_UMP_LEGACY_RAWMIDI 1
#define CONFIG_MAX1118_MODULE 1
#define CONFIG_USB_F_SS_LB_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_HL_MODULE 1
#define CONFIG_ISA_DMA_API 1
#define CONFIG_NET_ACT_SKBMOD_MODULE 1
#define CONFIG_LEDS_LP50XX_MODULE 1
#define CONFIG_USB_EHCI_PCI 1
#define CONFIG_EDAC_PND2_MODULE 1
#define CONFIG_CHARGER_ADP5061_MODULE 1
#define CONFIG_MFD_RT5033_MODULE 1
#define CONFIG_DRM_DISPLAY_DP_TUNNEL 1
#define CONFIG_ACPI_HMAT 1
#define CONFIG_RUST_OVERFLOW_CHECKS 1
#define CONFIG_ADXL345_MODULE 1
#define CONFIG_REGULATOR_RT5120_MODULE 1
#define CONFIG_GNSS_SIRF_SERIAL_MODULE 1
#define CONFIG_IP_SET_HASH_IP_MODULE 1
#define CONFIG_VIRTIO_MENU 1
#define CONFIG_RTC_DRV_RX8581_MODULE 1
#define CONFIG_SND_SOC_SOF_HDA_AUDIO_CODEC 1
#define CONFIG_SND_SOC_AMD_PS_MACH_MODULE 1
#define CONFIG_BRIDGE_MRP 1
#define CONFIG_NVME_TARGET_TCP_TLS 1
#define CONFIG_SURFACE_PRO3_BUTTON_MODULE 1
#define CONFIG_NET_VENDOR_CADENCE 1
#define CONFIG_NFT_BRIDGE_META_MODULE 1
#define CONFIG_SPLIT_PTE_PTLOCKS 1
#define CONFIG_SND_SOC_RT9120_MODULE 1
#define CONFIG_BLK_DEV_WRITE_MOUNTED 1
#define CONFIG_CRYPTO_DEV_NITROX_CNN55XX_MODULE 1
#define CONFIG_NET_VENDOR_BROCADE 1
#define CONFIG_HAVE_ARCH_KSTACK_ERASE 1
#define CONFIG_MT76x02_USB_MODULE 1
#define CONFIG_USB_NET_SMSC75XX_MODULE 1
#define CONFIG_ROMFS_BACKED_BY_BLOCK 1
#define CONFIG_SENSORS_K10TEMP_MODULE 1
#define CONFIG_RTC_DRV_DS1305_MODULE 1
#define CONFIG_SENSORS_BH1770_MODULE 1
#define CONFIG_ALTERA_PR_IP_CORE_MODULE 1
#define CONFIG_ADXL372_MODULE 1
#define CONFIG_DRM_ST7571_MODULE 1
#define CONFIG_SURFACE_ACPI_NOTIFY_MODULE 1
#define CONFIG_MCB_PCI_MODULE 1
#define CONFIG_HAVE_IOREMAP_PROT 1
#define CONFIG_CC_NO_STRINGOP_OVERFLOW 1
#define CONFIG_SECURITY_APPARMOR 1
#define CONFIG_DRM_UDL_MODULE 1
#define CONFIG_LEDS_TRIGGER_TIMER_MODULE 1
#define CONFIG_MMC_REALTEK_USB_MODULE 1
#define CONFIG_INTEGRITY_AUDIT 1
#define CONFIG_VIRTIO_FS 1
#define CONFIG_B53_MMAP_DRIVER_MODULE 1
#define CONFIG_SECURITY_SMACK_NETFILTER 1
#define CONFIG_TOUCHSCREEN_AD7879_MODULE 1
#define CONFIG_NET_SELFTESTS_MODULE 1
#define CONFIG_ARCH_SUPPORTS_MEMORY_FAILURE 1
#define CONFIG_CRASH_HOTPLUG 1
#define CONFIG_DW_DMAC_MODULE 1
#define CONFIG_SND_SOC_SOF_AMD_SOUNDWIRE_MODULE 1
#define CONFIG_SENSORS_GL520SM_MODULE 1
#define CONFIG_USB_CONFIGFS_F_LB_SS 1
#define CONFIG_CRYPTO_DEV_ATMEL_I2C_MODULE 1
#define CONFIG_CC10001_ADC_MODULE 1
#define CONFIG_ARCH_WANT_PMD_MKWRITE 1
#define CONFIG_USB_SERIAL_QCAUX_MODULE 1
#define CONFIG_SENSORS_AD7314_MODULE 1
#define CONFIG_6LOWPAN_DEBUGFS 1
#define CONFIG_I2C_STUB_MODULE 1
#define CONFIG_NET_DSA_MSCC_FELIX_DSA_LIB_MODULE 1
#define CONFIG_SND_SOC_AMD_MACH_COMMON_MODULE 1
#define CONFIG_MOST_MODULE 1
#define CONFIG_BATTERY_DA9150_MODULE 1
#define CONFIG_USB_SERIAL_GARMIN_MODULE 1
#define CONFIG_MITIGATION_RFDS 1
#define CONFIG_LCD_TDO24M_MODULE 1
#define CONFIG_SIEMENS_SIMATIC_IPC_BATT_ELKHARTLAKE_MODULE 1
#define CONFIG_CHT_DC_TI_PMIC_OPREGION 1
#define CONFIG_NET_DSA_MXL862_MODULE 1
#define CONFIG_INTEL_PMT_TELEMETRY_MODULE 1
#define CONFIG_USB_CYPRESS_CY7C63_MODULE 1
#define CONFIG_QLA3XXX_MODULE 1
#define CONFIG_AS_HAS_NON_CONST_ULEB128 1
#define CONFIG_AD525X_DPOT_SPI_MODULE 1
#define CONFIG_RTL8187_LEDS 1
#define CONFIG_F2FS_UNFAIR_RWSEM 1
#define CONFIG_US5182D_MODULE 1
#define CONFIG_INTEL_SOC_DTS_IOSF_CORE_MODULE 1
#define CONFIG_CHARGER_RT9467_MODULE 1
#define CONFIG_LLD_VERSION 0
#define CONFIG_ENS210_MODULE 1
#define CONFIG_PINCTRL_CHERRYVIEW 1
#define CONFIG_USB_STORAGE_ONETOUCH_MODULE 1
#define CONFIG_REMOTEPROC 1
#define CONFIG_I2C_VIAPRO_MODULE 1
#define CONFIG_OCFS2_FS_O2CB_MODULE 1
#define CONFIG_6LOWPAN_NHC_DEST_MODULE 1
#define CONFIG_W1_MODULE 1
#define CONFIG_ALTERA_MBOX_MODULE 1
#define CONFIG_CRYPTO_HASH 1
#define CONFIG_MOST_NET_MODULE 1
#define CONFIG_SND_USB_UA101_MODULE 1
#define CONFIG_GROUP_SCHED_BANDWIDTH 1
#define CONFIG_SND_SOC_AMD_RENOIR_MODULE 1
#define CONFIG_MLXSW_CORE_THERMAL 1
#define CONFIG_MTD_INTEL_DG_MODULE 1
#define CONFIG_CRYPTO_AUTHENC_MODULE 1
#define CONFIG_DRM_CLIENT_LIB 1
#define CONFIG_ARCH_ENABLE_MEMORY_HOTPLUG 1
#define CONFIG_NET_ACT_GACT_MODULE 1
#define CONFIG_MEDIA_ATTACH 1
#define CONFIG_IIO_ST_SENSORS_SPI_MODULE 1
#define CONFIG_TOUCHSCREEN_ATMEL_MXT_T37 1
#define CONFIG_DRM_XE_DISPLAY 1
#define CONFIG_VIDEO_VICODEC_MODULE 1
#define CONFIG_IP_NF_TARGET_NETMAP_MODULE 1
#define CONFIG_USB_DWC3_HAPS_MODULE 1
#define CONFIG_IP_NF_MANGLE_MODULE 1
#define CONFIG_IIO_ST_ACCEL_I2C_3AXIS_MODULE 1
#define CONFIG_NF_CONNTRACK_SANE_MODULE 1
#define CONFIG_MD_BITMAP 1
#define CONFIG_NETFILTER_XT_MATCH_DEVGROUP_MODULE 1
#define CONFIG_IP6_NF_MATCH_EUI64_MODULE 1
#define CONFIG_SERIAL_ARC_MODULE 1
#define CONFIG_THUNDER_NIC_RGX_MODULE 1
#define CONFIG_ATL1_MODULE 1
#define CONFIG_RPMSG_QCOM_GLINK_RPM_MODULE 1
#define CONFIG_SND_AMD_SOUNDWIRE_ACPI_MODULE 1
#define CONFIG_DAX 1
#define CONFIG_GOOGLE_FIRMWARE 1
#define CONFIG_MEMREGION 1
#define CONFIG_INTEL_RAPL_CORE_MODULE 1
#define CONFIG_LEDS_SGM3140_MODULE 1
#define CONFIG_IOSM_MODULE 1
#define CONFIG_TCP_CONG_WESTWOOD_MODULE 1
#define CONFIG_SND_SOC_TAS2764_MODULE 1
#define CONFIG_ACPI_EC 1
#define CONFIG_NETFILTER_EGRESS 1
#define CONFIG_NFC_S3FWRN82_UART_MODULE 1
#define CONFIG_IR_NUVOTON_MODULE 1
#define CONFIG_L2TP_V3 1
#define CONFIG_USB_G_ACM_MS_MODULE 1
#define CONFIG_SENSORS_MAX15301_MODULE 1
#define CONFIG_BD79703_MODULE 1
#define CONFIG_I2C_HID_OF_MODULE 1
#define CONFIG_DVB_USB_AU6610_MODULE 1
#define CONFIG_SYSTEM_TRUSTED_KEYS ""
#define CONFIG_LEDS_MT6323_MODULE 1
#define CONFIG_CHARGER_SMB347_MODULE 1
#define CONFIG_SND_SOC_AMD_VANGOGH_MACH_MODULE 1
#define CONFIG_IP_MROUTE_MULTIPLE_TABLES 1
#define CONFIG_NET_DSA_TAG_BRCM_COMMON_MODULE 1
#define CONFIG_FPGA_MGR_ALTERA_CVP_MODULE 1
#define CONFIG_NLS_CODEPAGE_1251_MODULE 1
#define CONFIG_HID_PRODIKEYS_MODULE 1
#define CONFIG_DRM_SSD130X_SPI_MODULE 1
#define CONFIG_NTB_EPF_MODULE 1
#define CONFIG_NVIDIA_WMI_EC_BACKLIGHT_MODULE 1
#define CONFIG_REGULATOR_TPS65912_MODULE 1
#define CONFIG_PMIC_DA9052 1
#define CONFIG_LEDS_PCA9532_MODULE 1
#define CONFIG_SND_SOC_INTEL_CHT_BSW_NAU8824_MACH_MODULE 1
#define CONFIG_GPIOLIB_IRQCHIP 1
#define CONFIG_XILLYBUS_CLASS_MODULE 1
#define CONFIG_KEYBOARD_DLINK_DIR685_MODULE 1
#define CONFIG_RCU_BOOST_DELAY 500
#define CONFIG_SPEAKUP_SYNTH_ACNTSA_MODULE 1
#define CONFIG_TINYDRM_ILI9341_MODULE 1
#define CONFIG_HYPERV_BALLOON_MODULE 1
#define CONFIG_NET_SCH_SFQ_MODULE 1
#define CONFIG_SND_SOC_SOF_APOLLOLAKE_MODULE 1
#define CONFIG_SPEAKUP_SYNTH_BNS_MODULE 1
#define CONFIG_INPUT_TPS6594_PWRBUTTON_MODULE 1
#define CONFIG_QCOM_MDT_LOADER_MODULE 1
#define CONFIG_SCSI_SAS_ATTRS_MODULE 1
#define CONFIG_LEDS_WM8350_MODULE 1
#define CONFIG_EFI 1
#define CONFIG_VBOXSF_FS_MODULE 1
#define CONFIG_SUNRPC_MODULE 1
#define CONFIG_NLS_MAC_CELTIC_MODULE 1
#define CONFIG_TI_DAC7311_MODULE 1
#define CONFIG_INTEL_SCU_IPC_UTIL_MODULE 1
#define CONFIG_THERMAL_EMERGENCY_POWEROFF_DELAY_MS 100
#define CONFIG_NF_CONNTRACK_NETBIOS_NS_MODULE 1
#define CONFIG_NF_NAT_OVS 1
#define CONFIG_TYPEC_RT1719_MODULE 1
#define CONFIG_DVB_STV0900_MODULE 1
#define CONFIG_ABP2030PA_SPI_MODULE 1
#define CONFIG_USB_CDNS_HOST 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_HDAUDIO_MODULE 1
#define CONFIG_RMI4_F34 1
#define CONFIG_SND_PDAUDIOCF_MODULE 1
#define CONFIG_CHELSIO_LIB_MODULE 1
#define CONFIG_FS_STACK 1
#define CONFIG_BMI088_ACCEL_MODULE 1
#define CONFIG_LEDS_BRIGHTNESS_HW_CHANGED 1
#define CONFIG_SENSORS_LTC2947_MODULE 1
#define CONFIG_MT76x2E_MODULE 1
#define CONFIG_VIDEO_MGB4_MODULE 1
#define CONFIG_SOFTLOCKUP_DETECTOR_INTR_STORM 1
#define CONFIG_YENTA_MODULE 1
#define CONFIG_AD7091R_MODULE 1
#define CONFIG_RTC_DRV_88PM860X_MODULE 1
#define CONFIG_VIDEO_MAX96717_MODULE 1
#define CONFIG_X86_SUPPORTS_MEMORY_FAILURE 1
#define CONFIG_ARCH_SELECTS_KEXEC_FILE 1
#define CONFIG_GENERIC_CPU_DEVICES 1
#define CONFIG_LEDS_PCA963X_MODULE 1
#define CONFIG_CONNECTOR 1
#define CONFIG_SND_SOC_ARIZONA_MODULE 1
#define CONFIG_SENSORS_TC654_MODULE 1
#define CONFIG_RTC_DRV_MC13XXX_MODULE 1
#define CONFIG_VIRTIO_PCI_LIB 1
#define CONFIG_HVC_XEN_FRONTEND 1
#define CONFIG_GPIO_RDC321X_MODULE 1
#define CONFIG_DRM_VGEM_MODULE 1
#define CONFIG_HSR_MODULE 1
#define CONFIG_REGULATOR_TPS6586X_MODULE 1
#define CONFIG_PINCTRL_INTEL_PLATFORM_MODULE 1
#define CONFIG_TCP_MD5SIG 1
#define CONFIG_TSL2591_MODULE 1
#define CONFIG_INTEL_PUNIT_IPC_MODULE 1
#define CONFIG_INPUT_REGULATOR_HAPTIC_MODULE 1
#define CONFIG_SSB_BLOCKIO 1
#define CONFIG_ARCH_HAVE_EXTRA_ELF_NOTES 1
#define CONFIG_DM_UEVENT 1
#define CONFIG_GENERIC_PT 1
#define CONFIG_UBIFS_FS_ZSTD 1
#define CONFIG_MEMORY_HOTREMOVE 1
#define CONFIG_CRYPTO_LIB_CHACHA 1
#define CONFIG_SMSC_SCH311X_WDT_MODULE 1
#define CONFIG_PAC1934_MODULE 1
#define CONFIG_EDAC_I82975X_MODULE 1
#define CONFIG_BRIDGE_EBT_LOG_MODULE 1
#define CONFIG_SFP_MODULE 1
#define CONFIG_CPU_IDLE 1
#define CONFIG_OBJTOOL 1
#define CONFIG_CGROUP_FREEZER 1
#define CONFIG_EROFS_FS_ZIP_ZSTD 1
#define CONFIG_RT2X00_MODULE 1
#define CONFIG_PREEMPT_COUNT 1
#define CONFIG_GPIB_AGILENT_82350B_MODULE 1
#define CONFIG_XEN_PVCALLS_BACKEND_MODULE 1
#define CONFIG_LEDS_MENF21BMC_MODULE 1
#define CONFIG_SENSORS_TSC1641_MODULE 1
#define CONFIG_KXSD9_I2C_MODULE 1
#define CONFIG_VGA_SWITCHEROO 1
#define CONFIG_CAN_MODULE 1
#define CONFIG_CRYPTO_LIB_BLAKE2B 1
#define CONFIG_PINCTRL_LAKEFIELD_MODULE 1
#define CONFIG_AD7150_MODULE 1
#define CONFIG_TI_ADS1100_MODULE 1
#define CONFIG_SND_SOC_TAS571X_MODULE 1
#define CONFIG_GVE_MODULE 1
#define CONFIG_IIO_CONFIGFS_MODULE 1
#define CONFIG_SCSI_LOWLEVEL_PCMCIA 1
#define CONFIG_IP6_NF_IPTABLES_LEGACY_MODULE 1
#define CONFIG_MLX5_CLS_ACT 1
#define CONFIG_SWIOTLB_XEN 1
#define CONFIG_HID_BATTERY_STRENGTH 1
#define CONFIG_DVB_NXT200X_MODULE 1
#define CONFIG_NET_SCH_HHF_MODULE 1
#define CONFIG_PTP_1588_CLOCK_VMW_MODULE 1
#define CONFIG_LEDS_CLASS_MULTICOLOR_MODULE 1
#define CONFIG_DW_EDMA_PCIE_MODULE 1
#define CONFIG_AIC94XX_DEBUG 1
#define CONFIG_SND_SOC_SOF_XTENSA_MODULE 1
#define CONFIG_CHARGER_TPS65090_MODULE 1
#define CONFIG_HID_SENSOR_TEMP_MODULE 1
#define CONFIG_IOMMU_DEFAULT_DMA_LAZY 1
#define CONFIG_HID_SENSOR_HUB_MODULE 1
#define CONFIG_IPW2200_QOS 1
#define CONFIG_HID_PICOLCD_CIR 1
#define CONFIG_PM_CLK 1
#define CONFIG_MC3230_MODULE 1
#define CONFIG_NET_XGRESS 1
#define CONFIG_XEN_GNTDEV_MODULE 1
#define CONFIG_SND_VX222_MODULE 1
#define CONFIG_KVM_XEN 1
#define CONFIG_LMK04832_MODULE 1
#define CONFIG_SATA_HOST 1
#define CONFIG_CRASH_DM_CRYPT_CONFIGS 1
#define CONFIG_SND_PCM_TIMER 1
#define CONFIG_INV_MPU6050_SPI_MODULE 1
#define CONFIG_SCSI_PROC_FS 1
#define CONFIG_MITIGATION_MMIO_STALE_DATA 1
#define CONFIG_SND_SOC_RT9123_MODULE 1
#define CONFIG_SND_SOC_RT5670_MODULE 1
#define CONFIG_DVB_STB6000_MODULE 1
#define CONFIG_SENSORS_LTC4286 1
#define CONFIG_QED_ISCSI 1
#define CONFIG_CRYPTO_HW 1
#define CONFIG_LTC1660_MODULE 1
#define CONFIG_TIPC_MODULE 1
#define CONFIG_X86_PLATFORM_DEVICES 1
#define CONFIG_REGULATOR_MT6358_MODULE 1
#define CONFIG_MACINTOSH_DRIVERS 1
#define CONFIG_NFT_SOCKET_MODULE 1
#define CONFIG_NETFILTER_NETLINK_QUEUE_MODULE 1
#define CONFIG_CFG80211_REQUIRE_SIGNED_REGDB 1
#define CONFIG_MPU3050_MODULE 1
#define CONFIG_KALLSYMS_ALL 1
#define CONFIG_USB_F_MASS_STORAGE_MODULE 1
#define CONFIG_ATH12K_COREDUMP 1
#define CONFIG_COREDUMP 1
#define CONFIG_RELOCATABLE 1
#define CONFIG_SERIAL_JSM_MODULE 1
#define CONFIG_ACPI_CONFIGFS_MODULE 1
#define CONFIG_VIRTIO_MEM_MODULE 1
#define CONFIG_SATA_ACARD_AHCI_MODULE 1
#define CONFIG_HAVE_KVM_MSI 1
#define CONFIG_CC_HAS_ZERO_CALL_USED_REGS 1
#define CONFIG_GOOGLE_VPD_MODULE 1
#define CONFIG_BRIDGE_EBT_PKTTYPE_MODULE 1
#define CONFIG_INTEL_QUICKI2C_MODULE 1
#define CONFIG_RC_DEVICES 1
#define CONFIG_B43_BUSES_BCMA_AND_SSB 1
#define CONFIG_JOYSTICK_GUILLEMOT_MODULE 1
#define CONFIG_ARCH_KEEP_MEMBLOCK 1
#define CONFIG_CRYPTO_HASH2 1
#define CONFIG_SECCOMP 1
#define CONFIG_SND_SOC_WM8978_MODULE 1
#define CONFIG_SNET_VDPA_MODULE 1
#define CONFIG_SND_SOC_CS35L56_I2C_MODULE 1
#define CONFIG_NET_DSA_MV88E6XXX_PTP 1
#define CONFIG_DAMON 1
#define CONFIG_TIFM_CORE_MODULE 1
#define CONFIG_CRYPTO_LIB_GF128MUL_MODULE 1
#define CONFIG_SOUNDWIRE_INTEL_MODULE 1
#define CONFIG_SPLIT_PMD_PTLOCKS 1
#define CONFIG_VL53L1X_I2C_MODULE 1
#define CONFIG_ACPI_SBS_MODULE 1
#define CONFIG_X86_CX8 1
#define CONFIG_HID_MICROSOFT_MODULE 1
#define CONFIG_LIBERTAS_MESH 1
#define CONFIG_SGETMASK_SYSCALL 1
#define CONFIG_USB_MUSB_DUAL_ROLE 1
#define CONFIG_USB_G_MULTI_MODULE 1
#define CONFIG_VIDEO_CAMERA_LENS 1
#define CONFIG_SND_SOC_PCM3060_MODULE 1
#define CONFIG_IP6_NF_IPTABLES_MODULE 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_RT274_MODULE 1
#define CONFIG_MAX1027_MODULE 1
#define CONFIG_SHMEM 1
#define CONFIG_A11Y_BRAILLE_CONSOLE 1
#define CONFIG_IWLWIFI_OPMODE_MODULAR 1
#define CONFIG_TRANSPARENT_HUGEPAGE_TMPFS_HUGE_ADVISE 1
#define CONFIG_FPGA_MGR_MACHXO2_SPI_MODULE 1
#define CONFIG_SND_SOC_CS42L56_MODULE 1
#define CONFIG_WIZNET_W5300_MODULE 1
#define CONFIG_IIO_BUFFER_DMAENGINE_MODULE 1
#define CONFIG_SENSORS_MAX17616_MODULE 1
#define CONFIG_LEDS_IS31FL319X_MODULE 1
#define CONFIG_NFT_CT_MODULE 1
#define CONFIG_RTL8723BS_MODULE 1
#define CONFIG_SND_ALS4000_MODULE 1
#define CONFIG_IO_URING_ZCRX 1
#define CONFIG_NET_ACT_IFE_MODULE 1
#define CONFIG_VSOCKMON_MODULE 1
#define CONFIG_ARCH_HAS_NMI_SAFE_THIS_CPU_OPS 1
#define CONFIG_DVB_DIB3000MC_MODULE 1
#define CONFIG_I2C_BOARDINFO 1
#define CONFIG_HAVE_ARCH_GET_SECUREBOOT 1
#define CONFIG_VIDEO_OV7740_MODULE 1
#define CONFIG_SERIO_ALTERA_PS2_MODULE 1
#define CONFIG_ATL2_MODULE 1
#define CONFIG_GPIO_BD9571MWV_MODULE 1
#define CONFIG_UIO_MODULE 1
#define CONFIG_KEXEC_SIG 1
#define CONFIG_SSB_PCIHOST 1
#define CONFIG_ATA_VERBOSE_ERROR 1
#define CONFIG_SECURITY_APPARMOR_HASH_DEFAULT 1
#define CONFIG_WEXT_CORE 1
#define CONFIG_SND_HDA_CODEC_CONEXANT_MODULE 1
#define CONFIG_RTC_DRV_R9701_MODULE 1
#define CONFIG_DRM_PANEL_WIDECHIPS_WS2401_MODULE 1
#define CONFIG_MFD_WM8998 1
#define CONFIG_PLDMFW 1
#define CONFIG_VIDEO_MAX9271_LIB_MODULE 1
#define CONFIG_SENSORS_TPS40422_MODULE 1
#define CONFIG_MS_BLOCK_MODULE 1
#define CONFIG_THERMAL_NETLINK 1
#define CONFIG_BACKLIGHT_LM3639_MODULE 1
#define CONFIG_PSE_PD692X0_MODULE 1
#define CONFIG_VIRTIO_ANCHOR 1
#define CONFIG_SKGE_MODULE 1
#define CONFIG_RMI4_SPI_MODULE 1
#define CONFIG_SND_SOC_ES8328_I2C_MODULE 1
#define CONFIG_MT76_SDIO_MODULE 1
#define CONFIG_CHELSIO_T3_MODULE 1
#define CONFIG_LIBIE_ADMINQ_MODULE 1
#define CONFIG_SATA_SIL_MODULE 1
#define CONFIG_SND_TIMER_MODULE 1
#define CONFIG_INTEL_SMARTCONNECT_MODULE 1
#define CONFIG_NETLINK_DIAG_MODULE 1
#define CONFIG_NLS_MAC_ICELAND_MODULE 1
#define CONFIG_SMS_SIANO_RC 1
#define CONFIG_HAVE_POSIX_CPU_TIMERS_TASK_WORK 1
#define CONFIG_RPCSEC_GSS_KRB5_ENCTYPES_AES_SHA2 1
#define CONFIG_NLS_CODEPAGE_949_MODULE 1
#define CONFIG_SENSORS_W83L785TS_MODULE 1
#define CONFIG_CROS_EC_LIGHTBAR_MODULE 1
#define CONFIG_SENSORS_XDPE152_MODULE 1
#define CONFIG_VIRTIO_BLK 1
#define CONFIG_USER_NS_UNPRIVILEGED 1
#define CONFIG_CPU_SUP_INTEL 1
#define CONFIG_BCH_MODULE 1
#define CONFIG_RTLWIFI_PCI_MODULE 1
#define CONFIG_ARCH_SUPPORTS_SCHED_CLUSTER 1
#define CONFIG_DRM_HISI_HIBMC_MODULE 1
#define CONFIG_BRIDGE_MODULE 1
#define CONFIG_IRQ_FORCED_THREADING 1
#define CONFIG_HARDLOCKUP_DETECTOR 1
#define CONFIG_VIDEO_GO7007_LOADER_MODULE 1
#define CONFIG_CRYPTO_MANAGER2 1
#define CONFIG_NET_VENDOR_MICROCHIP 1
#define CONFIG_MESSAGE_LOGLEVEL_DEFAULT 4
#define CONFIG_SND_SOC_FS210X_MODULE 1
#define CONFIG_KEYBOARD_CROS_EC_MODULE 1
#define CONFIG_RTC_DRV_DS1343_MODULE 1
#define CONFIG_LCD_OTM3225A_MODULE 1
#define CONFIG_INTEL_BXT_PMIC_THERMAL_MODULE 1
#define CONFIG_SCSI_CXGB4_ISCSI_MODULE 1
#define CONFIG_IP_NF_FILTER_MODULE 1
#define CONFIG_SQUASHFS_MODULE 1
#define CONFIG_WLAN_VENDOR_ATH 1
#define CONFIG_SND_DUMMY_MODULE 1
#define CONFIG_SPI_AMD_MODULE 1
#define CONFIG_ITCO_WDT_MODULE 1
#define CONFIG_CFG80211_WEXT 1
#define CONFIG_MLXREG_LC_MODULE 1
#define CONFIG_SENSORS_VIA_CPUTEMP_MODULE 1
#define CONFIG_DVB_S921_MODULE 1
#define CONFIG_SENSORS_LM95245_MODULE 1
#define CONFIG_DA9062_WATCHDOG_MODULE 1
#define CONFIG_FPGA_DFL_FME_MODULE 1
#define CONFIG_NLS_CODEPAGE_932_MODULE 1
#define CONFIG_WLAN_VENDOR_MARVELL 1
#define CONFIG_NET_SCH_MQPRIO_LIB_MODULE 1
#define CONFIG_AD4695_MODULE 1
#define CONFIG_KVM_HYPERV 1
#define CONFIG_HAVE_DYNAMIC_FTRACE_NO_PATCHABLE 1
#define CONFIG_SOCK_RX_QUEUE_MAPPING 1
#define CONFIG_X86_MCE_THRESHOLD 1
#define CONFIG_RESCTRL_FS_PSEUDO_LOCK 1
#define CONFIG_AUXILIARY_BUS 1
#define CONFIG_RTC_DRV_RX8111_MODULE 1
#define CONFIG_ARCH_HIBERNATION_HEADER 1
#define CONFIG_DECOMPRESS_LZ4 1
#define CONFIG_VFIO_CONTAINER 1
#define CONFIG_RTC_DRV_LP8788_MODULE 1
#define CONFIG_TOUCHSCREEN_PCAP_MODULE 1
#define CONFIG_SENSORS_VT1211_MODULE 1
#define CONFIG_DVB_CX24117_MODULE 1
#define CONFIG_USB_GSPCA_ETOMS_MODULE 1
#define CONFIG_ARCH_WANT_DEFAULT_BPF_JIT 1
#define CONFIG_GPIO_SIM_MODULE 1
#define CONFIG_NLS_ISO8859_1_MODULE 1
#define CONFIG_SND_SOC_CHV3_CODEC_MODULE 1
#define CONFIG_ARCH_HAS_KCOV 1
#define CONFIG_HID_TOPSEED_MODULE 1
#define CONFIG_NET_EMATCH_META_MODULE 1
#define CONFIG_MPLS_IPTUNNEL_MODULE 1
#define CONFIG_DYNAMIC_FTRACE_WITH_DIRECT_CALLS 1
#define CONFIG_PM_SLEEP_DEBUG 1
#define CONFIG_BT_HCIUART_RTL 1
#define CONFIG_GENERIC_IRQ_INJECTION 1
#define CONFIG_AFS_FSCACHE 1
#define CONFIG_HSC030PA_I2C_MODULE 1
#define CONFIG_USB_TRANCEVIBRATOR_MODULE 1
#define CONFIG_NET_VENDOR_CAVIUM 1
#define CONFIG_LEDS_TCA6507_MODULE 1
#define CONFIG_WLAN_VENDOR_ZYDAS 1
#define CONFIG_AD3552R_LIB_MODULE 1
#define CONFIG_LIBERTAS_SDIO_MODULE 1
#define CONFIG_SENSORS_SHT21_MODULE 1
#define CONFIG_USB_GSPCA_MR97310A_MODULE 1
#define CONFIG_INPUT_AW86927_MODULE 1
#define CONFIG_PCNET32_MODULE 1
#define CONFIG_BCACHE_ASYNC_REGISTRATION 1
#define CONFIG_INTEL_SAR_INT1092_MODULE 1
#define CONFIG_PATA_TIMINGS 1
#define CONFIG_NETFILTER_XT_MARK_MODULE 1
#define CONFIG_COMPAT 1
#define CONFIG_VIRT_CPU_ACCOUNTING 1
#define CONFIG_SND_SOC_SOF_ELKHARTLAKE_MODULE 1
#define CONFIG_USB_SERIAL_DIGI_ACCELEPORT_MODULE 1
#define CONFIG_ARCH_ENABLE_HUGEPAGE_MIGRATION 1
#define CONFIG_PSTORE 1
#define CONFIG_IIO_ST_LSM6DSX_SPI_MODULE 1
#define CONFIG_HID_VRC2_MODULE 1
#define CONFIG_NET_CLS_ROUTE4_MODULE 1
#define CONFIG_TMPFS_INODE64 1
#define CONFIG_TI_TSC2046_MODULE 1
#define CONFIG_ZRAM_DEF_COMP_ZSTD 1
#define CONFIG_SCSI_UFS_CRYPTO 1
#define CONFIG_IIO_TRIGGERED_EVENT_MODULE 1
#define CONFIG_DVB_USB_AF9035_MODULE 1
#define CONFIG_SND_BCD2000_MODULE 1
#define CONFIG_NET_SCH_CHOKE_MODULE 1
#define CONFIG_MXM_WMI_MODULE 1
#define CONFIG_NIC7018_WDT_MODULE 1
#define CONFIG_SCSI_3W_SAS_MODULE 1
#define CONFIG_WILC1000_MODULE 1
#define CONFIG_PCI_ENDPOINT_TEST_MODULE 1
#define CONFIG_INTEL_XWAY_PHY_MODULE 1
#define CONFIG_RMI4_F55 1
#define CONFIG_EXCLUSIVE_SYSTEM_RAM 1
#define CONFIG_FW_LOADER_COMPRESS 1
#define CONFIG_CRYPTO_LIB_POLY1305_RSIZE 11
#define CONFIG_INIT_ENV_ARG_LIMIT 32
#define CONFIG_CACHEFILES_MODULE 1
#define CONFIG_QEDF_MODULE 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_RT298_MODULE 1
#define CONFIG_BCM_KONA_USB2_PHY_MODULE 1
#define CONFIG_ADMV1013_MODULE 1
#define CONFIG_STANDALONE 1
#define CONFIG_XEN_PV_MSR_SAFE 1
#define CONFIG_USB_SERIAL_CONSOLE 1
#define CONFIG_USB_CONFIGFS_EEM 1
#define CONFIG_TEHUTI_TN40_MODULE 1
#define CONFIG_XFRM_MIGRATE 1
#define CONFIG_SND_DYNAMIC_MINORS 1
#define CONFIG_IP_PIMSM_V1 1
#define CONFIG_CRYPTO_DEV_QAT_C62X_MODULE 1
#define CONFIG_CC_HAS_AUTO_VAR_INIT_ZERO 1
#define CONFIG_SCSI_VIRTIO 1
#define CONFIG_FPGA_DFL_NIOS_INTEL_PAC_N3000_MODULE 1
#define CONFIG_SND_SOC_LPASS_TX_MACRO_MODULE 1
#define CONFIG_DM_FLAKEY_MODULE 1
#define CONFIG_HOTPLUG_PCI_CPCI 1
#define CONFIG_ZD1211RW_MODULE 1
#define CONFIG_SPARSEMEM_VMEMMAP_PREINIT 1
#define CONFIG_HOTPLUG_PARALLEL 1
#define CONFIG_CHARGER_MAX8997_MODULE 1
#define CONFIG_SECURITY_INFINIBAND 1
#define CONFIG_VIDEO_GO7007_USB_S2250_BOARD_MODULE 1
#define CONFIG_FUN_CORE_MODULE 1
#define CONFIG_GPIB_COMMON_MODULE 1
#define CONFIG_USB_GSPCA_XIRLINK_CIT_MODULE 1
#define CONFIG_DVB_DRXK_MODULE 1
#define CONFIG_JFFS2_FS_POSIX_ACL 1
#define CONFIG_REGULATOR_MT6359_MODULE 1
#define CONFIG_I2C_PCA_PLATFORM_MODULE 1
#define CONFIG_SND_HDA_CODEC_ALC880_MODULE 1
#define CONFIG_EXT_GROUP_SCHED 1
#define CONFIG_EROFS_FS_SECURITY 1
#define CONFIG_I2C_HID_MODULE 1
#define CONFIG_PREEMPT_BUILD 1
#define CONFIG_BT_HCIUART_MRVL 1
#define CONFIG_TPS6594_ESM_MODULE 1
#define CONFIG_DRM_DISPLAY_HDMI_CEC_NOTIFIER_HELPER 1
#define CONFIG_MEM_SOFT_DIRTY 1
#define CONFIG_LOGIWHEELS_FF 1
#define CONFIG_DRM_AMDGPU_MODULE 1
#define CONFIG_YENTA_O2 1
#define CONFIG_RTC_DRV_MAX8997_MODULE 1
#define CONFIG_SND_EMU10K1X_MODULE 1
#define CONFIG_MANAGER_SBS_MODULE 1
#define CONFIG_AF_RXRPC_MODULE 1
#define CONFIG_JOYSTICK_STINGER_MODULE 1
#define CONFIG_842_COMPRESS_MODULE 1
#define CONFIG_BATTERY_S2MU005_MODULE 1
#define CONFIG_SND_SOC_PCM186X_MODULE 1
#define CONFIG_SERIAL_ARC_NR_PORTS 1
#define CONFIG_DVB_USB_ANYSEE_MODULE 1
#define CONFIG_DEFAULT_TCP_CONG "cubic"
#define CONFIG_VL53L0X_I2C_MODULE 1
#define CONFIG_DRM_XE_PREEMPT_TIMEOUT_MIN 1
#define CONFIG_I2C_TINY_USB_MODULE 1
#define CONFIG_IR_TTUSBIR_MODULE 1
#define CONFIG_MPTCP_IPV6 1
#define CONFIG_MSHV_ROOT_MODULE 1
#define CONFIG_USER_EVENTS 1
#define CONFIG_NETFILTER_NETLINK_ACCT_MODULE 1
#define CONFIG_SND_SOC_AMD_ACP_PCM_MODULE 1
#define CONFIG_PRINTK_EXECUTION_CTX 1
#define CONFIG_WLAN_VENDOR_SILABS 1
#define CONFIG_IPW2100_MONITOR 1
#define CONFIG_VORTEX_MODULE 1
#define CONFIG_HAVE_KERNEL_ZSTD 1
#define CONFIG_CRAMFS_BLOCKDEV 1
#define CONFIG_ARCH_SUPPORTS_LTO_CLANG 1
#define CONFIG_PHY_CAN_TRANSCEIVER_MODULE 1
#define CONFIG_CPUFREQ_ARCH_CUR_FREQ 1
#define CONFIG_SND_SOC_RT715_SDW_MODULE 1
#define CONFIG_SND_SOC_AC97_BUS 1
#define CONFIG_NETFILTER_XT_MATCH_L2TP_MODULE 1
#define CONFIG_SND_SOC_SOF_HDA_COMMON_MODULE 1
#define CONFIG_VIDEO_PVRUSB2_SYSFS 1
#define CONFIG_MFD_DA9063_MODULE 1
#define CONFIG_IP6_NF_SECURITY_MODULE 1
#define CONFIG_MEN_Z188_ADC_MODULE 1
#define CONFIG_USB_STORAGE_REALTEK_MODULE 1
#define CONFIG_NET_VENDOR_OKI 1
#define CONFIG_RTW88_8821CS_MODULE 1
#define CONFIG_WIL6210_MODULE 1
#define CONFIG_SECURITY_IPE 1
#define CONFIG_I2C_TAOS_EVM_MODULE 1
#define CONFIG_BLK_INLINE_ENCRYPTION_FALLBACK 1
#define CONFIG_CC_MS_EXTENSIONS "-fms-extensions"
#define CONFIG_CRYPTO_CRC32_MODULE 1
#define CONFIG_IQS620AT_TEMP_MODULE 1
#define CONFIG_TPS6594_PFSM_MODULE 1
#define CONFIG_SPI_MEM 1
#define CONFIG_INTEL_UNCORE_FREQ_CONTROL_MODULE 1
#define CONFIG_UCSI_ACPI_MODULE 1
#define CONFIG_MMC_BLOCK_MODULE 1
#define CONFIG_MFD_MENF21BMC_MODULE 1
#define CONFIG_RTC_DRV_RX8025_MODULE 1
#define CONFIG_GCC_NO_STRINGOP_OVERFLOW 1
#define CONFIG_CONTIG_ALLOC 1
#define CONFIG_VIDEO_MT9V111_MODULE 1
#define CONFIG_SND_SOC_SOF_INTEL_HIFI_EP_IPC_MODULE 1
#define CONFIG_CRYPTO_LIB_SM3_MODULE 1
#define CONFIG_SMBFS_MODULE 1
#define CONFIG_PCI_DIRECT 1
#define CONFIG_BROADCAST_TLB_FLUSH 1
#define CONFIG_USB_DWC3_PCI_MODULE 1
#define CONFIG_USB_SI4713_MODULE 1
#define CONFIG_JOYSTICK_AS5011_MODULE 1
#define CONFIG_SND_HDA_CODEC_ALC662_MODULE 1
#define CONFIG_CAN_PEAK_PCIEC 1
#define CONFIG_CPU_FREQ_GOV_ATTR_SET 1
#define CONFIG_SENSORS_CRPS_MODULE 1
#define CONFIG_P2SB 1
#define CONFIG_RWSEM_SPIN_ON_OWNER 1
#define CONFIG_HAVE_BOOTMEM_INFO_NODE 1
#define CONFIG_HOTPLUG_PCI_CPCI_ZT5550_MODULE 1
#define CONFIG_ARCH_HAS_STRICT_MODULE_RWX 1
#define CONFIG_DRM_PRIVACY_SCREEN 1
#define CONFIG_SND_SOC_AMD_ACP63_TOPLEVEL_MODULE 1
#define CONFIG_SCSI_ACARD_MODULE 1
#define CONFIG_SND_SOC_ES7241_MODULE 1
#define CONFIG_DVB_DIB3000MB_MODULE 1
#define CONFIG_DVB_TS2020_MODULE 1
#define CONFIG_MFD_TPS6594_SPI_MODULE 1
#define CONFIG_WATCHDOG_PRETIMEOUT_GOV_PANIC 1
#define CONFIG_LRU_GEN 1
#define CONFIG_PROC_PID_ARCH_STATUS 1
#define CONFIG_ARCH_SUPPORTS_KEXEC_BZIMAGE_VERIFY_SIG 1
#define CONFIG_EXAR_WDT_MODULE 1
#define CONFIG_GPIO_WHISKEY_COVE_MODULE 1
#define CONFIG_SENSORS_TPS23861_MODULE 1
#define CONFIG_WLAN_VENDOR_INTEL 1
#define CONFIG_HAVE_IRQ_EXIT_ON_IRQ_STACK 1
#define CONFIG_CAN_CC770_ISA_MODULE 1
#define CONFIG_VIDEO_CX88_MPEG_MODULE 1
#define CONFIG_LIVEUPDATE 1
#define CONFIG_PINCTRL_METEORPOINT_MODULE 1
#define CONFIG_CRYPTO_ESSIV_MODULE 1
#define CONFIG_USB_SERIAL_SPCP8X5_MODULE 1
#define CONFIG_FPGA_MGR_XILINX_SELECTMAP_MODULE 1
#define CONFIG_ATH5K_DEBUG 1
#define CONFIG_HINIC_MODULE 1
#define CONFIG_BATTERY_GAUGE_LTC2941_MODULE 1
#define CONFIG_GPIO_GENERIC_PLATFORM_MODULE 1
#define CONFIG_MITIGATION_IBRS_ENTRY 1
#define CONFIG_ARCH_HAS_KERNEL_FPU_SUPPORT 1
#define CONFIG_KEYBOARD_QT1070_MODULE 1
#define CONFIG_SND_SOC_INTEL_GLK_DA7219_MAX98357A_MACH_MODULE 1
#define CONFIG_RPMSG_TTY_MODULE 1
#define CONFIG_AFE4404_MODULE 1
#define CONFIG_OPEN_ALLIANCE_HELPERS 1
#define CONFIG_EUROTECH_WDT_MODULE 1
#define CONFIG_HID_CMEDIA_MODULE 1
#define CONFIG_DVB_LNBP21_MODULE 1
#define CONFIG_RPCSEC_GSS_KRB5_ENCTYPES_AES_SHA1 1
#define CONFIG_HAVE_RELIABLE_STACKTRACE 1
#define CONFIG_INPUT_PCSPKR_MODULE 1
#define CONFIG_MFD_MC13XXX_MODULE 1
#define CONFIG_HOTPLUG_CORE_SYNC 1
#define CONFIG_MFD_ATC260X_MODULE 1
#define CONFIG_DVB_AV7110_IR 1
#define CONFIG_HID_ICADE_MODULE 1
#define CONFIG_DVB_AU8522_DTV_MODULE 1
#define CONFIG_SCSI_UFS_HWMON 1
#define CONFIG_MELLANOX_PLATFORM 1
#define CONFIG_RTC_DRV_TPS6594_MODULE 1
#define CONFIG_NET_VENDOR_ATHEROS 1
#define CONFIG_DVB_SP887X_MODULE 1
#define CONFIG_LEDS_TRIGGER_CAMERA_MODULE 1
#define CONFIG_REGULATOR_RTMV20_MODULE 1
#define CONFIG_DVB_TDA10021_MODULE 1
#define CONFIG_PATA_RZ1000_MODULE 1
#define CONFIG_VMD_MODULE 1
#define CONFIG_VIRTIO_MMIO_MODULE 1
#define CONFIG_ELFCORE 1
#define CONFIG_I2C_ALI1563_MODULE 1
#define CONFIG_CARL9170_WPC 1
#define CONFIG_IOSF_MBI 1
#define CONFIG_BLK_PM 1
#define CONFIG_X86_PM_TIMER 1
#define CONFIG_SPI_ALTERA_DFL_MODULE 1
#define CONFIG_HDC2010_MODULE 1
#define CONFIG_SENSORS_ASUS_WMI_MODULE 1
#define CONFIG_SND_VMASTER 1
#define CONFIG_SERIAL_8250_RSA 1
#define CONFIG_PPS_CLIENT_PARPORT_MODULE 1
#define CONFIG_SENSORS_STTS751_MODULE 1
#define CONFIG_MLX5_CORE_EN 1
#define CONFIG_VHOST_ENABLE_FORK_OWNER_CONTROL 1
#define CONFIG_REGULATOR_MAX77541_MODULE 1
#define CONFIG_CIFS_DEBUG 1
#define CONFIG_USBIP_VHCI_HCD_MODULE 1
#define CONFIG_DVB_CX24116_MODULE 1
#define CONFIG_BRIDGE_EBT_DNAT_MODULE 1
#define CONFIG_POSIX_AUX_CLOCKS 1
#define CONFIG_NET_VENDOR_SILAN 1
#define CONFIG_MEDIA_TUNER_MXL5005S_MODULE 1
#define CONFIG_NET_DSA_MV88E6XXX_LEDS 1
#define CONFIG_HID_MULTITOUCH_MODULE 1
#define CONFIG_SND_HDA_CODEC_SI3054_MODULE 1
#define CONFIG_DYNAMIC_SIGFRAME 1
#define CONFIG_TOUCHSCREEN_ELO_MODULE 1
#define CONFIG_BMG160_SPI_MODULE 1
#define CONFIG_SND_SOC_SOF_COMETLAKE_MODULE 1
#define CONFIG_SENSORS_UCD9000_MODULE 1
#define CONFIG_SND_SOC_PCM3168A_MODULE 1
#define CONFIG_TOUCHSCREEN_ZINITIX_MODULE 1
#define CONFIG_GNSS_MODULE 1
#define CONFIG_DRM_APPLETBDRM_MODULE 1
#define CONFIG_SND_VERBOSE_PROCFS 1
#define CONFIG_INPUT_MAX8997_HAPTIC_MODULE 1
#define CONFIG_NET_SCH_INGRESS_MODULE 1
#define CONFIG_BRIDGE_EBT_AMONG_MODULE 1
#define CONFIG_MEDIA_TUNER_TDA827X_MODULE 1
#define CONFIG_SENSORS_HMC5843_MODULE 1
#define CONFIG_CRYPTO_LIB_MLDSA_MODULE 1
#define CONFIG_LEDS_KTD202X_MODULE 1
#define CONFIG_GENERIC_CPU_AUTOPROBE 1
#define CONFIG_WLAN_VENDOR_ST 1
#define CONFIG_SOLARIS_X86_PARTITION 1
#define CONFIG_NIU_MODULE 1
#define CONFIG_VMGENID 1
#define CONFIG_ADIN_PHY_MODULE 1
#define CONFIG_RETHOOK 1
#define CONFIG_JFFS2_ZLIB 1
#define CONFIG_NFC_MICROREAD_MODULE 1
#define CONFIG_INPUT_MOUSEDEV_MODULE 1
#define CONFIG_NET_SCH_CAKE_MODULE 1
#define CONFIG_NETDEVICES 1
#define CONFIG_FW_CS_DSP_MODULE 1
#define CONFIG_DRM_CLIENT_DEFAULT "fbdev"
#define CONFIG_X86_INTEL_TSX_MODE_AUTO 1
#define CONFIG_LAN743X_MODULE 1
#define CONFIG_IIO_BUFFER_DMA_MODULE 1
#define CONFIG_WILCO_EC_MODULE 1
#define CONFIG_NLS_CODEPAGE_874_MODULE 1
#define CONFIG_NR_CPUS_RANGE_END 8192
#define CONFIG_VIDEO_TEA6415C_MODULE 1
#define CONFIG_RTL8180_MODULE 1
#define CONFIG_SPI_XILINX_MODULE 1
#define CONFIG_USB_GSPCA_BENQ_MODULE 1
#define CONFIG_BMP280_MODULE 1
#define CONFIG_BLK_RQ_ALLOC_TIME 1
#define CONFIG_MFD_TI_LP873X_MODULE 1
#define CONFIG_ARCH_CLOCKSOURCE_INIT 1
#define CONFIG_INET_XFRM_TUNNEL_MODULE 1
#define CONFIG_INPUT_MISC 1
#define CONFIG_SENSORS_PXE1610_MODULE 1
#define CONFIG_UBIFS_FS_ZLIB 1
#define CONFIG_INV_ICM45600_I2C_MODULE 1
#define CONFIG_NF_NAT_H323_MODULE 1
#define CONFIG_IP_PIMSM_V2 1
#define CONFIG_MFD_OCELOT_MODULE 1
#define CONFIG_PATA_PARPORT_EPAT_MODULE 1
#define CONFIG_ETHTOOL_NETLINK 1
#define CONFIG_AD7606_IFACE_SPI_MODULE 1
#define CONFIG_WATCHDOG_PRETIMEOUT_GOV_SEL_MODULE 1
#define CONFIG_NVME_TARGET_LOOP_MODULE 1
#define CONFIG_GPIO_MAX730X_MODULE 1
#define CONFIG_VIRTIO_PCI_LIB_LEGACY 1
#define CONFIG_RCU_BOOST 1
#define CONFIG_COMMON_CLK 1
#define CONFIG_SND_SOC_TLV320ADC3XXX_MODULE 1
#define CONFIG_USBPCWATCHDOG_MODULE 1
#define CONFIG_DEBUG_INFO 1
#define CONFIG_KXSD9_MODULE 1
#define CONFIG_SND_RME96_MODULE 1
#define CONFIG_ACRN_HSM_MODULE 1
#define CONFIG_VIDEO_CX2341X_MODULE 1
#define CONFIG_RTC_DRV_DS1302_MODULE 1
#define CONFIG_ACPI_APEI_EINJ_MODULE 1
#define CONFIG_RMI4_F3A 1
#define CONFIG_RT2X00_LIB_LEDS 1
#define CONFIG_MD_CLUSTER_MODULE 1
#define CONFIG_SND_SOC_SOF_HDA_LINK_BASELINE_MODULE 1
#define CONFIG_X86_AMD_FREQ_SENSITIVITY_MODULE 1
#define CONFIG_RTC_DRV_DS1374_WDT 1
#define CONFIG_POWER_RESET_MT6323 1
#define CONFIG_VIDEO_CADENCE_CSI2TX_MODULE 1
#define CONFIG_MAX31865_MODULE 1
#define CONFIG_HID_PICOLCD_FB 1
#define CONFIG_SCSI_SCAN_ASYNC 1
#define CONFIG_RTC_DRV_M48T86_MODULE 1
#define CONFIG_SND_SOC_INTEL_BDW_RT5677_MACH_MODULE 1
#define CONFIG_CRYPTO_BLOWFISH_MODULE 1
#define CONFIG_BCM54140_PHY_MODULE 1
#define CONFIG_RTW89_PCI_MODULE 1
#define CONFIG_CRYPTO_SM3_MODULE 1
#define CONFIG_SENSORS_IBM_CFFPS_MODULE 1
#define CONFIG_USB_PULSE8_CEC_MODULE 1
#define CONFIG_SENSORS_KFAN_MODULE 1
#define CONFIG_PHYLINK_MODULE 1
#define CONFIG_EFI_SOFT_RESERVE 1
#define CONFIG_SENSORS_MPQ7932_REGULATOR 1
#define CONFIG_SENSORS_ISL29028_MODULE 1
#define CONFIG_RTC_DRV_MAX8998_MODULE 1
#define CONFIG_SATA_PMP 1
#define CONFIG_PCIE_ECRC 1
#define CONFIG_DMA_SHARED_BUFFER 1
#define CONFIG_MODULES 1
#define CONFIG_MLX5_VDPA 1
#define CONFIG_SND_SOC_AMD_RENOIR_MACH_MODULE 1
#define CONFIG_RT2800PCI_RT35XX 1
#define CONFIG_IPV6_SEG6_HMAC 1
#define CONFIG_SND_SEQ_VIRMIDI_MODULE 1
#define CONFIG_SND_SIMPLE_CARD_UTILS_MODULE 1
#define CONFIG_BACKLIGHT_ADP8870_MODULE 1
#define CONFIG_IDLE_INJECT 1
#define CONFIG_GPIO_TWL4030_MODULE 1
#define CONFIG_NF_NAT_MODULE 1
#define CONFIG_CACHESTAT_SYSCALL 1
#define CONFIG_CMA_SIZE_MBYTES 0
#define CONFIG_CROS_EC_SPI_MODULE 1
#define CONFIG_SND_HDA_INPUT_BEEP 1
#define CONFIG_REGULATOR_TPS65023_MODULE 1
#define CONFIG_CAN_MCP251XFD_MODULE 1
#define CONFIG_USB_CONFIGFS_ACM 1
#define CONFIG_PVH 1
#define CONFIG_SPI_SIFIVE_MODULE 1
#define CONFIG_IIO_ST_ACCEL_SPI_3AXIS_MODULE 1
#define CONFIG_SND_SOC_SOF_INTEL_COMMON_MODULE 1
#define CONFIG_MAX_SKB_FRAGS 17
#define CONFIG_USERFAULTFD 1
#define CONFIG_MFD_DA9062_MODULE 1
#define CONFIG_X86_ACPI_CPUFREQ_MODULE 1
#define CONFIG_SENSORS_PC87427_MODULE 1
#define CONFIG_SND_SOC_SOF_INTEL_SOUNDWIRE_MODULE 1
#define CONFIG_BOOT_PRINTK_DELAY 1
#define CONFIG_AD5360_MODULE 1
#define CONFIG_CRYPTO_ACOMP2 1
#define CONFIG_SND_CA0106_MODULE 1
#define CONFIG_LEDS_EXPRESSWIRE 1
#define CONFIG_VIDEO_AU0828_V4L2 1
#define CONFIG_DM_WRITECACHE_MODULE 1
#define CONFIG_HOTPLUG_PCI_ACPI_IBM_MODULE 1
#define CONFIG_VIDEO_APTINA_PLL_MODULE 1
#define CONFIG_DRM_I915_TIMESLICE_DURATION 1
#define CONFIG_SND_SOC_ADAU7002_MODULE 1
#define CONFIG_SENSORS_W83773G_MODULE 1
#define CONFIG_V4L2_CCI_I2C_MODULE 1
#define CONFIG_NF_NAT_TFTP_MODULE 1
#define CONFIG_RTW88_8723D_MODULE 1
#define CONFIG_MFD_CS42L43_SDW_MODULE 1
#define CONFIG_PPS_CLIENT_GPIO_MODULE 1
#define CONFIG_INET_TABLE_PERTURB_ORDER 16
#define CONFIG_BACKLIGHT_BD6107_MODULE 1
#define CONFIG_SND_ALS300_MODULE 1
#define CONFIG_LEDS_TRIGGER_MTD 1
#define CONFIG_VIRTIO_INPUT_MODULE 1
#define CONFIG_IIO_SW_TRIGGER_MODULE 1
#define CONFIG_HID_LOGITECH_MODULE 1
#define CONFIG_SND_NM256_MODULE 1
#define CONFIG_IXGBEVF_IPSEC 1
#define CONFIG_SND_SOC_SOF_AMD_REMBRANDT_MODULE 1
#define CONFIG_MAX30102_MODULE 1
#define CONFIG_NITRO_ENCLAVES_MODULE 1
#define CONFIG_HW_RANDOM_VIA_MODULE 1
#define CONFIG_IO_DELAY_0X80 1
#define CONFIG_KEYBOARD_NEWTON_MODULE 1
#define CONFIG_X86_X32_ABI 1
#define CONFIG_RT2X00_LIB_USB_MODULE 1
#define CONFIG_CORTINA_PHY_MODULE 1
#define CONFIG_SENSORS_HMC5843_SPI_MODULE 1
#define CONFIG_IIO_BUFFER 1
#define CONFIG_INPUT_RAVE_SP_PWRBUTTON_MODULE 1
#define CONFIG_SND_SOC_SSM4567_MODULE 1
#define CONFIG_GPIO_SCH311X_MODULE 1
#define CONFIG_LIQUIDIO_VF_MODULE 1
#define CONFIG_DS1803_MODULE 1
#define CONFIG_DVB_B2C2_FLEXCOP_USB_MODULE 1
#define CONFIG_HAVE_CONTEXT_TRACKING_USER_OFFSTACK 1
#define CONFIG_INET_ESPINTCP 1
#define CONFIG_SND_SOC_AW88395_LIB_MODULE 1
#define CONFIG_SENSORS_FAM15H_POWER_MODULE 1
#define CONFIG_ISCSI_BOOT_SYSFS_MODULE 1
#define CONFIG_SND_SOC_RT712_SDCA_SDW_MODULE 1
#define CONFIG_TCM_IBLOCK_MODULE 1
#define CONFIG_TSL4531_MODULE 1
#define CONFIG_IIO_SYSFS_TRIGGER_MODULE 1
#define CONFIG_HID_SENSOR_MAGNETOMETER_3D_MODULE 1
#define CONFIG_AD9739A_MODULE 1
#define CONFIG_NFC_PN544_I2C_MODULE 1
#define CONFIG_NET_VENDOR_I825XX 1
#define CONFIG_DMA_ENGINE_RAID 1
#define CONFIG_SENSORS_NCT7904_MODULE 1
#define CONFIG_NF_CONNTRACK_FTP_MODULE 1
#define CONFIG_MFD_MP2629_MODULE 1
#define CONFIG_GPD_POCKET_FAN_MODULE 1
#define CONFIG_REGULATOR_PCA9450_MODULE 1
#define CONFIG_MAXLINEAR_86110_PHY_MODULE 1
#define CONFIG_ZPA2326_MODULE 1
#define CONFIG_FWCTL_MLX5_MODULE 1
#define CONFIG_MMU_GATHER_TABLE_FREE 1
#define CONFIG_PERSISTENT_KEYRINGS 1
#define CONFIG_BACKLIGHT_DA903X_MODULE 1
#define CONFIG_CHELSIO_T1_MODULE 1
#define CONFIG_PMS7003_MODULE 1
#define CONFIG_USB_GSPCA_TOPRO_MODULE 1
#define CONFIG_GPIB_LPVO_MODULE 1
#define CONFIG_SENSORS_PWM_FAN_MODULE 1
#define CONFIG_ADXL355_SPI_MODULE 1
#define CONFIG_BITREVERSE 1
#define CONFIG_ACPI_LEGACY_TABLES_LOOKUP 1
#define CONFIG_CRASH_DUMP 1
#define CONFIG_PSI 1
#define CONFIG_MAX517_MODULE 1
#define CONFIG_HAVE_ARCH_KASAN_VMALLOC 1
#define CONFIG_KEYBOARD_ADC_MODULE 1
#define CONFIG_IPV6_NDISC_NODETYPE 1
#define CONFIG_USB_ISP1761_UDC 1
#define CONFIG_BACKLIGHT_PANDORA_MODULE 1
#define CONFIG_EDAC_ECS 1
#define CONFIG_SND_SOC_ES8323_MODULE 1
#define CONFIG_XEN_PCIDEV_BACKEND_MODULE 1
#define CONFIG_DRM_GUD_MODULE 1
#define CONFIG_EXTCON_AXP288_MODULE 1
#define CONFIG_MFD_CS47L92 1
#define CONFIG_HID_MONTEREY_MODULE 1
#define CONFIG_MSI_LAPTOP_MODULE 1
#define CONFIG_GFS2_FS_LOCKING_DLM 1
#define CONFIG_IIO_BACKEND_MODULE 1
#define CONFIG_USB_NET_NET1080_MODULE 1
#define CONFIG_LEDS_DA903X_MODULE 1
#define CONFIG_INPUT_IQS269A_MODULE 1
#define CONFIG_NCT6694_WATCHDOG_MODULE 1
#define CONFIG_SPEAKUP_SYNTH_DECEXT_MODULE 1
#define CONFIG_BLK_DEV_SD 1
#define CONFIG_IIO_ST_GYRO_I2C_3AXIS_MODULE 1
#define CONFIG_MT76x0U_MODULE 1
#define CONFIG_INTEL_INT0002_VGPIO_MODULE 1
#define CONFIG_USB_XHCI_PCI 1
#define CONFIG_RT2800USB_RT3573 1
#define CONFIG_SND_SOC_INTEL_AVS_MODULE 1
#define CONFIG_SENSORS_VT8231_MODULE 1
#define CONFIG_HAVE_FTRACE_GRAPH_FUNC 1
#define CONFIG_ATH9K_BTCOEX_SUPPORT 1
#define CONFIG_TOUCHSCREEN_HYCON_HY46XX_MODULE 1
#define CONFIG_SND_SOC_CS42XX8_I2C_MODULE 1
#define CONFIG_SSB_DRIVER_PCICORE_POSSIBLE 1
#define CONFIG_INPUT_MOUSEDEV_PSAUX 1
#define CONFIG_IIO_ST_MAGN_SPI_3AXIS_MODULE 1
#define CONFIG_NFC_PN544_MODULE 1
#define CONFIG_MEMBLOCK_KHO_SCRATCH 1
#define CONFIG_SCHED_INFO 1
#define CONFIG_FUSION_CTL_MODULE 1
#define CONFIG_AD74115_MODULE 1
#define CONFIG_PINCTRL_ELKHARTLAKE_MODULE 1
#define CONFIG_ATH10K_TRACING 1
#define CONFIG_IP_VS_LC_MODULE 1
#define CONFIG_KVM_EXTERNAL_WRITE_TRACKING 1
#define CONFIG_NLS_ISO8859_3_MODULE 1
#define CONFIG_USB_CHIPIDEA_MODULE 1
#define CONFIG_TPS6105X_MODULE 1
#define CONFIG_DM_PCACHE_MODULE 1
#define CONFIG_W1_SLAVE_DS2780_MODULE 1
#define CONFIG_PVPANIC_MMIO_MODULE 1
#define CONFIG_SND_SOC_WCD939X_SDW_MODULE 1
#define CONFIG_UDF_FS_MODULE 1
#define CONFIG_HAVE_KPROBES 1
#define CONFIG_NET_SCH_ETF_MODULE 1
#define CONFIG_NVME_FC_MODULE 1
#define CONFIG_DRM_PANEL_ORISETECH_OTA5601A_MODULE 1
#define CONFIG_IIO_INV_SENSORS_TIMESTAMP_MODULE 1
#define CONFIG_REGULATOR_TPS51632_MODULE 1
#define CONFIG_IGB_HWMON 1
#define CONFIG_ACPI_HOTPLUG_CPU 1
#define CONFIG_DEV_DAX_KMEM_MODULE 1
#define CONFIG_CRYPTO_KRB5_MODULE 1
#define CONFIG_GPIO_ALTERA_MODULE 1
#define CONFIG_DEBUG_MEMORY_INIT 1
#define CONFIG_USB_SERIAL_KEYSPAN_PDA_MODULE 1
#define CONFIG_BOOTTIME_TRACING 1
#define CONFIG_VIDEO_CX231XX_DVB_MODULE 1
#define CONFIG_RC_MAP_MODULE 1
#define CONFIG_RTLWIFI_USB_MODULE 1
#define CONFIG_RTL8192D_COMMON_MODULE 1
#define CONFIG_CM3605_MODULE 1
#define CONFIG_HAVE_PCSPKR_PLATFORM 1
#define CONFIG_HAVE_PV_STEAL_CLOCK_GEN 1
#define CONFIG_NLS_UCS2_UTILS_MODULE 1
#define CONFIG_VIDEO_OV5693_MODULE 1
#define CONFIG_SND_HDA_CODEC_CA0110_MODULE 1
#define CONFIG_MEDIA_PLATFORM_DRIVERS 1
#define CONFIG_RADIO_TEA5764_MODULE 1
#define CONFIG_MEDIA_TEST_SUPPORT 1
#define CONFIG_SERIAL_MEN_Z135_MODULE 1
#define CONFIG_MFD_AXP20X_MODULE 1
#define CONFIG_HAVE_KVM_CPU_RELAX_INTERCEPT 1
#define CONFIG_SND_VX_LIB_MODULE 1
#define CONFIG_HID_JABRA_MODULE 1
#define CONFIG_VIDEO_ALVIUM_CSI2_MODULE 1
#define CONFIG_ASN1_ENCODER_MODULE 1
#define CONFIG_DVB_MB86A16_MODULE 1
#define CONFIG_ACPI_CPU_FREQ_PSS 1
#define CONFIG_INTEL_RAPL_MODULE 1
#define CONFIG_GPIO_ELKHARTLAKE_MODULE 1
#define CONFIG_PINCTRL_MCP23S08_SPI_MODULE 1
#define CONFIG_X86_CMOV 1
#define CONFIG_CHELSIO_INLINE_CRYPTO 1
#define CONFIG_MTD_PHRAM_MODULE 1
#define CONFIG_ETHOC_MODULE 1
#define CONFIG_LWTUNNEL 1
#define CONFIG_X86_PMEM_LEGACY_DEVICE 1
#define CONFIG_INTEL_WMI_THUNDERBOLT_MODULE 1
#define CONFIG_REGULATOR_MT6360_MODULE 1
#define CONFIG_SND_ICE1724_MODULE 1
#define CONFIG_XPOWER_PMIC_OPREGION 1
#define CONFIG_OMFS_FS_MODULE 1
#define CONFIG_SND_RIPTIDE_MODULE 1
#define CONFIG_BCM_VK_TTY 1
#define CONFIG_CMA_ALIGNMENT 8
#define CONFIG_RANDOMIZE_MEMORY 1
#define CONFIG_SND_HDA_SCODEC_COMPONENT_MODULE 1
#define CONFIG_MT7601U_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_BPF_MODULE 1
#define CONFIG_IWLEGACY_MODULE 1
#define CONFIG_FORCEDETH_MODULE 1
#define CONFIG_ACER_WIRELESS_MODULE 1
#define CONFIG_USB_SERIAL_IPAQ_MODULE 1
#define CONFIG_RTW88_8723CS_MODULE 1
#define CONFIG_INTEL_UNCORE_FREQ_CONTROL_TPMI_MODULE 1
#define CONFIG_FS_ENCRYPTION_INLINE_CRYPT 1
#define CONFIG_ACPI_BGRT 1
#define CONFIG_ENC28J60_MODULE 1
#define CONFIG_SND_SOC_SMA1303_MODULE 1
#define CONFIG_REGULATOR_MT6357_MODULE 1
#define CONFIG_XEN_PVHVM_GUEST 1
#define CONFIG_SSB_SDIOHOST 1
#define CONFIG_NUMA_MIGRATION 1
#define CONFIG_SND_HDA_CODEC_ALC882_MODULE 1
#define CONFIG_VIDEO_OV9734_MODULE 1
#define CONFIG_MDIO_THUNDER_MODULE 1
#define CONFIG_SQUASHFS_COMP_CACHE_FULL 1
#define CONFIG_SND_SOC_WM8960_MODULE 1
#define CONFIG_8139TOO_MODULE 1
#define CONFIG_CRYPTO_XCTR_MODULE 1
#define CONFIG_TOUCHSCREEN_FUJITSU_MODULE 1
#define CONFIG_RTC_DRV_PCF2123_MODULE 1
#define CONFIG_VIDEO_CX88_VP3054_MODULE 1
#define CONFIG_RMI4_F1A 1
#define CONFIG_TYPEC_UCSI_MODULE 1
#define CONFIG_BATTERY_TWL4030_MADC_MODULE 1
#define CONFIG_SYSVIPC_SYSCTL 1
#define CONFIG_USB_SERIAL_OMNINET_MODULE 1
#define CONFIG_TOUCHSCREEN_ROHM_BU21023_MODULE 1
#define CONFIG_I2C_MUX_MODULE 1
#define CONFIG_DRM_PANEL 1
#define CONFIG_PATA_CMD64X_MODULE 1
#define CONFIG_AIC7XXX_CMDS_PER_DEVICE 32
#define CONFIG_FANOTIFY 1
#define CONFIG_LCD_L4F00242T03_MODULE 1
#define CONFIG_DMADEVICES 1
#define CONFIG_SND_SOC_SIMPLE_MUX_MODULE 1
#define CONFIG_TCP_CONG_YEAH_MODULE 1
#define CONFIG_SENSORS_APPLESMC_MODULE 1
#define CONFIG_ARCH_HAS_CPU_PASID 1
#define CONFIG_FS_MBCACHE 1
#define CONFIG_LEDS_PCA995X_MODULE 1
#define CONFIG_RTW88_8821CU_MODULE 1
#define CONFIG_ZPA2326_I2C_MODULE 1
#define CONFIG_UEFI_CPER_X86 1
#define CONFIG_GPIO_REGMAP_MODULE 1
#define CONFIG_BCM87XX_PHY_MODULE 1
#define CONFIG_INIT_ON_ALLOC_DEFAULT_ON 1
#define CONFIG_SQUASHFS_FRAGMENT_CACHE_SIZE 3
#define CONFIG_TPS68470_PMIC_OPREGION 1
#define CONFIG_SND_SOC_XILINX_I2S_MODULE 1
#define CONFIG_PTP_1588_CLOCK_FC3W_MODULE 1
#define CONFIG_IIO_ST_PRESS_MODULE 1
#define CONFIG_SND_SOC_CS48L32_MODULE 1
#define CONFIG_AXP20X_POWER_MODULE 1
#define CONFIG_KSM 1
#define CONFIG_USB_UAS_MODULE 1
#define CONFIG_CAN_RX_OFFLOAD 1
#define CONFIG_PHYSICAL_ALIGN 0x200000
#define CONFIG_SND_HWDEP_MODULE 1
#define CONFIG_AHCI_DWC_MODULE 1
#define CONFIG_PM_QOS_CPU_SYSTEM_WAKEUP 1
#define CONFIG_KEYBOARD_APPLESPI_MODULE 1
#define CONFIG_MTD_VIRT_CONCAT 1
#define CONFIG_RC_XBOX_DVD_MODULE 1
#define CONFIG_CRYPTO_LIB_SHA256 1
#define CONFIG_IIO_ST_LSM6DSX_MODULE 1
#define CONFIG_AF_RXRPC_IPV6 1
#define CONFIG_LZ4HC_COMPRESS_MODULE 1
#define CONFIG_SND_SOC_RT5677_SPI_MODULE 1
#define CONFIG_SERIAL_8250_DMA 1
#define CONFIG_BT_HCIBTUSB_BCM 1
#define CONFIG_EDAC_I10NM_MODULE 1
#define CONFIG_NET_IP_TUNNEL_MODULE 1
#define CONFIG_AD5592R_MODULE 1
#define CONFIG_FXAS21002C_I2C_MODULE 1
#define CONFIG_I2C_DESIGNWARE_PCI 1
#define CONFIG_HAVE_NOINSTR_HACK 1
#define CONFIG_SCSI_BNX2X_FCOE_MODULE 1
#define CONFIG_HAVE_PCI 1
#define CONFIG_DVB_TDA665x_MODULE 1
#define CONFIG_MEDIA_TUNER_QM1D1C0042_MODULE 1
#define CONFIG_DM_CLONE_MODULE 1
#define CONFIG_MFD_CS40L50_SPI_MODULE 1
#define CONFIG_REGULATOR_FP9931_MODULE 1
#define CONFIG_AD7124_MODULE 1
#define CONFIG_SERIAL_ALTERA_UART_MODULE 1
#define CONFIG_INTEGRITY_MACHINE_KEYRING 1
#define CONFIG_MLXSW_I2C_MODULE 1
#define CONFIG_NEED_SG_DMA_FLAGS 1
#define CONFIG_SND_SOC_INTEL_GLK_RT5682_MAX98357A_MACH_MODULE 1
#define CONFIG_ARCH_SUPPORTS_AUTOFDO_CLANG 1
#define CONFIG_IP_NF_TARGET_SYNPROXY_MODULE 1
#define CONFIG_USB_KEENE_MODULE 1
#define CONFIG_SURFACE_HID_MODULE 1
#define CONFIG_RC_DECODERS 1
#define CONFIG_MT76x2_COMMON_MODULE 1
#define CONFIG_BME680_SPI_MODULE 1
#define CONFIG_AD7380_MODULE 1
#define CONFIG_W1_SLAVE_SMEM_MODULE 1
#define CONFIG_I2C_CHT_WC_MODULE 1
#define CONFIG_DRM_ACCEL_HABANALABS_MODULE 1
#define CONFIG_INTEL_MEI_VSC_MODULE 1
#define CONFIG_GP2AP002_MODULE 1
#define CONFIG_CRYPTO_LIB_BLAKE2S_ARCH 1
#define CONFIG_SND_SOC_PCM179X_MODULE 1
#define CONFIG_REGULATOR_MT6311_MODULE 1
#define CONFIG_PATA_TRIFLEX_MODULE 1
#define CONFIG_ACRN_GUEST 1
#define CONFIG_DELL_UART_BACKLIGHT_MODULE 1
#define CONFIG_RTW89_8852B_COMMON_MODULE 1
#define CONFIG_MFD_LP8788 1
#define CONFIG_PCMCIA_FDOMAIN_MODULE 1
#define CONFIG_ISL29020_MODULE 1
#define CONFIG_SND_HDA_SCODEC_CS35L41_SPI_MODULE 1
#define CONFIG_BRIDGE_EBT_802_3_MODULE 1
#define CONFIG_X86_P4_CLOCKMOD_MODULE 1
#define CONFIG_INTEL_IDMA64_MODULE 1
#define CONFIG_ACPI_CONTAINER 1
#define CONFIG_SFC_FALCON_MTD 1
#define CONFIG_CEC_GPIO_MODULE 1
#define CONFIG_DVB_USB_M920X_MODULE 1
#define CONFIG_DVB_TDA10023_MODULE 1
#define CONFIG_MEDIATEK_MT6370_ADC_MODULE 1
#define CONFIG_CHR_DEV_SG_MODULE 1
#define CONFIG_PROBE_EVENTS_BTF_ARGS 1
#define CONFIG_SMC_HS_CTRL_BPF 1
#define CONFIG_RTC_DRV_RV3032_MODULE 1
#define CONFIG_ARCH_HAS_HW_PTE_YOUNG 1
#define CONFIG_PINCTRL_CY8C95X0_MODULE 1
#define CONFIG_TOUCHSCREEN_COLIBRI_VF50_MODULE 1
#define CONFIG_MMU 1
#define CONFIG_QTNFMAC_PCIE_MODULE 1
#define CONFIG_NET_DSA_HIRSCHMANN_HELLCREEK_MODULE 1
#define CONFIG_SSB_DRIVER_PCICORE 1
#define CONFIG_BACKLIGHT_KTD2801_MODULE 1
#define CONFIG_MEDIA_TUNER_MT2131_MODULE 1
#define CONFIG_DIBS_MODULE 1
#define CONFIG_IEEE802154_SOCKET_MODULE 1
#define CONFIG_HID_NVIDIA_SHIELD_MODULE 1
#define CONFIG_IP6_NF_MATCH_MH_MODULE 1
#define CONFIG_SECURITY 1
#define CONFIG_SND_SOC_TAS2781_FMWLIB_MODULE 1
#define CONFIG_DRM_MIPI_DSI 1
#define CONFIG_FS_ENCRYPTION 1
#define CONFIG_IR_XMP_DECODER_MODULE 1
#define CONFIG_MEDIA_COMMON_OPTIONS 1
#define CONFIG_USB_RAW_GADGET_MODULE 1
#define CONFIG_MSCC_OCELOT_SWITCH_LIB_MODULE 1
#define CONFIG_REGULATOR_LTC3676_MODULE 1
#define CONFIG_CRYPTO_RNG2 1
#define CONFIG_SENSORS_MP5920_MODULE 1
#define CONFIG_NLS_ISO8859_2_MODULE 1
#define CONFIG_HID_TIVO_MODULE 1
#define CONFIG_SND_SOC_WM8737_MODULE 1
#define CONFIG_W1_SLAVE_DS2781_MODULE 1
#define CONFIG_SND_SOC_AMD_RV_RT5682_MACH_MODULE 1
#define CONFIG_VIDEO_OV7640_MODULE 1
#define CONFIG_SND_SOC_AK4118_MODULE 1
#define CONFIG_IPV6_GRE_MODULE 1
#define CONFIG_DRM_XE_FORCE_PROBE ""
#define CONFIG_SND_HDA_I915 1
#define CONFIG_W1_MASTER_SGI_MODULE 1
#define CONFIG_KEYBOARD_GPIO_MODULE 1
#define CONFIG_MUX_ADGS1408_MODULE 1
#define CONFIG_WILC1000_SDIO_MODULE 1
#define CONFIG_NET_FOU_IP_TUNNELS 1
#define CONFIG_SND_SOC_INTEL_EHL_RT5660_MACH_MODULE 1
#define CONFIG_DRM_LOAD_EDID_FIRMWARE 1
#define CONFIG_HAVE_DYNAMIC_FTRACE_WITH_REGS 1
#define CONFIG_INPUT_PWM_VIBRA_MODULE 1
#define CONFIG_KEXEC_HANDOVER 1
#define CONFIG_MINIX_FS_MODULE 1
#define CONFIG_SND_USB_AUDIO_MODULE 1
#define CONFIG_RC_CORE 1
#define CONFIG_DVB_VIDTV_MODULE 1
#define CONFIG_ADXL380_I2C_MODULE 1
#define CONFIG_BMP280_SPI_MODULE 1
#define CONFIG_X86_REQUIRED_FEATURE_LM 1
#define CONFIG_USB_CDNS3_PCI_WRAP_MODULE 1
#define CONFIG_SENSORS_ASUS_EC_MODULE 1
#define CONFIG_CRYPTO_DRBG_CTR 1
#define CONFIG_XEN_BLKDEV_FRONTEND_MODULE 1
#define CONFIG_NET_SCH_QFQ_MODULE 1
#define CONFIG_MANTIS_CORE_MODULE 1
#define CONFIG_I2C_ZHAOXIN_MODULE 1
#define CONFIG_LAN865X_MODULE 1
#define CONFIG_ASUS_NB_WMI_MODULE 1
#define CONFIG_IPE_POLICY_SIG_SECONDARY_KEYRING 1
#define CONFIG_DRM_AMD_DC_FP 1
#define CONFIG_SPI_DESIGNWARE_MODULE 1
#define CONFIG_ND_BTT_MODULE 1
#define CONFIG_CAN_KVASER_PCIEFD_MODULE 1
#define CONFIG_USB_CDNSP_PCI_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_ZYTRONIC 1
#define CONFIG_SHRINKER_DEBUG 1
#define CONFIG_CRYPTO_AES_NI_INTEL_MODULE 1
#define CONFIG_RTC_DRV_PCAP_MODULE 1
#define CONFIG_NFT_OSF_MODULE 1
#define CONFIG_BME680_I2C_MODULE 1
#define CONFIG_MOUSE_SYNAPTICS_USB_MODULE 1
#define CONFIG_MFD_CROS_EC_DEV_MODULE 1
#define CONFIG_BNGE_MODULE 1
#define CONFIG_GPIO_AMD8111_MODULE 1
#define CONFIG_VCAP 1
#define CONFIG_CFG80211_DEFAULT_PS 1
#define CONFIG_GPIO_TQMX86_MODULE 1
#define CONFIG_SND_SOC_RT722_SDCA_SDW_MODULE 1
#define CONFIG_XFS_ONLINE_REPAIR 1
#define CONFIG_BT_LE_L2CAP_ECRED 1
#define CONFIG_ADMV1014_MODULE 1
#define CONFIG_MT76_CONNAC_LIB_MODULE 1
#define CONFIG_CAN_KVASER_PCI_MODULE 1
#define CONFIG_PSE_TPS23881_MODULE 1
#define CONFIG_SND_SEQUENCER_MODULE 1
#define CONFIG_SND_SOC_TAS2781_I2C_MODULE 1
#define CONFIG_SOUNDWIRE_MODULE 1
#define CONFIG_OPENVSWITCH_GENEVE_MODULE 1
#define CONFIG_WATCHDOG_PRETIMEOUT_GOV 1
#define CONFIG_XILLYBUS_MODULE 1
#define CONFIG_MLXREG_DPU_MODULE 1
#define CONFIG_NET_TC_SKB_EXT 1
#define CONFIG_WLAN_VENDOR_MEDIATEK 1
#define CONFIG_CAN_CALC_BITTIMING 1
#define CONFIG_IPC_NS 1
#define CONFIG_RTC_DRV_DS1390_MODULE 1
#define CONFIG_ARCH_HAS_DEBUG_VIRTUAL 1
#define CONFIG_HID_PID 1
#define CONFIG_PCI_TSM 1
#define CONFIG_PARPORT_PC_SUPERIO 1
#define CONFIG_SND_SOC_FSL_XCVR_MODULE 1
#define CONFIG_IOMMU_SUPPORT 1
#define CONFIG_MUX_GPIO_MODULE 1
#define CONFIG_IPMI_WATCHDOG_MODULE 1
#define CONFIG_NET_ACT_NAT_MODULE 1
#define CONFIG_BROADCOM_PHY_MODULE 1
#define CONFIG_REGULATOR_PALMAS_MODULE 1
#define CONFIG_OVERLAY_FS_XINO_AUTO 1
#define CONFIG_USB_CHIPIDEA_MSM_MODULE 1
#define CONFIG_VDPA_SIM_MODULE 1
#define CONFIG_DPLL 1
#define CONFIG_SND_SOC_MAX98357A_MODULE 1
#define CONFIG_HID_MACALLY_MODULE 1
#define CONFIG_PATA_PARPORT_KBIC_MODULE 1
#define CONFIG_VFIO_IOMMU_TYPE1_MODULE 1
#define CONFIG_JOYSTICK_ADI_MODULE 1
#define CONFIG_ARCH_SUPPORTS_KEXEC_PURGATORY 1
#define CONFIG_MEMBARRIER 1
#define CONFIG_SND_SOC_WM8961_MODULE 1
#define CONFIG_SENSORS_DME1737_MODULE 1
#define CONFIG_ENERGY_MODEL 1
#define CONFIG_B43_BCMA 1
#define CONFIG_SND_SOC_TAS5720_MODULE 1
#define CONFIG_HID_GOOGLE_HAMMER_MODULE 1
#define CONFIG_SND_SOC_SOF_COFFEELAKE_MODULE 1
#define CONFIG_CHARGER_BQ2515X_MODULE 1
#define CONFIG_SND_SOC_CS4341_MODULE 1
#define CONFIG_EFI_MIXED 1
#define CONFIG_PCI_IOV 1
#define CONFIG_AD4030_MODULE 1
#define CONFIG_AXP288_FUEL_GAUGE_MODULE 1
#define CONFIG_TOUCHSCREEN_NOVATEK_NVT_TS_MODULE 1
#define CONFIG_USB_VL600_MODULE 1
#define CONFIG_SENSORS_MP5990_MODULE 1
#define CONFIG_CPU_IDLE_GOV_MENU 1
#define CONFIG_INV_ICM42600_MODULE 1
#define CONFIG_CROS_EC_ISHTP_MODULE 1
#define CONFIG_NETKIT 1
#define CONFIG_SENSORS_XDP710_MODULE 1
#define CONFIG_GPIO_KEMPLD_MODULE 1
#define CONFIG_GPIO_PCA9570_MODULE 1
#define CONFIG_SERIAL_8250_CS_MODULE 1
#define CONFIG_JFFS2_FS_DEBUG 0
#define CONFIG_TYPEC_TCPCI_MT6370_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_HELPER_MODULE 1
#define CONFIG_CRC32_ARCH 1
#define CONFIG_INFINIBAND_IPOIB_MODULE 1
#define CONFIG_I2C_SI4713_MODULE 1
#define CONFIG_I40E_DCB 1
#define CONFIG_X86_16BIT 1
#define CONFIG_SND_SOC_WM8974_MODULE 1
#define CONFIG_MACHZ_WDT_MODULE 1
#define CONFIG_VIDEO_LM3560_MODULE 1
#define CONFIG_EXTCON_MAX14577_MODULE 1
#define CONFIG_USB_SERIAL_MCT_U232_MODULE 1
#define CONFIG_SND_FIREWIRE_MOTU_MODULE 1
#define CONFIG_VIDEO_OV2640_MODULE 1
#define CONFIG_SECURITY_TOMOYO_ACTIVATION_TRIGGER "/usr/lib/systemd/systemd"
#define CONFIG_VSOCKETS_MODULE 1
#define CONFIG_SYSTEM_REVOCATION_LIST 1
#define CONFIG_CHECK_SIGNATURE 1
#define CONFIG_KEYBOARD_CYPRESS_SF_MODULE 1
#define CONFIG_QED_OOO 1
#define CONFIG_ARCH_SUPPORTS_CFI 1
#define CONFIG_MEDIA_DIGITAL_TV_SUPPORT 1
#define CONFIG_USB_CONFIGFS_RNDIS 1
#define CONFIG_SENSORS_EMC2305_MODULE 1
#define CONFIG_MXC4005_MODULE 1
#define CONFIG_X86_ACPI_CPUFREQ_CPB 1
#define CONFIG_NET_VENDOR_NETRONOME 1
#define CONFIG_NET_CLS_CGROUP_MODULE 1
#define CONFIG_CRYPTO_DRBG_MENU 1
#define CONFIG_CLS_U32_MARK 1
#define CONFIG_READ_ONLY_THP_FOR_FS 1
#define CONFIG_ARCH_HAS_PARANOID_L1D_FLUSH 1
#define CONFIG_SCSI_SNIC_MODULE 1
#define CONFIG_DVB_LNBH25_MODULE 1
#define CONFIG_BATTERY_CW2015_MODULE 1
#define CONFIG_KEBA_CP500_MODULE 1
#define CONFIG_SND_SOC_RT1308_MODULE 1
#define CONFIG_PCI_XEN 1
#define CONFIG_SND_SOC_CS42L52_MODULE 1
#define CONFIG_MT7996E_MODULE 1
#define CONFIG_W1_SLAVE_THERM_MODULE 1
#define CONFIG_MAX30100_MODULE 1
#define CONFIG_SECURITY_LOADPIN_ENFORCE 1
#define CONFIG_VHOST_IOTLB_MODULE 1
#define CONFIG_IPMI_DMI_DECODE 1
#define CONFIG_SND_SOC_WM8524_MODULE 1
#define CONFIG_CW1200_WLAN_SPI_MODULE 1
#define CONFIG_XZ_DEC 1
#define CONFIG_HSA_AMD 1
#define CONFIG_SENSORS_ADS7828_MODULE 1
#define CONFIG_LCD_VGG2432A4_MODULE 1
#define CONFIG_PINCTRL_GEMINILAKE_MODULE 1
#define CONFIG_BMI323_I2C_MODULE 1
#define CONFIG_SND_HDA_CODEC_ALC260_MODULE 1
#define CONFIG_IIO_MS_SENSORS_I2C_MODULE 1
#define CONFIG_USB_DSBR_MODULE 1
#define CONFIG_CC_HAS_KASAN_SW_TAGS 1
#define CONFIG_CIFS_ALLOW_INSECURE_LEGACY 1
#define CONFIG_EDAC_IGEN6_MODULE 1
#define CONFIG_ATH11K_MODULE 1
#define CONFIG_THERMAL_HWMON 1
#define CONFIG_LEDS_TRIGGER_CPU 1
#define CONFIG_GPIO_JANZ_TTL_MODULE 1
#define CONFIG_HAVE_OBJTOOL 1
#define CONFIG_MLX5_EN_ARFS 1
#define CONFIG_HAVE_KERNEL_LZ4 1
#define CONFIG_PCI_QUIRKS 1
#define CONFIG_MFD_CS40L50_I2C_MODULE 1
#define CONFIG_NET_DSA_TAG_BRCM_MODULE 1
#define CONFIG_NET_SCH_FQ_CODEL 1
#define CONFIG_IPV6_ILA_MODULE 1
#define CONFIG_WM831X_WATCHDOG_MODULE 1
#define CONFIG_PLX_DMA_MODULE 1
#define CONFIG_NET_VENDOR_FUNGIBLE 1
#define CONFIG_PATA_MARVELL_MODULE 1
#define CONFIG_MTD_NAND_NANDSIM_MODULE 1
#define CONFIG_GENERIC_PINCONF 1
#define CONFIG_MOUSE_PS2_MODULE 1
#define CONFIG_MEDIA_TUNER_SI2157_MODULE 1
#define CONFIG_DW_DMAC_PCI 1
#define CONFIG_NFS_COMMON_LOCALIO_SUPPORT_MODULE 1
#define CONFIG_TOUCHSCREEN_DA9034_MODULE 1
#define CONFIG_BLK_CGROUP_IOPRIO 1
#define CONFIG_IPACK_BUS_MODULE 1
#define CONFIG_SCSI_FLASHPOINT 1
#define CONFIG_MD 1
#define CONFIG_EFI_DEV_PATH_PARSER 1
#define CONFIG_INTEL_DC_TI_ADC_MODULE 1
#define CONFIG_I2C_VIRTIO_MODULE 1
#define CONFIG_PCPU_DEV_REFCNT 1
#define CONFIG_SPI_SLAVE_SYSTEM_CONTROL_MODULE 1
#define CONFIG_PVPANIC 1
#define CONFIG_I40E_MODULE 1
#define CONFIG_IR_ITE_CIR_MODULE 1
#define CONFIG_MFD_CS47L90 1
#define CONFIG_RTC_DRV_DS1347_MODULE 1
#define CONFIG_MTRR_SANITIZER_SPARE_REG_NR_DEFAULT 0
#define CONFIG_EDAC_ATOMIC_SCRUB 1
#define CONFIG_CRYPTO_LIB_SM3_ARCH 1
#define CONFIG_CXL_RAS 1
#define CONFIG_SND_SOC_RT5631_MODULE 1
#define CONFIG_NET_VENDOR_AMAZON 1
#define CONFIG_MODULE_UNLOAD 1
#define CONFIG_NET_VENDOR_INTEL 1
#define CONFIG_IGB_DCA 1
#define CONFIG_THERMAL_DEFAULT_GOV_STEP_WISE 1
#define CONFIG_DVB_TDA8261_MODULE 1
#define CONFIG_ATH9K_RFKILL 1
#define CONFIG_SENSORS_MENF21BMC_HWMON_MODULE 1
#define CONFIG_BATTERY_MAX17042_MODULE 1
#define CONFIG_XEN_XENBUS_FRONTEND 1
#define CONFIG_FPGA_DFL_FME_MGR_MODULE 1
#define CONFIG_CONSOLE_LOGLEVEL_DEFAULT 4
#define CONFIG_CADENCE_WATCHDOG_MODULE 1
#define CONFIG_RT2800USB_RT55XX 1
#define CONFIG_SPEAKUP_SYNTH_LTLK_MODULE 1
#define CONFIG_DVB_DIB7000M_MODULE 1
#define CONFIG_USB_GSPCA_T613_MODULE 1
#define CONFIG_REGULATOR_ADP5055_MODULE 1
#define CONFIG_VITESSE_PHY_MODULE 1
#define CONFIG_TCP_CONG_BIC_MODULE 1
#define CONFIG_IGBVF_MODULE 1
#define CONFIG_PAGE_COUNTER 1
#define CONFIG_CONSOLE_TRANSLATIONS 1
#define CONFIG_IP_VS_RR_MODULE 1
#define CONFIG_CPU_FREQ_GOV_POWERSAVE 1
#define CONFIG_CRYPTO_TWOFISH_COMMON_MODULE 1
#define CONFIG_USB_ACM_MODULE 1
#define CONFIG_DVB_CX22700_MODULE 1
#define CONFIG_SENSORS_IR36021_MODULE 1
#define CONFIG_WATCHDOG_OPEN_TIMEOUT 0
#define CONFIG_GPIO_LATCH_MODULE 1
#define CONFIG_BUILDTIME_TABLE_SORT 1
#define CONFIG_BATTERY_DS2760_MODULE 1
#define CONFIG_NLS_ISO8859_5_MODULE 1
#define CONFIG_DVB_USB_VP702X_MODULE 1
#define CONFIG_E1000E_MODULE 1
#define CONFIG_HAVE_CONTEXT_TRACKING_USER 1
#define CONFIG_SND_SOC_SOF_AMD_VANGOGH_MODULE 1
#define CONFIG_IEEE802154_DRIVERS_MODULE 1
#define CONFIG_BINFMT_SCRIPT 1
#define CONFIG_OPT4060_MODULE 1
#define CONFIG_CPU_IDLE_GOV_LADDER 1
#define CONFIG_SENSORS_CORSAIR_PSU_MODULE 1
#define CONFIG_ARCH_HAS_COPY_MC 1
#define CONFIG_MD_RAID1_MODULE 1
#define CONFIG_VIRTIO_NET_MODULE 1
#define CONFIG_PINMUX 1
#define CONFIG_REGULATOR_PV88060_MODULE 1
#define CONFIG_CRYPTO_SIG2 1
#define CONFIG_XFS_DRAIN_INTENTS 1
#define CONFIG_LCD_ILI9320_MODULE 1
#define CONFIG_XEN_MEMORY_HOTPLUG_LIMIT 512
#define CONFIG_MAC80211_MODULE 1
#define CONFIG_ATLAS_EZO_SENSOR_MODULE 1
#define CONFIG_DVB_STV0910_MODULE 1
#define CONFIG_THRUSTMASTER_FF 1
#define CONFIG_SND_MIXER_OSS_MODULE 1
#define CONFIG_RTW88_8822CU_MODULE 1
#define CONFIG_SND_SOC_WM8741_MODULE 1
#define CONFIG_SND_SOC_INTEL_SOF_CML_RT1011_RT5682_MACH_MODULE 1
#define CONFIG_MYRI10GE_DCA 1
#define CONFIG_MEDIA_TUNER_TDA18271_MODULE 1
#define CONFIG_MULTIUSER 1
#define CONFIG_RETU_WATCHDOG_MODULE 1
#define CONFIG_CRYPTO_842_MODULE 1
#define CONFIG_USB_AN2720 1
#define CONFIG_FONT_8x16 1
#define CONFIG_HWLAT_TRACER 1
#define CONFIG_SND_USB_US122L_MODULE 1
#define CONFIG_LIBERTAS_MODULE 1
#define CONFIG_NLS_MAC_ROMAN_MODULE 1
#define CONFIG_RTW88_8822C_MODULE 1
#define CONFIG_PPP_MODULE 1
#define CONFIG_ZOPT2201_MODULE 1
#define CONFIG_HID_SENSOR_CUSTOM_INTEL_HINGE_MODULE 1
#define CONFIG_PNP_DEBUG_MESSAGES 1
#define CONFIG_HAVE_KVM_IRQ_ROUTING 1
#define CONFIG_NETFILTER_SKIP_EGRESS 1
#define CONFIG_TOOLS_SUPPORT_RELR 1
#define CONFIG_SND_SOC_WM8804_SPI_MODULE 1
#define CONFIG_BRIDGE_IGMP_SNOOPING 1
#define CONFIG_SECURITY_SELINUX_AVC_STATS 1
#define CONFIG_AD5446_SPI_MODULE 1
#define CONFIG_USB_GSPCA_JL2005BCD_MODULE 1
#define CONFIG_VCNL4035_MODULE 1
#define CONFIG_I2C_DLN2_MODULE 1
#define CONFIG_CMA 1
#define CONFIG_USB_LINK_LAYER_TEST_MODULE 1
#define CONFIG_SND_USB_TONEPORT_MODULE 1
#define CONFIG_IP6_NF_FILTER_MODULE 1
#define CONFIG_HID_SAITEK_MODULE 1
#define CONFIG_FWCTL_BNXT_MODULE 1
#define CONFIG_CAN_UCAN_MODULE 1
#define CONFIG_PATA_PCMCIA_MODULE 1
#define CONFIG_IP_NF_ARPTABLES_MODULE 1
#define CONFIG_HID_VIVALDI_MODULE 1
#define CONFIG_MHI_WWAN_CTRL_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_MARK_MODULE 1
#define CONFIG_EDAC_I3200_MODULE 1
#define CONFIG_CHARGER_GPIO_MODULE 1
#define CONFIG_SPI_SC18IS602_MODULE 1
#define CONFIG_SCSI_DH 1
#define CONFIG_HID_ACRUX_MODULE 1
#define CONFIG_MFD_RETU_MODULE 1
#define CONFIG_VIRT_XFER_TO_GUEST_WORK 1
#define CONFIG_NETFILTER_XT_MATCH_LENGTH_MODULE 1
#define CONFIG_RTC_DRV_M41T80_MODULE 1
#define CONFIG_TMPFS_XATTR 1
#define CONFIG_TOUCHSCREEN_USB_GUNZE 1
#define CONFIG_NEED_PER_CPU_PAGE_FIRST_CHUNK 1
#define CONFIG_SND_SOC_WM8962_MODULE 1
#define CONFIG_BRCMFMAC_PCIE 1
#define CONFIG_TCG_INFINEON_MODULE 1
#define CONFIG_DRM_XE_TIMESLICE_MIN 1
#define CONFIG_RTC_DRV_FTRTC010_MODULE 1
#define CONFIG_SND_HDA_CODEC_HDMI_GENERIC_MODULE 1
#define CONFIG_RTC_DRV_DS1307_CENTURY 1
#define CONFIG_DVB_BCM3510_MODULE 1
#define CONFIG_TOUCHSCREEN_AD7877_MODULE 1
#define CONFIG_SND_SOC_ADAU1761_SPI_MODULE 1
#define CONFIG_BLOCK 1
#define CONFIG_CYPRESS_FIRMWARE_MODULE 1
#define CONFIG_PCI_LABEL 1
#define CONFIG_MFD_BQ257XX_MODULE 1
#define CONFIG_SLICOSS_MODULE 1
#define CONFIG_TWL6040_CORE 1
#define CONFIG_SND_LX6464ES_MODULE 1
#define CONFIG_PTP_1588_CLOCK_OPTIONAL_MODULE 1
#define CONFIG_CRYPTO_JITTERENTROPY_MEMORY_BLOCKS 64
#define CONFIG_ASUS_WMI_DEPRECATED_ATTRS 1
#define CONFIG_DM_BUFIO_MODULE 1
#define CONFIG_V4L2_FLASH_LED_CLASS_MODULE 1
#define CONFIG_PRINTK_INDEX 1
#define CONFIG_SPEAKUP_SYNTH_TXPRT_MODULE 1
#define CONFIG_NET_VENDOR_3COM 1
#define CONFIG_MPTCP 1
#define CONFIG_TYPEC_TCPCI_MAXIM_MODULE 1
#define CONFIG_RUSTC_LLVM_MAJOR_VERSION 22
#define CONFIG_CPU_FREQ 1
#define CONFIG_STACKTRACE_BUILD_ID 1
#define CONFIG_USB_G_SERIAL_MODULE 1
#define CONFIG_FAT_DEFAULT_IOCHARSET "ascii"
#define CONFIG_SND_SOC_MAX98388_MODULE 1
#define CONFIG_SENSORS_DS620_MODULE 1
#define CONFIG_NFSD_PNFS 1
#define CONFIG_TTY 1
#define CONFIG_USB_GR_UDC_MODULE 1
#define CONFIG_ARCH_SUPPORTS_PMD_PFNMAP 1
#define CONFIG_HPET_EMULATE_RTC 1
#define CONFIG_MITIGATION_TSA 1
#define CONFIG_HAVE_UNSTABLE_SCHED_CLOCK 1
#define CONFIG_DVB_USB_ZD1301_MODULE 1
#define CONFIG_DECOMPRESS_LZMA 1
#define CONFIG_DVB_MANTIS_MODULE 1
#define CONFIG_IR_IGUANA_MODULE 1
#define CONFIG_DRM_SYSFB_HELPER 1
#define CONFIG_SND_SOC_AK4375_MODULE 1
#define CONFIG_CEC_NXP_TDA9950_MODULE 1
#define CONFIG_IPW2200_MONITOR 1
#define CONFIG_842_DECOMPRESS_MODULE 1
#define CONFIG_FEALNX_MODULE 1
#define CONFIG_I40EVF_MODULE 1
#define CONFIG_CFS_BANDWIDTH 1
#define CONFIG_LEDS_LM3530_MODULE 1
#define CONFIG_MOUSE_PS2_CYPRESS 1
#define CONFIG_B43_BCMA_PIO 1
#define CONFIG_X86_DISABLED_FEATURE_K6_MTRR 1
#define CONFIG_ACPI_TAD_MODULE 1
#define CONFIG_SYMBOLIC_ERRNAME 1
#define CONFIG_SENSORS_LINEAGE_MODULE 1
#define CONFIG_VIDEO_CX88_ENABLE_VP3054 1
#define CONFIG_ARCH_HAS_CPU_RESCTRL 1
#define CONFIG_CAN_PEAK_USB_MODULE 1
#define CONFIG_LEDS_AW200XX_MODULE 1
#define CONFIG_CHARGER_BQ257XX_MODULE 1
#define CONFIG_QUEUED_SPINLOCKS 1
#define CONFIG_SENSORS_LTC2978_MODULE 1
#define CONFIG_ARCH_SUPPORTS_INT128 1
#define CONFIG_TCP_CONG_BBR_MODULE 1
#define CONFIG_PATA_PARPORT_ATEN_MODULE 1
#define CONFIG_CRYPTO_MD4_MODULE 1
#define CONFIG_SERIAL_8250_CONSOLE 1
#define CONFIG_LOCK_MM_AND_FIND_VMA 1
#define CONFIG_SOC_BUS 1
#define CONFIG_JOYSTICK_WALKERA0701_MODULE 1
#define CONFIG_MODULE_SIG_HASH "sha512"
#define CONFIG_NETWORK_PHY_TIMESTAMPING 1
#define CONFIG_APPLICOM_MODULE 1
#define CONFIG_PROC_KCORE 1
#define CONFIG_ARCH_USE_CMPXCHG_LOCKREF 1
#define CONFIG_FW_LOADER_DEBUG 1
#define CONFIG_RTW88_LEDS 1
#define CONFIG_VIDEO_CX25840_MODULE 1
#define CONFIG_REGULATOR_GPIO_MODULE 1
#define CONFIG_XFS_POSIX_ACL 1
#define CONFIG_BLK_MQ_STACKING 1
#define CONFIG_LEDS_BLINKM_MULTICOLOR 1
#define CONFIG_TEST_POWER_MODULE 1
#define CONFIG_SFC_SIENA_MCDI_MON 1
#define CONFIG_CRYPTO_LIB_GF128HASH 1
#define CONFIG_CHARGER_SURFACE_MODULE 1
#define CONFIG_SENSORS_NZXT_KRAKEN2_MODULE 1
#define CONFIG_AOSONG_AGS02MA_MODULE 1
#define CONFIG_HAVE_TRUSTED_KEYS 1
#define CONFIG_SND_SOC_ES8326_MODULE 1
#define CONFIG_MERAKI_MX100_MODULE 1
#define CONFIG_CARL9170_LEDS 1
#define CONFIG_NF_DUP_NETDEV_MODULE 1
#define CONFIG_NET_ACT_CSUM_MODULE 1
#define CONFIG_AD5593R_MODULE 1
#define CONFIG_MEDIA_TUNER_TDA9887_MODULE 1
#define CONFIG_CROS_EC_CHARDEV_MODULE 1
#define CONFIG_SCSI_UFSHCD_MODULE 1
#define CONFIG_POWERCAP 1
#define CONFIG_CHARGER_RT5033_MODULE 1
#define CONFIG_IOMMUFD_MODULE 1
#define CONFIG_TIMERLAT_TRACER 1
#define CONFIG_MICROCHIP_T1_PHY_MODULE 1
#define CONFIG_INET6_IPCOMP_MODULE 1
#define CONFIG_CRYPTO_DEV_SP_CCP 1
#define CONFIG_TOUCHSCREEN_EKTF2127_MODULE 1
#define CONFIG_FW_LOADER_SYSFS 1
#define CONFIG_NFT_COMPAT_MODULE 1
#define CONFIG_NET_DSA_TAG_XRS700X_MODULE 1
#define CONFIG_HAVE_KERNEL_XZ 1
#define CONFIG_RTC_DRV_CMOS 1
#define CONFIG_CRYPTO_ALGAPI2 1
#define CONFIG_SQUASHFS_ZSTD 1
#define CONFIG_SCSI_PMCRAID_MODULE 1
#define CONFIG_DMA_CMA 1
#define CONFIG_BCM7XXX_PHY_MODULE 1
#define CONFIG_SENSORS_SBTSI_MODULE 1
#define CONFIG_CPU_MITIGATIONS 1
#define CONFIG_TOUCHSCREEN_WM97XX_MODULE 1
#define CONFIG_OCFS2_DEBUG_MASKLOG 1
#define CONFIG_MEDIA_TUNER_R820T_MODULE 1
#define CONFIG_NTB_MODULE 1
#define CONFIG_NLS_ISO8859_4_MODULE 1
#define CONFIG_INTEL_CHTDC_TI_PWRBTN_MODULE 1
#define CONFIG_RAID6_PQ 1
#define CONFIG_SND_BEBOB_MODULE 1
#define CONFIG_DRM_I915_GVT_KVMGT_MODULE 1
#define CONFIG_TOUCHSCREEN_SUR40_MODULE 1
#define CONFIG_REGULATOR_SLG51000_MODULE 1
#define CONFIG_HID_WACOM_MODULE 1
#define CONFIG_SENSORS_MP2975_MODULE 1
#define CONFIG_MD_RAID0_MODULE 1
#define CONFIG_TULIP_NAPI 1
#define CONFIG_CHARGER_MT6370_MODULE 1
#define CONFIG_CLZ_TAB 1
#define CONFIG_PROC_MEM_ALWAYS_FORCE 1
#define CONFIG_SND_INTEL8X0M_MODULE 1
#define CONFIG_BLKDEV_UBLK_LEGACY_OPCODES 1
#define CONFIG_SND_CS4281_MODULE 1
#define CONFIG_CHROME_PLATFORMS 1
#define CONFIG_IA32_EMULATION 1
#define CONFIG_ARCH_USES_PG_ARCH_2 1
#define CONFIG_NVME_TARGET_MODULE 1
#define CONFIG_PINCONF 1
#define CONFIG_PM_DEVFREQ_EVENT 1
#define CONFIG_SF_PDMA_MODULE 1
#define CONFIG_SND_HDA_PATCH_LOADER 1
#define CONFIG_GPIO_CGBC_MODULE 1
#define CONFIG_FUNCTION_ALIGNMENT 16
#define CONFIG_X86_LOCAL_APIC 1
#define CONFIG_F2FS_STAT_FS 1
#define CONFIG_SND_COMPRESS_OFFLOAD_MODULE 1
#define CONFIG_MODULE_COMPRESS_ZSTD 1
#define CONFIG_VIRTIO_RTC_PTP 1
#define CONFIG_SND_DESIGNWARE_I2S_MODULE 1
#define CONFIG_CFG80211_USE_KERNEL_REGDB_KEYS 1
#define CONFIG_NCN26000_PHY_MODULE 1
#define CONFIG_MTRR_SANITIZER_ENABLE_DEFAULT 1
#define CONFIG_NETFILTER_XT_MATCH_PKTTYPE_MODULE 1
#define CONFIG_CRYPTO_XTS 1
#define CONFIG_SND_SOC_SRC4XXX_I2C_MODULE 1
#define CONFIG_PCMCIA_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_MAC_MODULE 1
#define CONFIG_IIO_SW_DEVICE_MODULE 1
#define CONFIG_INET6_ESPINTCP 1
#define CONFIG_SND_SOC_INTEL_SOF_CS42L42_MACH_MODULE 1
#define CONFIG_AMD_IOMMU 1
#define CONFIG_DVB_TC90522_MODULE 1
#define CONFIG_PHY_SAMSUNG_USB2_MODULE 1
#define CONFIG_LEDS_TRIGGER_HEARTBEAT_MODULE 1
#define CONFIG_ARCH_SUPPORTS_CRASH_HOTPLUG 1
#define CONFIG_REGULATOR_TPS65086_MODULE 1
#define CONFIG_INET_SCTP_DIAG_MODULE 1
#define CONFIG_X86_PLATFORM_DRIVERS_HP 1
#define CONFIG_SI1133_MODULE 1
#define CONFIG_RTW88_8822B_MODULE 1
#define CONFIG_PPS_MODULE 1
#define CONFIG_NFC_PORT100_MODULE 1
#define CONFIG_INTERCONNECT 1
#define CONFIG_MAC80211_HAS_RC 1
#define CONFIG_CRASH_MAX_MEMORY_RANGES 8192
#define CONFIG_NLS_MAC_GREEK_MODULE 1
#define CONFIG_SND_SOC_WM8753_MODULE 1
#define CONFIG_VIDEO_EM28XX_MODULE 1
#define CONFIG_GLOB 1
#define CONFIG_RTW89_8851BU_MODULE 1
#define CONFIG_CAN_SJA1000_ISA_MODULE 1
#define CONFIG_ATH12K_MODULE 1
#define CONFIG_OCTEON_EP_VF_MODULE 1
#define CONFIG_CAN_BCM_MODULE 1
#define CONFIG_PAC1921_MODULE 1
#define CONFIG_SPI_MICROCHIP_CORE_QSPI_MODULE 1
#define CONFIG_SCSI_SYM53C8XX_DMA_ADDRESSING_MODE 1
#define CONFIG_SENSORS_TMP421_MODULE 1
#define CONFIG_USB_GSPCA_MARS_MODULE 1
#define CONFIG_IP_ROUTE_CLASSID 1
#define CONFIG_ST_UVIS25_I2C_MODULE 1
#define CONFIG_VIDEO_VIVID_OSD 1
#define CONFIG_BACKLIGHT_LV5207LP_MODULE 1
#define CONFIG_GPIO_MAX7360_MODULE 1
#define CONFIG_RPMSG_MODULE 1
#define CONFIG_INFINIBAND_BNG_RE_MODULE 1
#define CONFIG_FM10K_MODULE 1
#define CONFIG_DEVMEM 1
#define CONFIG_SENSORS_ADS7871_MODULE 1
#define CONFIG_USBIP_HOST_MODULE 1
#define CONFIG_BACKLIGHT_GPIO_MODULE 1
#define CONFIG_VIDEO_IMX214_MODULE 1
#define CONFIG_SAMSUNG_Q10_MODULE 1
#define CONFIG_USB_GADGET_VBUS_DRAW 2
#define CONFIG_NETFILTER_XT_CONNMARK_MODULE 1
#define CONFIG_NFS_V4_SECURITY_LABEL 1
#define CONFIG_MFD_ARIZONA_MODULE 1
#define CONFIG_ISCSI_IBFT_MODULE 1
#define CONFIG_DRM_I915_USERFAULT_AUTOSUSPEND 250
#define CONFIG_NET_DSA_YT921X_MODULE 1
#define CONFIG_KEXEC_CORE 1
#define CONFIG_MFD_BD9571MWV_MODULE 1
#define CONFIG_NET_9P_FD_MODULE 1
#define CONFIG_MEDIA_TUNER_TDA18218_MODULE 1
#define CONFIG_DVB_DRXD_MODULE 1
#define CONFIG_DRIVER_DEFERRED_PROBE_TIMEOUT 10
#define CONFIG_LSM "landlock,lockdown,yama,integrity,bpf"
#define CONFIG_MTD_PSTORE_MODULE 1
#define CONFIG_SND_HDA_EXT_CORE_MODULE 1
#define CONFIG_REGULATOR_WM8350_MODULE 1
#define CONFIG_ARCH_HAS_PKEYS 1
#define CONFIG_USB_FUNCTIONFS_RNDIS 1
#define CONFIG_I2C_USBIO_MODULE 1
#define CONFIG_BMC150_ACCEL_I2C_MODULE 1
#define CONFIG_DELL_WMI_PRIVACY 1
#define CONFIG_SND_AMD_ASOC_RENOIR_MODULE 1
#define CONFIG_PALMAS_GPADC_MODULE 1
#define CONFIG_HID_RETRODE_MODULE 1
#define CONFIG_TIPC_MEDIA_IB 1
#define CONFIG_USB_NET_MCS7830_MODULE 1
#define CONFIG_GNSS_USB_MODULE 1
#define CONFIG_FB_CFB_COPYAREA 1
#define CONFIG_IB700_WDT_MODULE 1
#define CONFIG_CRYPTO_ALGAPI 1
#define CONFIG_ICP10100_MODULE 1
#define CONFIG_DYNAMIC_EVENTS 1
#define CONFIG_HTU21_MODULE 1
#define CONFIG_SND_PCXHR_MODULE 1
#define CONFIG_SND_SOC_TLV320AIC23_MODULE 1
#define CONFIG_CHARGER_MAX77693_MODULE 1
#define CONFIG_VIRTIO_VFIO_PCI_ADMIN_LEGACY 1
#define CONFIG_SERIAL_EARLYCON 1
#define CONFIG_HP_WMI_MODULE 1
#define CONFIG_RTC_DRV_M41T94_MODULE 1
#define CONFIG_SND_SOC_INTEL_USER_FRIENDLY_LONG_NAMES 1
#define CONFIG_CAN_NCT6694_MODULE 1
#define CONFIG_NF_NAT_IRC_MODULE 1
#define CONFIG_GET_FREE_REGION 1
#define CONFIG_USB_F_HID_MODULE 1
#define CONFIG_AD5770R_MODULE 1
#define CONFIG_DEVPORT 1
#define CONFIG_SPI_ALTERA_CORE_MODULE 1
#define CONFIG_SENSORS_HIH6130_MODULE 1
#define CONFIG_MFD_INTEL_M10_BMC_CORE_MODULE 1
#define CONFIG_USB 1
#define CONFIG_NETFILTER_XT_TARGET_CT_MODULE 1
#define CONFIG_SND_SOC_SOF_INTEL_ATOM_HIFI_EP_MODULE 1
#define CONFIG_N_HDLC_MODULE 1
#define CONFIG_ATH9K_STATION_STATISTICS 1
#define CONFIG_ELF_CORE 1
#define CONFIG_MFD_WM831X 1
#define CONFIG_PCI_HOST_COMMON 1
#define CONFIG_TASK_DELAY_ACCT 1
#define CONFIG_F2FS_FS_XATTR 1
#define CONFIG_JOYSTICK_DB9_MODULE 1
#define CONFIG_DVB_ATBM8830_MODULE 1
#define CONFIG_SERIAL_FSL_LPUART_MODULE 1
#define CONFIG_DM_DELAY_MODULE 1
#define CONFIG_SCSI_QLOGIC_1280_MODULE 1
#define CONFIG_DVB_PLL_MODULE 1
#define CONFIG_THERMAL 1
#define CONFIG_SPI_AX88796C_COMPRESSION 1
#define CONFIG_NFC_ST21NFCA_MODULE 1
#define CONFIG_SI7020_MODULE 1
#define CONFIG_DEBUG_INFO_DWARF5 1
#define CONFIG_NETFILTER_BPF_LINK 1
#define CONFIG_DVB_LG2160_MODULE 1
#define CONFIG_BEFS_FS_MODULE 1
#define CONFIG_REGULATOR_TWL4030_MODULE 1
#define CONFIG_NET_VENDOR_DLINK 1
#define CONFIG_IP_SET_HASH_IPPORTNET_MODULE 1
#define CONFIG_I2C_MUX_MLXCPLD_MODULE 1
#define CONFIG_SND_USB_US144MKII_MODULE 1
#define CONFIG_KVM_SMM 1
#define CONFIG_PPPOE_HASH_BITS 4
#define CONFIG_CAN_EMS_USB_MODULE 1
#define CONFIG_FTRACE_SYSCALLS 1
#define CONFIG_SND_HDA_CODEC_ALC262_MODULE 1
#define CONFIG_PINCTRL_BROXTON_MODULE 1
#define CONFIG_NET_TEAM_MODE_ROUNDROBIN_MODULE 1
#define CONFIG_CAN_VXCAN_MODULE 1
#define CONFIG_DVB_USB_NOVA_T_USB2_MODULE 1
#define CONFIG_SENSORS_LTC4245_MODULE 1
#define CONFIG_SENSORS_AS370_MODULE 1
#define CONFIG_UCSI_STM32G0_MODULE 1
#define CONFIG_CRYPTO_MD5 1
#define CONFIG_SND_DRIVERS 1
#define CONFIG_REGULATOR_FAN53555_MODULE 1
#define CONFIG_NET_VENDOR_EZCHIP 1
#define CONFIG_IIO_KX022A_SPI_MODULE 1
#define CONFIG_SND_AC97_POWER_SAVE_DEFAULT 10
#define CONFIG_INTEL_MEI_LB_MODULE 1
#define CONFIG_X86_BUS_LOCK_DETECT 1
#define CONFIG_INPUT_CMA3000_MODULE 1
#define CONFIG_DVB_USB_CXUSB_ANALOG 1
#define CONFIG_SMSC9420_MODULE 1
#define CONFIG_ATH6KL_MODULE 1
#define CONFIG_INPUT_KEYSPAN_REMOTE_MODULE 1
#define CONFIG_ATH9K_HTC_MODULE 1
#define CONFIG_DM_AUDIT 1
#define CONFIG_NETFILTER_XT_MATCH_POLICY_MODULE 1
#define CONFIG_HALTPOLL_CPUIDLE_MODULE 1
#define CONFIG_XZ_DEC_X86 1
#define CONFIG_USB_ISP1301_MODULE 1
#define CONFIG_SND_HDA_HWDEP 1
#define CONFIG_DA9150_GPADC_MODULE 1
#define CONFIG_VT_CONSOLE_SLEEP 1
#define CONFIG_NLS_KOI8_U_MODULE 1
#define CONFIG_NET_VENDOR_SOCIONEXT 1
#define CONFIG_SCSI_SPI_ATTRS_MODULE 1
#define CONFIG_RUSTC_VERSION 109701
#define CONFIG_CRYPTO_SERPENT_MODULE 1
#define CONFIG_MTD_BLKDEVS_MODULE 1
#define CONFIG_SENSORS_NZXT_KRAKEN3_MODULE 1
#define CONFIG_KEYBOARD_MAX7359_MODULE 1
#define CONFIG_MCP4018_MODULE 1
#define CONFIG_SND_SOC_INTEL_BYTCR_RT5640_MACH_MODULE 1
#define CONFIG_DEBUG_KERNEL 1
#define CONFIG_MDIO_MSCC_MIIM_MODULE 1
#define CONFIG_KEXEC_HANDOVER_DEBUGFS 1
#define CONFIG_SND_SOC_INTEL_SOUNDWIRE_SOF_MACH_MODULE 1
#define CONFIG_RCU_NOCB_CPU 1
#define CONFIG_SURFACE_HOTPLUG_MODULE 1
#define CONFIG_ASYNC_TX_DMA 1
#define CONFIG_MFD_MT6370_MODULE 1
#define CONFIG_SND_SOC_PCM512x_I2C_MODULE 1
#define CONFIG_DRM_XE_DP_TUNNEL 1
#define CONFIG_SCSI_QLA_ISCSI_MODULE 1
#define CONFIG_NVME_TARGET_PASSTHRU 1
#define CONFIG_CAN_M_CAN_MODULE 1
#define CONFIG_MOUSE_ELAN_I2C_SMBUS 1
#define CONFIG_CEC_CORE_MODULE 1
#define CONFIG_BRCM_TRACING 1
#define CONFIG_BATTERY_MAX17040_MODULE 1
#define CONFIG_WLAN_VENDOR_TI 1
#define CONFIG_EEPROM_93CX6_MODULE 1
#define CONFIG_VIDEOBUF2_CORE_MODULE 1
#define CONFIG_PCIE_EDR 1
#define CONFIG_USB_SERIAL_DEBUG_MODULE 1
#define CONFIG_HID_VIEWSONIC_MODULE 1
#define CONFIG_MISC_FILESYSTEMS 1
#define CONFIG_QUOTA_TREE_MODULE 1
#define CONFIG_NFT_FIB_MODULE 1
#define CONFIG_NET_DSA_REALTEK_MODULE 1
#define CONFIG_MDIO_BITBANG_MODULE 1
#define CONFIG_NET_ACT_TUNNEL_KEY_MODULE 1
#define CONFIG_CGROUP_RDMA 1
#define CONFIG_USB_XEN_HCD_MODULE 1
#define CONFIG_CAN_PLX_PCI_MODULE 1
#define CONFIG_DP83TD510_PHY_MODULE 1
#define CONFIG_INOTIFY_USER 1
#define CONFIG_DVB_CX22702_MODULE 1
#define CONFIG_USB_GSPCA_VICAM_MODULE 1
#define CONFIG_TOUCHSCREEN_CHIPONE_ICN8505_MODULE 1
#define CONFIG_NLS_ISO8859_7_MODULE 1
#define CONFIG_ALTERA_MSGDMA_MODULE 1
#define CONFIG_BMI088_ACCEL_SPI_MODULE 1
#define CONFIG_SENSORS_LTC2947_SPI_MODULE 1
#define CONFIG_PHYLIB_MODULE 1
#define CONFIG_HIBMCGE_MODULE 1
#define CONFIG_B43_HWRNG 1
#define CONFIG_DVB_GP8PSK_FE_MODULE 1
#define CONFIG_SQUASHFS_MOUNT_DECOMP_THREADS 1
#define CONFIG_SPI_MUX_MODULE 1
#define CONFIG_ARCH_HAS_GIGANTIC_PAGE 1
#define CONFIG_KEYBOARD_OPENCORES_MODULE 1
#define CONFIG_NR_CPUS_DEFAULT 8192
#define CONFIG_FPGA_DFL_FME_REGION_MODULE 1
#define CONFIG_SND_SOC_TLV320ADCX140_MODULE 1
#define CONFIG_DEV_DAX_HMEM_MODULE 1
#define CONFIG_SND_SOC_INTEL_SKL_HDA_DSP_GENERIC_MACH_MODULE 1
#define CONFIG_REGULATOR_TPS65090_MODULE 1
#define CONFIG_NET_EMATCH_IPT_MODULE 1
#define CONFIG_USB_MICROTEK_MODULE 1
#define CONFIG_HDMI 1
#define CONFIG_IOMMU_PT_X86_64 1
#define CONFIG_SND_SOC_RT5659_MODULE 1
#define CONFIG_NET_UDP_TUNNEL_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_COMPOSITE_MODULE 1
#define CONFIG_SND_SOC_WM8804_I2C_MODULE 1
#define CONFIG_X86_DEBUGCTLMSR 1
#define CONFIG_DVB_USB_DIB3000MC_MODULE 1
#define CONFIG_DRM_GM12U320_MODULE 1
#define CONFIG_RTW88_8822CS_MODULE 1
#define CONFIG_NET_DSA_TAG_RTL8_4_MODULE 1
#define CONFIG_SND_SOC_SSM2602_I2C_MODULE 1
#define CONFIG_SIEMENS_SIMATIC_IPC_BATT_F7188X_MODULE 1
#define CONFIG_MODULE_FORCE_LOAD 1
#define CONFIG_GEHC_PMC_ADC_MODULE 1
#define CONFIG_DEV_DAX_FSDEV_MODULE 1
#define CONFIG_INPUT_TABLET 1
#define CONFIG_CRYPTO_BLOWFISH_X86_64_MODULE 1
#define CONFIG_V4L_PLATFORM_DRIVERS 1
#define CONFIG_NCSI_OEM_CMD_GET_MAC 1
#define CONFIG_MAXIM_THERMOCOUPLE_MODULE 1
#define CONFIG_PPPOE_MODULE 1
#define CONFIG_SND_SOC_FSL_UTILS_MODULE 1
#define CONFIG_LIBERTAS_THINFIRM_MODULE 1
#define CONFIG_HAVE_ARCH_SOFT_DIRTY 1
#define CONFIG_DP83867_PHY_MODULE 1
#define CONFIG_XILINX_GMII2RGMII_MODULE 1
#define CONFIG_SYSFB_SIMPLEFB 1
#define CONFIG_HUAWEI_WMI_MODULE 1
#define CONFIG_CAN_GS_USB_MODULE 1
#define CONFIG_XILINX_DMA_MODULE 1
#define CONFIG_HAVE_DYNAMIC_FTRACE_WITH_ARGS 1
#define CONFIG_TSL2583_MODULE 1
#define CONFIG_PATA_AMD_MODULE 1
#define CONFIG_ARCH_HAS_SYSCALL_WRAPPER 1
#define CONFIG_WLAN_VENDOR_QUANTENNA 1
#define CONFIG_REED_SOLOMON_MODULE 1
#define CONFIG_HAVE_ARCH_MMAP_RND_COMPAT_BITS 1
#define CONFIG_SND_SOC_SOF_JASPERLAKE_MODULE 1
#define CONFIG_USERIO_MODULE 1
#define CONFIG_FAT_DEFAULT_CODEPAGE 437
#define CONFIG_SND_SOC_INTEL_AVS_MACH_MAX98357A_MODULE 1
#define CONFIG_RDMA_SIW_MODULE 1
#define CONFIG_SCSI_UFS_BSG 1
#define CONFIG_VIDEO_OV01A10_MODULE 1
#define CONFIG_RMI4_2D_SENSOR 1
#define CONFIG_DMA_COHERENT_POOL 1
#define CONFIG_JSA1212_MODULE 1
#define CONFIG_SENSORS_LM25066_MODULE 1
#define CONFIG_AD9834_MODULE 1
#define CONFIG_NET_DSA_SJA1105_TAS 1
#define CONFIG_MMC_REALTEK_PCI_MODULE 1
#define CONFIG_SOUNDWIRE_AMD_MODULE 1
#define CONFIG_SENSORS_PC87360_MODULE 1
#define CONFIG_MFD_RC5T583 1
#define CONFIG_SND_SOC_INTEL_CATPT_MODULE 1
#define CONFIG_HYPERV 1
#define CONFIG_NLATTR 1
#define CONFIG_TI_LMP92064_MODULE 1
#define CONFIG_SUNRPC_XPRT_RDMA_MODULE 1
#define CONFIG_DVB_SI21XX_MODULE 1
#define CONFIG_SLAB_BUCKETS 1
#define CONFIG_ACPI_PCI_SLOT 1
#define CONFIG_PDC_ADMA_MODULE 1
#define CONFIG_RT2800PCI_RT3290 1
#define CONFIG_HAVE_GUP_FAST 1
#define CONFIG_SENSORS_Q54SJ108A2_MODULE 1
#define CONFIG_MLX4_EN_DCB 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_DA7219_MODULE 1
#define CONFIG_NFT_REJECT_INET_MODULE 1
#define CONFIG_SND_OXYGEN_LIB_MODULE 1
#define CONFIG_REGULATOR_MAX8893_MODULE 1
#define CONFIG_CORDIC_MODULE 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_SSM4567_MODULE 1
#define CONFIG_SND_SOC_SMA1307_MODULE 1
#define CONFIG_ADXL372_SPI_MODULE 1
#define CONFIG_DRM_ST7571_SPI_MODULE 1
#define CONFIG_RTC_DRV_M48T35_MODULE 1
#define CONFIG_NUMA_BALANCING_DEFAULT_ENABLED 1
#define CONFIG_MFD_AS3711 1
#define CONFIG_SCHED_MC 1
#define CONFIG_HYPERV_KEYBOARD_MODULE 1
#define CONFIG_PATA_PARPORT_FRPW_MODULE 1
#define CONFIG_RTC_DRV_PCF2127_MODULE 1
#define CONFIG_NET_SCH_DEFAULT 1
#define CONFIG_TCP_CONG_ADVANCED 1
#define CONFIG_CEPH_FS_SECURITY_LABEL 1
#define CONFIG_AD5761_MODULE 1
#define CONFIG_REGULATOR_TPS62360_MODULE 1
#define CONFIG_MLX5_TC_CT 1
#define CONFIG_ARCH_HAS_CC_PLATFORM 1
#define CONFIG_SND_SOC_RT5682_MODULE 1
#define CONFIG_USB_KAWETH_MODULE 1
#define CONFIG_USB_NET_CDC_MBIM_MODULE 1
#define CONFIG_SENSORS_LM90_MODULE 1
#define CONFIG_JOYSTICK_QWIIC_MODULE 1
#define CONFIG_MCTP_TRANSPORT_USB_MODULE 1
#define CONFIG_CHROMEOS_PRIVACY_SCREEN_MODULE 1
#define CONFIG_DE2104X_DSL 0
#define CONFIG_MMU_NOTIFIER 1
#define CONFIG_NFT_REJECT_NETDEV_MODULE 1
#define CONFIG_FUSION 1
#define CONFIG_CRYPTO_CAMELLIA_MODULE 1
#define CONFIG_HID_GFRM_MODULE 1
#define CONFIG_RTC_DRV_M41T93_MODULE 1
#define CONFIG_SENSORS_DA9052_ADC_MODULE 1
#define CONFIG_AD4851_MODULE 1
#define CONFIG_MEDIA_USB_SUPPORT 1
#define CONFIG_RTW89_DEBUG 1
#define CONFIG_ADE9000_MODULE 1
#define CONFIG_MOUSE_ELAN_I2C_MODULE 1
#define CONFIG_RTLWIFI_MODULE 1
#define CONFIG_SMB_SERVER_CHECK_CAP_NET_ADMIN 1
#define CONFIG_HAVE_EBPF_JIT 1
#define CONFIG_USB_SERIAL_EMPEG_MODULE 1
#define CONFIG_NET_ACT_MIRRED_MODULE 1
#define CONFIG_NET_VENDOR_ADAPTEC 1
#define CONFIG_BACKLIGHT_ADP5520_MODULE 1
#define CONFIG_NET_VENDOR_WANGXUN 1
#define CONFIG_INTEGRITY 1
#define CONFIG_PM_OPP 1
#define CONFIG_RFS_ACCEL 1
#define CONFIG_FUNCTION_ALIGNMENT_16B 1
#define CONFIG_SCSI_MPT3SAS_MODULE 1
#define CONFIG_KALLSYMS 1
#define CONFIG_SND_SOC_SOF_PCI_DEV_MODULE 1
#define CONFIG_INPUT_AXP20X_PEK_MODULE 1
#define CONFIG_X86_AMD_PSTATE_DEFAULT_MODE 3
#define CONFIG_FUSION_MAX_SGE 128
#define CONFIG_LEDS_TRIGGER_ACTIVITY_MODULE 1
#define CONFIG_HID_PLANTRONICS_MODULE 1
#define CONFIG_HID_SEMITEK_MODULE 1
#define CONFIG_REGULATOR_RT4831_MODULE 1
#define CONFIG_SMS_SIANO_MDTV_MODULE 1
#define CONFIG_INPUT_E3X0_BUTTON_MODULE 1
#define CONFIG_XEN_AUTO_XLATE 1
#define CONFIG_SND_SOC_CS42L51_MODULE 1
#define CONFIG_I2C_CGBC_MODULE 1
#define CONFIG_LEDS_LM3532_MODULE 1
#define CONFIG_SND_SOC_SOF_INTEL_TGL_MODULE 1
#define CONFIG_SLIP_MODE_SLIP6 1
#define CONFIG_SCSI_MOD 1
#define CONFIG_SND_SEQ_UMP_CLIENT_MODULE 1
#define CONFIG_PPS_CLIENT_KTIMER_MODULE 1
#define CONFIG_INPUT_DRV260X_HAPTICS_MODULE 1
#define CONFIG_ZSMALLOC_CHAIN_SIZE 8
#define CONFIG_CUSE_MODULE 1
#define CONFIG_IIO_MODULE 1
#define CONFIG_ATH9K_HW_MODULE 1
#define CONFIG_FUNCTION_GRAPH_TRACER 1
#define CONFIG_BCMA_DRIVER_GPIO 1
#define CONFIG_NET_DSA_AR9331_MODULE 1
#define CONFIG_RTC_DRV_MAX8925_MODULE 1
#define CONFIG_DVB_BUDGET_CI_MODULE 1
#define CONFIG_MAX5432_MODULE 1
#define CONFIG_I2C_HELPER_AUTO 1
#define CONFIG_TOUCHSCREEN_TOUCHWIN_MODULE 1
#define CONFIG_NTB_IDT_MODULE 1
#define CONFIG_REGULATOR_ARIZONA_LDO1_MODULE 1
#define CONFIG_HZ 1000
#define CONFIG_I2C_PARPORT_MODULE 1
#define CONFIG_ATH12K_TRACING 1
#define CONFIG_TRACING 1
#define CONFIG_ACPI 1
#define CONFIG_RCU_EXPERT 1
#define CONFIG_ARCH_USE_QUEUED_SPINLOCKS 1
#define CONFIG_SP5100_TCO_MODULE 1
#define CONFIG_MLX5_TC_SAMPLE 1
#define CONFIG_IWLWIFI_LEDS 1
#define CONFIG_CHECKPOINT_RESTORE 1
#define CONFIG_PCI_LOCKLESS_CONFIG 1
#define CONFIG_BLK_DEV_DM_MODULE 1
#define CONFIG_FONT_TER16x32 1
#define CONFIG_JAILHOUSE_GUEST 1
#define CONFIG_ICE_HWMON 1
#define CONFIG_NF_CONNTRACK_LABELS 1
#define CONFIG_NETFILTER_NETLINK_OSF_MODULE 1
#define CONFIG_KVM_COMMON 1
#define CONFIG_W1_SLAVE_DS2406_MODULE 1
#define CONFIG_RUNTIME_TESTING_MENU 1
#define CONFIG_SND_SOC_AMD_LEGACY_SDW_MACH_MODULE 1
#define CONFIG_SENSORS_ISL29018_MODULE 1
#define CONFIG_ENS160_I2C_MODULE 1
#define CONFIG_RTW88_PCI_MODULE 1
#define CONFIG_VIRTUALIZATION 1
#define CONFIG_MFD_VX855_MODULE 1
#define CONFIG_USB_SERIAL_NAVMAN_MODULE 1
#define CONFIG_SND_SOC_CS40L50_MODULE 1
#define CONFIG_USB_CONFIGFS_F_PRINTER 1
#define CONFIG_TCS3414_MODULE 1
#define CONFIG_CHELSIO_T4_MODULE 1
#define CONFIG_DRM_RADEON_MODULE 1
#define CONFIG_DVB_USB_AZ6027_MODULE 1
#define CONFIG_NET_CLS_FLOWER_MODULE 1
#define CONFIG_DVB_MT312_MODULE 1
#define CONFIG_I2C_KEMPLD_MODULE 1
#define CONFIG_INTEL_SOC_PMIC_CHTDC_TI_MODULE 1
#define CONFIG_TOUCHSCREEN_IQS5XX_MODULE 1
#define CONFIG_TASKSTATS 1
#define CONFIG_TI_TLC4541_MODULE 1
#define CONFIG_TARGET_CORE_MODULE 1
#define CONFIG_USB_CONFIGFS_F_FS 1
#define CONFIG_NFT_FIB_NETDEV_MODULE 1
#define CONFIG_IP6_NF_TARGET_MASQUERADE_MODULE 1
#define CONFIG_PTDUMP 1
#define CONFIG_SND_MIA_MODULE 1
#define CONFIG_PATA_PARPORT_MODULE 1
#define CONFIG_INTEL_THC_HID_MODULE 1
#define CONFIG_VIDEO_IMX258_MODULE 1
#define CONFIG_MDIO_REGMAP_MODULE 1
#define CONFIG_IO_URING_BPF_OPS 1
#define CONFIG_CXL_REGION 1
#define CONFIG_GENERIC_CLOCKEVENTS_BROADCAST_IDLE 1
#define CONFIG_ZONEFS_FS_MODULE 1
#define CONFIG_MT76_CORE_MODULE 1
#define CONFIG_MTDRAM_ERASE_SIZE 128
#define CONFIG_DYNAMIC_FTRACE_WITH_ARGS 1
#define CONFIG_RTW89_DEBUGMSG 1
#define CONFIG_SENSORS_MR75203_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_AUDIT_MODULE 1
#define CONFIG_TOUCHSCREEN_MTOUCH_MODULE 1
#define CONFIG_ATH9K_DEBUGFS 1
#define CONFIG_CXL_PORT_MODULE 1
#define CONFIG_SMPRO_ERRMON_MODULE 1
#define CONFIG_PHY_PXA_28NM_USB2_MODULE 1
#define CONFIG_DRM_I915_PXP 1
#define CONFIG_UIO_SERCOS3_MODULE 1
#define CONFIG_OPENVSWITCH_MODULE 1
#define CONFIG_COMMON_CLK_CS2000_CP_MODULE 1
#define CONFIG_MFD_MAX5970_MODULE 1
#define CONFIG_ACPI_FFH 1
#define CONFIG_SFC_MCDI_LOGGING 1
#define CONFIG_QLCNIC_DCB 1
#define CONFIG_IPV6_SIT_MODULE 1
#define CONFIG_INTEL_SCU_IPC 1
#define CONFIG_RTC_DRV_WM8350_MODULE 1
#define CONFIG_RT2800_LIB_MMIO_MODULE 1
#define CONFIG_AD9523_MODULE 1
#define CONFIG_DMABUF_HEAPS 1
#define CONFIG_SND_SOC_RT5645_MODULE 1
#define CONFIG_SENSORS_APS_379_MODULE 1
#define CONFIG_OA_TC6_MODULE 1
#define CONFIG_STE10XP_MODULE 1
#define CONFIG_FS_POSIX_ACL 1
#define CONFIG_DVB_CX24110_MODULE 1
#define CONFIG_BLK_DEV_RAM_COUNT 16
#define CONFIG_INTERVAL_TREE_SPAN_ITER 1
#define CONFIG_NLS_ISO8859_6_MODULE 1
#define CONFIG_USB_STORAGE_USBAT_MODULE 1
#define CONFIG_SENSORS_ADC128D818_MODULE 1
#define CONFIG_RTW88_8821AU_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_DSCP_MODULE 1
#define CONFIG_INPUT_ATLAS_BTNS_MODULE 1
#define CONFIG_CRYPTO_ARIA_MODULE 1
#define CONFIG_USB_GSPCA_SQ905C_MODULE 1
#define CONFIG_MT7921U_MODULE 1
#define CONFIG_DRM_XE_MODULE 1
#define CONFIG_INET_RAW_DIAG_MODULE 1
#define CONFIG_ADL8113_MODULE 1
#define CONFIG_DVB_TDA10086_MODULE 1
#define CONFIG_ASUS_WIRELESS_MODULE 1
#define CONFIG_SND_HDA_CODEC_HDMI_INTEL_MODULE 1
#define CONFIG_DW_WATCHDOG_MODULE 1
#define CONFIG_VALIDATE_FS_PARSER 1
#define CONFIG_IR_IMON_MODULE 1
#define CONFIG_SLIP_COMPRESSED 1
#define CONFIG_HOTPLUG_PCI_CPCI_GENERIC_MODULE 1
#define CONFIG_DRM_VMWGFX_MODULE 1
#define CONFIG_PREEMPTION 1
#define CONFIG_BINARY_PRINTF 1
#define CONFIG_SND_SOC_PCM3060_SPI_MODULE 1
#define CONFIG_INTEL_SCU 1
#define CONFIG_TIGON3_HWMON 1
#define CONFIG_HAVE_ARCH_KCSAN 1
#define CONFIG_UIO_DMEM_GENIRQ_MODULE 1
#define CONFIG_SND_SOC_AMD_SDW_MACH_COMMON_MODULE 1
#define CONFIG_HAVE_PERF_EVENTS_NMI 1
#define CONFIG_USB_SERIAL_MOS7715_PARPORT 1
#define CONFIG_SND_SOC_NAU8315_MODULE 1
#define CONFIG_VIDEO_RDACM20_MODULE 1
#define CONFIG_QCOM_TZMEM_MODULE 1
#define CONFIG_INPUT_ADXL34X_SPI_MODULE 1
#define CONFIG_MFD_CORE 1
#define CONFIG_PVPANIC_PCI_MODULE 1
#define CONFIG_SPI_PXA2XX_PCI_MODULE 1
#define CONFIG_TRACE_IRQFLAGS_SUPPORT 1
#define CONFIG_BATTERY_DS2782_MODULE 1
#define CONFIG_IPVLAN_L3S 1
#define CONFIG_CRYPTO_XXHASH 1
#define CONFIG_SENSORS_NCT7363_MODULE 1
#define CONFIG_AD525X_DPOT_I2C_MODULE 1
#define CONFIG_IR_SHARP_DECODER_MODULE 1
#define CONFIG_TIMERFD 1
#define CONFIG_RTC_HCTOSYS_DEVICE "rtc0"
#define CONFIG_JOYSTICK_FSIA6B_MODULE 1
#define CONFIG_SND_SOC_LPASS_WSA_MACRO_MODULE 1
#define CONFIG_MFD_DA9055 1
#define CONFIG_SND_USB_POD_MODULE 1
#define CONFIG_UFS_FS_MODULE 1
#define CONFIG_PSTORE_BLK_BLKDEV ""
#define CONFIG_USB_STORAGE_FREECOM_MODULE 1
#define CONFIG_DRM_SSD130X_MODULE 1
#define CONFIG_PATA_PARPORT_DSTR_MODULE 1
#define CONFIG_SENSORS_W83627HF_MODULE 1
#define CONFIG_KEYS_REQUEST_CACHE 1
#define CONFIG_SEL3350_PLATFORM_MODULE 1
#define CONFIG_SND_SOC_INTEL_BDW_RT5650_MACH_MODULE 1
#define CONFIG_MLX5_VFIO_PCI_MODULE 1
#define CONFIG_SND_SOC_NTP8835_MODULE 1
#define CONFIG_BCM84881_PHY_MODULE 1
#define CONFIG_SND_JACK_INPUT_DEV 1
#define CONFIG_MFD_MAX8998 1
#define CONFIG_JFFS2_FS_MODULE 1
#define CONFIG_SND_SOC_SOF_INTEL_PTL_MODULE 1
#define CONFIG_SND_SOC_UDA1334_MODULE 1
#define CONFIG_DRM_CLIENT_SETUP 1
#define CONFIG_VIDEO_OG0VE1B_MODULE 1
#define CONFIG_NET_VENDOR_MYRI 1
#define CONFIG_NET_VENDOR_META 1
#define CONFIG_REGULATOR_WM8400_MODULE 1
#define CONFIG_IKCONFIG_PROC 1
#define CONFIG_NET_TEAM_MODE_LOADBALANCE_MODULE 1
#define CONFIG_USB_SERIAL_ARK3116_MODULE 1
#define CONFIG_SECURITY_PATH 1
#define CONFIG_LEDS_PCA955X_MODULE 1
#define CONFIG_HID_SUNPLUS_MODULE 1
#define CONFIG_CRYPTO_SERPENT_SSE2_X86_64_MODULE 1
#define CONFIG_DRM_I915_USERPTR 1
#define CONFIG_SERIO_I8042 1
#define CONFIG_NET_IFE_SKBMARK_MODULE 1
#define CONFIG_SND_HDA_ACPI_MODULE 1
#define CONFIG_UCLAMP_BUCKETS_COUNT 5
#define CONFIG_MCP3422_MODULE 1
#define CONFIG_NF_NAT_SNMP_BASIC_MODULE 1
#define CONFIG_ADIS16201_MODULE 1
#define CONFIG_SND_EMU10K1_SEQ_MODULE 1
#define CONFIG_MEN_A21_WDT_MODULE 1
#define CONFIG_LLC2_MODULE 1
#define CONFIG_VMCORE_INFO 1
#define CONFIG_CAN_MCBA_USB_MODULE 1
#define CONFIG_SND_KORG1212_MODULE 1
#define CONFIG_GPIB_TMS9914_MODULE 1
#define CONFIG_INTEL_TH_ACPI_MODULE 1
#define CONFIG_TI_ADS7950_MODULE 1
#define CONFIG_SND_SOC_ACPI_MODULE 1
#define CONFIG_SIOX_MODULE 1
#define CONFIG_INTEL_TH_GTH_MODULE 1
#define CONFIG_DRM_PANEL_MIPI_DBI_MODULE 1
#define CONFIG_DLM_DEBUG 1
#define CONFIG_SCD4X_MODULE 1
#define CONFIG_USB_NET_CH9200_MODULE 1
#define CONFIG_USB_SI470X_MODULE 1
#define CONFIG_CHARGER_MAX8971_MODULE 1
#define CONFIG_SND_SOC_CS35L56_SHARED_MODULE 1
#define CONFIG_NFT_FWD_NETDEV_MODULE 1
#define CONFIG_LCD_LMS501KF03_MODULE 1
#define CONFIG_AD5766_MODULE 1
#define CONFIG_FB_CORE 1
#define CONFIG_LENOVO_WMI_HOTKEY_UTILITIES_MODULE 1
#define CONFIG_DRM_GEM_DMA_HELPER_MODULE 1
#define CONFIG_VIDEO_S5KJN1_MODULE 1
#define CONFIG_SENSORS_LM93_MODULE 1
#define CONFIG_IRQ_DOMAIN 1
#define CONFIG_HID_ELO_MODULE 1
#define CONFIG_SND_SOC_AMD_SOUNDWIRE_MODULE 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_NAU8825_MODULE 1
#define CONFIG_HAVE_KERNEL_GZIP 1
#define CONFIG_PROBE_EVENTS 1
#define CONFIG_BPF_JIT_ALWAYS_ON 1
#define CONFIG_LDISC_AUTOLOAD 1
#define CONFIG_MITIGATION_SPECTRE_V1 1
#define CONFIG_DYNAMIC_DEBUG_CORE 1
#define CONFIG_XDP_SOCKETS_DIAG_MODULE 1
#define CONFIG_PCI_PRI 1
#define CONFIG_ADXL313_SPI_MODULE 1
#define CONFIG_MFD_JANZ_CMODIO_MODULE 1
#define CONFIG_SIS190_MODULE 1
#define CONFIG_DEVICE_PRIVATE 1
#define CONFIG_CRYPTO_AKCIPHER2 1
#define CONFIG_WATCHDOG_HANDLE_BOOT_ENABLED 1
#define CONFIG_INTEL_POWERCLAMP_MODULE 1
#define CONFIG_NF_NAT_REDIRECT 1
#define CONFIG_GPIO_TPIC2810_MODULE 1
#define CONFIG_SECURITY_SELINUX_SIDTAB_HASH_BITS 9
#define CONFIG_SWIOTLB 1
#define CONFIG_SENSORS_SMSC47B397_MODULE 1
#define CONFIG_SCHED_AUTOGROUP 1
#define CONFIG_GIGABYTE_WMI_MODULE 1
#define CONFIG_IGC_MODULE 1
#define CONFIG_FW_ATTR_CLASS_MODULE 1
#define CONFIG_IP_VS_SH_MODULE 1
#define CONFIG_USB_XHCI_DBGCAP 1
#define CONFIG_NETFILTER_XT_MATCH_CPU_MODULE 1
#define CONFIG_SCSI_MVSAS_DEBUG 1
#define CONFIG_HAVE_ARCH_HUGE_VMALLOC 1
#define CONFIG_DEVFREQ_GOV_USERSPACE_MODULE 1
#define CONFIG_MFD_INTEL_M10_BMC_SPI_MODULE 1
#define CONFIG_NFT_CONNLIMIT_MODULE 1
#define CONFIG_INPUT_TWL4030_VIBRA_MODULE 1
#define CONFIG_LEDS_LM3533_MODULE 1
#define CONFIG_SCREEN_INFO 1
#define CONFIG_NLS_MAC_CYRILLIC_MODULE 1
#define CONFIG_INTEL_MEI_MODULE 1
#define CONFIG_GPIO_RC5T583 1
#define CONFIG_BT_BCM_MODULE 1
#define CONFIG_HARDENED_USERCOPY 1
#define CONFIG_BUILDTIME_MCOUNT_SORT 1
#define CONFIG_TOUCHSCREEN_EETI_MODULE 1
#define CONFIG_SND_SOC_AMD_ACP_COMMON_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_MARK_MODULE 1
#define CONFIG_ACPI_EXTLOG_MODULE 1
#define CONFIG_HAS_IOMEM 1
#define CONFIG_NET_SCH_BPF 1
#define CONFIG_SIEMENS_SIMATIC_IPC_BATT_APOLLOLAKE_MODULE 1
#define CONFIG_HAVE_CMPXCHG_DOUBLE 1
#define CONFIG_KEYBOARD_MAX7360_MODULE 1
#define CONFIG_PCIEASPM 1
#define CONFIG_CMA_AREAS 7
#define CONFIG_MVMDIO_MODULE 1
#define CONFIG_SECURITY_APPARMOR_PARANOID_LOAD 1
#define CONFIG_NETFILTER_XTABLES_MODULE 1
#define CONFIG_MT7915E_MODULE 1
#define CONFIG_SND_SOC_AMD_SOF_SDW_MACH_MODULE 1
#define CONFIG_CM36651_MODULE 1
#define CONFIG_MEDIA_TUNER_MXL5007T_MODULE 1
#define CONFIG_WAFER_WDT_MODULE 1
#define CONFIG_BT_MRVL_SDIO_MODULE 1
#define CONFIG_UIO_AEC_MODULE 1
#define CONFIG_SERIAL_UARTLITE_MODULE 1
#define CONFIG_LIBIPW_MODULE 1
#define CONFIG_RESET_TI_TPS380X_MODULE 1
#define CONFIG_B43LEGACY_MODULE 1
#define CONFIG_X86_SGX_KVM 1
#define CONFIG_SCSI_FDOMAIN_PCI_MODULE 1
#define CONFIG_W1_SLAVE_DS2405_MODULE 1
#define CONFIG_TRACER_MAX_TRACE 1
#define CONFIG_KEY_NOTIFICATIONS 1
#define CONFIG_XEN_GRANT_DMA_OPS 1
#define CONFIG_USB_USBIO_MODULE 1
#define CONFIG_SND_SOC_TAS2781_COMLIB_I2C_MODULE 1
#define CONFIG_WWAN_HWSIM_MODULE 1
#define CONFIG_IPV6_MULTIPLE_TABLES 1
#define CONFIG_BRIDGE_EBT_T_FILTER_MODULE 1
#define CONFIG_USB_ADUTUX_MODULE 1
#define CONFIG_SENSORS_BPA_RS600_MODULE 1
#define CONFIG_SENSORS_SMPRO_MODULE 1
#define CONFIG_INTEL_IDXD_PERFMON 1
#define CONFIG_SND_SOC_ACPI_INTEL_SDCA_QUIRKS_MODULE 1
#define CONFIG_CRYPTO_LIB_AESCFB 1
#define CONFIG_BT_HCIBTSDIO_MODULE 1
#define CONFIG_REGULATOR_DA9062_MODULE 1
#define CONFIG_SENSORS_IR35221_MODULE 1
#define CONFIG_DVB_USB_A800_MODULE 1
#define CONFIG_IR_STREAMZAP_MODULE 1
#define CONFIG_BNXT_DCB 1
#define CONFIG_NF_CONNTRACK_PROCFS 1
#define CONFIG_NF_CONNTRACK_H323_MODULE 1
#define CONFIG_MEDIA_TUNER_FC0011_MODULE 1
#define CONFIG_HID_UNIVERSAL_PIDFF_MODULE 1
#define CONFIG_VHOST_NET_MODULE 1
#define CONFIG_TCP_CONG_BBR3_MODULE 1
#define CONFIG_B53_SPI_DRIVER_MODULE 1
#define CONFIG_IP_VS_PROTO_UDP 1
#define CONFIG_ARCH_HAS_DEVMEM_IS_ALLOWED 1
#define CONFIG_USB_CHIPIDEA_UDC 1
#define CONFIG_XZ_DEC_POWERPC 1
#define CONFIG_SND_SOC_TAS2770_MODULE 1
#define CONFIG_BPF 1
#define CONFIG_USB_CONFIGFS_F_MIDI 1
#define CONFIG_XZ_DEC_ARM64 1
#define CONFIG_LOCALVERSION ""
#define CONFIG_IIO_CROS_EC_BARO_MODULE 1
#define CONFIG_MMC_SDHCI_F_SDH30_MODULE 1
#define CONFIG_USB_CONFIGFS_F_HID 1
#define CONFIG_INTEL_MRFLD_PWRBTN_MODULE 1
#define CONFIG_HID_GT683R_MODULE 1
#define CONFIG_SND_SOC_CS42XX8_MODULE 1
#define CONFIG_MOUSE_PS2_SYNAPTICS 1
#define CONFIG_SND_SOC_TAS2780_MODULE 1
#define CONFIG_BT_INTEL_MODULE 1
#define CONFIG_IOSCHED_BFQ 1
#define CONFIG_AXP288_CHARGER_MODULE 1
#define CONFIG_LIBETH_MODULE 1
#define CONFIG_SECURITY_SMACK 1
#define CONFIG_MICROCHIP_PHY_MODULE 1
#define CONFIG_PINCTRL_AMD 1
#define CONFIG_HID_EVISION_MODULE 1
#define CONFIG_TYPEC_NVIDIA_ALTMODE_MODULE 1
#define CONFIG_DVB_RTL2830_MODULE 1
#define CONFIG_USB_STORAGE_DATAFAB_MODULE 1
#define CONFIG_SENSORS_MPQ8785_MODULE 1
#define CONFIG_DVB_USB_AF9015_MODULE 1
#define CONFIG_PATA_HPT366_MODULE 1
#define CONFIG_HID_TWINHAN_MODULE 1
#define CONFIG_GPIO_TPS6586X 1
#define CONFIG_NET_DSA_SJA1105_MODULE 1
#define CONFIG_REGMAP_MMIO 1
#define CONFIG_KEXEC 1
#define CONFIG_MMC_TEST_MODULE 1
#define CONFIG_TCG_TIS_ST33ZP24_I2C_MODULE 1
#define CONFIG_SND_ALOOP_MODULE 1
#define CONFIG_SND_HRTIMER_MODULE 1
#define CONFIG_HPET 1
#define CONFIG_NF_NAT_SIP_MODULE 1
#define CONFIG_SFC_SIENA_MCDI_LOGGING 1
#define CONFIG_HVC_IRQ 1
#define CONFIG_B53_MDIO_DRIVER_MODULE 1
#define CONFIG_RT2X00_LIB_MMIO_MODULE 1
#define CONFIG_NLS_ISO8859_9_MODULE 1
#define CONFIG_CHARGER_BD99954_MODULE 1
#define CONFIG_IP_NF_TARGET_ECN_MODULE 1
#define CONFIG_INTEL_MEI_WDT_MODULE 1
#define CONFIG_REGULATOR_PV88090_MODULE 1
#define CONFIG_PDS_CORE_MODULE 1
#define CONFIG_CRYPTO_ADIANTUM_MODULE 1
#define CONFIG_DRM_VIRTIO_GPU_KMS 1
#define CONFIG_CRYPTO_BLOWFISH_COMMON_MODULE 1
#define CONFIG_CROS_EC_TYPEC_MODULE 1
#define CONFIG_DVB_TTUSB_BUDGET_MODULE 1
#define CONFIG_SLUB 1
#define CONFIG_SND_SOC_AMD_SOUNDWIRE_LINK_BASELINE_MODULE 1
#define CONFIG_MFD_LP3943_MODULE 1
#define CONFIG_X86_POWERNOW_K8_MODULE 1
#define CONFIG_SND_SOC_AMD_ACPI_MACH_MODULE 1
#define CONFIG_NET_SCH_PRIO_MODULE 1
#define CONFIG_AD8460_MODULE 1
#define CONFIG_DA9063_WATCHDOG_MODULE 1
#define CONFIG_IFB_MODULE 1
#define CONFIG_GPIO_74X164_MODULE 1
#define CONFIG_SND_SOC_CS35L56_SPI_MODULE 1
#define CONFIG_VIDEO_RDACM21_MODULE 1
#define CONFIG_STACKPROTECTOR 1
#define CONFIG_INPUT_IMS_PCU_MODULE 1
#define CONFIG_EXT4_FS_POSIX_ACL 1
#define CONFIG_NET_VENDOR_AMD 1
#define CONFIG_T5403_MODULE 1
#define CONFIG_SND_SOC_UDA1342_MODULE 1
#define CONFIG_VIDEO_OV7670_MODULE 1
#define CONFIG_BATTERY_DS2781_MODULE 1
#define CONFIG_MOUSE_PS2_ALPS 1
#define CONFIG_IR_MCEUSB_MODULE 1
#define CONFIG_USB_SERIAL_CP210X_MODULE 1
#define CONFIG_PTP_NETC_V4_TIMER_MODULE 1
#define CONFIG_TCG_CRB 1
#define CONFIG_SLIP_MODULE 1
#define CONFIG_HP_ILO_MODULE 1
#define CONFIG_SND_SOC_SSM2602_SPI_MODULE 1
#define CONFIG_VIDEO_OV5695_MODULE 1
#define CONFIG_SND_SOC_AW88399_MODULE 1
#define CONFIG_SND_SOC_TOPOLOGY 1
#define CONFIG_DVB_USB_DW2102_MODULE 1
#define CONFIG_IP_NF_IPTABLES_MODULE 1
#define CONFIG_TSM_REPORTS_MODULE 1
#define CONFIG_SND_SOC_ADAU1761_MODULE 1
#define CONFIG_USB_IOWARRIOR_MODULE 1
#define CONFIG_REGULATOR_MAX20411_MODULE 1
#define CONFIG_ST_UVIS25_SPI_MODULE 1
#define CONFIG_DRM_XE_PAGEMAP 1
#define CONFIG_HID_KENSINGTON_MODULE 1
#define CONFIG_SND_ES1938_MODULE 1
#define CONFIG_PCI_IDE 1
#define CONFIG_USB_GSPCA_STV0680_MODULE 1
#define CONFIG_B43_PCICORE_AUTOSELECT 1
#define CONFIG_HAVE_REGS_AND_STACK_ACCESS_API 1
#define CONFIG_EARLY_PRINTK_DBGP 1
#define CONFIG_GENERIC_ADC_THERMAL_MODULE 1
#define CONFIG_X86_FRED 1
#define CONFIG_SND_SOC_WM8750_MODULE 1
#define CONFIG_USB_GSPCA_SN9C20X_MODULE 1
#define CONFIG_REGULATOR_MAX77838_MODULE 1
#define CONFIG_HAVE_STACK_VALIDATION 1
#define CONFIG_DVB_ZL10353_MODULE 1
#define CONFIG_MFD_MAX8997 1
#define CONFIG_OCTEONEP_VDPA_MODULE 1
#define CONFIG_TABLET_USB_ACECAD_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_DSCP_MODULE 1
#define CONFIG_LTC2309_MODULE 1
#define CONFIG_USB_PXA27X_MODULE 1
#define CONFIG_PWM_LPSS_PLATFORM_MODULE 1
#define CONFIG_SCD30_CORE_MODULE 1
#define CONFIG_HAVE_SAMPLE_FTRACE_DIRECT 1
#define CONFIG_SND_USB_PODHD_MODULE 1
#define CONFIG_E1000E_HWTS 1
#define CONFIG_USB_DUMMY_HCD_MODULE 1
#define CONFIG_HAVE_GIGANTIC_FOLIOS 1
#define CONFIG_DVB_TDA8083_MODULE 1
#define CONFIG_PATA_PARPORT_COMM_MODULE 1
#define CONFIG_B53_SERDES_MODULE 1
#define CONFIG_USB_DWC2_PCI_MODULE 1
#define CONFIG_INET_PSP 1
#define CONFIG_KVM_INTEL_TDX 1
#define CONFIG_AD9832_MODULE 1
#define CONFIG_FIRMWARE_MEMMAP 1
#define CONFIG_PORTWELL_EC_MODULE 1
#define CONFIG_ARCH_DMA_ADDR_T_64BIT 1
#define CONFIG_DVB_STV090x_MODULE 1
#define CONFIG_AIC7XXX_RESET_DELAY_MS 15000
#define CONFIG_VIRTIO_VSOCKETS_COMMON_MODULE 1
#define CONFIG_NFT_COMPAT_ARP_MODULE 1
#define CONFIG_ASUS_WMI_MODULE 1
#define CONFIG_HID_A4TECH_MODULE 1
#define CONFIG_VIDEO_IMX319_MODULE 1
#define CONFIG_USB_F_FS_MODULE 1
#define CONFIG_SENSORS_ADT7X10_MODULE 1
#define CONFIG_DVB_ASCOT2E_MODULE 1
#define CONFIG_LEDS_CLASS_FLASH_MODULE 1
#define CONFIG_VIDEO_CX88_BLACKBIRD_MODULE 1
#define CONFIG_ASUS_LAPTOP_MODULE 1
#define CONFIG_LENOVO_WMI_GAMEZONE_MODULE 1
#define CONFIG_EFI_ESRT 1
#define CONFIG_MEDIA_TUNER_TEA5767_MODULE 1
#define CONFIG_WATCH_QUEUE 1
#define CONFIG_NET_TULIP 1
#define CONFIG_SND_SOC_TLV320AIC3X_SPI_MODULE 1
#define CONFIG_CRYPTO_LIB_ARC4_MODULE 1
#define CONFIG_AGP 1
#define CONFIG_MFD_CS40L50_CORE_MODULE 1
#define CONFIG_SENSORS_LM92_MODULE 1
#define CONFIG_MMC_SDRICOH_CS_MODULE 1
#define CONFIG_TEXTSEARCH_BM_MODULE 1
#define CONFIG_RTC_DRV_DS1553_MODULE 1
#define CONFIG_RTC_DRV_HID_SENSOR_TIME_MODULE 1
#define CONFIG_REGULATOR_TPS6105X_MODULE 1
#define CONFIG_SND_PROC_FS 1
#define CONFIG_USB_GSPCA_SUNPLUS_MODULE 1
#define CONFIG_HID_SENSOR_INCLINOMETER_3D_MODULE 1
#define CONFIG_FPGA_MGR_XILINX_SPI_MODULE 1
#define CONFIG_BATMAN_ADV_DAT 1
#define CONFIG_UTS_NS 1
#define CONFIG_MLX5_FPGA 1
#define CONFIG_HAVE_IRQ_TIME_ACCOUNTING 1
#define CONFIG_PATA_CYPRESS_MODULE 1
#define CONFIG_ACPI_APEI_PCIEAER 1
#define CONFIG_MITIGATION_SPECTRE_V2 1
#define CONFIG_CRYPTO_CTR 1
#define CONFIG_SND_SOC_RT1017_SDCA_SDW_MODULE 1
#define CONFIG_DVB_M88DS3103_MODULE 1
#define CONFIG_TOUCHSCREEN_DA9052_MODULE 1
#define CONFIG_SERIAL_8250_PCILIB 1
#define CONFIG_SHUFFLE_PAGE_ALLOCATOR 1
#define CONFIG_WFX_MODULE 1
#define CONFIG_DVB_AF9013_MODULE 1
#define CONFIG_CAN_VCAN_MODULE 1
#define CONFIG_POSIX_CPU_TIMERS_TASK_WORK 1
#define CONFIG_SND_INTEL_NHLT 1
#define CONFIG_HID_ALPS_MODULE 1
#define CONFIG_IGB_MODULE 1
#define CONFIG_INTEL_HID_EVENT_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_SECMARK_MODULE 1
#define CONFIG_SCSI_AIC94XX_MODULE 1
#define CONFIG_MWIFIEX_MODULE 1
#define CONFIG_INTEL_HFI_THERMAL 1
#define CONFIG_TOUCHSCREEN_USB_ITM 1
#define CONFIG_VHOST_MENU 1
#define CONFIG_GPIO_MAX3191X_MODULE 1
#define CONFIG_LOG_CPU_MAX_BUF_SHIFT 12
#define CONFIG_NTFS_FS_POSIX_ACL 1
#define CONFIG_TYPEC_STUSB160X_MODULE 1
#define CONFIG_ARCH_CPUIDLE_HALTPOLL 1
#define CONFIG_LEDS_USER_MODULE 1
#define CONFIG_AD5686_SPI_MODULE 1
#define CONFIG_SENSORS_FSCHMD_MODULE 1
#define CONFIG_EXTCON_MAX8997_MODULE 1
#define CONFIG_SENSORS_MP2925_MODULE 1
#define CONFIG_LENOVO_SE30_WDT_MODULE 1
#define CONFIG_BLK_DEV_FD_MODULE 1
#define CONFIG_USB_EHCI_TT_NEWSCHED 1
#define CONFIG_SENSORS_NCT6775_CORE_MODULE 1
#define CONFIG_PARPORT_SERIAL_MODULE 1
#define CONFIG_REDMI_WMI_MODULE 1
#define CONFIG_BMG160_I2C_MODULE 1
#define CONFIG_RMI4_F03 1
#define CONFIG_CRYPTO_CBC 1
#define CONFIG_SND_USB_AUDIO_QMI_MODULE 1
#define CONFIG_SND_PCM_MODULE 1
#define CONFIG_ALIBABA_ENI_VDPA_MODULE 1
#define CONFIG_SND_SOC_GTM601_MODULE 1
#define CONFIG_SND_SEQ_MIDI_EVENT_MODULE 1
#define CONFIG_6LOWPAN_NHC_MOBILITY_MODULE 1
#define CONFIG_INTEL_TPMI_MODULE 1
#define CONFIG_NFS_ACL_SUPPORT_MODULE 1
#define CONFIG_HAVE_KVM_PM_NOTIFIER 1
#define CONFIG_HAVE_KERNEL_LZO 1
#define CONFIG_CGROUP_WRITEBACK 1
#define CONFIG_SECURITY_LOCKDOWN_LSM 1
#define CONFIG_SENSORS_LATTEPANDA_SIGMA_EC_MODULE 1
#define CONFIG_I2C_MUX_PCA9541_MODULE 1
#define CONFIG_NET_DEVLINK 1
#define CONFIG_DRM_I915_REQUEST_TIMEOUT 20000
#define CONFIG_FUTEX_MPOL 1
#define CONFIG_IIO_ST_LSM6DSX_I2C_MODULE 1
#define CONFIG_SND_SOC_WCD939X_MODULE 1
#define CONFIG_USB_CATC_MODULE 1
#define CONFIG_RMI4_F12 1
#define CONFIG_HOTPLUG_CORE_SYNC_DEAD 1
#define CONFIG_AD8366_MODULE 1
#define CONFIG_MARVELL_88X2222_PHY_MODULE 1
#define CONFIG_BMG160_MODULE 1
#define CONFIG_HP_ACCEL_MODULE 1
#define CONFIG_DCA_MODULE 1
#define CONFIG_MAC80211_RC_DEFAULT_MINSTREL 1
#define CONFIG_NF_CONNTRACK_SNMP_MODULE 1
#define CONFIG_CRASH_DM_CRYPT 1
#define CONFIG_NLS_KOI8_R_MODULE 1
#define CONFIG_CRYPTO_LIB_POLY1305_ARCH 1
#define CONFIG_SND_SOC_DA7219_MODULE 1
#define CONFIG_RTW88_8821A_MODULE 1
#define CONFIG_ENS160_SPI_MODULE 1
#define CONFIG_TEXTSEARCH_KMP_MODULE 1
#define CONFIG_DVB_EC100_MODULE 1
#define CONFIG_P54_USB_MODULE 1
#define CONFIG_SENSIRION_SGP40_MODULE 1
#define CONFIG_IIO_ST_SENSORS_I2C_MODULE 1
#define CONFIG_SPI_TLE62X0_MODULE 1
#define CONFIG_HIST_TRIGGERS 1
#define CONFIG_DM_MULTIPATH_ST_MODULE 1
#define CONFIG_REGMAP_SCCB_MODULE 1
#define CONFIG_NETFILTER_INGRESS 1
#define CONFIG_W1_SLAVE_DS2433_MODULE 1
#define CONFIG_MFD_CS42L43_I2C_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_CONNMARK_MODULE 1
#define CONFIG_WL1251_SPI_MODULE 1
#define CONFIG_RTW89_8852CU_MODULE 1
#define CONFIG_LEDS_NIC78BX_MODULE 1
#define CONFIG_SERIO_PCIPS2_MODULE 1
#define CONFIG_RT2800PCI_RT33XX 1
#define CONFIG_IIO_BUFFER_HW_CONSUMER_MODULE 1
#define CONFIG_DVB_DS3000_MODULE 1
#define CONFIG_VIDEO_RJ54N1_MODULE 1
#define CONFIG_AMD8111_ETH_MODULE 1
#define CONFIG_NF_FLOW_TABLE_INET_MODULE 1
#define CONFIG_ACCESSIBILITY 1
#define CONFIG_KRETPROBE_ON_RETHOOK 1
#define CONFIG_AM2315_MODULE 1
#define CONFIG_NS83820_MODULE 1
#define CONFIG_USB_NET_HUAWEI_CDC_NCM_MODULE 1
#define CONFIG_DM_MULTIPATH_IOA_MODULE 1
#define CONFIG_SND_SOC_TFA9879_MODULE 1
#define CONFIG_ACPI_PROCESSOR_AGGREGATOR_MODULE 1
#define CONFIG_USB_STORAGE_JUMPSHOT_MODULE 1
#define CONFIG_BCMA_DRIVER_PCI 1
#define CONFIG_BT_LEDS 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_PROBE_MODULE 1
#define CONFIG_PATA_ATIIXP_MODULE 1
#define CONFIG_PATA_HPT3X3_DMA 1
#define CONFIG_USB_F_UVC_MODULE 1
#define CONFIG_CRYPTO_DEV_AMLOGIC_GXL_DEBUG 1
#define CONFIG_SENSORS_MP5926_MODULE 1
#define CONFIG_NLS_ISO8859_8_MODULE 1
#define CONFIG_TOUCHSCREEN_ATMEL_MXT_MODULE 1
#define CONFIG_ACPI_SLEEP 1
#define CONFIG_SENSORS_ISL68137_MODULE 1
#define CONFIG_CX_ECAT_MODULE 1
#define CONFIG_UID16 1
#define CONFIG_SND_SOC_ALC5623_MODULE 1
#define CONFIG_PCENGINES_APU2_MODULE 1
#define CONFIG_XZ_DEC_MICROLZMA 1
#define CONFIG_TIPC_MEDIA_UDP 1
#define CONFIG_CHROMEOS_LAPTOP_MODULE 1
#define CONFIG_SWAP 1
#define CONFIG_CB710_DEBUG_ASSUMPTIONS 1
#define CONFIG_MTD_UBI_NVMEM_MODULE 1
#define CONFIG_SND_SOC_WCD938X_SDW_MODULE 1
#define CONFIG_ASYNC_RAID6_TEST_MODULE 1
#define CONFIG_EPIC100_MODULE 1
#define CONFIG_MAGIC_SYSRQ_SERIAL 1
#define CONFIG_HAVE_STACKPROTECTOR 1
#define CONFIG_BNX2_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_LOG_MODULE 1
#define CONFIG_MT7615E_MODULE 1
#define CONFIG_HW_RANDOM_AMD_MODULE 1
#define CONFIG_ACPI_MDIO_MODULE 1
#define CONFIG_FXOS8700_I2C_MODULE 1
#define CONFIG_HMC425_MODULE 1
#define CONFIG_SENSORS_THMC50_MODULE 1
#define CONFIG_SENSORS_STPDDC60_MODULE 1
#define CONFIG_SENSORS_MP9945_MODULE 1
#define CONFIG_MFD_MAX14577_MODULE 1
#define CONFIG_BATTERY_DS2780_MODULE 1
#define CONFIG_SND_SEQ_MIDI_EMUL_MODULE 1
#define CONFIG_SND_SOC_WSA881X_MODULE 1
#define CONFIG_HAVE_ARCH_JUMP_LABEL 1
#define CONFIG_USB_CONFIGFS_ECM 1
#define CONFIG_GPIO_VIPERBOARD_MODULE 1
#define CONFIG_CRYPTO_PCBC_MODULE 1
#define CONFIG_COMPAL_LAPTOP_MODULE 1
#define CONFIG_INPUT_ADXL34X_I2C_MODULE 1
#define CONFIG_IEEE802154_MCR20A_MODULE 1
#define CONFIG_PLATFORM_SI4713_MODULE 1
#define CONFIG_NETDEVSIM_MODULE 1
#define CONFIG_CRYPTO_CAMELLIA_X86_64_MODULE 1
#define CONFIG_STEAM_FF 1
#define CONFIG_RTC_DRV_DA9052_MODULE 1
#define CONFIG_WIZNET_BUS_ANY 1
#define CONFIG_BCMA_MODULE 1
#define CONFIG_LEDS_DA9052_MODULE 1
#define CONFIG_HID_HOLTEK_MODULE 1
#define CONFIG_DRM_VBOXVIDEO_MODULE 1
#define CONFIG_NETCONSOLE_DYNAMIC 1
#define CONFIG_NF_CONNTRACK_BROADCAST_MODULE 1
#define CONFIG_BOARD_TPCI200_MODULE 1
#define CONFIG_GENWQE_MODULE 1
#define CONFIG_ARCH_HAS_NON_OVERLAPPING_ADDRESS_SPACE 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_RT5514_MODULE 1
#define CONFIG_CHARGER_RT9455_MODULE 1
#define CONFIG_RT2800USB_RT33XX 1
#define CONFIG_ISL29125_MODULE 1
#define CONFIG_MMC_SDHCI_PLTFM_MODULE 1
#define CONFIG_PATA_PARPORT_FIT2_MODULE 1
#define CONFIG_KVM_MAX_NR_VCPUS 1024
#define CONFIG_SENSORS_SPD5118_DETECT 1
#define CONFIG_MT76x0_COMMON_MODULE 1
#define CONFIG_CXL_MEM_MODULE 1
#define CONFIG_SND_OPL3_LIB_MODULE 1
#define CONFIG_PINCTRL_MCP23S08_I2C_MODULE 1
#define CONFIG_BXT_WC_PMIC_OPREGION 1
#define CONFIG_DELL_SMBIOS_SMM 1
#define CONFIG_VIRTIO_PMEM_MODULE 1
#define CONFIG_NFT_SYNPROXY_MODULE 1
#define CONFIG_HID_ZYDACRON_MODULE 1
#define CONFIG_PREEMPT_RCU 1
#define CONFIG_KEMPLD_WDT_MODULE 1
#define CONFIG_USB_NET_ZAURUS_MODULE 1
#define CONFIG_VIDEO_SAA6588_MODULE 1
#define CONFIG_ADIS16203_MODULE 1
#define CONFIG_HAVE_SYSCALL_TRACEPOINTS 1
#define CONFIG_IOMMU_IOVA 1
#define CONFIG_INV_ICM45600_MODULE 1
#define CONFIG_EEEPC_LAPTOP_MODULE 1
#define CONFIG_I2C_LJCA_MODULE 1
#define CONFIG_XOR_BLOCKS 1
#define CONFIG_DNOTIFY 1
#define CONFIG_LEDS_TRIGGER_BACKLIGHT_MODULE 1
#define CONFIG_BPF_STREAM_PARSER 1
#define CONFIG_MEDIA_SUBDRV_AUTOSELECT 1
#define CONFIG_RDS_MODULE 1
#define CONFIG_XILINX_VCU_MODULE 1
#define CONFIG_I2C_ROBOTFUZZ_OSIF_MODULE 1
#define CONFIG_NET_DSA_MICROCHIP_KSZ9477_I2C_MODULE 1
#define CONFIG_MACVLAN_MODULE 1
#define CONFIG_SENSORS_SHT15_MODULE 1
#define CONFIG_ARCH_SUPPORTS_KEXEC 1
#define CONFIG_IP_NF_RAW_MODULE 1
#define CONFIG_HAVE_HW_BREAKPOINT 1
#define CONFIG_BRIDGE_NF_EBTABLES_LEGACY_MODULE 1
#define CONFIG_SECURITY_SMACK_BRINGUP 1
#define CONFIG_SENSORS_MCP9982_MODULE 1
#define CONFIG_PHY_COMMON_PROPS 1
#define CONFIG_AD5764_MODULE 1
#define CONFIG_MOUSE_VSXXXAA_MODULE 1
#define CONFIG_CLK_TWL6040_MODULE 1
#define CONFIG_SPI_CH341_MODULE 1
#define CONFIG_VIDEO_TEA6420_MODULE 1
#define CONFIG_SCSI_MPT3SAS_MAX_SGE 128
#define CONFIG_VIDEO_DT3155_MODULE 1
#define CONFIG_DRM_PANEL_BACKLIGHT_QUIRKS_MODULE 1
#define CONFIG_CRYPTO_CTS 1
#define CONFIG_DVB_USB_EC168_MODULE 1
#define CONFIG_TDX_GUEST_DRIVER_MODULE 1
#define CONFIG_RSI_91X_MODULE 1
#define CONFIG_SND_SOC_WCD_CLASSH_MODULE 1
#define CONFIG_USB_GSPCA_SPCA1528_MODULE 1
#define CONFIG_TOUCHSCREEN_ILI210X_MODULE 1
#define CONFIG_AD7625_MODULE 1
#define CONFIG_GPIO_AGGREGATOR_MODULE 1
#define CONFIG_BMA220_SPI_MODULE 1
#define CONFIG_SND_FIREWIRE_LIB_MODULE 1
#define CONFIG_ARCH_VMLINUX_NEEDS_RELOCS 1
#define CONFIG_HAVE_NMI 1
#define CONFIG_EXTCON_RT8973A_MODULE 1
#define CONFIG_CC_HAS_INT128 1
#define CONFIG_SENSORS_F75375S_MODULE 1
#define CONFIG_SND_INDIGOIOX_MODULE 1
#define CONFIG_SND_SOC_SOF_TOPLEVEL 1
#define CONFIG_SND_SOC_INTEL_SOF_NUVOTON_COMMON_MODULE 1
#define CONFIG_SCSI_NETLINK 1
#define CONFIG_CRYPTO_USER_API_AEAD_MODULE 1
#define CONFIG_INTEL_VBTN_MODULE 1
#define CONFIG_SPI_KSPI2_MODULE 1
#define CONFIG_NETCONSOLE_MODULE 1
#define CONFIG_THINKPAD_ACPI_ALSA_SUPPORT 1
#define CONFIG_SND_SOC_PM4125_MODULE 1
#define CONFIG_NVSW_SN2201_MODULE 1
#define CONFIG_HAVE_VIRT_CPU_ACCOUNTING_GEN 1
#define CONFIG_VIRTIO_VFIO_PCI_MODULE 1
#define CONFIG_SND_HDSPM_MODULE 1
#define CONFIG_X86_CHECK_BIOS_CORRUPTION 1
#define CONFIG_ACPI_WMI_MODULE 1
#define CONFIG_GENERIC_CLOCKEVENTS_BROADCAST 1
#define CONFIG_CRYPTO_DEV_SAFEXCEL_MODULE 1
#define CONFIG_DVB_TTUSB_DEC_MODULE 1
#define CONFIG_RTC_NVMEM 1
#define CONFIG_RTC_DRV_SD2405AL_MODULE 1
#define CONFIG_SURFACE3_WMI_MODULE 1
#define CONFIG_WATCHDOG_PRETIMEOUT_GOV_NOOP_MODULE 1
#define CONFIG_SND_SOC_WCD937X_MODULE 1
#define CONFIG_PINCTRL_MAX7360_MODULE 1
#define CONFIG_HAVE_ARCH_COMPAT_MMAP_BASES 1
#define CONFIG_SPS30_I2C_MODULE 1
#define CONFIG_XEN_PVHVM_SMP 1
#define CONFIG_KEYBOARD_LM8323_MODULE 1
#define CONFIG_IIO_SSP_SENSORHUB_MODULE 1
#define CONFIG_TOUCHSCREEN_IMAGIS_MODULE 1
#define CONFIG_SCSI_HPTIOP_MODULE 1
#define CONFIG_JFS_POSIX_ACL 1
#define CONFIG_VIDEO_AU0828_RC 1
#define CONFIG_LCD_HX8357_MODULE 1
#define CONFIG_P54_SPI_MODULE 1
#define CONFIG_DELL_WMI_DESCRIPTOR_MODULE 1
#define CONFIG_WATCHDOG_SYSFS 1
#define CONFIG_ARCH_SUPPORTS_PUD_PFNMAP 1
#define CONFIG_OPT4001_MODULE 1
#define CONFIG_SENSORS_POWERZ_MODULE 1
#define CONFIG_MEDIA_ALTERA_CI_MODULE 1
#define CONFIG_PM_TRACE_RTC 1
#define CONFIG_SENSORS_TPS546D24_MODULE 1
#define CONFIG_NCSI_OEM_CMD_KEEP_PHY 1
#define CONFIG_USB_SERIAL_QT2_MODULE 1
#define CONFIG_SPI_GPIO_MODULE 1
#define CONFIG_HID_LED_MODULE 1
#define CONFIG_KEYBOARD_ADP5588_MODULE 1
#define CONFIG_FB_SYS_FILLRECT 1
#define CONFIG_SENSORS_I5K_AMB_MODULE 1
#define CONFIG_INTEL_IDXD_BUS_MODULE 1
#define CONFIG_I2C_DIOLAN_U2C_MODULE 1
#define CONFIG_SND_SOC_WCD9335_MODULE 1
#define CONFIG_XARRAY_MULTI 1
#define CONFIG_USB_SERIAL_IPW_MODULE 1
#define CONFIG_DRM_ACCEL_QAIC_MODULE 1
#define CONFIG_USBIP_VUDC_MODULE 1
#define CONFIG_RMI4_F11 1
#define CONFIG_ARCH_SUPPORTS_KEXEC_FILE 1
#define CONFIG_DCB 1
#define CONFIG_ZSWAP 1
#define CONFIG_VIDEO_IMX111_MODULE 1
#define CONFIG_SENSORS_TMP103_MODULE 1
#define CONFIG_MT7921_COMMON_MODULE 1
#define CONFIG_HX9023S_MODULE 1
#define CONFIG_SND_SOC_RT1015P_MODULE 1
#define CONFIG_RTLWIFI_DEBUG 1
#define CONFIG_TI_ADS8344_MODULE 1
#define CONFIG_USB_R8A66597_HCD_MODULE 1
#define CONFIG_MEDIA_TUNER_FC0013_MODULE 1
#define CONFIG_SENSORS_ADM1025_MODULE 1
#define CONFIG_INPUT_AD714X_MODULE 1
#define CONFIG_CRYPTO_TWOFISH_MODULE 1
#define CONFIG_HAVE_ARCH_PREL32_RELOCATIONS 1
#define CONFIG_ATH5K_TRACER 1
#define CONFIG_PACKING 1
#define CONFIG_FUSION_SPI_MODULE 1
#define CONFIG_IPV6_MIP6_MODULE 1
#define CONFIG_SND_FM801_TEA575X_BOOL 1
#define CONFIG_NET_DSA_QCA8K_LEDS_SUPPORT 1
#define CONFIG_W1_SLAVE_DS2430_MODULE 1
#define CONFIG_BT_HCIUART_QCA 1
#define CONFIG_MHI_NET_MODULE 1
#define CONFIG_STREAM_PARSER 1
#define CONFIG_SND_SOC_SOF_AMD_RENOIR_MODULE 1
#define CONFIG_WINBOND_840_MODULE 1
#define CONFIG_XEN_COMPAT_XENFS 1
#define CONFIG_HID_RAPOO_MODULE 1
#define CONFIG_UEFI_CPER 1
#define CONFIG_AS_WRUSS 1
#define CONFIG_SENSORS_CORSAIR_CPRO_MODULE 1
#define CONFIG_X86_CPA_STATISTICS 1
#define CONFIG_X86_MPPARSE 1
#define CONFIG_IP_VS_SED_MODULE 1
#define CONFIG_LIBFCOE_MODULE 1
#define CONFIG_ADF4377_MODULE 1
#define CONFIG_X86_HAVE_PAE 1
#define CONFIG_TI_ADS131M02_MODULE 1
#define CONFIG_HRTIMER_REARM_DEFERRED 1
#define CONFIG_XZ_DEC_ARM 1
#define CONFIG_SND_HDA_SCODEC_CS35L41_I2C_MODULE 1
#define CONFIG_DVB_RTL2832_MODULE 1
#define CONFIG_INET_ESP_OFFLOAD_MODULE 1
#define CONFIG_NET_DSA_MT7530_MODULE 1
#define CONFIG_NET_DSA_MODULE 1
#define CONFIG_SENSORS_INA2XX_MODULE 1
#define CONFIG_MEEGOPAD_ANX7428_MODULE 1
#define CONFIG_MTD_UBI_BEB_LIMIT 20
#define CONFIG_HOTPLUG_PCI 1
#define CONFIG_VIDEO_S5K5BAF_MODULE 1
#define CONFIG_USB_VIDEO_CLASS_MODULE 1
#define CONFIG_CC_HAS_NAMED_AS_FIXED_SANITIZERS 1
#define CONFIG_F2FS_FS_LZO 1
#define CONFIG_SCSI_PM8001_MODULE 1
#define CONFIG_SENSORS_AD7418_MODULE 1
#define CONFIG_NFC_NCI_MODULE 1
#define CONFIG_SND_SOC_RT5640_MODULE 1
#define CONFIG_HAVE_FENTRY 1
#define CONFIG_AXP20X_ADC_MODULE 1
#define CONFIG_IEEE802154_MODULE 1
#define CONFIG_RTC_DRV_DS1374_MODULE 1
#define CONFIG_SND_SOC_RT1015_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_IDLETIMER_MODULE 1
#define CONFIG_ZSMALLOC_STAT 1
#define CONFIG_CIFS_POSIX 1
#define CONFIG_HID_COUGAR_MODULE 1
#define CONFIG_HSC030PA_MODULE 1
#define CONFIG_MMC_HSQ_MODULE 1
#define CONFIG_SND_SOC_MAX98090_MODULE 1
#define CONFIG_PWM 1
#define CONFIG_PARAVIRT_XXL 1
#define CONFIG_NET_VENDOR_HUAWEI 1
#define CONFIG_HAVE_MIXED_BREAKPOINTS_REGS 1
#define CONFIG_DRM_XE_JOB_TIMEOUT_MIN 1
#define CONFIG_AD7780_MODULE 1
#define CONFIG_CONFIGFS_FS 1
#define CONFIG_QCOM_HIDMA_MGMT_MODULE 1
#define CONFIG_NVIDIA_SHIELD_FF 1
#define CONFIG_JFFS2_FS_WRITEBUFFER 1
#define CONFIG_INTEL_MEI_VSC_HW_MODULE 1
#define CONFIG_LPC_SCH_MODULE 1
#define CONFIG_SAMSUNG_GALAXYBOOK_MODULE 1
#define CONFIG_DEFAULT_INIT ""
#define CONFIG_SND_SOC_WM8985_MODULE 1
#define CONFIG_RT2500PCI_MODULE 1
#define CONFIG_SND_SPI 1
#define CONFIG_XILLYUSB_MODULE 1
#define CONFIG_SPS30_MODULE 1
#define CONFIG_MAX1241_MODULE 1
#define CONFIG_KXCJK1013_MODULE 1
#define CONFIG_ARCH_MIGHT_HAVE_PC_SERIO 1
#define CONFIG_MLX_PLATFORM_MODULE 1
#define CONFIG_VIRT_DRIVERS 1
#define CONFIG_DMABUF_HEAPS_CMA 1
#define CONFIG_CAN_ETAS_ES58X_MODULE 1
#define CONFIG_CRYPTO_DEV_NITROX_MODULE 1
#define CONFIG_PCI_HYPERV_MODULE 1
#define CONFIG_ATA_ACPI 1
#define CONFIG_RTW88_8723DU_MODULE 1
#define CONFIG_NET_CLS 1
#define CONFIG_XFS_LIVE_HOOKS 1
#define CONFIG_SND_SOC_ICS43432_MODULE 1
#define CONFIG_HAVE_EXIT_THREAD 1
#define CONFIG_NET_VENDOR_AGERE 1
#define CONFIG_W1_CON 1
#define CONFIG_HID_ACRUX_FF 1
#define CONFIG_NFT_REJECT_IPV4_MODULE 1
#define CONFIG_RTC_DRV_DA9055_MODULE 1
#define CONFIG_IP6_NF_MATCH_OPTS_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_EGALAX 1
#define CONFIG_THUNDER_NIC_BGX_MODULE 1
#define CONFIG_ARCH_HAS_LAZY_MMU_MODE 1
#define CONFIG_CRYPTO_DEV_PADLOCK_SHA_MODULE 1
#define CONFIG_SATA_MV_MODULE 1
#define CONFIG_SCHEDSTATS 1
#define CONFIG_ALTERA_STAPL_MODULE 1
#define CONFIG_INFINIBAND_IPOIB_DEBUG 1
#define CONFIG_VIA_VELOCITY_MODULE 1
#define CONFIG_REALTEK_PHY_MODULE 1
#define CONFIG_CRYPTO_KPP2 1
#define CONFIG_TCP_AO 1
#define CONFIG_AD7091R8_MODULE 1
#define CONFIG_NET_ACT_SKBEDIT_MODULE 1
#define CONFIG_DRM_DISPLAY_DP_AUX_CEC 1
#define CONFIG_MCP9600_MODULE 1
#define CONFIG_DRM_I915_STOP_TIMEOUT 100
#define CONFIG_SND_SOC_SOF_MERRIFIELD_MODULE 1
#define CONFIG_SENSORS_LENOVO_EC_MODULE 1
#define CONFIG_ARCH_SUPPORTS_KEXEC_SIG 1
#define CONFIG_PATA_PARPORT_FIT3_MODULE 1
#define CONFIG_TPS65010_MODULE 1
#define CONFIG_MOUSE_GPIO_MODULE 1
#define CONFIG_VHOST_VSOCK_MODULE 1
#define CONFIG_BLK_DEV_LOOP_MIN_COUNT 0
#define CONFIG_SND_SOC_RT700_SDW_MODULE 1
#define CONFIG_B43LEGACY_HWRNG 1
#define CONFIG_NFT_QUEUE_MODULE 1
#define CONFIG_CRYPTO_DRBG_HASH 1
#define CONFIG_MCP4922_MODULE 1
#define CONFIG_BRCMDBG 1
#define CONFIG_SUNDANCE_MODULE 1
#define CONFIG_DCACHE_WORD_ACCESS 1
#define CONFIG_RANDOMIZE_KSTACK_OFFSET_DEFAULT 1
#define CONFIG_DRM_TTM_HELPER_MODULE 1
#define CONFIG_CDROM_MODULE 1
#define CONFIG_P54_COMMON_MODULE 1
#define CONFIG_BACKLIGHT_RAVE_SP_MODULE 1
#define CONFIG_SFC_SIENA_MTD 1
#define CONFIG_ACERHDF_MODULE 1
#define CONFIG_DRM_VKMS_MODULE 1
#define CONFIG_MEDIA_TUNER_TEA5761_MODULE 1
#define CONFIG_AD7173_MODULE 1
#define CONFIG_SENSORS_SCH56XX_COMMON_MODULE 1
#define CONFIG_CONTEXT_SWITCH_TRACER 1
#define CONFIG_USB_GSPCA_VC032X_MODULE 1
#define CONFIG_SND_SOC_NTPFW_MODULE 1
#define CONFIG_XEN_SCSI_FRONTEND_MODULE 1
#define CONFIG_RUSTC_LLVM_VERSION 220108
#define CONFIG_EXTCON 1
#define CONFIG_CRYPTO_DEV_QAT_DH895xCCVF_MODULE 1
#define CONFIG_RESET_GPIO_MODULE 1
#define CONFIG_ADXL367_MODULE 1
#define CONFIG_DRM_ST7586_MODULE 1
#define CONFIG_IIO_INTERRUPT_TRIGGER_MODULE 1
#define CONFIG_IE6XX_WDT_MODULE 1
#define CONFIG_MT7663_USB_SDIO_COMMON_MODULE 1
#define CONFIG_ARCH_HAS_PTDUMP 1
#define CONFIG_DRM_I2C_NXP_TDA998X_MODULE 1
#define CONFIG_USB_GSPCA_STK014_MODULE 1
#define CONFIG_TOUCHSCREEN_SURFACE3_SPI_MODULE 1
#define CONFIG_DMA_ACPI 1
#define CONFIG_INPUT_KEYBOARD 1
#define CONFIG_DP83TC811_PHY_MODULE 1
#define CONFIG_CRYPTO_DEV_QAT_MODULE 1
#define CONFIG_SND_SOC_INTEL_SOF_RT5682_MACH_MODULE 1
#define CONFIG_TOUCHSCREEN_EXC3000_MODULE 1
#define CONFIG_TRUSTED_KEYS_MODULE 1
#define CONFIG_CROS_EC_UART_MODULE 1
#define CONFIG_ATH9K_COMMON_MODULE 1
#define CONFIG_TCG_TIS_I2C_NUVOTON_MODULE 1
#define CONFIG_MQ_IOSCHED_KYBER 1
#define CONFIG_CHARGER_BQ24735_MODULE 1
#define CONFIG_SND_SEQ_DUMMY_MODULE 1
#define CONFIG_TOSHIBA_BT_RFKILL_MODULE 1
#define CONFIG_XZ_DEC_RISCV 1
#define CONFIG_DEVICE_MIGRATION 1
#define CONFIG_KEYBOARD_LM8333_MODULE 1
#define CONFIG_ACPI_REV_OVERRIDE_POSSIBLE 1
#define CONFIG_SND_MPU401_UART_MODULE 1
#define CONFIG_DELL_WMI_SYSMAN_MODULE 1
#define CONFIG_DRAGONRISE_FF 1
#define CONFIG_THREAD_INFO_IN_TASK 1
#define CONFIG_SYSFS 1
#define CONFIG_XFS_RT 1
#define CONFIG_RD_ZSTD 1
#define CONFIG_IRQ_TIME_ACCOUNTING 1
#define CONFIG_USB_MR800_MODULE 1
#define CONFIG_SECURITY_SELINUX_DEVELOP 1
#define CONFIG_MT7925E_MODULE 1
#define CONFIG_ADXL380_MODULE 1
#define CONFIG_HAVE_ARCH_THREAD_STRUCT_WHITELIST 1
#define CONFIG_PATA_PARPORT_ON26_MODULE 1
#define CONFIG_BRCMFMAC_PROTO_BCDC 1
#define CONFIG_ATH12K_AHB 1
#define CONFIG_SIGNATURE 1
#define CONFIG_MFD_SM501_GPIO 1
#define CONFIG_HL_HLDIO 1
#define CONFIG_INFINIBAND_SRPT_MODULE 1
#define CONFIG_CRYPTO_LIB_SHA512 1
#define CONFIG_X86_64 1
#define CONFIG_NET_CLS_FLOW_MODULE 1
#define CONFIG_SND_SOC_WM8523_MODULE 1
#define CONFIG_VIDEO_SAA7146_MODULE 1
#define CONFIG_SND_SOC_INTEL_BROADWELL_MACH_MODULE 1
#define CONFIG_TOUCHSCREEN_ST1232_MODULE 1
#define CONFIG_DM_THIN_PROVISIONING_MODULE 1
#define CONFIG_TPS6507X_MODULE 1
#define CONFIG_TCP_CONG_HYBLA_MODULE 1
#define CONFIG_SND_UMP_MODULE 1
#define CONFIG_SND_SOC_AW87390_MODULE 1
#define CONFIG_MEDIA_TUNER_XC5000_MODULE 1
#define CONFIG_POWER_RESET_QEMU_VIRT_CTRL_MODULE 1
#define CONFIG_HAVE_RSEQ 1
#define CONFIG_ATLAS_PH_SENSOR_MODULE 1
#define CONFIG_HID_AUREAL_MODULE 1
#define CONFIG_LEDS_PCA9532_GPIO 1
#define CONFIG_DVB_CORE_MODULE 1
#define CONFIG_IP_NF_TARGET_REJECT_MODULE 1
#define CONFIG_REGMAP_IRQ 1
#define CONFIG_SND_SOC_COMPRESS 1
#define CONFIG_NET_EMATCH_TEXT_MODULE 1
#define CONFIG_HAVE_KCSAN_COMPILER 1
#define CONFIG_TCG_VTPM_PROXY_MODULE 1
#define CONFIG_EFI_VARS_PSTORE 1
#define CONFIG_SND_ENS1370_MODULE 1
#define CONFIG_ADMV8818_MODULE 1
#define CONFIG_PINCTRL_METEORLAKE_MODULE 1
#define CONFIG_I2C_XILINX_MODULE 1
#define CONFIG_ATA_OVER_ETH_MODULE 1
#define CONFIG_SFC_MTD 1
#define CONFIG_IPVLAN_MODULE 1
#define CONFIG_MMC_ALCOR_MODULE 1
#define CONFIG_SERIO_RAW_MODULE 1
#define CONFIG_TSM 1
#define CONFIG_NCT7201_MODULE 1
#define CONFIG_WMI_BMOF_MODULE 1
#define CONFIG_STRICT_DEVMEM 1
#define CONFIG_GCC10_NO_ARRAY_BOUNDS 1
#define CONFIG_SND_SOC_CS35L41_LIB_MODULE 1
#define CONFIG_RTC_DRV_DS1672_MODULE 1
#define CONFIG_SENSORS_TMP102_MODULE 1
#define CONFIG_X86_PLATFORM_DRIVERS_DELL 1
#define CONFIG_RTW88_8821C_MODULE 1
#define CONFIG_SND_INDIGOIO_MODULE 1
#define CONFIG_MEDIA_TUNER_FC0012_MODULE 1
#define CONFIG_SENSORS_ADM1026_MODULE 1
#define CONFIG_VIDEO_S5K6A3_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_STATE_MODULE 1
#define CONFIG_DRM_DRAW 1
#define CONFIG_ACPI_APEI_ERST_DEBUG_MODULE 1
#define CONFIG_SND_SOC_ES8328_MODULE 1
#define CONFIG_SENSORS_NCT6775_I2C_MODULE 1
#define CONFIG_PINCTRL_BAYTRAIL 1
#define CONFIG_LEDS_MAX8997_MODULE 1
#define CONFIG_MMC35240_MODULE 1
#define CONFIG_SPI_DYNAMIC 1
#define CONFIG_PPP_DEFLATE_MODULE 1
#define CONFIG_W1_SLAVE_DS2431_MODULE 1
#define CONFIG_CPU_FREQ_GOV_ONDEMAND 1
#define CONFIG_PHY_CPCAP_USB_MODULE 1
#define CONFIG_SENSORS_MAX8688_MODULE 1
#define CONFIG_MFD_WM5110 1
#define CONFIG_MFD_88PM800_MODULE 1
#define CONFIG_BCM_VK_MODULE 1
#define CONFIG_SND_SOC_WM8728_MODULE 1
#define CONFIG_PPDEV_MODULE 1
#define CONFIG_TOUCHSCREEN_HIDEEP_MODULE 1
#define CONFIG_REGULATOR_AD5398_MODULE 1
#define CONFIG_DCDBAS_MODULE 1
#define CONFIG_VT_HW_CONSOLE_BINDING 1
#define CONFIG_I2C_ALGOBIT_MODULE 1
#define CONFIG_SPI_SLAVE_TIME_MODULE 1
#define CONFIG_INPUT_RT5120_PWRKEY_MODULE 1
#define CONFIG_SENSORS_PM6764TR_MODULE 1
#define CONFIG_DVB_AV7110_MODULE 1
#define CONFIG_EXTCON_USBC_TUSB320_MODULE 1
#define CONFIG_HAVE_RETHOOK 1
#define CONFIG_INPUT_ADXL34X_MODULE 1
#define CONFIG_I2C_HID_ACPI_MODULE 1
#define CONFIG_CRYPTO_CAST_COMMON_MODULE 1
#define CONFIG_NF_NAT_MASQUERADE 1
#define CONFIG_GENERIC_CLOCKEVENTS 1
#define CONFIG_ARCH_SUPPORTS_PROPELLER_CLANG 1
#define CONFIG_INPUT_DRV2665_HAPTICS_MODULE 1
#define CONFIG_MMIOTRACE 1
#define CONFIG_NF_CT_NETLINK_HELPER_MODULE 1
#define CONFIG_MFD_MT6360_MODULE 1
#define CONFIG_CMA_DEBUGFS 1
#define CONFIG_SND_SOC_CS35L32_MODULE 1
#define CONFIG_NFC_ST95HF_MODULE 1
#define CONFIG_MOUSE_SYNAPTICS_I2C_MODULE 1
#define CONFIG_NLS_CODEPAGE_852_MODULE 1
#define CONFIG_DIBS_LO 1
#define CONFIG_ADC_BATTERY_HELPER_MODULE 1
#define CONFIG_USB_SERIAL_WHITEHEAT_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_ECN_MODULE 1
#define CONFIG_SND_AW2_MODULE 1
#define CONFIG_SND_SOC_SOF_INTEL_TOPLEVEL 1
#define CONFIG_BMC150_MAGN_I2C_MODULE 1
#define CONFIG_BARCO_P50_GPIO_MODULE 1
#define CONFIG_BT_HCIUART_MODULE 1
#define CONFIG_IPMI_DEVICE_INTERFACE_MODULE 1
#define CONFIG_SND_CTL_INPUT_VALIDATION 1
#define CONFIG_DVB_USB_AF9005_MODULE 1
#define CONFIG_SND_HDA_CIRRUS_SCODEC_MODULE 1
#define CONFIG_VIDEO_USBTV_MODULE 1
#define CONFIG_SND_SOC_RT5682_SDW_MODULE 1
#define CONFIG_SND_HDSP_MODULE 1
#define CONFIG_XEN_PCI_STUB 1
#define CONFIG_SND_AMD_ASOC_ACP70_MODULE 1
#define CONFIG_SND_SOC_SOF_HDA_GENERIC_MODULE 1
#define CONFIG_RTC_CLASS 1
#define CONFIG_REGULATOR_RAA215300_MODULE 1
#define CONFIG_SENSORS_ASUS_ROG_RYUJIN_MODULE 1
#define CONFIG_INPUT_PWM_BEEPER_MODULE 1
#define CONFIG_CIFS_SWN_UPCALL 1
#define CONFIG_JOYSTICK_SEESAW_MODULE 1
#define CONFIG_CRYPTO_LZO 1
#define CONFIG_EXT_SUB_SCHED 1
#define CONFIG_LATTICE_ECP3_CONFIG_MODULE 1
#define CONFIG_NLS_CODEPAGE_869_MODULE 1
#define CONFIG_GPIO_WCD934X_MODULE 1
#define CONFIG_FWNODE_MDIO_MODULE 1
#define CONFIG_BATTERY_AXP20X_MODULE 1
#define CONFIG_PERF_EVENTS 1
#define CONFIG_DRM_PANIC_BACKGROUND_COLOR 0x0000aa
#define CONFIG_GPIO_ARIZONA_MODULE 1
#define CONFIG_RENESAS_PHY_MODULE 1
#define CONFIG_IP6_NF_MATCH_AH_MODULE 1
#define CONFIG_HAVE_HARDLOCKUP_DETECTOR_PERF 1
#define CONFIG_SENSORS_SURFACE_FAN_MODULE 1
#define CONFIG_MHI_WWAN_MBIM_MODULE 1
#define CONFIG_SENSORS_ADT7470_MODULE 1
#define CONFIG_NET_ACT_VLAN_MODULE 1
#define CONFIG_TCG_TIS 1
#define CONFIG_PINCTRL_DA9062_MODULE 1
#define CONFIG_REGULATOR_RTQ2134_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_LED_MODULE 1
#define CONFIG_SERIAL_8250_NR_UARTS 32
#define CONFIG_XEN_DOM0 1
#define CONFIG_GP2AP020A00F_MODULE 1
#define CONFIG_ADJD_S311_MODULE 1
#define CONFIG_ADIS16550_MODULE 1
#define CONFIG_CRC8_MODULE 1
#define CONFIG_PCIEPORTBUS 1
#define CONFIG_BATTERY_RX51_MODULE 1
#define CONFIG_SYSTEMPORT_MODULE 1
#define CONFIG_RAMDAX_MODULE 1
#define CONFIG_SENSORS_CORETEMP_MODULE 1
#define CONFIG_PCIE_DPC 1
#define CONFIG_USB_STORAGE_MODULE 1
#define CONFIG_DVB_USB_LME2510_MODULE 1
#define CONFIG_X86_ESPFIX64 1
#define CONFIG_REMOTEPROC_CDEV 1
#define CONFIG_BACKLIGHT_AW99706_MODULE 1
#define CONFIG_SENSORS_TPS53679_MODULE 1
#define CONFIG_PATA_IT821X_MODULE 1
#define CONFIG_IOMMU_API 1
#define CONFIG_ZISOFS 1
#define CONFIG_MAX5481_MODULE 1
#define CONFIG_MAPPING_DIRTY_HELPERS 1
#define CONFIG_USB_HCD_SSB_MODULE 1
#define CONFIG_CRYPTO_RSA 1
#define CONFIG_IPMB_DEVICE_INTERFACE_MODULE 1
#define CONFIG_HID_LOGITECH_HIDPP_MODULE 1
#define CONFIG_MODULE_COMPRESS_ALL 1
#define CONFIG_REGULATOR_WM8994_MODULE 1
#define CONFIG_VMXNET3_MODULE 1
#define CONFIG_SERIAL_8250_MANY_PORTS 1
#define CONFIG_IR_JVC_DECODER_MODULE 1
#define CONFIG_SCSI_AIC79XX_MODULE 1
#define CONFIG_NVME_TCP_MODULE 1
#define CONFIG_NET_IPGRE_BROADCAST 1
#define CONFIG_SENSORS_SHTC1_MODULE 1
#define CONFIG_SND_SOC_SDCA_FDL 1
#define CONFIG_LOCKD_V4 1
#define CONFIG_SURFACE_HID_CORE_MODULE 1
#define CONFIG_DM_DUST_MODULE 1
#define CONFIG_CIFS_DFS_UPCALL 1
#define CONFIG_TYPEC_TCPCI_MODULE 1
#define CONFIG_TI_ADC12138_MODULE 1
#define CONFIG_CALL_THUNKS 1
#define CONFIG_LEDS_OSRAM_AMS_AS3668_MODULE 1
#define CONFIG_AQUANTIA_PHY_MODULE 1
#define CONFIG_SENSORS_DELL_SMM_MODULE 1
#define CONFIG_EROFS_FS_PCPU_KTHREAD_HIPRI 1
#define CONFIG_TYPEC_TBT_ALTMODE_MODULE 1
#define CONFIG_WATCHDOG_CORE 1
#define CONFIG_X86_AMD_PSTATE_UT_MODULE 1
#define CONFIG_IIO_ST_ACCEL_3AXIS_MODULE 1
#define CONFIG_AD5421_MODULE 1
#define CONFIG_UCSI_CCG_MODULE 1
#define CONFIG_LTC2485_MODULE 1
#define CONFIG_SND_HDA_CODEC_HDMI_MODULE 1
#define CONFIG_SCSI_DH_EMC_MODULE 1
#define CONFIG_REGULATOR_VIRTUAL_CONSUMER_MODULE 1
#define CONFIG_IBMASR_MODULE 1
#define CONFIG_CROS_USBPD_NOTIFY_MODULE 1
#define CONFIG_SPI_VIRTIO_MODULE 1
#define CONFIG_REGULATOR_RT6160_MODULE 1
#define CONFIG_SND_SOC_CS4349_MODULE 1
#define CONFIG_PINCTRL_MADERA_MODULE 1
#define CONFIG_BQL 1
#define CONFIG_IO_URING 1
#define CONFIG_HID_SENSOR_ACCEL_3D_MODULE 1
#define CONFIG_DAMON_PADDR 1
#define CONFIG_IIO_ADIS_LIB_BUFFER 1
#define CONFIG_SND_SOC_RT1316_SDW_MODULE 1
#define CONFIG_ASYMMETRIC_KEY_TYPE 1
#define CONFIG_INV_ICM42600_SPI_MODULE 1
#define CONFIG_ACPI_TABLE_LIB 1
#define CONFIG_NFC_S3FWRN5_I2C_MODULE 1
#define CONFIG_RTC_DRV_PCF8523_MODULE 1
#define CONFIG_SENSORS_MAX20751_MODULE 1
#define CONFIG_INPUT_MOUSE 1
#define CONFIG_PROC_VMCORE 1
#define CONFIG_SENSORS_MP2891_MODULE 1
#define CONFIG_DEV_DAX_PMEM_MODULE 1
#define CONFIG_RTC_DRV_X1205_MODULE 1
#define CONFIG_MMC_USHC_MODULE 1
#define CONFIG_GPIO_AMD_FCH_MODULE 1
#define CONFIG_SATA_SX4_MODULE 1
#define CONFIG_MAX14001_MODULE 1
#define CONFIG_REGULATOR_MAX14577_MODULE 1
#define CONFIG_BMA400_SPI_MODULE 1
#define CONFIG_I2C_NCT6694_MODULE 1
#define CONFIG_INTEL_IOMMU_FLOPPY_WA 1
#define CONFIG_KVM_GENERIC_DIRTYLOG_READ_PROTECT 1
#define CONFIG_DECOMPRESS_XZ 1
#define CONFIG_MICROCHIP_T1S_PHY_MODULE 1
#define CONFIG_INTEL_MEI_GSC_PROXY_MODULE 1
#define CONFIG_NVME_HOST_AUTH 1
#define CONFIG_SND_HDA_CODEC_SIGMATEL_MODULE 1
#define CONFIG_MLX5_ESWITCH 1
#define CONFIG_LEDS_PWM_MODULE 1
#define CONFIG_VIDEO_SAA7134_MODULE 1
#define CONFIG_MAC_EMUMOUSEBTN_MODULE 1
#define CONFIG_USB_LEGOTOWER_MODULE 1
#define CONFIG_RTC_DRV_MAX6900_MODULE 1
#define CONFIG_INTEL_WMI_SBL_FW_UPDATE_MODULE 1
#define CONFIG_MTD_BLOCK_MODULE 1
#define CONFIG_CC_HAS_MULTIDIMENSIONAL_NONSTRING 1
#define CONFIG_SND_RME9652_MODULE 1
#define CONFIG_NET_DSA_BCM_SF2_MODULE 1
#define CONFIG_TOUCHSCREEN_GOODIX_BERLIN_I2C_MODULE 1
#define CONFIG_TIPC_CRYPTO 1
#define CONFIG_INFINIBAND_USER_ACCESS_MODULE 1
#define CONFIG_NLS_CODEPAGE_737_MODULE 1
#define CONFIG_SND_SOC_SOF_PANTHERLAKE_MODULE 1
#define CONFIG_SENSORS_SMSC47M192_MODULE 1
#define CONFIG_MODULES_USE_ELF_RELA 1
#define CONFIG_NFS_V4_2 1
#define CONFIG_NVME_KEYRING_MODULE 1
#define CONFIG_LOCK_EVENT_COUNTS 1
#define CONFIG_REGULATOR_TPS6524X_MODULE 1
#define CONFIG_CPU_FREQ_DEFAULT_GOV_SCHEDUTIL 1
#define CONFIG_RTC_DRV_RV3029C2_MODULE 1
#define CONFIG_RT2400PCI_MODULE 1
#define CONFIG_DRM_I915_MODULE 1
#define CONFIG_CLOSURES 1
#define CONFIG_MFD_AXP20X_I2C_MODULE 1
#define CONFIG_HAVE_CALL_THUNKS 1
#define CONFIG_BOOT_CONFIG 1
#define CONFIG_X86_CET 1
#define CONFIG_TULIP_MODULE 1
#define CONFIG_MUX_ADG792A_MODULE 1
#define CONFIG_PWM_PROVIDE_GPIO 1
#define CONFIG_COMMON_CLK_CDCE706_MODULE 1
#define CONFIG_HID_KYE_MODULE 1
#define CONFIG_USB_XHCI_HCD 1
#define CONFIG_ETHERNET 1
#define CONFIG_DRM_PANIC 1
#define CONFIG_INFINIBAND_RTRS_CLIENT_MODULE 1
#define CONFIG_I3C_OR_I2C 1
#define CONFIG_DRM_TTM_MODULE 1
#define CONFIG_VIDEO_OV772X_MODULE 1
#define CONFIG_NFSD_V3_ACL 1
#define CONFIG_BLK_DEV_PCIESSD_MTIP32XX_MODULE 1
#define CONFIG_PWM_TWL_LED_MODULE 1
#define CONFIG_I2C_PIIX4_MODULE 1
#define CONFIG_SND_SOC_INTEL_CHT_BSW_RT5645_MACH_MODULE 1
#define CONFIG_NETFILTER_CONNCOUNT_MODULE 1
#define CONFIG_MTD_CFI_I2 1
#define CONFIG_REGULATOR_LP8788_MODULE 1
#define CONFIG_AD7266_MODULE 1
#define CONFIG_DRM_NOUVEAU_SIL164_MODULE 1
#define CONFIG_REGULATOR_PF0900_MODULE 1
#define CONFIG_SND_SOC_LPASS_VA_MACRO_MODULE 1
#define CONFIG_SND_ENS1371_MODULE 1
#define CONFIG_KEYBOARD_LKKBD_MODULE 1
#define CONFIG_INTEL_QEP_MODULE 1
#define CONFIG_ZSWAP_COMPRESSOR_DEFAULT_ZSTD 1
#define CONFIG_DELL_PC_MODULE 1
#define CONFIG_CRYPTO_DEV_QAT_4XXX_MODULE 1
#define CONFIG_GTP_MODULE 1
#define CONFIG_TREE_SRCU 1
#define CONFIG_CXL_ACPI_MODULE 1
#define CONFIG_DRM_ACCEL_IVPU_MODULE 1
#define CONFIG_NETFS_STATS 1
#define CONFIG_CRYPTO_CAMELLIA_AESNI_AVX2_X86_64_MODULE 1
#define CONFIG_RADIO_SI470X_MODULE 1
#define CONFIG_STK8BA50_MODULE 1
#define CONFIG_REGULATOR_LTC3589_MODULE 1
#define CONFIG_NTFS_FS_MODULE 1
#define CONFIG_C2PORT_DURAMAR_2150_MODULE 1
#define CONFIG_IWLWIFI_MODULE 1
#define CONFIG_BT_MTK_MODULE 1
#define CONFIG_NF_CONNTRACK_AMANDA_MODULE 1
#define CONFIG_VEML6075_MODULE 1
#define CONFIG_TI_ADS7924_MODULE 1
#define CONFIG_REGULATOR_88PG86X_MODULE 1
#define CONFIG_PSE_REGULATOR_MODULE 1
#define CONFIG_EEPROM_AT24_MODULE 1
#define CONFIG_BT_HIDP_MODULE 1
#define CONFIG_SND_MAESTRO3_INPUT 1
#define CONFIG_TSM_MEASUREMENTS 1
#define CONFIG_SCSI_UFSHCD_PLATFORM_MODULE 1
#define CONFIG_MOXA_INTELLIO_MODULE 1
#define CONFIG_ACPI_PROCESSOR 1
#define CONFIG_BACKLIGHT_MP3309C_MODULE 1
#define CONFIG_ARCH_HAS_STRICT_KERNEL_RWX 1
#define CONFIG_SUNRPC_BACKCHANNEL 1
#define CONFIG_MFD_CGBC_MODULE 1
#define CONFIG_I2C_SLAVE 1
#define CONFIG_RTL8192SE_MODULE 1
#define CONFIG_VMWARE_PVSCSI_MODULE 1
#define CONFIG_WL1251_MODULE 1
#define CONFIG_HAVE_LIVEPATCH 1
#define CONFIG_SND_SOC_AK4554_MODULE 1
#define CONFIG_DVB_USB_DIBUSB_MB_FAULTY 1
#define CONFIG_ZSWAP_DEFAULT_ON 1
#define CONFIG_ATH11K_CFR 1
#define CONFIG_REGULATOR_RTQ6752_MODULE 1
#define CONFIG_NF_CONNTRACK_TIMEOUT 1
#define CONFIG_TOUCHSCREEN_MELFAS_MIP4_MODULE 1
#define CONFIG_WWAN_MODULE 1
#define CONFIG_GPIO_WINBOND_MODULE 1
#define CONFIG_NET_ACT_POLICE_MODULE 1
#define CONFIG_HID_UCLOGIC_MODULE 1
#define CONFIG_BLOCK_HOLDER_DEPRECATED 1
#define CONFIG_HID_WALTOP_MODULE 1
#define CONFIG_PATA_OLDPIIX_MODULE 1
#define CONFIG_ADF4371_MODULE 1
#define CONFIG_BALLOON_MIGRATION 1
#define CONFIG_PREEMPT 1
#define CONFIG_USB_STORAGE_ISD200_MODULE 1
#define CONFIG_INTEL_TCC 1
#define CONFIG_GPIO_CROS_EC_MODULE 1
#define CONFIG_ADRF6780_MODULE 1
#define CONFIG_USB_SNP_CORE_MODULE 1
#define CONFIG_ARCH_WANT_OLD_COMPAT_IPC 1
#define CONFIG_SENSORS_AQUACOMPUTER_D5NEXT_MODULE 1
#define CONFIG_DRM_MIPI_DBI_MODULE 1
#define CONFIG_KEXEC_BZIMAGE_VERIFY_SIG 1
#define CONFIG_SCSI_LPFC_MODULE 1
#define CONFIG_SND_SOC_INTEL_HASWELL_MACH_MODULE 1
#define CONFIG_GENERIC_IRQ_ENTRY 1
#define CONFIG_INTEL_IDLE 1
#define CONFIG_SND_SOC_CS35L33_MODULE 1
#define CONFIG_REALTEK_AUTOPM 1
#define CONFIG_MCP3911_MODULE 1
#define CONFIG_VIDEO_IR_I2C_MODULE 1
#define CONFIG_GENERIC_IRQ_MATRIX_ALLOCATOR 1
#define CONFIG_LEDS_TRIGGER_GPIO_MODULE 1
#define CONFIG_NI903X_WDT_MODULE 1
#define CONFIG_LV0104CS_MODULE 1
#define CONFIG_NFT_REJECT_MODULE 1
#define CONFIG_SND_RME32_MODULE 1
#define CONFIG_INET_DIAG_DESTROY 1
#define CONFIG_LP_CONSOLE 1
#define CONFIG_VIDEO_IVTV_ALSA_MODULE 1
#define CONFIG_RANDOMIZE_MEMORY_PHYSICAL_PADDING 0xa
#define CONFIG_8139CP_MODULE 1
#define CONFIG_NET_NS 1
#define CONFIG_NET_TEAM_MODE_BROADCAST_MODULE 1
#define CONFIG_CRC16 1
#define CONFIG_SOCK_CGROUP_DATA 1
#define CONFIG_SCHED_CLUSTER 1
#define CONFIG_VIDEO_CADENCE_CSI2RX_MODULE 1
#define CONFIG_MITIGATION_RETHUNK 1
#define CONFIG_TABLET_USB_PEGASUS_MODULE 1
#define CONFIG_ISL29003_MODULE 1
#define CONFIG_AD7606_IFACE_PARALLEL_MODULE 1
#define CONFIG_JOYSTICK_PSXPAD_SPI_MODULE 1
#define CONFIG_USB_AUTOSUSPEND_DELAY 2
#define CONFIG_CRYPTO_SEQIV_MODULE 1
#define CONFIG_SND_SOC_ADAU7118_HW_MODULE 1
#define CONFIG_SERIAL_SCCNXP_MODULE 1
#define CONFIG_DP83640_PHY_MODULE 1
#define CONFIG_ARCH_MMAP_RND_COMPAT_BITS_MAX 16
#define CONFIG_NLS_CODEPAGE_866_MODULE 1
#define CONFIG_ASYNC_KERNEL_PGTABLE_FREE 1
#define CONFIG_SND_SOC_RT711_SDW_MODULE 1
#define CONFIG_CRYPTO_CAMELLIA_AESNI_AVX_X86_64_MODULE 1
#define CONFIG_PRINTER_MODULE 1
#define CONFIG_SENSORS_FTSTEUTATES_MODULE 1
#define CONFIG_BRCMSMAC_LEDS 1
#define CONFIG_IPMI_HANDLER_MODULE 1
#define CONFIG_MUTEX_SPIN_ON_OWNER 1
#define CONFIG_ACPI_APEI_GHES 1
#define CONFIG_FSNOTIFY 1
#define CONFIG_NET_FLOW_LIMIT 1
#define CONFIG_NET_DSA_TAG_KSZ_MODULE 1
#define CONFIG_FS_DAX_PMD 1
#define CONFIG_MOUSE_PS2_VMMOUSE 1
#define CONFIG_AMD_MEM_ENCRYPT 1
#define CONFIG_NFT_REJECT_IPV6_MODULE 1
#define CONFIG_CHELSIO_TLS_DEVICE_MODULE 1
#define CONFIG_GNSS_UBX_SERIAL_MODULE 1
#define CONFIG_CIFS_MODULE 1
#define CONFIG_DW_EDMA_MODULE 1
#define CONFIG_OCFS2_FS_USERSPACE_CLUSTER_MODULE 1
#define CONFIG_DRM_ANALOGIX_ANX78XX_MODULE 1
#define CONFIG_NET_DSA_MICROCHIP_KSZ_COMMON_MODULE 1
#define CONFIG_MSI_WMI_MODULE 1
#define CONFIG_ALX_MODULE 1
#define CONFIG_INPUT_TOUCHSCREEN 1
#define CONFIG_TIME_NS_VDSO 1
#define CONFIG_VIDEO_OV5670_MODULE 1
#define CONFIG_BFQ_GROUP_IOSCHED 1
#define CONFIG_CICADA_PHY_MODULE 1
#define CONFIG_VIRTIO 1
#define CONFIG_NET_DROP_MONITOR 1
#define CONFIG_IP_SET_HASH_NETIFACE_MODULE 1
#define CONFIG_INTEL_ATOMISP2_PM_MODULE 1
#define CONFIG_I2C_SI470X_MODULE 1
#define CONFIG_SND_INTEL_DSP_CONFIG_MODULE 1
#define CONFIG_INPUT_DA9063_ONKEY_MODULE 1
#define CONFIG_VIDEO_UPD64031A_MODULE 1
#define CONFIG_NET_DSA_TAG_BRCM_LEGACY_MODULE 1
#define CONFIG_BOSCH_BNO055_I2C_MODULE 1
#define CONFIG_TOUCHSCREEN_HIMAX_HX852X_MODULE 1
#define CONFIG_CLS_U32_PERF 1
#define CONFIG_MMC_BLOCK_MINORS 8
#define CONFIG_CRYPTO_USER_API_HASH_MODULE 1
#define CONFIG_QED_FCOE 1
#define CONFIG_CRYPTO_ARIA_GFNI_AVX512_X86_64_MODULE 1
#define CONFIG_PARTITION_ADVANCED 1
#define CONFIG_JOYSTICK_JOYDUMP_MODULE 1
#define CONFIG_ACER_WMI_MODULE 1
#define CONFIG_JOYSTICK_GAMECON_MODULE 1
#define CONFIG_ROHM_BD79112_MODULE 1
#define CONFIG_NFT_FIB_INET_MODULE 1
#define CONFIG_DVB_MT352_MODULE 1
#define CONFIG_SENSORS_MC13783_ADC_MODULE 1
#define CONFIG_EEPROM_IDT_89HPESX_MODULE 1
#define CONFIG_ALTERA_FREEZE_BRIDGE_MODULE 1
#define CONFIG_SND_SOC_CS42L42_CORE_MODULE 1
#define CONFIG_ALTERA_TSE_MODULE 1
#define CONFIG_SENSORS_LTC4151_MODULE 1
#define CONFIG_LEDS_WM831X_STATUS_MODULE 1
#define CONFIG_ZRAM_DEF_COMP "zstd"
#define CONFIG_I8K 1
#define CONFIG_ATH9K_CHANNEL_CONTEXT 1
#define CONFIG_FDDI_MODULE 1
#define CONFIG_ATH5K_PCI 1
#define CONFIG_REGULATOR_88PM8607_MODULE 1
#define CONFIG_TCG_ATMEL_MODULE 1
#define CONFIG_GPIO_LJCA_MODULE 1
#define CONFIG_EDAC_I7CORE_MODULE 1
#define CONFIG_SND_SOC_CS35L41_MODULE 1
#define CONFIG_INPUT_IDEAPAD_SLIDEBAR_MODULE 1
#define CONFIG_CHARGER_LP8727_MODULE 1
#define CONFIG_SND_SOC_WM8804_MODULE 1
#define CONFIG_ATH11K_AHB_MODULE 1
#define CONFIG_NFSD_MODULE 1
#define CONFIG_PM_GENERIC_DOMAINS_SLEEP 1
#define CONFIG_HID_CHICONY_MODULE 1
#define CONFIG_USB_MA901_MODULE 1
#define CONFIG_HP_BIOSCFG_MODULE 1
#define CONFIG_ISCSI_IBFT_FIND 1
#define CONFIG_DRM_GPUSVM_MODULE 1
#define CONFIG_SENSORS_MAX197_MODULE 1
#define CONFIG_PCI_ECAM 1
#define CONFIG_SYSTEM_TRUSTED_KEYRING 1
#define CONFIG_SERIAL_SPRD_MODULE 1
#define CONFIG_HAVE_KERNEL_BZIP2 1
#define CONFIG_CRYPTO_ZSTD 1
#define CONFIG_MFD_INTEL_LPSS_PCI_MODULE 1
#define CONFIG_HID_MCP2200_MODULE 1
#define CONFIG_DM_VERITY_VERIFY_ROOTHASH_SIG_PLATFORM_KEYRING 1
#define CONFIG_ARCH_MMAP_RND_BITS_MAX 32
#define CONFIG_BMP280_I2C_MODULE 1
#define CONFIG_VIDEO_TUNER_MODULE 1
#define CONFIG_LTC2497_MODULE 1
#define CONFIG_SENSORS_HAC300S_MODULE 1
#define CONFIG_NET_EMATCH_IPSET_MODULE 1
#define CONFIG_ACPI_NHLT 1
#define CONFIG_IP_VS_MH_MODULE 1
#define CONFIG_MEDIA_TUNER_XC2028_MODULE 1
#define CONFIG_BATMAN_ADV_BLA 1
#define CONFIG_REGULATOR_MAX77857_MODULE 1
#define CONFIG_AD7192_MODULE 1
#define CONFIG_CGROUP_DEVICE 1
#define CONFIG_SMB_SERVER_MODULE 1
#define CONFIG_BATTERY_BQ27XXX_HDQ_MODULE 1
#define CONFIG_USB_NET_CDC_SUBSET_MODULE 1
#define CONFIG_SENSORS_NTC_THERMISTOR_MODULE 1
#define CONFIG_SCSI_FC_ATTRS_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_QUOTA_MODULE 1
#define CONFIG_INPUT_CM109_MODULE 1
#define CONFIG_MFD_SKY81452_MODULE 1
#define CONFIG_VIDEO_SAA7134_DVB_MODULE 1
#define CONFIG_DVB_USB_OPERA1_MODULE 1
#define CONFIG_RTC_DRV_PCF8583_MODULE 1
#define CONFIG_PATA_PARPORT_ON20_MODULE 1
#define CONFIG_PINCTRL_INTEL 1
#define CONFIG_PCIEAER_INJECT_MODULE 1
#define CONFIG_MEDIA_TUNER_MODULE 1
#define CONFIG_SYNC_FILE 1
#define CONFIG_BPF_SYSCALL 1
#define CONFIG_USB_BDC_UDC_MODULE 1
#define CONFIG_CAN_SOFTING_MODULE 1
#define CONFIG_PCI_PWRCTRL_GENERIC_MODULE 1
#define CONFIG_HYPERV_TIMER 1
#define CONFIG_SYSTEM_REVOCATION_KEYS ""
#define CONFIG_DEVFREQ_GOV_PASSIVE_MODULE 1
#define CONFIG_VIDEO_GO7007_MODULE 1
#define CONFIG_SND_PCI 1
#define CONFIG_VZ89X_MODULE 1
#define CONFIG_USB_NET_INT51X1_MODULE 1
#define CONFIG_USB_EHCI_HCD_PLATFORM_MODULE 1
#define CONFIG_HID_PENMOUNT_MODULE 1
#define CONFIG_IP_SET_LIST_SET_MODULE 1
#define CONFIG_LIBFC_MODULE 1
#define CONFIG_IIO_ST_LSM9DS0_I2C_MODULE 1
#define CONFIG_RTC_DRV_RS5C348_MODULE 1
#define CONFIG_ICPLUS_PHY_MODULE 1
#define CONFIG_DM_DEBUG_BLOCK_MANAGER_LOCKING 1
#define CONFIG_CMDLINE_LOG_WRAP_IDEAL_LEN 1021
#define CONFIG_VIDEO_OV08X40_MODULE 1
#define CONFIG_BRIDGE_EBT_ARPREPLY_MODULE 1
#define CONFIG_NFS_V4_2_SSC_HELPER 1
#define CONFIG_HAVE_KVM_DIRTY_RING_TSO 1
#define CONFIG_IIO_KFIFO_BUF_MODULE 1
#define CONFIG_JOYSTICK_INTERACT_MODULE 1
#define CONFIG_MTD_CFI_I1 1
#define CONFIG_LEDS_LP3944_MODULE 1
#define CONFIG_VIRTIO_PCI 1
#define CONFIG_RD_LZMA 1
#define CONFIG_ADIS16480_MODULE 1
#define CONFIG_DA311_MODULE 1
#define CONFIG_MFD_INTEL_M10_BMC_PMCI_MODULE 1
#define CONFIG_W1_SLAVE_DS2408_MODULE 1
#define CONFIG_TOUCHSCREEN_HAMPSHIRE_MODULE 1
#define CONFIG_NFP_APP_FLOWER 1
#define CONFIG_VIRTIO_PCI_LEGACY 1
#define CONFIG_NTFS3_LZX_XPRESS 1
#define CONFIG_SND_SOC_FS_AMP_LIB_MODULE 1
#define CONFIG_RTC_DRV_DS1685_FAMILY_MODULE 1
#define CONFIG_DRM_XEN 1
#define CONFIG_SND_SOC_WM8711_MODULE 1
#define CONFIG_SENSORS_BEL_PFE_MODULE 1
#define CONFIG_HAVE_ARCH_USERFAULTFD_MINOR 1
#define CONFIG_MEDIA_TUNER_MXL301RF_MODULE 1
#define CONFIG_ARCH_SUPPORTS_UPROBES 1
#define CONFIG_SND_MAESTRO3_MODULE 1
#define CONFIG_MEMORY_ISOLATION 1
#define CONFIG_CIFS_SMB_DIRECT 1
#define CONFIG_IWLEGACY_DEBUGFS 1
#define CONFIG_IP_MROUTE 1
#define CONFIG_JOYSTICK_TMDC_MODULE 1
#define CONFIG_DRM_GMA500_MODULE 1
#define CONFIG_ARCH_HAS_DEBUG_VM_PGTABLE 1
#define CONFIG_VIDEO_CS3308_MODULE 1
#define CONFIG_INTEL_MRFLD_ADC_MODULE 1
#define CONFIG_FB_SYS_IMAGEBLIT 1
#define CONFIG_NET_DSA_TAG_NONE_MODULE 1
#define CONFIG_PTE_MARKER_UFFD_WP 1
#define CONFIG_MMA7455_MODULE 1
#define CONFIG_USB_CONFIGFS_F_MIDI2 1
#define CONFIG_ARCH_SUPPORTS_ACPI 1
#define CONFIG_PREEMPT_DYNAMIC 1
#define CONFIG_RTL8XXXU_MODULE 1
#define CONFIG_TINYDRM_REPAPER_MODULE 1
#define CONFIG_USB_NET_KALMIA_MODULE 1
#define CONFIG_USB_SERIAL_BELKIN_MODULE 1
#define CONFIG_CRYPTO_JITTERENTROPY_OSR 1
#define CONFIG_HAVE_KRETPROBES 1
#define CONFIG_ADVANTECH_EC_WDT_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_GOTOP 1
#define CONFIG_SND_SOC_XTFPGA_I2S_MODULE 1
#define CONFIG_ZSWAP_SHRINKER_DEFAULT_ON 1
#define CONFIG_SPI_SPIDEV_MODULE 1
#define CONFIG_RTW88_8814A_MODULE 1
#define CONFIG_QRTR_SMD_MODULE 1
#define CONFIG_USB_GSPCA_PAC207_MODULE 1
#define CONFIG_NET_VENDOR_EMULEX 1
#define CONFIG_SI1145_MODULE 1
#define CONFIG_RTC_DRV_RC5T583_MODULE 1
#define CONFIG_MARVELL_88Q2XXX_PHY_MODULE 1
#define CONFIG_NLS_CODEPAGE_850_MODULE 1
#define CONFIG_IIO_RESCALE_MODULE 1
#define CONFIG_IPE_BOOT_POLICY ""
#define CONFIG_AD7949_MODULE 1
#define CONFIG_EFI_EMBEDDED_FIRMWARE 1
#define CONFIG_SKB_DECRYPTED 1
#define CONFIG_NINTENDO_FF 1
#define CONFIG_OPENVSWITCH_GRE_MODULE 1
#define CONFIG_NLS_MAC_INUIT_MODULE 1
#define CONFIG_SND_SOC_INTEL_BYT_CHT_ES8316_MACH_MODULE 1
#define CONFIG_MFD_MAX77693_MODULE 1
#define CONFIG_NF_CONNTRACK_BRIDGE_MODULE 1
#define CONFIG_X86_IO_APIC 1
#define CONFIG_HID_SENSOR_DEVICE_ROTATION_MODULE 1
#define CONFIG_VIDEO_IPU3_CIO2_MODULE 1
#define CONFIG_KEYS 1
#define CONFIG_ADUX1020_MODULE 1
#define CONFIG_VIDEO_TVAUDIO_MODULE 1
#define CONFIG_INPUT_YEALINK_MODULE 1
#define CONFIG_MT7921S_MODULE 1
#define CONFIG_PINCTRL_LEWISBURG_MODULE 1
#define CONFIG_IFCVF_MODULE 1
#define CONFIG_RTC_DRV_ISL1208_MODULE 1
#define CONFIG_DVB_OR51132_MODULE 1
#define CONFIG_INA2XX_ADC_MODULE 1
#define CONFIG_SND_SOC_CS42L43_SDW_MODULE 1
#define CONFIG_MFD_VIPERBOARD_MODULE 1
#define CONFIG_IIO_ST_MAGN_I2C_3AXIS_MODULE 1
#define CONFIG_SENSORS_NCT6694_MODULE 1
#define CONFIG_CASSINI_MODULE 1
#define CONFIG_HID_GREENASIA_MODULE 1
#define CONFIG_CW1200_WLAN_SDIO_MODULE 1
#define CONFIG_CXD2880_SPI_DRV_MODULE 1
#define CONFIG_HAVE_INTEL_TXT 1
#define CONFIG_TOUCHSCREEN_MMS114_MODULE 1
#define CONFIG_SATA_NV_MODULE 1
#define CONFIG_DVB_TEST_DRIVERS 1
#define CONFIG_HID_SENSOR_GYRO_3D_MODULE 1
#define CONFIG_IPMI_POWEROFF_MODULE 1
#define CONFIG_TI_ADS7138_MODULE 1
#define CONFIG_SND_HDA_SCODEC_CS35L56_MODULE 1
#define CONFIG_CAN_M_CAN_PLATFORM_MODULE 1
#define CONFIG_RTC_DRV_ISL12022_MODULE 1
#define CONFIG_SND_SOC_CS4271_I2C_MODULE 1
#define CONFIG_NET_SWITCHDEV 1
#define CONFIG_REGULATOR_PV88080_MODULE 1
#define CONFIG_X86_THERMAL_VECTOR 1
#define CONFIG_REGMAP_SPI_AVMM_MODULE 1
#define CONFIG_SENSORS_MP9941_MODULE 1
#define CONFIG_SENSORS_LT3074_REGULATOR_MODULE 1
#define CONFIG_MACB_USE_HWSTAMP 1
#define CONFIG_ADXL372_I2C_MODULE 1
#define CONFIG_DRM_ST7571_I2C_MODULE 1
#define CONFIG_INTEL_SCU_PCI 1
#define CONFIG_SND_AMD_ASOC_ACP63_MODULE 1
#define CONFIG_SCSI_SYM53C8XX_2_MODULE 1
#define CONFIG_PNFS_BLOCK_MODULE 1
#define CONFIG_V4L2_ASYNC_MODULE 1
#define CONFIG_DVB_FIREDTV_INPUT 1
#define CONFIG_QLCNIC_HWMON 1
#define CONFIG_ACPI_CMPC_MODULE 1
#define CONFIG_PSAMPLE_MODULE 1
#define CONFIG_RTW88_8822BS_MODULE 1
#define CONFIG_I2C_SLAVE_EEPROM_MODULE 1
#define CONFIG_ACPI_DOCK 1
#define CONFIG_XEN_EFI 1
#define CONFIG_HAVE_USER_RETURN_NOTIFIER 1
#define CONFIG_ACPI_VIDEO_MODULE 1
#define CONFIG_IO_WQ 1
#define CONFIG_VHOST_MODULE 1
#define CONFIG_USB_MASS_STORAGE_MODULE 1
#define CONFIG_RADIO_SI4713_MODULE 1
#define CONFIG_XEN_NETDEV_FRONTEND_MODULE 1
#define CONFIG_INTEL_MEI_ME_MODULE 1
#define CONFIG_IIO_CROS_EC_ACTIVITY_MODULE 1
#define CONFIG_HAVE_ARCH_HUGE_VMAP 1
#define CONFIG_VDSO_GETRANDOM 1
#define CONFIG_SND_SOC_RT9123P_MODULE 1
#define CONFIG_RTLBTCOEXIST_MODULE 1
#define CONFIG_SND_HDA_SCODEC_TAS2781_I2C_MODULE 1
#define CONFIG_NET_DSA_MV88E6XXX_MODULE 1
#define CONFIG_VIA_RHINE_MMIO 1
#define CONFIG_INTEL_TH_PTI_MODULE 1
#define CONFIG_ADM8211_MODULE 1
#define CONFIG_MCB_MODULE 1
#define CONFIG_AS_VERSION 24700
#define CONFIG_SENSORS_LT7182S_MODULE 1
#define CONFIG_CRYPTO_DEV_CCP 1
#define CONFIG_RTW89_8852BE_MODULE 1
#define CONFIG_SENSORS_ACBEL_FSG032_MODULE 1
#define CONFIG_AMT_MODULE 1
#define CONFIG_BLK_CGROUP_PUNT_BIO 1
#define CONFIG_YENTA_TOSHIBA 1
#define CONFIG_INET_UDP_DIAG_MODULE 1
#define CONFIG_USB_STORAGE_ALAUDA_MODULE 1
#define CONFIG_NET_SCH_HTB_MODULE 1
#define CONFIG_IP_VS_FO_MODULE 1
#define CONFIG_EDAC_IE31200_MODULE 1
#define CONFIG_CHELSIO_IPSEC_INLINE_MODULE 1
#define CONFIG_USB_NET_DRIVERS_MODULE 1
#define CONFIG_ARCH_USE_QUEUED_RWLOCKS 1
#define CONFIG_SCSI_SAS_LIBSAS_MODULE 1
#define CONFIG_LTC2471_MODULE 1
#define CONFIG_INPUT_PALMAS_PWRBUTTON_MODULE 1
#define CONFIG_DVB_TUA6100_MODULE 1
#define CONFIG_TOUCHSCREEN_CYTTSP_I2C_MODULE 1
#define CONFIG_CRYPTO_LIB_SHA1_ARCH 1
#define CONFIG_NFT_HASH_MODULE 1
#define CONFIG_I2C_SIS5595_MODULE 1
#define CONFIG_EXTCON_PTN5150_MODULE 1
#define CONFIG_IEEE802154_FAKELB_MODULE 1
#define CONFIG_AIR_EN8811H_PHY_MODULE 1
#define CONFIG_PATA_NINJA32_MODULE 1
#define CONFIG_INTEL_SOC_PMIC_CHTWC 1
#define CONFIG_UBIFS_FS_AUTHENTICATION 1
#define CONFIG_BTT 1
#define CONFIG_USB_MAX3421_HCD_MODULE 1
#define CONFIG_BRCMFMAC_SDIO 1
#define CONFIG_EXTCON_USB_GPIO_MODULE 1
#define CONFIG_ACPI_APEI_EINJ_CXL 1
#define CONFIG_LEDS_TRIGGER_PATTERN_MODULE 1
#define CONFIG_REGULATOR_RTQ2208_MODULE 1
#define CONFIG_RTC_DRV_ABX80X_MODULE 1
#define CONFIG_EDAC_I3000_MODULE 1
#define CONFIG_SND_SST_ATOM_HIFI2_PLATFORM_PCI_MODULE 1
#define CONFIG_DM_CRYPT_MODULE 1
#define CONFIG_IPV6_FOU_TUNNEL_MODULE 1
#define CONFIG_IRQ_SIM 1
#define CONFIG_HID_THRUSTMASTER_MODULE 1
#define CONFIG_NFS_FS_MODULE 1
#define CONFIG_LTC2496_MODULE 1
#define CONFIG_DVB_S5H1420_MODULE 1
#define CONFIG_BE2NET_BE3 1
#define CONFIG_NET_VENDOR_NATSEMI 1
#define CONFIG_IIO_CROS_EC_ACCEL_LEGACY_MODULE 1
#define CONFIG_EEEPC_WMI_MODULE 1
#define CONFIG_CROS_HPS_I2C_MODULE 1
#define CONFIG_EXTCON_INTEL_CHT_WC_MODULE 1
#define CONFIG_PATA_PARPORT_EPATC8 1
#define CONFIG_RTC_DRV_BQ32K_MODULE 1
#define CONFIG_MD_BITMAP_FILE 1
#define CONFIG_FUTEX_PI 1
#define CONFIG_HAS_IOPORT_MAP 1
#define CONFIG_XFRM_STATISTICS 1
#define CONFIG_STM_MODULE 1
#define CONFIG_AD7191_MODULE 1
#define CONFIG_THINKPAD_ACPI_HOTKEY_POLL 1
#define CONFIG_SND_SOC_CS4271_SPI_MODULE 1
#define CONFIG_ZRAM_BACKEND_LZO 1
#define CONFIG_RTC_DRV_MAX6902_MODULE 1
#define CONFIG_IP_VS_PROTO_AH 1
#define CONFIG_SND_SOC_SOF_METEORLAKE_MODULE 1
#define CONFIG_RTC_INTF_DEV 1
#define CONFIG_NETFILTER_SYNPROXY_MODULE 1
#define CONFIG_DVB_M88RS2000_MODULE 1
#define CONFIG_IP6_NF_MATCH_IPV6HEADER_MODULE 1
#define CONFIG_NFS_V4_0 1
#define CONFIG_I2C_AMD_MP2_MODULE 1
#define CONFIG_CRYPTO_DRBG_HMAC 1
#define CONFIG_BRIDGE_EBT_STP_MODULE 1
#define CONFIG_NFS_LOCALIO 1
#define CONFIG_DRM_SSD130X_I2C_MODULE 1
#define CONFIG_USB_SERIAL_KEYSPAN_MODULE 1
#define CONFIG_DVB_SI2165_MODULE 1
#define CONFIG_RTL8723BE_MODULE 1
#define CONFIG_REGULATOR_RT5033_MODULE 1
#define CONFIG_QCOM_PMIC_PDCHARGER_ULOG_MODULE 1
#define CONFIG_IP6_NF_MATCH_FRAG_MODULE 1
#define CONFIG_SENSORS_ADCXX_MODULE 1
#define CONFIG_REALTEK_PHY_HWMON 1
#define CONFIG_PATA_ALI_MODULE 1
#define CONFIG_RTC_DRV_PCF85063_MODULE 1
#define CONFIG_TSYS02D_MODULE 1
#define CONFIG_MLX5_EN_IPSEC 1
#define CONFIG_DVB_MMAP 1
#define CONFIG_SENSORS_EMC6W201_MODULE 1
#define CONFIG_RUST_IS_AVAILABLE 1
#define CONFIG_USB_G_NCM_MODULE 1
#define CONFIG_HIBERNATION_DEF_COMP "lzo"
#define CONFIG_SENSORS_AMC6821_MODULE 1
#define CONFIG_MTD_NAND_ECC_SW_HAMMING 1
#define CONFIG_BNA_MODULE 1
#define CONFIG_SPI_OFFLOAD 1
#define CONFIG_PARPORT_MODULE 1
#define CONFIG_MT7615_COMMON_MODULE 1
#define CONFIG_DRM_DISPLAY_HELPER_MODULE 1
#define CONFIG_BRIDGE_EBT_MARK_T_MODULE 1
#define CONFIG_CROS_EC_SYSFS_MODULE 1
#define CONFIG_NF_CONNTRACK_PPTP_MODULE 1
#define CONFIG_ARCH_SUPPORTS_LTO_CLANG_THIN 1
#define CONFIG_ARCH_MMAP_RND_BITS 28
#define CONFIG_MITIGATION_RETPOLINE 1
#define CONFIG_TYPEC_FUSB302_MODULE 1
#define CONFIG_EXTCON_INTEL_INT3496_MODULE 1
#define CONFIG_SENSORS_W83792D_MODULE 1
#define CONFIG_EROFS_FS_ZIP_LZMA 1
#define CONFIG_SENSORS_TMP464_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_IPCOMP_MODULE 1
#define CONFIG_SFC_SIENA_SRIOV 1
#define CONFIG_KPROBES_ON_FTRACE 1
#define CONFIG_ADA4250_MODULE 1
#define CONFIG_MLX5_MPFS 1
#define CONFIG_SND_SOC_WCD938X_MODULE 1
#define CONFIG_ALIM1535_WDT_MODULE 1
#define CONFIG_PCIE_DW 1
#define CONFIG_XFRM_SUB_POLICY 1
#define CONFIG_ARCH_DEFAULT_CRASH_DUMP 1
#define CONFIG_RT2800PCI_MODULE 1
#define CONFIG_BMI323_SPI_MODULE 1
#define CONFIG_IP6_NF_MATCH_RPFILTER_MODULE 1
#define CONFIG_SND_SOC_SOF_MODULE 1
#define CONFIG_DRM_BOCHS_MODULE 1
#define CONFIG_HID_SENSOR_PRESS_MODULE 1
#define CONFIG_TI_DAC7612_MODULE 1
#define CONFIG_SND_SOC_USB_MODULE 1
#define CONFIG_MM_ID 1
#define CONFIG_NET_SCH_SFB_MODULE 1
#define CONFIG_GENERIC_PINCTRL_GROUPS 1
#define CONFIG_LTC2983_MODULE 1
#define CONFIG_HID_SENSOR_HUMIDITY_MODULE 1
#define CONFIG_BMC150_MAGN_SPI_MODULE 1
#define CONFIG_RTW89_8851B_MODULE 1
#define CONFIG_MDIO_MODULE 1
#define CONFIG_AD7298_MODULE 1
#define CONFIG_SND_SOC_SOF_AMD_ACP70_MODULE 1
#define CONFIG_SND_SOC_CS35L45_SPI_MODULE 1
#define CONFIG_AD5504_MODULE 1
#define CONFIG_YENTA_RICOH 1
#define CONFIG_XFS_FS_MODULE 1
#define CONFIG_SRF04_MODULE 1
#define CONFIG_DVB_USB_DVBSKY_MODULE 1
#define CONFIG_TOUCHSCREEN_SX8654_MODULE 1
#define CONFIG_SX9310_MODULE 1
#define CONFIG_SENSORS_AD7414_MODULE 1
#define CONFIG_CAN_PEAK_PCI_MODULE 1
#define CONFIG_MFD_WM5102 1
#define CONFIG_BMI160_MODULE 1
#define CONFIG_NLS_CODEPAGE_857_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_TEE_MODULE 1
#define CONFIG_X86_SGX 1
#define CONFIG_PROFILING 1
#define CONFIG_SND_SOC_RT1011_MODULE 1
#define CONFIG_VIDEO_SAA7134_GO7007_MODULE 1
#define CONFIG_CHARGER_BQ24190_MODULE 1
#define CONFIG_THINKPAD_ACPI_VIDEO 1
#define CONFIG_RSEQ_SLICE_EXTENSION 1
#define CONFIG_SND_SOC_AW88261_MODULE 1
#define CONFIG_NET_VENDOR_ALACRITECH 1
#define CONFIG_RTW88_8812A_MODULE 1
#define CONFIG_CROS_EC_TYPEC_ALTMODES 1
#define CONFIG_HW_RANDOM_TIMERIOMEM_MODULE 1
#define CONFIG_RT2X00_LIB_FIRMWARE 1
#define CONFIG_BT_HCIBCM203X_MODULE 1
#define CONFIG_IAQCORE_MODULE 1
#define CONFIG_SND_HDA_CODEC_HDMI_ATI_MODULE 1
#define CONFIG_ACPI_WATCHDOG 1
#define CONFIG_HID_SAMSUNG_MODULE 1
#define CONFIG_SND_SOC_SPDIF_MODULE 1
#define CONFIG_MEDIA_TUNER_IT913X_MODULE 1
#define CONFIG_SND_SOC_RTQ9124_MODULE 1
#define CONFIG_SND_SIMPLE_CARD_MODULE 1
#define CONFIG_SND_SOC_RT5651_MODULE 1
#define CONFIG_USB4_NET_MODULE 1
#define CONFIG_VFIO_DEVICE_CDEV 1
#define CONFIG_NLS_CODEPAGE_864_MODULE 1
#define CONFIG_CAN_8DEV_USB_MODULE 1
#define CONFIG_LEDS_SIEMENS_SIMATIC_IPC_MODULE 1
#define CONFIG_WIRELESS_HOTKEY_MODULE 1
#define CONFIG_USB_CXACRU_MODULE 1
#define CONFIG_KVM_VFIO 1
#define CONFIG_F2FS_IOSTAT 1
#define CONFIG_HID_BPF 1
#define CONFIG_COMMON_CLK_MAX9485_MODULE 1
#define CONFIG_6LOWPAN_NHC_ROUTING_MODULE 1
#define CONFIG_USB_SERIAL_FTDI_SIO_MODULE 1
#define CONFIG_ADIS16130_MODULE 1
#define CONFIG_USB_CDNS2_UDC_MODULE 1
#define CONFIG_SCSI_CONSTANTS 1
#define CONFIG_HAVE_ARCH_TRANSPARENT_HUGEPAGE 1
#define CONFIG_NET_SCH_FIFO 1
#define CONFIG_SYSTEM76_ACPI_MODULE 1
#define CONFIG_BRIDGE_VLAN_FILTERING 1
#define CONFIG_TRACE_IRQFLAGS_NMI_SUPPORT 1
#define CONFIG_BT_HCIUART_ATH3K 1
#define CONFIG_TYPEC_TCPM_MODULE 1
#define CONFIG_IIO_ST_MAGN_3AXIS_MODULE 1
#define CONFIG_GPIO_MPSSE_MODULE 1
#define CONFIG_INFINIBAND_EFA_MODULE 1
#define CONFIG_I2C_MLXCPLD_MODULE 1
#define CONFIG_NLS_DEFAULT "utf8"
#define CONFIG_ZRAM_TRACK_ENTRY_ACTIME 1
#define CONFIG_SND_HDA_CODEC_CS420X_MODULE 1
#define CONFIG_THP_SWAP 1
#define CONFIG_MEDIA_TUNER_XC4000_MODULE 1
#define CONFIG_SENSORS_MP2975_REGULATOR 1
#define CONFIG_SND_SOC_ADI_AXI_I2S_MODULE 1
#define CONFIG_MFD_DA9150_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_ELO 1
#define CONFIG_RTW88_8723X_MODULE 1
#define CONFIG_MITIGATION_VMSCAPE 1
#define CONFIG_CRYPTO_DH_RFC7919_GROUPS 1
#define CONFIG_SENSORS_ADT7462_MODULE 1
#define CONFIG_MOUSE_PS2_SENTELIC 1
#define CONFIG_RTW88_88XXA_MODULE 1
#define CONFIG_CC_HAS_MIN_FUNCTION_ALIGNMENT 1
#define CONFIG_SENSORS_HS3001_MODULE 1
#define CONFIG_JOYSTICK_XPAD_MODULE 1
#define CONFIG_BT_MRVL_MODULE 1
#define CONFIG_SCSI_FDOMAIN_MODULE 1
#define CONFIG_MOST_COMPONENTS_MODULE 1
#define CONFIG_SENSORS_TC74_MODULE 1
#define CONFIG_SND_SOC_SOF_ICELAKE_MODULE 1
#define CONFIG_DMA_NEED_SYNC 1
#define CONFIG_VEML6030_MODULE 1
#define CONFIG_AF_RXRPC_DEBUG 1
#define CONFIG_NLS_ISO8859_13_MODULE 1
#define CONFIG_INTEL_LDMA 1
#define CONFIG_SND_SOC_CS35L56_MODULE 1
#define CONFIG_MMC_SDHCI_PCI_MODULE 1
#define CONFIG_MMC_VIA_SDMMC_MODULE 1
#define CONFIG_MENZ069_WATCHDOG_MODULE 1
#define CONFIG_AMD_ATL_PRM 1
#define CONFIG_X86_REQUIRED_FEATURE_ALWAYS 1
#define CONFIG_DRM_AMD_DC 1
#define CONFIG_XOR_BLOCKS_ARCH 1
#define CONFIG_EARLY_PRINTK_USB 1
#define CONFIG_REGULATOR_NETLINK_EVENTS 1
#define CONFIG_DVB_NETUP_UNIDVB_MODULE 1
#define CONFIG_MTDRAM_TOTAL_SIZE 4096
#define CONFIG_LOCK_DOWN_KERNEL_FORCE_NONE 1
#define CONFIG_REGULATOR 1
#define CONFIG_TYPEC_MUX_PI3USB30532_MODULE 1
#define CONFIG_HID_PLAYSTATION_MODULE 1
#define CONFIG_SND_SOC_INTEL_SOF_ES8336_MACH_MODULE 1
#define CONFIG_MODULE_SRCVERSION_ALL 1
#define CONFIG_SENSORS_INA3221_MODULE 1
#define CONFIG_ACPI_I2C_OPREGION 1
#define CONFIG_NFP_MODULE 1
#define CONFIG_6LOWPAN_GHC_EXT_HDR_DEST_MODULE 1
#define CONFIG_XEN_BLKDEV_BACKEND_MODULE 1
#define CONFIG_VIDEO_LM3646_MODULE 1
#define CONFIG_SND_SOC_TAS2562_MODULE 1
#define CONFIG_MEDIATEK_MT6360_ADC_MODULE 1
#define CONFIG_SND_SOC_SOF_CLIENT_MODULE 1
#define CONFIG_INPUT_SPARSEKMAP_MODULE 1
#define CONFIG_BACKLIGHT_MT6370_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_CONNLABEL_MODULE 1
#define CONFIG_DMI_SCAN_MACHINE_NON_EFI_FALLBACK 1
#define CONFIG_DVB_LGDT3306A_MODULE 1
#define CONFIG_TYPEC_WCOVE_MODULE 1
#define CONFIG_GRO_CELLS 1
#define CONFIG_TOUCHSCREEN_GOODIX_MODULE 1
#define CONFIG_RTC_DRV_WM831X_MODULE 1
#define CONFIG_VIDEO_CX25821_MODULE 1
#define CONFIG_CRYPTO_JITTERENTROPY_MEMORY_BLOCKSIZE 32
#define CONFIG_PACKET_DIAG_MODULE 1
#define CONFIG_GENERIC_STRNCPY_FROM_USER 1
#define CONFIG_ISCSI_TARGET_CXGB4_MODULE 1
#define CONFIG_HID_RMI_MODULE 1
#define CONFIG_BE2NET_BE2 1
#define CONFIG_TOUCHSCREEN_WDT87XX_I2C_MODULE 1
#define CONFIG_GPIO_NOVALAKE_MODULE 1
#define CONFIG_TEXTSEARCH 1
#define CONFIG_XFS_BTREE_IN_MEM 1
#define CONFIG_MFD_DA9052_SPI 1
#define CONFIG_HAVE_MOVE_PMD 1
#define CONFIG_NETXEN_NIC_MODULE 1
#define CONFIG_DRM_XE_ENABLE_SCHEDTIMEOUT_LIMIT 1
#define CONFIG_VHOST_VDPA_MODULE 1
#define CONFIG_IWLWIFI_DEBUGFS 1
#define CONFIG_USB_SERIAL_WISHBONE_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_RECENT_MODULE 1
#define CONFIG_PROC_EVENTS 1
#define CONFIG_IIO_CROS_EC_SENSORS_LID_ANGLE_MODULE 1
#define CONFIG_INFINIBAND_SRP_MODULE 1
#define CONFIG_USB_F_MIDI2_MODULE 1
#define CONFIG_FAILOVER_MODULE 1
#define CONFIG_TYPEC_MUX_NB7VPQ904M_MODULE 1
#define CONFIG_PAGE_MAPCOUNT 1
#define CONFIG_LINEAR_RANGES 1
#define CONFIG_SATA_VIA_MODULE 1
#define CONFIG_PATA_NS87415_MODULE 1
#define CONFIG_TRUSTED_KEYS_TEE 1
#define CONFIG_BOSCH_BNO055_SERIAL_MODULE 1
#define CONFIG_WEXT_PROC 1
#define CONFIG_CRYPTO_CAST6_AVX_X86_64_MODULE 1
#define CONFIG_SND_SOC_AK5558_MODULE 1
#define CONFIG_RTC_DRV_GOLDFISH_MODULE 1
#define CONFIG_NF_TPROXY_IPV4_MODULE 1
#define CONFIG_NF_CONNTRACK_IRC_MODULE 1
#define CONFIG_SCHED_STACK_END_CHECK 1
#define CONFIG_DM_LOG_USERSPACE_MODULE 1
#define CONFIG_INT340X_THERMAL_MODULE 1
#define CONFIG_LEDS_LP5812_MODULE 1
#define CONFIG_PATA_MPIIX_MODULE 1
#define CONFIG_BRIDGE_EBT_BROUTE_MODULE 1
#define CONFIG_SND_SOC_PCM3060_I2C_MODULE 1
#define CONFIG_AD5696_I2C_MODULE 1
#define CONFIG_CHARGER_RT9756_MODULE 1
#define CONFIG_VIRTIO_DMA_SHARED_BUFFER_MODULE 1
#define CONFIG_SND_HDA_CORE_MODULE 1
#define CONFIG_RAS_CEC 1
#define CONFIG_SCSI_UFS_CDNS_PLATFORM_MODULE 1
#define CONFIG_HID 1
#define CONFIG_X86_CPU_RESCTRL 1
#define CONFIG_CRYPTO_LZ4_MODULE 1
#define CONFIG_XILINX_XDMA_MODULE 1
#define CONFIG_DM_VERITY_VERIFY_ROOTHASH_SIG_SECONDARY_KEYRING 1
#define CONFIG_NET_VENDOR_HISILICON 1
#define CONFIG_SCSI_MYRS_MODULE 1
#define CONFIG_SND_SOC_INTEL_SOF_MAXIM_COMMON_MODULE 1
#define CONFIG_NFC_PN533_MODULE 1
#define CONFIG_ALIENWARE_WMI_WMAX 1
#define CONFIG_MTK_T7XX_MODULE 1
#define CONFIG_NE2K_PCI_MODULE 1
#define CONFIG_NET_TEAM_MODE_RANDOM_MODULE 1
#define CONFIG_FBNIC_MODULE 1
#define CONFIG_SATA_VITESSE_MODULE 1
#define CONFIG_FPGA_MGR_LATTICE_SYSCONFIG_MODULE 1
#define CONFIG_USB_GADGETFS_MODULE 1
#define CONFIG_SND_SOC_GENERIC_DMAENGINE_PCM 1
#define CONFIG_NFT_MASQ_MODULE 1
#define CONFIG_NET_IFE_SKBPRIO_MODULE 1
#define CONFIG_AD7887_MODULE 1
#define CONFIG_HID_CP2112_MODULE 1
#define CONFIG_NET_SCH_TEQL_MODULE 1
#define CONFIG_CRYPTO_LIB_UTILS 1
#define CONFIG_SND_SOC_DA7213_MODULE 1
#define CONFIG_VEML6070_MODULE 1
#define CONFIG_SG_POOL 1
#define CONFIG_X86 1
#define CONFIG_MFD_WM831X_SPI 1
#define CONFIG_ARCH_SUPPORTS_HUGE_PFNMAP 1
#define CONFIG_SND_HDA_CODEC_CM9825_MODULE 1
#define CONFIG_SERIAL_RP2_MODULE 1
#define CONFIG_CRYPTO_DH 1
#define CONFIG_KFENCE 1
#define CONFIG_MTD_BLOCK2MTD_MODULE 1
#define CONFIG_EXTCON_MAX77843_MODULE 1
#define CONFIG_CC_HAS_WORKING_NOSANITIZE_ADDRESS 1
#define CONFIG_INPUT_BMA150_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_HMARK_MODULE 1
#define CONFIG_BLK_CGROUP_RWSTAT 1
#define CONFIG_USB_CDNS3_MODULE 1
#define CONFIG_X86_REQUIRED_FEATURE_NOPL 1
#define CONFIG_QCOM_HIDMA_MODULE 1
#define CONFIG_NTFS3_FS_POSIX_ACL 1
#define CONFIG_DELL_WMI_MODULE 1
#define CONFIG_SMS_SDIO_DRV_MODULE 1
#define CONFIG_USB_G_WEBCAM_MODULE 1
#define CONFIG_SND_SOC_INTEL_CHT_BSW_MAX98090_TI_MACH_MODULE 1
#define CONFIG_CROS_EC_PROTO_MODULE 1
#define CONFIG_CORE_DUMP_DEFAULT_ELF_HEADERS 1
#define CONFIG_EXTCON_MAX3355_MODULE 1
#define CONFIG_SURFACE_AGGREGATOR_BUS 1
#define CONFIG_NET_EMATCH 1
#define CONFIG_SND_HDA_POWER_SAVE_DEFAULT 10
#define CONFIG_SND_SOC_INTEL_BYT_CHT_CX2072X_MACH_MODULE 1
#define CONFIG_PWM_TWL_MODULE 1
#define CONFIG_B44_PCI_AUTOSELECT 1
#define CONFIG_TYPEC_MODULE 1
#define CONFIG_RPMSG_CHAR_MODULE 1
#define CONFIG_MODULE_SIG_SHA512 1
#define CONFIG_LTC2664_MODULE 1
#define CONFIG_IP6_NF_MATCH_HL_MODULE 1
#define CONFIG_MOST_CDEV_MODULE 1
#define CONFIG_SENSORS_SMSC47M1_MODULE 1
#define CONFIG_REGULATOR_MAX8952_MODULE 1
#define CONFIG_SENSORS_NCT6775_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_OWNER_MODULE 1
#define CONFIG_BINFMT_MISC 1
#define CONFIG_CAN_PEAK_PCIEFD_MODULE 1
#define CONFIG_BLK_DEV_RNBD_CLIENT_MODULE 1
#define CONFIG_SND_SOC_CS35L36_MODULE 1
#define CONFIG_INTEL_TCC_COOLING_MODULE 1
#define CONFIG_MT792x_LIB_MODULE 1
#define CONFIG_SBC_FITPC2_WATCHDOG_MODULE 1
#define CONFIG_DVB_STV6110x_MODULE 1
#define CONFIG_USB_PCI 1
#define CONFIG_SND_SOC_MSM8916_WCD_DIGITAL_MODULE 1
#define CONFIG_USB_GSPCA_FINEPIX_MODULE 1
#define CONFIG_MRP_MODULE 1
#define CONFIG_SCHED_MM_CID 1
#define CONFIG_ACPI_VIOT 1
#define CONFIG_NFSD_BLOCKLAYOUT 1
#define CONFIG_VIDEO_THP7312_MODULE 1
#define CONFIG_PWM_DWC_CORE_MODULE 1
#define CONFIG_GPIO_MADERA_MODULE 1
#define CONFIG_MCP4131_MODULE 1
#define CONFIG_ADVISE_SYSCALLS 1
#define CONFIG_MT76x2U_MODULE 1
#define CONFIG_THERMAL_GOV_STEP_WISE 1
#define CONFIG_NET 1
#define CONFIG_MODULE_FORCE_UNLOAD 1
#define CONFIG_MOUSE_APPLETOUCH_MODULE 1
#define CONFIG_X86_VSYSCALL_EMULATION 1
#define CONFIG_ARCH_ENABLE_SPLIT_PMD_PTLOCK 1
#define CONFIG_HAVE_OPTPROBES 1
#define CONFIG_WLAN_VENDOR_MICROCHIP 1
#define CONFIG_MPL115_I2C_MODULE 1
#define CONFIG_REGULATOR_MAX8925_MODULE 1
#define CONFIG_IEEE802154_ADF7242_MODULE 1
#define CONFIG_SCSI_MVSAS_TASKLET 1
#define CONFIG_NET_DSA_TAG_GSWIP_MODULE 1
#define CONFIG_XFRM_IPCOMP_MODULE 1
#define CONFIG_DVB_USB_PCTV452E_MODULE 1
#define CONFIG_HMC6352_MODULE 1
#define CONFIG_GPIO_ACPI 1
#define CONFIG_NFC_FDP_I2C_MODULE 1
#define CONFIG_MTRR_SANITIZER 1
#define CONFIG_AD5110_MODULE 1
#define CONFIG_MFD_TQMX86_MODULE 1
#define CONFIG_DEFAULT_CUBIC 1
#define CONFIG_XFRM_USER_MODULE 1
#define CONFIG_NLS_CODEPAGE_865_MODULE 1
#define CONFIG_USB_DEFAULT_AUTHORIZATION_MODE 1
#define CONFIG_NET_REDIRECT 1
#define CONFIG_ACPI_THERMAL 1
#define CONFIG_INPUT_ARIZONA_HAPTICS_MODULE 1
#define CONFIG_LOAD_UEFI_KEYS 1
#define CONFIG_USB_LAN78XX_MODULE 1
#define CONFIG_AD2S1200_MODULE 1
#define CONFIG_VIRTIO_RTC_CLASS 1
#define CONFIG_SMS_USB_DRV_MODULE 1
#define CONFIG_GACT_PROB 1
#define CONFIG_NET_VENDOR_ENGLEDER 1
#define CONFIG_ATL1E_MODULE 1
#define CONFIG_X86_SPEEDSTEP_LIB_MODULE 1
#define CONFIG_VIDEO_CAMERA_SENSOR 1
#define CONFIG_TRACEPOINTS 1
#define CONFIG_SCHED_SMT 1
#define CONFIG_LIRC 1
#define CONFIG_UNINLINE_SPIN_UNLOCK 1
#define CONFIG_SND_SOC_MTK_BTCVSD_MODULE 1
#define CONFIG_PCSPKR_PLATFORM 1
#define CONFIG_INITRAMFS_SOURCE ""
#define CONFIG_EXFAT_FS_MODULE 1
#define CONFIG_PROC_THERMAL_MMIO_RAPL_MODULE 1
#define CONFIG_VCNL3020_MODULE 1
#define CONFIG_B43_PHY_N 1
#define CONFIG_SIGNED_PE_FILE_VERIFICATION 1
#define CONFIG_UNIX98_PTYS 1
#define CONFIG_RANDOMIZE_KSTACK_OFFSET 1
#define CONFIG_CLKBLD_I8253 1
#define CONFIG_SOUNDWIRE_QCOM_MODULE 1
#define CONFIG_SPI_XCOMM_MODULE 1
#define CONFIG_USB_APPLEDISPLAY_MODULE 1
#define CONFIG_PPP_SYNC_TTY_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_CONNBYTES_MODULE 1
#define CONFIG_ARCH_HAS_NONLEAF_PMD_YOUNG 1
#define CONFIG_TYPEC_MUX_INTEL_PMC_MODULE 1
#define CONFIG_JOYSTICK_GRIP_MP_MODULE 1
#define CONFIG_RTW88_8822BU_MODULE 1
#define CONFIG_SATA_ULI_MODULE 1
#define CONFIG_AMD_XGBE_HAVE_ECC 1
#define CONFIG_PCI_PF_STUB_MODULE 1
#define CONFIG_DRM_CIRRUS_QEMU_MODULE 1
#define CONFIG_SND_SOC_SOF_INTEL_ICL_MODULE 1
#define CONFIG_ACPI_PROCESSOR_CSTATE 1
#define CONFIG_DRM_SUBALLOC_HELPER_MODULE 1
#define CONFIG_VIDEO_RP1_CFE_MODULE 1
#define CONFIG_SENSORS_MAX1111_MODULE 1
#define CONFIG_PPP_BSDCOMP_MODULE 1
#define CONFIG_USB_GADGET_MODULE 1
#define CONFIG_BRIDGE_EBT_LIMIT_MODULE 1
#define CONFIG_ARCH_WANT_OPTIMIZE_HUGETLB_VMEMMAP 1
#define CONFIG_SENSORS_MC34VR500_MODULE 1
#define CONFIG_HID_WIIMOTE_MODULE 1
#define CONFIG_CRYPTO_SM4_GENERIC_MODULE 1
#define CONFIG_INTEL_IDXD_MODULE 1
#define CONFIG_ARCH_SPARSEMEM_DEFAULT 1
#define CONFIG_BACKLIGHT_KTZ8866_MODULE 1
#define CONFIG_KEXEC_JUMP 1
#define CONFIG_VFIO_MODULE 1
#define CONFIG_NFC_HCI_MODULE 1
#define CONFIG_NLS_ISO8859_14_MODULE 1
#define CONFIG_EXECMEM 1
#define CONFIG_HARDLOCKUP_DETECTOR_COUNTS_HRTIMER 1
#define CONFIG_SND_SOC_SOF_IPC4 1
#define CONFIG_DVB_ZD1301_DEMOD_MODULE 1
#define CONFIG_DEBUG_INFO_BTF_MODULES 1
#define CONFIG_SND_SOC_WM_ADSP_MODULE 1
#define CONFIG_SND_SOC_INTEL_BYTCR_RT5651_MACH_MODULE 1
#define CONFIG_NET_VENDOR_REALTEK 1
#define CONFIG_XFRM_OFFLOAD 1
#define CONFIG_ZRAM_MULTI_COMP 1
#define CONFIG_ADIS16209_MODULE 1
#define CONFIG_IPV6_SEG6_LWTUNNEL 1
#define CONFIG_MEDIA_TUNER_TDA18212_MODULE 1
#define CONFIG_CHARGER_CROS_PCHG_MODULE 1
#define CONFIG_NET_DSA_TAG_RTL4_A_MODULE 1
#define CONFIG_BMI088_ACCEL_I2C_MODULE 1
#define CONFIG_SENSORS_LTC2947_I2C_MODULE 1
#define CONFIG_OVERLAY_FS_MODULE 1
#define CONFIG_SECONDARY_TRUSTED_KEYRING 1
#define CONFIG_ICS932S401_MODULE 1
#define CONFIG_DRM_COREBOOTDRM_MODULE 1
#define CONFIG_BT_MODULE 1
#define CONFIG_ZRAM_BACKEND_DEFLATE 1
#define CONFIG_TOUCHSCREEN_USB_IDEALTEK 1
#define CONFIG_HOTPLUG_SPLIT_STARTUP 1
#define CONFIG_VT 1
#define CONFIG_USB_GSPCA_JEILINJ_MODULE 1
#define CONFIG_NET_CLS_ACT 1
#define CONFIG_XEN_PV_DOM0 1
#define CONFIG_DVB_USB_MXL111SF_MODULE 1
#define CONFIG_ET131X_MODULE 1
#define CONFIG_COMPAT_OLD_SIGACTION 1
#define CONFIG_EEPROM_MAX6875_MODULE 1
#define CONFIG_VIDEO_VIMC_MODULE 1
#define CONFIG_LIBNVDIMM_MODULE 1
#define CONFIG_PAHOLE_HAS_LANG_EXCLUDE 1
#define CONFIG_SERIAL_ALTERA_JTAGUART_MODULE 1
#define CONFIG_RTC_DRV_ABB5ZES3_MODULE 1
#define CONFIG_IP_SET_HASH_IPPORTIP_MODULE 1
#define CONFIG_BATTERY_GOLDFISH_MODULE 1
#define CONFIG_SMP 1
#define CONFIG_ARCH_MMAP_RND_COMPAT_BITS 8
#define CONFIG_AMD_SFH_HID_MODULE 1
#define CONFIG_VLAN_8021Q_MVRP 1
#define CONFIG_MITIGATION_GDS 1
#define CONFIG_SCSI_BNX2_ISCSI_MODULE 1
#define CONFIG_R8169_LEDS 1
#define CONFIG_INFINIBAND_RDMAVT_MODULE 1
#define CONFIG_BT_HCIBTUSB_RTL 1
#define CONFIG_W1_SLAVE_DS250X_MODULE 1
#define CONFIG_VIDEO_GC08A3_MODULE 1
#define CONFIG_DETECT_HUNG_TASK_BLOCKER 1
#define CONFIG_CFG80211_MODULE 1
#define CONFIG_NFT_QUOTA_MODULE 1
#define CONFIG_PARPORT_PC_MODULE 1
#define CONFIG_ARCH_SUPPORTS_MSEAL_SYSTEM_MAPPINGS 1
#define CONFIG_LIQUIDIO_CORE_MODULE 1
#define CONFIG_CEPH_FS_POSIX_ACL 1
#define CONFIG_REGULATOR_MAX8997_MODULE 1
#define CONFIG_HID_REDRAGON_MODULE 1
#define CONFIG_BT_RTL_MODULE 1
#define CONFIG_SECURITYFS 1
#define CONFIG_VIDEO_CX88_DVB_MODULE 1
#define CONFIG_INV_ICM45600_SPI_MODULE 1
#define CONFIG_TOUCHSCREEN_GOODIX_BERLIN_CORE_MODULE 1
#define CONFIG_VIDEO_SOLO6X10_MODULE 1
#define CONFIG_QUEUED_RWLOCKS 1
#define CONFIG_VMWARE_VMCI_VSOCKETS_MODULE 1
#define CONFIG_BT_HCIVHCI_MODULE 1
#define CONFIG_SND_SST_ATOM_HIFI2_PLATFORM_ACPI_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_DCCP_MODULE 1
#define CONFIG_LSM_MMAP_MIN_ADDR 65536
#define CONFIG_MAC80211_RC_MINSTREL 1
#define CONFIG_X86_KERNEL_IBT 1
#define CONFIG_XEN_PCIDEV_FRONTEND_MODULE 1
#define CONFIG_VIDEO_CX231XX_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_HASHLIMIT_MODULE 1
#define CONFIG_HAVE_ARCH_AUDITSYSCALL 1
#define CONFIG_FIREWIRE_SBP2_MODULE 1
#define CONFIG_SND_SOC_STI_SAS_MODULE 1
#define CONFIG_SND_SOC_AK5386_MODULE 1
#define CONFIG_SND_HDA_SCODEC_TAS2781_SPI_MODULE 1
#define CONFIG_SND_SOC_STA350_MODULE 1
#define CONFIG_BLK_DEV_LOOP_MODULE 1
#define CONFIG_TI_ADS1298_MODULE 1
#define CONFIG_IPV6_SUBTREES 1
#define CONFIG_HID_LENOVO_GO_S_MODULE 1
#define CONFIG_SENSORS_ADT7310_MODULE 1
#define CONFIG_INTEL_TH_PCI_MODULE 1
#define CONFIG_HID_EMS_FF_MODULE 1
#define CONFIG_SPEAKUP_MODULE 1
#define CONFIG_MICROSEMI_PHY_MODULE 1
#define CONFIG_HID_SENSOR_IIO_TRIGGER_MODULE 1
#define CONFIG_VIDEO_OV2659_MODULE 1
#define CONFIG_X86_REQUIRED_FEATURE_CPUID 1
#define CONFIG_DELL_SMBIOS_MODULE 1
#define CONFIG_BTRFS_FS_POSIX_ACL 1
#define CONFIG_HID_UDRAW_PS3_MODULE 1
#define CONFIG_HID_APPLE_MODULE 1
#define CONFIG_DVB_USB_DIGITV_MODULE 1
#define CONFIG_AC97_BUS_MODULE 1
#define CONFIG_VMWARE_BALLOON_MODULE 1
#define CONFIG_STK3310_MODULE 1
#define CONFIG_VIDEO_SAA7134_ALSA_MODULE 1
#define CONFIG_USB_BELKIN 1
#define CONFIG_PCI_PWRCTRL_TC9563_MODULE 1
#define CONFIG_DRM_RADEON_USERPTR 1
#define CONFIG_INTEL_IOATDMA_MODULE 1
#define CONFIG_SND_SOC_RT5682S_MODULE 1
#define CONFIG_XIAOMI_WMI_MODULE 1
#define CONFIG_RCU_STALL_COMMON 1
#define CONFIG_USB_UEAGLEATM_MODULE 1
#define CONFIG_BLK_DEV_ZONED 1
#define CONFIG_REGULATOR_LP872X_MODULE 1
#define CONFIG_SATA_ZPODD 1
#define CONFIG_RT2X00_LIB_MODULE 1
#define CONFIG_HAVE_ASM_MODVERSIONS 1
#define CONFIG_DVB_STB6100_MODULE 1
#define CONFIG_HID_SENSOR_IIO_COMMON_MODULE 1
#define CONFIG_RAS_FMPM_MODULE 1
#define CONFIG_TCP_CONG_CDG_MODULE 1
#define CONFIG_AD7405_MODULE 1
#define CONFIG_INFINIBAND_ADDR_TRANS 1
#define CONFIG_APDS9960_MODULE 1
#define CONFIG_NFS_DEBUG 1
#define CONFIG_XEN_PVH 1
#define CONFIG_SND_SOC_INTEL_SOF_TI_COMMON_MODULE 1
#define CONFIG_IOMMU_PT_VTDSS 1
#define CONFIG_NET_FC 1
#define CONFIG_BT_HCIRSI_MODULE 1
#define CONFIG_DYNAMIC_PHYSICAL_MASK 1
#define CONFIG_MFD_TPS65912_I2C_MODULE 1
#define CONFIG_SND_SOC_WCD934X_MODULE 1
#define CONFIG_TINYDRM_ILI9486_MODULE 1
#define CONFIG_KS8851_MODULE 1
#define CONFIG_UIO_PCI_GENERIC_SVA_MODULE 1
#define CONFIG_SCSI_LOGGING 1
#define CONFIG_HAVE_PERF_EVENTS 1
#define CONFIG_TI_ADC084S021_MODULE 1
#define CONFIG_RFKILL_LEDS 1
#define CONFIG_AD7476_MODULE 1
#define CONFIG_DRM_FBDEV_OVERALLOC 100
#define CONFIG_SECRETMEM 1
#define CONFIG_MSA311_MODULE 1
#define CONFIG_MFD_88PM805_MODULE 1
#define CONFIG_IO_STRICT_DEVMEM 1
#define CONFIG_VIDEO_OV2685_MODULE 1
#define CONFIG_IIO_SSP_SENSORS_COMMONS_MODULE 1
#define CONFIG_DM_VERITY_MODULE 1
#define CONFIG_NFT_NUMGEN_MODULE 1
#define CONFIG_BITLAND_MIFS_WMI_MODULE 1
#define CONFIG_ATM_MODULE 1
#define CONFIG_REGULATOR_TPS65185_MODULE 1
#define CONFIG_REGULATOR_TPS68470_MODULE 1
#define CONFIG_BACKLIGHT_88PM860X_MODULE 1
#define CONFIG_NET_SCH_MQPRIO_MODULE 1
#define CONFIG_SENSORS_APDS990X_MODULE 1
#define CONFIG_RUSTC_HAS_SPAN_FILE 1
#define CONFIG_AIC7XXX_DEBUG_MASK 0
#define CONFIG_W1_SLAVE_DS2423_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_U32_MODULE 1
#define CONFIG_DVB_DM1105_MODULE 1
#define CONFIG_SCSI_SYM53C8XX_MMIO 1
#define CONFIG_IPW2100_MODULE 1
#define CONFIG_GPIB_PCMCIA 1
#define CONFIG_NLS_CODEPAGE_855_MODULE 1
#define CONFIG_USB_DWC2_DUAL_ROLE 1
#define CONFIG_I2C_OCORES_MODULE 1
#define CONFIG_RTC_DRV_DS1511_MODULE 1
#define CONFIG_MEDIATEK_MT6359_AUXADC_MODULE 1
#define CONFIG_NGBE_MODULE 1
#define CONFIG_X86_L1_CACHE_SHIFT 6
#define CONFIG_IP6_NF_TARGET_HL_MODULE 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_MAX98373_MODULE 1
#define CONFIG_NFC_VIRTUAL_NCI_MODULE 1
#define CONFIG_HUGETLB_PMD_PAGE_TABLE_SHARING 1
#define CONFIG_REGULATOR_MC13892_MODULE 1
#define CONFIG_BMI270_I2C_MODULE 1
#define CONFIG_SENSORS_MP2856_MODULE 1
#define CONFIG_NET_KEY_MIGRATE 1
#define CONFIG_APDS9160_MODULE 1
#define CONFIG_SND_INDIGODJX_MODULE 1
#define CONFIG_USB_STORAGE_KARMA_MODULE 1
#define CONFIG_VIDEO_AK7375_MODULE 1
#define CONFIG_SMBDIRECT_MODULE 1
#define CONFIG_HID_MAYFLASH_MODULE 1
#define CONFIG_B43LEGACY_PCI_AUTOSELECT 1
#define CONFIG_MEMSTICK_JMICRON_38X_MODULE 1
#define CONFIG_MEDIA_TUNER_QT1010_MODULE 1
#define CONFIG_ATH9K_DYNACK 1
#define CONFIG_INTEL_PMC_CORE_MODULE 1
#define CONFIG_BONDING_MODULE 1
#define CONFIG_SND_ISIGHT_MODULE 1
#define CONFIG_PCIE_TPH 1
#define CONFIG_LTO_NONE 1
#define CONFIG_LEDS_QNAP_MCU_MODULE 1
#define CONFIG_DELL_SMBIOS_WMI 1
#define CONFIG_SND_HDA_CODEC_HDMI_NVIDIA_MODULE 1
#define CONFIG_SURFACE_DTX_MODULE 1
#define CONFIG_NLS_CODEPAGE_862_MODULE 1
#define CONFIG_GPIO_WS16C48_MODULE 1
#define CONFIG_TYPEC_MUX_IT5205_MODULE 1
#define CONFIG_SERIAL_8250_PCI1XXXX_MODULE 1
#define CONFIG_TULIP_MWI 1
#define CONFIG_HAVE_DMA_CONTIGUOUS 1
#define CONFIG_KEYBOARD_SAMSUNG_MODULE 1
#define CONFIG_DVB_ISL6405_MODULE 1
#define CONFIG_ADIS16136_MODULE 1
#define CONFIG_IR_WINBOND_CIR_MODULE 1
#define CONFIG_CM3323_MODULE 1
#define CONFIG_RTW88_8723DS_MODULE 1
#define CONFIG_SENSORS_ADT7475_MODULE 1
#define CONFIG_ARCH_PROC_KCORE_TEXT 1
#define CONFIG_SENSORS_MP2993_MODULE 1
#define CONFIG_CAN_NETLINK 1
#define CONFIG_JFFS2_FS_XATTR 1
#define CONFIG_KEYBOARD_MATRIX_MODULE 1
#define CONFIG_BACKLIGHT_CLASS_DEVICE 1
#define CONFIG_CFG80211_DEBUGFS 1
#define CONFIG_NF_TABLES_MODULE 1
#define CONFIG_SERIAL_FSL_LINFLEXUART_MODULE 1
#define CONFIG_CRYPTO_MANAGER 1
#define CONFIG_EPROBE_EVENTS 1
#define CONFIG_ADXL367_SPI_MODULE 1
#define CONFIG_USB_F_EEM_MODULE 1
#define CONFIG_HIBERNATION_COMP_LZO 1
#define CONFIG_SENSORS_PCF8591_MODULE 1
#define CONFIG_SUSPEND_FREEZER 1
#define CONFIG_NET_VENDOR_MARVELL 1
#define CONFIG_CAN_ISOTP_MODULE 1
#define CONFIG_RTW89_CORE_MODULE 1
#define CONFIG_SCSI_DC395x_MODULE 1
#define CONFIG_CPU_SUP_HYGON 1
#define CONFIG_DVB_NET 1
#define CONFIG_SSB_MODULE 1
#define CONFIG_ADXRS450_MODULE 1
#define CONFIG_W83877F_WDT_MODULE 1
#define CONFIG_CRYPTO_LIB_POLY1305_GENERIC 1
#define CONFIG_DECOMPRESS_LZO 1
#define CONFIG_SND_SOC_SOF_ACPI_DEV_MODULE 1
#define CONFIG_QRTR_MHI_MODULE 1
#define CONFIG_NLS_ISO8859_15_MODULE 1
#define CONFIG_LEDS_PWM_MULTICOLOR_MODULE 1
#define CONFIG_BACKLIGHT_QCOM_WLED_MODULE 1
#define CONFIG_CRYPTO_ACOMP_MODULE 1
#define CONFIG_MEDIA_CAMERA_SUPPORT 1
#define CONFIG_IWLWIFI_DEVICE_TRACING 1
#define CONFIG_BACKLIGHT_SAHARA_MODULE 1
#define CONFIG_RFKILL_GPIO_MODULE 1
#define CONFIG_UNACCEPTED_MEMORY 1
#define CONFIG_NET_DSA_SMSC_LAN9303_I2C_MODULE 1
#define CONFIG_TYPEC_MUX_TUSB1046_MODULE 1
#define CONFIG_INTEL_EHL_PSE_IO_MODULE 1
#define CONFIG_NTB_NETDEV_MODULE 1
#define CONFIG_SND_SEQ_UMP 1
#define CONFIG_VIDEO_VIVID_CEC 1
#define CONFIG_NET_SCH_PLUG_MODULE 1
#define CONFIG_NET_DSA_TAG_SJA1105_MODULE 1
#define CONFIG_DEV_DAX_CXL_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_CLUSTER_MODULE 1
#define CONFIG_VIDEO_SAA6752HS_MODULE 1
#define CONFIG_PPP_MULTILINK 1
#define CONFIG_QCOM_QMI_HELPERS_MODULE 1
#define CONFIG_LZ4_DECOMPRESS 1
#define CONFIG_USB_SERIAL_IR_MODULE 1
#define CONFIG_SND_HDA_CODEC_CA0132_MODULE 1
#define CONFIG_IP_VS_PROTO_ESP 1
#define CONFIG_SND_SOC_CS35L45_MODULE 1
#define CONFIG_SCSI_CHELSIO_FCOE_MODULE 1
#define CONFIG_VIDEO_VD55G1_MODULE 1
#define CONFIG_ARCH_SUPPORTS_SCHED_SMT 1
#define CONFIG_QUOTA_NETLINK_INTERFACE 1
#define CONFIG_USB_EMI62_MODULE 1
#define CONFIG_NFT_DUP_NETDEV_MODULE 1
#define CONFIG_PM_TRACE 1
#define CONFIG_SENSORS_XGENE_MODULE 1
#define CONFIG_MPRLS0025PA_I2C_MODULE 1
#define CONFIG_SCSI_SAS_HOST_SMP 1
#define CONFIG_IIO_ST_SENSORS_CORE_MODULE 1
#define CONFIG_IP6_NF_NAT_MODULE 1
#define CONFIG_RTC_MC146818_LIB 1
#define CONFIG_RD_LZO 1
#define CONFIG_RTW89_8852C_MODULE 1
#define CONFIG_NET_VENDOR_AQUANTIA 1
#define CONFIG_HID_LENOVO_MODULE 1
#define CONFIG_CEPH_FS_MODULE 1
#define CONFIG_OVPN_MODULE 1
#define CONFIG_RUSTC_HAS_UNNECESSARY_TRANSMUTES 1
#define CONFIG_SND_SOC_ES8375_MODULE 1
#define CONFIG_SENSORS_K8TEMP_MODULE 1
#define CONFIG_ZL3073X_I2C_MODULE 1
#define CONFIG_ATA_SFF 1
#define CONFIG_INPUT_MOUSEDEV_SCREEN_X 1024
#define CONFIG_INPUT_MAX7360_ROTARY_MODULE 1
#define CONFIG_USB_RAREMONO_MODULE 1
#define CONFIG_PINCTRL 1
#define CONFIG_NET_DSA_VITESSE_VSC73XX_SPI_MODULE 1
#define CONFIG_SENSORS_PIM4328_MODULE 1
#define CONFIG_STP_MODULE 1
#define CONFIG_REGULATOR_MAX8649_MODULE 1
#define CONFIG_ATH9K_PCI_NO_EEPROM_MODULE 1
#define CONFIG_JOYSTICK_SPACEORB_MODULE 1
#define CONFIG_NFC_NXP_NCI_MODULE 1
#define CONFIG_TCM_QLA2XXX_MODULE 1
#define CONFIG_ATH12K_DEBUGFS 1
#define CONFIG_SENSORS_HTU31_MODULE 1
#define CONFIG_MCP320X_MODULE 1
#define CONFIG_JME_MODULE 1
#define CONFIG_XEN_ACPI_PROCESSOR_MODULE 1
#define CONFIG_USB_SERIAL_VISOR_MODULE 1
#define CONFIG_MTD_SPI_NOR_USE_4K_SECTORS 1
#define CONFIG_BE2NET_MODULE 1
#define CONFIG_NET_SCH_RED_MODULE 1
#define CONFIG_DAMON_VADDR 1
#define CONFIG_DVB_VES1X93_MODULE 1
#define CONFIG_VIDEO_MT9V011_MODULE 1
#define CONFIG_VIDEO_TVEEPROM_MODULE 1
#define CONFIG_TI_ADS8688_MODULE 1
#define CONFIG_NF_TPROXY_IPV6_MODULE 1
#define CONFIG_MOST_USB_HDM_MODULE 1
#define CONFIG_DEBUG_BOOT_PARAMS 1
#define CONFIG_MFD_NCT6694_MODULE 1
#define CONFIG_STAGING 1
#define CONFIG_ACPI_LPIT 1
#define CONFIG_SENSORS_CROS_EC_MODULE 1
#define CONFIG_SCSI_DH_HP_SW_MODULE 1
#define CONFIG_MCP3564_MODULE 1
#define CONFIG_MISC_RTSX_MODULE 1
#define CONFIG_MEDIA_CONTROLLER 1
#define CONFIG_EFI_RCI2_TABLE 1
#define CONFIG_RTC_DRV_EM3027_MODULE 1
#define CONFIG_USB_SUPPORT 1
#define CONFIG_WLCORE_SDIO_MODULE 1
#define CONFIG_DVB_MXL5XX_MODULE 1
#define CONFIG_TCG_TIS_CORE 1
#define CONFIG_TOUCHSCREEN_HYNITRON_CST816X_MODULE 1
#define CONFIG_IP_VS_LBLC_MODULE 1
#define CONFIG_ACPI_PROCESSOR_IDLE 1
#define CONFIG_CRYPTO_JITTERENTROPY 1
#define CONFIG_PREVENT_FIRMWARE_BUILD 1
#define CONFIG_W1_MASTER_UART_MODULE 1
#define CONFIG_PATA_VIA_MODULE 1
#define CONFIG_SENSORS_ATXP1_MODULE 1
#define CONFIG_HW_RANDOM_VIRTIO_MODULE 1
#define CONFIG_FXOS8700_SPI_MODULE 1
#define CONFIG_MEGARAID_SAS_MODULE 1
#define CONFIG_CHARGER_LP8788_MODULE 1
#define CONFIG_DRM_XE_PREEMPT_TIMEOUT_MAX 10000000
#define CONFIG_TOUCHSCREEN_EGALAX_SERIAL_MODULE 1
#define CONFIG_IP_VS_TAB_BITS 15
#define CONFIG_PWM_PCA9685_MODULE 1
#define CONFIG_NFC_TRF7970A_MODULE 1
#define CONFIG_USB_CONFIGFS_SERIAL 1
#define CONFIG_MFD_MAX77705_MODULE 1
#define CONFIG_SND_SOC_AMD_LEGACY_MACH_MODULE 1
#define CONFIG_SENSORS_FSP_3Y_MODULE 1
#define CONFIG_PSTORE_COMPRESS 1
#define CONFIG_SND_SOC_INTEL_BYTCR_WM5102_MACH_MODULE 1
#define CONFIG_DM_ZERO_MODULE 1
#define CONFIG_XILINX_AXI_EMAC_MODULE 1
#define CONFIG_RTW88_8814AU_MODULE 1
#define CONFIG_ARCH_HAS_CPU_RELAX 1
#define CONFIG_I2C_GPIO_MODULE 1
#define CONFIG_IP_SET_HASH_NETNET_MODULE 1
#define CONFIG_KS8851_MLL_MODULE 1
#define CONFIG_FW_LOADER_COMPRESS_ZSTD 1
#define CONFIG_SND_FIREWIRE_TASCAM_MODULE 1
#define CONFIG_ACPI_MADT_WAKEUP 1
#define CONFIG_IR_REDRAT3_MODULE 1
#define CONFIG_IEEE802154_HWSIM_MODULE 1
#define CONFIG_NFT_LIMIT_MODULE 1
#define CONFIG_IPV6_TUNNEL_MODULE 1
#define CONFIG_XZ_DEC_ARMTHUMB 1
#define CONFIG_BT_HCIUART_SERDEV 1
#define CONFIG_INTEL_GTT_MODULE 1
#define CONFIG_RMI4_F21 1
#define CONFIG_ZONE_DMA32 1
#define CONFIG_CC_HAS_KASAN_GENERIC 1
#define CONFIG_NET_FAILOVER_MODULE 1
#define CONFIG_MLXSW_SPECTRUM_DCB 1
#define CONFIG_X86_IOPL_IOPERM 1
#define CONFIG_KEXEC_FILE 1
#define CONFIG_B43_PIO 1
#define CONFIG_SENSORS_ADM1031_MODULE 1
#define CONFIG_PRINTK_TIME 1
#define CONFIG_SND_SOC_RT286_MODULE 1
#define CONFIG_SPI_INTEL_PLATFORM_MODULE 1
#define CONFIG_DAMON_SYSFS 1
#define CONFIG_TSL2772_MODULE 1
#define CONFIG_TIFM_7XX1_MODULE 1
#define CONFIG_REGULATOR_MAX77693_MODULE 1
#define CONFIG_PING_MODULE 1
#define CONFIG_HOLTEK_FF 1
#define CONFIG_SOUNDWIRE_GENERIC_ALLOCATION_MODULE 1
#define CONFIG_SND_SOC_CS35L34_MODULE 1
#define CONFIG_AMD_MP2_STB 1
#define CONFIG_I2C_CROS_EC_TUNNEL_MODULE 1
#define CONFIG_BOSCH_BNO055_MODULE 1
#define CONFIG_INPUT_RETU_PWRBUTTON_MODULE 1
#define CONFIG_GREENASIA_FF 1
#define CONFIG_FSCACHE_STATS 1
#define CONFIG_APPLE_MFI_FASTCHARGE_MODULE 1
#define CONFIG_ACPI_CPPC_LIB 1
#define CONFIG_STMMAC_PCI_MODULE 1
#define CONFIG_DMI_SYSFS 1
#define CONFIG_ZLIB_INFLATE 1
#define CONFIG_ARCH_WANTS_THP_SWAP 1
#define CONFIG_MMA7455_SPI_MODULE 1
#define CONFIG_RTC_DRV_TPS6586X_MODULE 1
#define CONFIG_FPROBE_EVENTS 1
#define CONFIG_HID_BIGBEN_FF_MODULE 1
#define CONFIG_HID_BETOP_FF_MODULE 1
#define CONFIG_IPW2200_RADIOTAP 1
#define CONFIG_SENSORS_AHT10_MODULE 1
#define CONFIG_SND_SOC_SOF_AMD_TOPLEVEL_MODULE 1
#define CONFIG_W1_MASTER_DS2482_MODULE 1
#define CONFIG_MTD_UBI_MODULE 1
#define CONFIG_NLS_CODEPAGE_863_MODULE 1
#define CONFIG_RTC_DRV_RP5C01_MODULE 1
#define CONFIG_OVMF_DEBUG_LOG 1
#define CONFIG_BLK_DEV_RAM_MODULE 1
#define CONFIG_VGA_ARB 1
#define CONFIG_CRYPTO_LIB_CURVE25519_MODULE 1
#define CONFIG_SND_FIREWIRE 1
#define CONFIG_LOGIRUMBLEPAD2_FF 1
#define CONFIG_PERF_EVENTS_AMD_UNCORE_MODULE 1
#define CONFIG_DP83TG720_PHY_MODULE 1
#define CONFIG_ATL1C_MODULE 1
#define CONFIG_APDS9802ALS_MODULE 1
#define CONFIG_TCG_XEN_MODULE 1
#define CONFIG_SND_SOC_AMD_CZ_DA7219MX98357_MACH_MODULE 1
#define CONFIG_EXTCON_MAX14526_MODULE 1
#define CONFIG_DE2104X_MODULE 1
#define CONFIG_GPIO_ADP5520_MODULE 1
#define CONFIG_MFD_KEMPLD_MODULE 1
#define CONFIG_USB_EPSON2888 1
#define CONFIG_ARCH_USE_MEMTEST 1
#define CONFIG_HID_GENERIC 1
#define CONFIG_ACPI_PFRUT_MODULE 1
#define CONFIG_USB_PHY 1
#define CONFIG_DEBUG_INFO_BTF 1
#define CONFIG_TABLET_USB_AIPTEK_MODULE 1
#define CONFIG_PMIC_OPREGION 1
#define CONFIG_SENSORS_XDP720_MODULE 1
#define CONFIG_CAN_RAW_MODULE 1
#define CONFIG_INTEL_IOMMU_SVM 1
#define CONFIG_VIDEO_OV5675_MODULE 1
#define CONFIG_TI_ADC108S102_MODULE 1
#define CONFIG_QCA808X_PHY_MODULE 1
#define CONFIG_CRC_OPTIMIZATIONS 1
#define CONFIG_SND_HDA_SCODEC_CS35L41_MODULE 1
#define CONFIG_NET_DSA_XRS700X_MODULE 1
#define CONFIG_X86_MCE_AMD 1
#define CONFIG_MAX5487_MODULE 1
#define CONFIG_DS4424_MODULE 1
#define CONFIG_APERTURE_HELPERS 1
#define CONFIG_UNICODE 1
#define CONFIG_GAMEPORT_MODULE 1
#define CONFIG_RMI4_I2C_MODULE 1
#define CONFIG_DM_LOG_WRITES_MODULE 1
#define CONFIG_B44_PCI 1
#define CONFIG_VIDEO_GS1662_MODULE 1
#define CONFIG_USB_SIERRA_NET_MODULE 1
#define CONFIG_TINYDRM_ILI9225_MODULE 1
#define CONFIG_IBM_ASM_MODULE 1
#define CONFIG_SPI_BITBANG_MODULE 1
#define CONFIG_SWPHY 1
#define CONFIG_SND_SOC_RT712_SDCA_DMIC_SDW_MODULE 1
#define CONFIG_CGROUP_CPUACCT 1
#define CONFIG_SENSORS_ADM1275_MODULE 1
#define CONFIG_SND_I2S_HI6210_I2S_MODULE 1
#define CONFIG_MODULE_ALLOW_MISSING_NAMESPACE_IMPORTS 1
#define CONFIG_VIDEO_SAA717X_MODULE 1
#define CONFIG_MEMSTICK_REALTEK_USB_MODULE 1
#define CONFIG_SND_HDA_COMPONENT 1
#define CONFIG_NETFILTER_NETLINK_HOOK_MODULE 1
#define CONFIG_EFI_SECRET_MODULE 1
#define CONFIG_SPI_DW_PCI_MODULE 1
#define CONFIG_NFC_PN544_MEI_MODULE 1
#define CONFIG_BMI323_MODULE 1
#define CONFIG_PA12203001_MODULE 1
#define CONFIG_USB_STORAGE_CYPRESS_ATACB_MODULE 1
#define CONFIG_SIS900_MODULE 1
#define CONFIG_PATA_WINBOND_MODULE 1
#define CONFIG_DRM_SCHED_MODULE 1
#define CONFIG_HSA_AMD_SVM 1
#define CONFIG_REGULATOR_RT6190_MODULE 1
#define CONFIG_DRM_PANEL_BRIDGE 1
#define CONFIG_DVB_USB_GL861_MODULE 1
#define CONFIG_IONIC_MODULE 1
#define CONFIG_IP_VS_WLC_MODULE 1
#define CONFIG_SERIAL_IPOCTAL_MODULE 1
#define CONFIG_NET_POLL_CONTROLLER 1
#define CONFIG_DW_DMAC_CORE 1
#define CONFIG_JOYSTICK_ANALOG_MODULE 1
#define CONFIG_CAN_JANZ_ICAN3_MODULE 1
#define CONFIG_ACPI_EC_DEBUGFS_MODULE 1
#define CONFIG_INFINIBAND_MTHCA_DEBUG 1
#define CONFIG_HID_XIAOMI_MODULE 1
#define CONFIG_FIREWIRE_OHCI_MODULE 1
#define CONFIG_TOUCHSCREEN_EDT_FT5X06_MODULE 1
#define CONFIG_FS_DAX 1
#define CONFIG_PWM_MAX7360_MODULE 1
#define CONFIG_INPUT_MAX8925_ONKEY_MODULE 1
#define CONFIG_RTW89_8852B_MODULE 1
#define CONFIG_BT_HCIUART_3WIRE 1
#define CONFIG_DIMLIB 1
#define CONFIG_TWL4030_MADC_MODULE 1
#define CONFIG_MMC_SDHCI_ACPI_MODULE 1
#define CONFIG_6LOWPAN_GHC_ICMPV6_MODULE 1
#define CONFIG_HAVE_KVM_READONLY_MEM 1
#define CONFIG_GPIO_MB86S7X_MODULE 1
#define CONFIG_INPUT_MOUSEDEV_SCREEN_Y 768
#define CONFIG_MEMCG 1
#define CONFIG_DRM_DISPLAY_DP_AUX_CHARDEV 1
#define CONFIG_MD_LLBITMAP 1
#define CONFIG_COMMON_CLK_SI5341_MODULE 1
#define CONFIG_PINCTRL_CANNONLAKE_MODULE 1
#define CONFIG_GOOGLE_FRAMEBUFFER_COREBOOT_MODULE 1
#define CONFIG_SENSORS_SPD5118_MODULE 1
#define CONFIG_BH1750_MODULE 1
#define CONFIG_CRYPTO_LIB_CHACHA20POLY1305 1
#define CONFIG_ZSTD_COMPRESS 1
#define CONFIG_MAILBOX 1
#define CONFIG_SPARSE_IRQ 1
#define CONFIG_ADV_SWBUTTON_MODULE 1
#define CONFIG_SENSORS_TSL2563_MODULE 1
#define CONFIG_NEED_SG_DMA_LENGTH 1
#define CONFIG_VHOST_TASK 1
#define CONFIG_IPV6_SEG6_BPF 1
#define CONFIG_BT_DEBUGFS 1
#define CONFIG_SND_SOC_INTEL_CHT_BSW_RT5672_MACH_MODULE 1
#define CONFIG_KMX61_MODULE 1
#define CONFIG_DVB_TUNER_DIB0070_MODULE 1
#define CONFIG_AMD_AE4DMA_MODULE 1
#define CONFIG_SUSPEND 1
#define CONFIG_GPIO_MC33880_MODULE 1
#define CONFIG_REGULATOR_WM831X_MODULE 1
#define CONFIG_GENERIC_ADC_BATTERY_MODULE 1
#define CONFIG_I2C_DESIGNWARE_AMDISP_MODULE 1
#define CONFIG_USB_SERIAL_F8153X_MODULE 1
#define CONFIG_SND_SOC_TSCS42XX_MODULE 1
#define CONFIG_SND_USB_AUDIO_MIDI_V2 1
#define CONFIG_SENSORS_GIGABYTE_WATERFORCE_MODULE 1
#define CONFIG_MTD_PARTITIONED_MASTER 1
#define CONFIG_SAMSUNG_LAPTOP_MODULE 1
#define CONFIG_GRACE_PERIOD_MODULE 1
#define CONFIG_HYPERV_VMBUS_MODULE 1
#define CONFIG_ATH6KL_DEBUG 1
#define CONFIG_NF_FLOW_TABLE_PROCFS 1
#define CONFIG_SOC_TI 1
#define CONFIG_MHI_BUS_EP_MODULE 1
#define CONFIG_RTL8192DE_MODULE 1
#define CONFIG_NFC_PN532_UART_MODULE 1
#define CONFIG_CRC_T10DIF_ARCH 1
#define CONFIG_HAVE_FUNCTION_ARG_ACCESS_API 1
#define CONFIG_SUNGEM_PHY_MODULE 1
#define CONFIG_MFD_CS42L43_MODULE 1
#define CONFIG_SND_SOC_ES8316_MODULE 1
#define CONFIG_ENVELOPE_DETECTOR_MODULE 1
#define CONFIG_RT2800_LIB_MODULE 1
#define CONFIG_CC_IMPLICIT_FALLTHROUGH "-Wimplicit-fallthrough=5"
#define CONFIG_FB_DMAMEM_HELPERS 1
#define CONFIG_IP_MULTIPLE_TABLES 1
#define CONFIG_MFD_WM831X_I2C 1
#define CONFIG_MADERA_IRQ_MODULE 1
#define CONFIG_USB_F_RNDIS_MODULE 1
#define CONFIG_RT2X00_LIB_CRYPTO 1
#define CONFIG_TMP117_MODULE 1
#define CONFIG_PPP_FILTER 1
#define CONFIG_PINCTRL_CS47L92 1
#define CONFIG_PTP_1588_CLOCK_VMCLOCK_MODULE 1
#define CONFIG_COMMON_CLK_WM831X_MODULE 1
#define CONFIG_CRYPTO_DEV_CCP_DEBUGFS 1
#define CONFIG_VDPA_SIM_BLOCK_MODULE 1
#define CONFIG_GPIO_PCA953X_IRQ 1
#define CONFIG_NET_DSA_TAG_OCELOT_8021Q_MODULE 1
#define CONFIG_USB_F_PRINTER_MODULE 1
#define CONFIG_MFD_BCM590XX_MODULE 1
#define CONFIG_WLAN_VENDOR_RALINK 1
#define CONFIG_IR_MCE_KBD_DECODER_MODULE 1
#define CONFIG_EDAC_MEM_REPAIR 1
#define CONFIG_X86_INTEL_LPSS 1
#define CONFIG_RATIONAL 1
#define CONFIG_SENSORS_LM25066_REGULATOR 1
#define CONFIG_INPUT_GPIO_BEEPER_MODULE 1
#define CONFIG_NF_CONNTRACK_MODULE 1
#define CONFIG_SIEMENS_SIMATIC_IPC_BATT_MODULE 1
#define CONFIG_GPIO_LP3943_MODULE 1
#define CONFIG_WILCO_EC_DEBUGFS_MODULE 1
#define CONFIG_EXTCON_ADC_JACK_MODULE 1
#define CONFIG_MFD_DA9052_I2C 1
#define CONFIG_W1_SLAVE_DS2438_MODULE 1
#define CONFIG_MEMORY_HOTPLUG 1
#define CONFIG_CRC64 1
#define CONFIG_TRUSTED_KEYS_TPM 1
#define CONFIG_MS5611_SPI_MODULE 1
#define CONFIG_GPIO_ML_IOH_MODULE 1
#define CONFIG_MS5611_MODULE 1
#define CONFIG_PSE_CONTROLLER 1
#define CONFIG_KEY_DH_OPERATIONS 1
#define CONFIG_HID_GYRATION_MODULE 1
#define CONFIG_NTSYNC_MODULE 1
#define CONFIG_NET_DSA_MXL_GSW1XX_MODULE 1
#define CONFIG_ARCH_WANT_GENERAL_HUGETLB 1
#define CONFIG_USB_U_ETHER_MODULE 1
#define CONFIG_VIDEO_TW2804_MODULE 1
#define CONFIG_ZONE_DMA 1
#define CONFIG_GNSS_SERIAL_MODULE 1
#define CONFIG_SND_USB_LINE6_MODULE 1
#define CONFIG_CHARGER_TWL6030_MODULE 1
#define CONFIG_TLS_DEVICE 1
#define CONFIG_DVB_USB_TTUSB2_MODULE 1
#define CONFIG_WIL6210_ISR_COR 1
#define CONFIG_SND_MAX_CARDS 32
#define CONFIG_REGULATOR_DA9055_MODULE 1
#define CONFIG_ARCH_HAS_PMEM_API 1
#define CONFIG_YAMAHA_YAS530_MODULE 1
#define CONFIG_CLOCKSOURCE_WATCHDOG 1
#define CONFIG_IIO_MUX_MODULE 1
#define CONFIG_SND_SOC_AK4104_MODULE 1
#define CONFIG_RESCTRL_FS 1
#define CONFIG_ARCH_MIGHT_HAVE_PC_PARPORT 1
#define CONFIG_RD_GZIP 1
#define CONFIG_SENSORS_I5500_MODULE 1
#define CONFIG_AMD_XGBE_MODULE 1
#define CONFIG_NVME_TARGET_DEBUGFS 1
#define CONFIG_INPUT_DRV2667_HAPTICS_MODULE 1
#define CONFIG_FB_DEFERRED_IO 1
#define CONFIG_LIBWX_MODULE 1
#define CONFIG_SND_SOC_CS35L35_MODULE 1
#define CONFIG_NET_SCH_NETEM_MODULE 1
#define CONFIG_IP_NF_MATCH_RPFILTER_MODULE 1
#define CONFIG_MSDOS_PARTITION 1
#define CONFIG_B43_SDIO 1
#define CONFIG_PCC 1
#define CONFIG_SYNTH_EVENTS 1
#define CONFIG_DVB_USB_DTV5100_MODULE 1
#define CONFIG_POWER_SUPPLY_HWMON 1
#define CONFIG_NETFILTER_NETLINK_LOG_MODULE 1
#define CONFIG_CPU_FREQ_GOV_CONSERVATIVE 1
#define CONFIG_ZSTD_COMMON 1
#define CONFIG_TCG_TIS_SPI_MODULE 1
#define CONFIG_DEFAULT_SECURITY_DAC 1
#define CONFIG_IIO_CROS_EC_LIGHT_PROX_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_3M 1
#define CONFIG_WATCHDOG 1
#define CONFIG_BRIDGE_NETFILTER_MODULE 1
#define CONFIG_NET_VENDOR_RDC 1
#define CONFIG_FIND_NORMAL_PAGE 1
#define CONFIG_SND_SOC_MAX9759_MODULE 1
#define CONFIG_INT3406_THERMAL_MODULE 1
#define CONFIG_MODULE_DECOMPRESS 1
#define CONFIG_NLS_CODEPAGE_860_MODULE 1
#define CONFIG_LOGITECH_FF 1
#define CONFIG_VIDEO_VIVID_MODULE 1
#define CONFIG_IR_IGORPLUGUSB_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_CONNSECMARK_MODULE 1
#define CONFIG_I2C_HID_CORE_MODULE 1
#define CONFIG_MWIFIEX_SDIO_MODULE 1
#define CONFIG_XFRM 1
#define CONFIG_HAVE_NOINSTR_VALIDATION 1
#define CONFIG_MFD_TPS65912_SPI_MODULE 1
#define CONFIG_IPV6_PIMSM_V2 1
#define CONFIG_ACPI_ADXL 1
#define CONFIG_FIX_EARLYCON_MEM 1
#define CONFIG_SCHED_CORE 1
#define CONFIG_TCG_TIS_I2C_ATMEL_MODULE 1
#define CONFIG_GNSS_MTK_SERIAL_MODULE 1
#define CONFIG_DVB_A8293_MODULE 1
#define CONFIG_PRESTERA_MODULE 1
#define CONFIG_INTEL_MEI_GSC_MODULE 1
#define CONFIG_X86_REQUIRED_FEATURE_XMM 1
#define CONFIG_ORANGEFS_FS_MODULE 1
#define CONFIG_MLX90614_MODULE 1
#define CONFIG_TOUCHSCREEN_DYNAPRO_MODULE 1
#define CONFIG_INTEL_SOC_PMIC 1
#define CONFIG_INPUT_AD714X_SPI_MODULE 1
#define CONFIG_SND_SOC_SOF_NOVALAKE_MODULE 1
#define CONFIG_ARCH_HAS_FAST_MULTIPLIER 1
#define CONFIG_IOMMUFD_DRIVER_CORE 1
#define CONFIG_REGULATOR_RC5T583_MODULE 1
#define CONFIG_CRYPTO_LIB_SHA512_ARCH 1
#define CONFIG_CGROUP_HUGETLB 1
#define CONFIG_FW_LOADER 1
#define CONFIG_X86_POSTED_MSI 1
#define CONFIG_INV_ICM42600_I2C_MODULE 1
#define CONFIG_TWL4030_CORE 1
#define CONFIG_USB_GSPCA_KINECT_MODULE 1
#define CONFIG_SND_SOC_RT1318_SDW_MODULE 1
#define CONFIG_DPS310_MODULE 1
#define CONFIG_RTC_SYSTOHC 1
#define CONFIG_JFS_FS_MODULE 1
#define CONFIG_CROS_EC_MKBP_PROXIMITY_MODULE 1
#define CONFIG_SENSORS_W83791D_MODULE 1
#define CONFIG_TOUCHSCREEN_RM_TS_MODULE 1
#define CONFIG_AMD_NUMA 1
#define CONFIG_FPGA_DFL_MODULE 1
#define CONFIG_INET_IPCOMP_MODULE 1
#define CONFIG_ROMFS_FS_MODULE 1
#define CONFIG_IP6_NF_MATCH_RT_MODULE 1
#define CONFIG_MMC_USDHI6ROL0_MODULE 1
#define CONFIG_SCSI_WD719X_MODULE 1
#define CONFIG_SND_SOC_SOF_TIGERLAKE_MODULE 1
#define CONFIG_NET_DSA_MICROCHIP_KSZ_SPI_MODULE 1
#define CONFIG_MEDIA_TUNER_MT20XX_MODULE 1
#define CONFIG_GPIO_MENZ127_MODULE 1
#define CONFIG_DRM_I915_HEARTBEAT_INTERVAL 2500
#define CONFIG_INFINIBAND_CXGB4_MODULE 1
#define CONFIG_SND_SOC_SOF_IPC3 1
#define CONFIG_VIDEO_IMX219_MODULE 1
#define CONFIG_L2TP_DEBUGFS_MODULE 1
#define CONFIG_PATA_TOSHIBA_MODULE 1
#define CONFIG_ARCH_HAS_CACHE_LINE_SIZE 1
#define CONFIG_SENSORS_TPS25990_REGULATOR 1
#define CONFIG_NTB_TRANSPORT_MODULE 1
#define CONFIG_DM_RAID_MODULE 1
#define CONFIG_F71808E_WDT_MODULE 1
#define CONFIG_X86_MINIMUM_CPU_FAMILY 64
#define CONFIG_EXPORTFS 1
#define CONFIG_RPR0521_MODULE 1
#define CONFIG_SND_SOC_CS43130_MODULE 1
#define CONFIG_BACKLIGHT_LP8788_MODULE 1
#define CONFIG_INTEL_TURBO_MAX_3 1
#define CONFIG_VIDEO_HDPVR_MODULE 1
#define CONFIG_CRYPTO_HCTR2_MODULE 1
#define CONFIG_SURFACE_AGGREGATOR_CDEV_MODULE 1
#define CONFIG_RTC_DRV_MT6397_MODULE 1
#define CONFIG_EXTCON_INTEL_MRFLD_MODULE 1
#define CONFIG_MAC80211_HWSIM_MODULE 1
#define CONFIG_SCA3300_MODULE 1
#define CONFIG_PARPORT_PC_PCMCIA_MODULE 1
#define CONFIG_TCP_CONG_VEGAS_MODULE 1
#define CONFIG_GPIO_DLN2_MODULE 1
#define CONFIG_PANIC_TIMEOUT 0
#define CONFIG_IBM_RTL_MODULE 1
#define CONFIG_VIDEO_IMX296_MODULE 1
#define CONFIG_NFC_MEI_PHY_MODULE 1
#define CONFIG_PTP_1588_CLOCK_MODULE 1
#define CONFIG_MDIO_BCM_UNIMAC_MODULE 1
#define CONFIG_SCSI_IPS_MODULE 1
#define CONFIG_FW_LOADER_COMPRESS_XZ 1
#define CONFIG_TYPEC_MUX_PS883X_MODULE 1
#define CONFIG_NET_CORE 1
#define CONFIG_DVB_LGDT330X_MODULE 1
#define CONFIG_AT76C50X_USB_MODULE 1
#define CONFIG_DWMAC_INTEL_MODULE 1
#define CONFIG_SOFT_WATCHDOG_MODULE 1
#define CONFIG_RTW89_8852A_MODULE 1
#define CONFIG_DRM_ST7735R_MODULE 1
#define CONFIG_LD_IS_BFD 1
#define CONFIG_INFINIBAND_ISERT_MODULE 1
#define CONFIG_MMU_LAZY_TLB_REFCOUNT 1
#define CONFIG_NAMESPACES 1
#define CONFIG_SND_PCM_ELD 1
#define CONFIG_DECOMPRESS_GZIP 1
#define CONFIG_CROS_EC_I2C_MODULE 1
#define CONFIG_HWMON 1
#define CONFIG_TYPEC_TPS6598X_MODULE 1
#define CONFIG_BRCMFMAC_MODULE 1
#define CONFIG_ACPI_BATTERY 1
#define CONFIG_I2C_PCI1XXXX_MODULE 1
#define CONFIG_TUXEDO_NB04_WMI_AB_MODULE 1
#define CONFIG_IP_NF_ARP_MANGLE_MODULE 1
#define CONFIG_RTW88_8821CE_MODULE 1
#define CONFIG_OPENSSL_SUPPORTS_ML_DSA 1
#define CONFIG_USB_SISUSBVGA_MODULE 1
#define CONFIG_CPU_RMAP 1
#define CONFIG_IP6_NF_RAW_MODULE 1
#define CONFIG_VFIO_PCI_CORE_MODULE 1
#define CONFIG_ARCH_SUPPORTS_NUMA_BALANCING 1
#define CONFIG_BUFFER_HEAD 1
#define CONFIG_DVB_NGENE_MODULE 1
#define CONFIG_MWIFIEX_USB_MODULE 1
#define CONFIG_NET_9P_RDMA_MODULE 1
#define CONFIG_PERF_EVENTS_INTEL_CSTATE_MODULE 1
#define CONFIG_CC_HAS_AUTO_VAR_INIT_PATTERN 1
#define CONFIG_SND_HDA_CODEC_SENARYTECH_MODULE 1
#define CONFIG_ABP2030PA_MODULE 1
#define CONFIG_VIDEO_CX23885_MODULE 1
#define CONFIG_ALIENWARE_WMI_MODULE 1
#define CONFIG_FORTIFY_SOURCE 1
#define CONFIG_INPUT_IQS626A_MODULE 1
#define CONFIG_HWSPINLOCK 1
#define CONFIG_I2C_DESIGNWARE_CORE 1
#define CONFIG_CAN_ESD_402_PCI_MODULE 1
#define CONFIG_DRM_ACCEL 1
#define CONFIG_ENCLOSURE_SERVICES_MODULE 1
#define CONFIG_NFC_MRVL_I2C_MODULE 1
#define CONFIG_BT_HCIBTUSB_MTK 1
#define CONFIG_NAU7802_MODULE 1
#define CONFIG_SND_SOC_WM5102_MODULE 1
#define CONFIG_SND_SOC_RL6231_MODULE 1
#define CONFIG_DVB_SI2168_MODULE 1
#define CONFIG_FB_SYSMEM_HELPERS_DEFERRED 1
#define CONFIG_MFD_SIMPLE_MFD_I2C_MODULE 1
#define CONFIG_6LOWPAN_MODULE 1
#define CONFIG_TOUCHSCREEN_S6SY761_MODULE 1
#define CONFIG_WPCM450_SOC_MODULE 1
#define CONFIG_DUMMY_MODULE 1
#define CONFIG_VIDEO_EM28XX_V4L2_MODULE 1
#define CONFIG_DM_BIO_PRISON_MODULE 1
#define CONFIG_MMC_SDHCI_IO_ACCESSORS 1
#define CONFIG_NET_DSA_SJA1105_VL 1
#define CONFIG_CRAMFS_MTD 1
#define CONFIG_BMC150_ACCEL_SPI_MODULE 1
#define CONFIG_MTD_ROM_MODULE 1
#define CONFIG_NETFILTER_FAMILY_ARP 1
#define CONFIG_SND_SOC_XILINX_SPDIF_MODULE 1
#define CONFIG_HIBERNATE_CALLBACKS 1
#define CONFIG_STM_SOURCE_HEARTBEAT_MODULE 1
#define CONFIG_DVB_USB_CXUSB_MODULE 1
#define CONFIG_IR_RCMM_DECODER_MODULE 1
#define CONFIG_TASKS_TRACE_RCU 1
#define CONFIG_XEN_FRONT_PGDIR_SHBUF_MODULE 1
#define CONFIG_VIDEO_S5C73M3_MODULE 1
#define CONFIG_6LOWPAN_NHC_MODULE 1
#define CONFIG_MHP_MEMMAP_ON_MEMORY 1
#define CONFIG_XEN_PVHVM 1
#define CONFIG_MOUSE_PS2_ELANTECH 1
#define CONFIG_VEML6046X00_MODULE 1
#define CONFIG_REGULATOR_RT6245_MODULE 1
#define CONFIG_HARDENED_USERCOPY_DEFAULT_ON 1
#define CONFIG_VIPERBOARD_ADC_MODULE 1
#define CONFIG_NET_VENDOR_MELLANOX 1
#define CONFIG_IR_SERIAL_MODULE 1
#define CONFIG_OCFS2_FS_MODULE 1
#define CONFIG_NET_VENDOR_SAMSUNG 1
#define CONFIG_SKY2_MODULE 1
#define CONFIG_GPIO_TPS68470_MODULE 1
#define CONFIG_SND_SOC_AK4619_MODULE 1
#define CONFIG_SND_SOC_RT1320_SDW_MODULE 1
#define CONFIG_USB_GSPCA_SPCA501_MODULE 1
#define CONFIG_MFD_RDC321X_MODULE 1
#define CONFIG_BT_LE 1
#define CONFIG_CGBC_WDT_MODULE 1
#define CONFIG_PCCARD_MODULE 1
#define CONFIG_DVB_SP8870_MODULE 1
#define CONFIG_IXGBE_MODULE 1
#define CONFIG_VIDEO_VD56G3_MODULE 1
#define CONFIG_HDC3020_MODULE 1
#define CONFIG_PINCTRL_UPBOARD_MODULE 1
#define CONFIG_SENSORS_NZXT_SMART2_MODULE 1
#define CONFIG_MT76x02_LIB_MODULE 1
#define CONFIG_BACKLIGHT_LM3509_MODULE 1
#define CONFIG_X86_TSC 1
#define CONFIG_USB_CONFIGFS_F_UVC 1
#define CONFIG_SND_SOC_ADAU1701_MODULE 1
#define CONFIG_DYNAMIC_DEBUG 1
#define CONFIG_XENFS_MODULE 1
#define CONFIG_ZRAM_MODULE 1
#define CONFIG_VIDEO_OV2680_MODULE 1
#define CONFIG_SND_SOC_INTEL_SOF_CIRRUS_COMMON_MODULE 1
#define CONFIG_SERIAL_DEV_CTRL_TTYPORT 1
#define CONFIG_SND_AZT3328_MODULE 1
#define CONFIG_PCI_DOMAINS 1
#define CONFIG_CHARGER_DA9150_MODULE 1
#define CONFIG_RTW89_8922AE_MODULE 1
#define CONFIG_FUSION_SAS_MODULE 1
#define CONFIG_CPU_FREQ_GOV_SCHEDUTIL 1
#define CONFIG_REGULATOR_DA9052_MODULE 1
#define CONFIG_LENOVO_SE10_WDT_MODULE 1
#define CONFIG_DRM_I915_COMPRESS_ERROR 1
#define CONFIG_BMC150_MAGN_MODULE 1
#define CONFIG_TOPSTAR_LAPTOP_MODULE 1
#define CONFIG_SURFACE_AGGREGATOR_REGISTRY_MODULE 1
#define CONFIG_EFI_RUNTIME_WRAPPERS 1
#define CONFIG_USB_MDC800_MODULE 1
#define CONFIG_NF_CT_NETLINK_MODULE 1
#define CONFIG_IIO_TRIGGERED_BUFFER_MODULE 1
#define CONFIG_MEDIA_HIDE_ANCILLARY_SUBDRV 1
#define CONFIG_INTEL_PCH_THERMAL_MODULE 1
#define CONFIG_NETFILTER_XT_NAT_MODULE 1
#define CONFIG_SERIAL_SC16IS7XX_MODULE 1
#define CONFIG_ATH10K_LEDS 1
#define CONFIG_DM9102_MODULE 1
#define CONFIG_SND_SOC_ADI_AXI_SPDIF_MODULE 1
#define CONFIG_FWCTL_PDS_MODULE 1
#define CONFIG_6LOWPAN_NHC_FRAGMENT_MODULE 1
#define CONFIG_PROC_SYSCTL 1
#define CONFIG_MOST_SND_MODULE 1
#define CONFIG_MODULE_SIG_KEY_TYPE_ECDSA 1
#define CONFIG_HDC100X_MODULE 1
#define CONFIG_MIGRATION 1
#define CONFIG_DVB_PLUTO2_MODULE 1
#define CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS 1
#define CONFIG_X86_REQUIRED_FEATURE_XMM2 1
#define CONFIG_ATH9K_MODULE 1
#define CONFIG_XILLYBUS_PCIE_MODULE 1
#define CONFIG_CRYPTO_AKCIPHER 1
#define CONFIG_HID_APPLEIR_MODULE 1
#define CONFIG_MTD_SPI_NOR_SWP_DISABLE_ON_VOLATILE 1
#define CONFIG_SX9360_MODULE 1
#define CONFIG_PHY_GOOGLE_USB_MODULE 1
#define CONFIG_TSM_GUEST 1
#define CONFIG_NET_SCHED 1
#define CONFIG_VIRTIO_RTC_MODULE 1
#define CONFIG_NET_CLS_FW_MODULE 1
#define CONFIG_HAVE_HARDLOCKUP_DETECTOR_BUDDY 1
#define CONFIG_NLS_CODEPAGE_861_MODULE 1
#define CONFIG_VIDEO_HEXIUM_ORION_MODULE 1
#define CONFIG_CRYPTO_CHACHA20_MODULE 1
#define CONFIG_TXGBEVF_MODULE 1
#define CONFIG_MPLS_ROUTING_MODULE 1
#define CONFIG_SI7210_MODULE 1
#define CONFIG_PAGE_POOL 1
#define CONFIG_CRYPTO_USER_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_ESP_MODULE 1
#define CONFIG_SECURITY_SELINUX_AVC_HASH_BITS 9
#define CONFIG_RT2500USB_MODULE 1
#define CONFIG_NVME_TARGET_TCP_MODULE 1
#define CONFIG_KFENCE_SAMPLE_INTERVAL 100
#define CONFIG_HID_XINMO_MODULE 1
#define CONFIG_NTFS3_FS_MODULE 1
#define CONFIG_NETPOLL 1
#define CONFIG_SCSI_DMX3191D_MODULE 1
#define CONFIG_VIDEO_IPU3_IMGU_MODULE 1
#define CONFIG_CPU_SUP_AMD 1
#define CONFIG_VIDEOBUF2_MEMOPS_MODULE 1
#define CONFIG_IIO_ST_PRESS_SPI_MODULE 1
#define CONFIG_INTEL_WMI 1
#define CONFIG_NET_MPLS_GSO_MODULE 1
#define CONFIG_MII_MODULE 1
#define CONFIG_SND_SOC_SOF_BAYTRAIL_MODULE 1
#define CONFIG_DM_VERITY_VERIFY_ROOTHASH_SIG 1
#define CONFIG_BCMA_DRIVER_GMAC_CMN 1
#define CONFIG_SONY_LAPTOP_MODULE 1
#define CONFIG_USB_ZERO_MODULE 1
#define CONFIG_NVMEM_SYSFS 1
#define CONFIG_HYPERV_STORAGE_MODULE 1
#define CONFIG_SND_SOC_ADAU1761_I2C_MODULE 1
#define CONFIG_SENSORS_ADM1266_MODULE 1
#define CONFIG_DVB_TDA18271C2DD_MODULE 1
#define CONFIG_9P_FS_POSIX_ACL 1
#define CONFIG_USB_STORAGE_ENE_UB6250_MODULE 1
#define CONFIG_B53_SRAB_DRIVER_MODULE 1
#define CONFIG_SCSI_COMMON 1
#define CONFIG_SPARSEMEM_EXTREME 1
#define CONFIG_MLX5_EN_RXNFC 1
#define CONFIG_USB_M5602_MODULE 1
#define CONFIG_RSEQ 1
#define CONFIG_SND_PCM_OSS_MODULE 1
#define CONFIG_IOMMU_DMA 1
#define CONFIG_SECURITY_TOMOYO_MAX_AUDIT_LOG 1024
#define CONFIG_SND_HDA_CODEC_CS421X_MODULE 1
#define CONFIG_SND_SOC_IDT821034_MODULE 1
#define CONFIG_VIA_WDT_MODULE 1
#define CONFIG_INTEL_OC_WATCHDOG_MODULE 1
#define CONFIG_JOYSTICK_GRIP_MODULE 1
#define CONFIG_NET_SCH_DRR_MODULE 1
#define CONFIG_KARMA_PARTITION 1
#define CONFIG_REGULATOR_MAX77826_MODULE 1
#define CONFIG_JOYSTICK_PSXPAD_SPI_FF 1
#define CONFIG_SENSORS_JC42_MODULE 1
#define CONFIG_TOUCHSCREEN_ILITEK_MODULE 1
#define CONFIG_SYSCTL_EXCEPTION_TRACE 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_I2S_TEST_MODULE 1
#define CONFIG_NEW_LEDS 1
#define CONFIG_USB_G_PRINTER_MODULE 1
#define CONFIG_SPI_AX88796C_MODULE 1
#define CONFIG_UCLAMP_TASK 1
#define CONFIG_CIFS_COMPRESSION 1
#define CONFIG_MHI_BUS_PCI_GENERIC_MODULE 1
#define CONFIG_CRYPTO_DEV_QAT_420XX_MODULE 1
#define CONFIG_SPI_SLAVE 1
#define CONFIG_RAS 1
#define CONFIG_SND_SOC_CS4270_MODULE 1
#define CONFIG_NF_TABLES_NETDEV 1
#define CONFIG_SSB_SPROM 1
#define CONFIG_SND_USB_6FIRE_MODULE 1
#define CONFIG_CRYPTO_LIB_GF128HASH_ARCH 1
#define CONFIG_CRYPTO_LIB_CURVE25519_ARCH 1
#define CONFIG_SND_SOC_SDCA_IRQ 1
#define CONFIG_VIDEO_ADP1653_MODULE 1
#define CONFIG_BT_6LOWPAN_MODULE 1
#define CONFIG_KVM_ASYNC_PF 1
#define CONFIG_DVB_STV0367_MODULE 1
#define CONFIG_SERIAL_8250_PERICOM_MODULE 1
#define CONFIG_PWM_DWC_MODULE 1
#define CONFIG_SPI_PCI1XXXX_MODULE 1
#define CONFIG_SCSI_IPR_MODULE 1
#define CONFIG_ARCH_WANT_IRQS_OFF_ACTIVATE_MM 1
#define CONFIG_DYNAMIC_FTRACE_WITH_JMP 1
#define CONFIG_KVM_MMIO 1
#define CONFIG_MOUSE_SERIAL_MODULE 1
#define CONFIG_DWMAC_MOTORCOMM_MODULE 1
#define CONFIG_SCSI_CXGB3_ISCSI_MODULE 1
#define CONFIG_SPI_DLN2_MODULE 1
#define CONFIG_I2C_DESIGNWARE_BAYTRAIL 1
#define CONFIG_DRM_SIMPLEDRM 1
#define CONFIG_SC1200_WDT_MODULE 1
#define CONFIG_PADATA 1
#define CONFIG_KEYBOARD_GPIO_POLLED_MODULE 1
#define CONFIG_HID_PXRC_MODULE 1
#define CONFIG_ARCH_HAS_PTE_SPECIAL 1
#define CONFIG_BLK_DEV_RBD_MODULE 1
#define CONFIG_SND_DARLA20_MODULE 1
#define CONFIG_SND_SOC_CS4265_MODULE 1
#define CONFIG_VIDEO_OV5648_MODULE 1
#define CONFIG_MEDIA_TUNER_MT2060_MODULE 1
#define CONFIG_CC_HAS_ASM_INLINE 1
#define CONFIG_POWER_RESET_TPS65086 1
#define CONFIG_HANGCHECK_TIMER_MODULE 1
#define CONFIG_SATA_AHCI_PLATFORM_MODULE 1
#define CONFIG_SENSORS_W83781D_MODULE 1
#define CONFIG_FB 1
#define CONFIG_REGULATOR_RT5190A_MODULE 1
#define CONFIG_IP_VS_FTP_MODULE 1
#define CONFIG_BT_HCIBCM4377_MODULE 1
#define CONFIG_INTEL_PMT_CLASS_MODULE 1
#define CONFIG_INPUT_MC13783_PWRBUTTON_MODULE 1
#define CONFIG_ADXL313_MODULE 1
#define CONFIG_PATA_NS87410_MODULE 1
#define CONFIG_HID_STEELSERIES_MODULE 1
#define CONFIG_HAVE_ACPI_APEI_NMI 1
#define CONFIG_TOUCHSCREEN_88PM860X_MODULE 1
#define CONFIG_SQUASHFS_DECOMP_SINGLE 1
#define CONFIG_USB_LEDS_TRIGGER_USBPORT_MODULE 1
#define CONFIG_SENSORS_TMP513_MODULE 1
#define CONFIG_CALL_PADDING 1
#define CONFIG_CC_HAS_NAMED_AS 1
#define CONFIG_FUJITSU_TABLET_MODULE 1
#define CONFIG_VIDEO_CS5345_MODULE 1
#define CONFIG_GENERIC_SYSCALL 1
#define CONFIG_F2FS_FS_LZ4 1
#define CONFIG_HAS_SECURITY_AUDIT 1
#define CONFIG_VIRT_WIFI_MODULE 1
#define CONFIG_PLIP_MODULE 1
#define CONFIG_V4L_TEST_DRIVERS 1
#define CONFIG_REGULATOR_88PM800_MODULE 1
#define CONFIG_DRM_PANIC_SCREEN_QR_CODE 1
#define CONFIG_SND_SOC_BD28623_MODULE 1
#define CONFIG_INPUT_88PM860X_ONKEY_MODULE 1
#define CONFIG_PWM_CROS_EC_MODULE 1
#define CONFIG_PDS_VDPA_MODULE 1
#define CONFIG_VIDEO_CX88_ALSA_MODULE 1
#define CONFIG_HAVE_ACPI_APEI 1
#define CONFIG_ARCH_SUPPORTS_KEXEC_SIG_FORCE 1
#define CONFIG_SCSI_ISCI_MODULE 1
#define CONFIG_X86_REQUIRED_FEATURE_FPU 1
#define CONFIG_BMA220_I2C_MODULE 1
#define CONFIG_ATM_DRIVERS 1
#define CONFIG_TOUCHSCREEN_PENMOUNT_MODULE 1
#define CONFIG_NLS_CODEPAGE_950_MODULE 1
#define CONFIG_CHARGER_BQ25980_MODULE 1
#define CONFIG_PINCTRL_CS47L90 1
#define CONFIG_IR_RC5_DECODER_MODULE 1
#define CONFIG_SENSORS_LM78_MODULE 1
#define CONFIG_RTW89_8852AE_MODULE 1
#define CONFIG_BT_HCIUART_INTEL 1
#define CONFIG_KPROBE_EVENTS 1
#define CONFIG_MLX4_DEBUG 1
#define CONFIG_PROC_VMCORE_DEVICE_DUMP 1
#define CONFIG_F2FS_FS_POSIX_ACL 1
#define CONFIG_SND_SOC_NAU8325_MODULE 1
#define CONFIG_CRYPTO_DEV_QAT_C3XXX_MODULE 1
#define CONFIG_CHARGER_BQ256XX_MODULE 1
#define CONFIG_BATTERY_SURFACE_MODULE 1
#define CONFIG_TI_FPC202_MODULE 1
#define CONFIG_IQS621_ALS_MODULE 1
#define CONFIG_CC_HAS_ASM_GOTO_TIED_OUTPUT 1
#define CONFIG_MITIGATION_SRBDS 1
#define CONFIG_ISCSI_TARGET_MODULE 1
#define CONFIG_TABLET_USB_KBTAB_MODULE 1
#define CONFIG_BLK_DEV_INITRD 1
#define CONFIG_CIFS_FSCACHE 1
#define CONFIG_SCSI_MPI3MR_MODULE 1
#define CONFIG_MFD_MAX77843 1
#define CONFIG_VIDEO_OV7251_MODULE 1
#define CONFIG_MEDIA_TUNER_TDA8290_MODULE 1
#define CONFIG_BE2ISCSI_MODULE 1
#define CONFIG_DWC_PCIE_PMU_MODULE 1
#define CONFIG_USB_F_SERIAL_MODULE 1
#define CONFIG_AFFS_FS_MODULE 1
#define CONFIG_NEED_TASKS_RCU 1
#define CONFIG_ADXL345_SPI_MODULE 1
#define CONFIG_MICROSOFT_MANA_MODULE 1
#define CONFIG_USB_SERIAL_OPTICON_MODULE 1
#define CONFIG_USB_GSPCA_SPCA500_MODULE 1
#define CONFIG_B43_PHY_LP 1
#define CONFIG_INET 1
#define CONFIG_MAX30208_MODULE 1
#define CONFIG_NR_CPUS_RANGE_BEGIN 8192
#define CONFIG_DL2K_MODULE 1
#define CONFIG_VIDEO_CX18_MODULE 1
#define CONFIG_PATA_HPT3X2N_MODULE 1
#define CONFIG_HID_PETALYNX_MODULE 1
#define CONFIG_SND_SOC_SOF_AMD_SOUNDWIRE_LINK_BASELINE_MODULE 1
#define CONFIG_DEVFREQ_GOV_SIMPLE_ONDEMAND_MODULE 1
#define CONFIG_TRANSPARENT_HUGEPAGE_SHMEM_HUGE_ADVISE 1
#define CONFIG_BLK_DEV_SR_MODULE 1
#define CONFIG_CHR_DEV_ST_MODULE 1
#define CONFIG_AD5686_MODULE 1
#define CONFIG_FUJITSU_ES_MODULE 1
#define CONFIG_ATH11K_PCI_MODULE 1
#define CONFIG_SND_SOC_AMD_CZ_RT5645_MACH_MODULE 1
#define CONFIG_POWER_RESET 1
#define CONFIG_NETFILTER_XT_TARGET_REDIRECT_MODULE 1
#define CONFIG_ATA 1
#define CONFIG_ADAPTEC_STARFIRE_MODULE 1
#define CONFIG_ADXRS290_MODULE 1
#define CONFIG_INFINIBAND_HFI1_MODULE 1
#define CONFIG_CRYPTO_DEV_QAT_6XXX_MODULE 1
#define CONFIG_XEN_PV_SMP 1
#define CONFIG_BLK_DEV_RAM_SIZE 16384
#define CONFIG_MMA7455_I2C_MODULE 1
#define CONFIG_USB_EMI26_MODULE 1
#define CONFIG_NGBEVF_MODULE 1
#define CONFIG_DLHL60D_MODULE 1
#define CONFIG_SND_SOC_MT6660_MODULE 1
#define CONFIG_SENSORS_ZL6100_MODULE 1
#define CONFIG_ATH6KL_USB_MODULE 1
#define CONFIG_SND_HDA_SCODEC_CS35L56_I2C_MODULE 1
#define CONFIG_MSI_WMI_PLATFORM_MODULE 1
#define CONFIG_TYPEC_MUX_FSA4480_MODULE 1
#define CONFIG_RPS 1
#define CONFIG_PCI_P2PDMA 1
#define CONFIG_HID_PICOLCD_LCD 1
#define CONFIG_TOUCHSCREEN_ELAN_MODULE 1
#define CONFIG_CRYPTO_CAST6_MODULE 1
#define CONFIG_NF_CONNTRACK_SECMARK 1
#define CONFIG_LEDS_TRIGGER_NETDEV_MODULE 1
#define CONFIG_CGROUP_NET_PRIO 1
#define CONFIG_MPILIB 1
#define CONFIG_MT7603E_MODULE 1
#define CONFIG_MEDIA_TUNER_MC44S803_MODULE 1
#define CONFIG_GARP_MODULE 1
#define CONFIG_IPE_POLICY_SIG_PLATFORM_KEYRING 1
#define CONFIG_RTC_DRV_RV3028_MODULE 1
#define CONFIG_GPIB_CB7210_MODULE 1
#define CONFIG_FIRMWARE_TABLE 1
#define CONFIG_SND_DMAENGINE_PCM_MODULE 1
#define CONFIG_LEDS_TLC591XX_MODULE 1
#define CONFIG_NET_ACT_SIMP_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_CHECKSUM_MODULE 1
#define CONFIG_RTC_DRV_SD3078_MODULE 1
#define CONFIG_IP_NF_SECURITY_MODULE 1
#define CONFIG_EPOLL 1
#define CONFIG_SND_ATIIXP_MODULE 1
#define CONFIG_ARCH_SUPPORTS_SCHED_MC 1
#define CONFIG_USB_FUNCTIONFS_MODULE 1
#define CONFIG_LEDS_MLXREG_MODULE 1
#define CONFIG_SND_SOC_PM4125_SDW_MODULE 1
#define CONFIG_ACPI_PLATFORM_PROFILE 1
#define CONFIG_TYPEC_MUX_GPIO_SBU_MODULE 1
#define CONFIG_USB_FUNCTIONFS_ETH 1
#define CONFIG_VIDEO_CAFE_CCIC_MODULE 1
#define CONFIG_GPIO_SWNODE_UNDEFINED 1
#define CONFIG_RTC_DRV_DS3232_MODULE 1
#define CONFIG_PINCTRL_TIGERLAKE_MODULE 1
#define CONFIG_CGROUPS 1
#define CONFIG_USB_AMD5536UDC_MODULE 1
#define CONFIG_VIDEO_SAA7146_VV_MODULE 1
#define CONFIG_UDMABUF 1
#define CONFIG_DRM_HYPERV_MODULE 1
#define CONFIG_CNIC_MODULE 1
#define CONFIG_SPS30_SERIAL_MODULE 1
#define CONFIG_MITIGATION_IBPB_ENTRY 1
#define CONFIG_CHARGER_CROS_CONTROL_MODULE 1
#define CONFIG_NTB_SWITCHTEC_MODULE 1
#define CONFIG_SND_SOC_AW88395_MODULE 1
#define CONFIG_PATA_JMICRON_MODULE 1
#define CONFIG_USB_F_SUBSET_MODULE 1
#define CONFIG_RTC_DRV_PCF85363_MODULE 1
#define CONFIG_HAVE_ARCH_KMSAN 1
#define CONFIG_SENSORS_PLI1209BC_REGULATOR 1
#define CONFIG_AD7791_MODULE 1
#define CONFIG_SND_SOC_SGTL5000_MODULE 1
#define CONFIG_I2C_ALI1535_MODULE 1
#define CONFIG_NET_CLS_MATCHALL_MODULE 1
#define CONFIG_XILINX_LL_TEMAC_MODULE 1
#define CONFIG_RUST_FW_LOADER_ABSTRACTIONS 1
#define CONFIG_PKCS8_PRIVATE_KEY_PARSER_MODULE 1
#define CONFIG_AD2S1210_MODULE 1
#define CONFIG_SERIAL_8250 1
#define CONFIG_ABP060MG_MODULE 1
#define CONFIG_NET_DSA_MT7530_MMIO_MODULE 1
#define CONFIG_HAVE_ARCH_KASAN 1
#define CONFIG_USB_SERIAL 1
#define CONFIG_CRYPTO_CHACHA20POLY1305_MODULE 1
#define CONFIG_USE_PERCPU_NUMA_NODE_ID 1
#define CONFIG_NUMA_KEEP_MEMINFO 1
#define CONFIG_HID_ELAN_MODULE 1
#define CONFIG_CEC_SECO_RC 1
#define CONFIG_SPI_INTEL_PCI_MODULE 1
#define CONFIG_CRYPTO_HASH_INFO 1
#define CONFIG_NET_DSA_MSCC_OCELOT_EXT_MODULE 1
#define CONFIG_DRM_AMD_ACP 1
#define CONFIG_QED_LL2 1
#define CONFIG_MFD_MAX8925 1
#define CONFIG_NETFILTER_XT_MATCH_IPVS_MODULE 1
#define CONFIG_PHY_TUSB1210_MODULE 1
#define CONFIG_CRC32 1
#define CONFIG_CRYPTO_DEV_QAT_DH895xCC_MODULE 1
#define CONFIG_EXT4_FS 1
#define CONFIG_AK8975_MODULE 1
#define CONFIG_SENSORS_INA238_MODULE 1
#define CONFIG_TOUCHSCREEN_TOUCHRIGHT_MODULE 1
#define CONFIG_HID_EZKEY_MODULE 1
#define CONFIG_CRYPTO_TWOFISH_AVX_X86_64_MODULE 1
#define CONFIG_FANOTIFY_ACCESS_PERMISSIONS 1
#define CONFIG_EDAC_DECODE_MCE 1
#define CONFIG_IR_SERIAL_TRANSMITTER 1
#define CONFIG_JOYSTICK_ZHENHUA_MODULE 1
#define CONFIG_FUEL_GAUGE_STC3117_MODULE 1
#define CONFIG_AD7768_1_MODULE 1
#define CONFIG_SND_SOC_INTEL_MACH 1
#define CONFIG_TOUCHSCREEN_HIMAX_HX83112B_MODULE 1
#define CONFIG_TCP_CONG_HSTCP_MODULE 1
#define CONFIG_RTL8192CU_MODULE 1
#define CONFIG_USB_G_DBGP_SERIAL 1
#define CONFIG_SND_HDA_INPUT_BEEP_MODE 0
#define CONFIG_GPIO_CDEV 1
#define CONFIG_CAN_F81604_MODULE 1
#define CONFIG_VIDEO_PVRUSB2_DVB 1
#define CONFIG_NETFILTER_XT_TARGET_NOTRACK_MODULE 1
#define CONFIG_ARCH_HAS_UACCESS_FLUSHCACHE 1
#define CONFIG_USB_SERIAL_XSENS_MT_MODULE 1
#define CONFIG_BATTERY_SBS_MODULE 1
#define CONFIG_SND_SOC_CS42L43_MODULE 1
#define CONFIG_RUST 1
#define CONFIG_ATH9K_PCOEM 1
#define CONFIG_NET_DSA_TAG_MXL_GSW1XX_MODULE 1
#define CONFIG_KVM_MMU_LOCKLESS_AGING 1
#define CONFIG_MLX5_CORE_IPOIB 1
#define CONFIG_SOUND_OSS_CORE 1
#define CONFIG_LIBIE_MODULE 1
#define CONFIG_SND_SOC_CS4271_MODULE 1
#define CONFIG_VBOXGUEST_MODULE 1
#define CONFIG_I2C_AMD8111_MODULE 1
#define CONFIG_VIDEO_IMX290_MODULE 1
#define CONFIG_BSD_PROCESS_ACCT_V3 1
#define CONFIG_MAX77541_ADC_MODULE 1
#define CONFIG_FUSE_PASSTHROUGH 1
#define CONFIG_SND_SOC_ACPI_AMD_MATCH_MODULE 1
#define CONFIG_CAN_C_CAN_PCI_MODULE 1
#define CONFIG_RTL8192C_COMMON_MODULE 1
#define CONFIG_NET_DSA_TAG_VSC73XX_8021Q_MODULE 1
#define CONFIG_BOOTPARAM_HUNG_TASK_PANIC 0
#define CONFIG_USB_F_OBEX_MODULE 1
#define CONFIG_HAVE_SETUP_PER_CPU_AREA 1
#define CONFIG_USBIP_VHCI_HC_PORTS 8
#define CONFIG_PCIE_PTM 1
#define CONFIG_NFC_NCI_UART_MODULE 1
#define CONFIG_SLIMBUS_MODULE 1
#define CONFIG_PATA_NETCELL_MODULE 1
#define CONFIG_ARCH_HAS_SET_DIRECT_MAP 1
#define CONFIG_USB_SERIAL_SIMPLE_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_REALM_MODULE 1
#define CONFIG_USB_M66592_MODULE 1
#define CONFIG_RUSTC_VERSION_TEXT "rustc 1.97.1 (8bab26f4f 2026-07-14) (Arch Linux rust 1:1.97.1-1)"
#define CONFIG_USB_CHIPIDEA_PCI_MODULE 1
#define CONFIG_CIFS_UPCALL 1
#define CONFIG_CRYPTO_DEV_QAT_C3XXXVF_MODULE 1
#define CONFIG_USB_SL811_HCD_MODULE 1
#define CONFIG_USB_TEST_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_RATEEST_MODULE 1
#define CONFIG_X86_REQUIRED_FEATURE_CX8 1
#define CONFIG_PCMCIA_LOAD_CIS 1
#define CONFIG_SND_MIXART_MODULE 1
#define CONFIG_SATA_MOBILE_LPM_POLICY 3
#define CONFIG_NET_CRC32C 1
#define CONFIG_DMARD10_MODULE 1
#define CONFIG_CHARGER_MANAGER_MODULE 1
#define CONFIG_CRYPTO_SERPENT_AVX_X86_64_MODULE 1
#define CONFIG_VCNL4000_MODULE 1
#define CONFIG_SND_SOC_AMD_SOF_MACH_MODULE 1
#define CONFIG_SND_HDA_GENERIC_MODULE 1
#define CONFIG_MFD_CS47L15 1
#define CONFIG_WL18XX_MODULE 1
#define CONFIG_WILC1000_SPI_MODULE 1
#define CONFIG_PCMCIA_PCNET_MODULE 1
#define CONFIG_PMIC_DA903X 1
#define CONFIG_IIO_ADC_HELPER_MODULE 1
#define CONFIG_NVMEM_RAVE_SP_EEPROM_MODULE 1
#define CONFIG_COMMON_CLK_SI5351_MODULE 1
#define CONFIG_DVB_FIREDTV_MODULE 1
#define CONFIG_SURFACE_KBD_MODULE 1
#define CONFIG_DECOMPRESS_BZIP2 1
#define CONFIG_ACPI_HOTPLUG_IOAPIC 1
#define CONFIG_RDMA_RXE_MODULE 1
#define CONFIG_MODULE_SIG 1
#define CONFIG_MODULE_SIG_FORMAT 1
#define CONFIG_BLK_DEV_RNBD_SERVER_MODULE 1
#define CONFIG_SND_SOF_SOF_HDA_SDW_BPT_MODULE 1
#define CONFIG_HAVE_ARCH_VMAP_STACK 1
#define CONFIG_HAVE_OBJTOOL_NOP_MCOUNT 1
#define CONFIG_EFI_STUB 1
#define CONFIG_ACPI_APEI_GHES_NVIDIA_MODULE 1
#define CONFIG_TOUCHSCREEN_CYTTSP_SPI_MODULE 1
#define CONFIG_GPIO_USBIO_MODULE 1
#define CONFIG_GPIO_WM8994_MODULE 1
#define CONFIG_BT_HCIUART_H4 1
#define CONFIG_VIDEO_OV6211_MODULE 1
#define CONFIG_SENSORS_OCC_MODULE 1
#define CONFIG_DMABUF_HEAPS_SYSTEM 1
#define CONFIG_MIN_HEAP 1
#define CONFIG_CAN_SJA1000_MODULE 1
#define CONFIG_SSB_DRIVER_GPIO 1
#define CONFIG_RTC_LIB 1
#define CONFIG_HAVE_MOVE_PUD 1
#define CONFIG_SND_SOC_SOF_INTEL_MTL_MODULE 1
#define CONFIG_SENSORS_LM77_MODULE 1
#define CONFIG_QED_SRIOV 1
#define CONFIG_THINKPAD_LMI_MODULE 1
#define CONFIG_PSE_SI3474_MODULE 1
#define CONFIG_INPUT_UINPUT_MODULE 1
#define CONFIG_INPUT_GPIO_ROTARY_ENCODER_MODULE 1
#define CONFIG_MFD_PALMAS_MODULE 1
#define CONFIG_SCSI_DEBUG_MODULE 1
#define CONFIG_LCD_LMS283GF05_MODULE 1
#define CONFIG_REGULATOR_AAT2870_MODULE 1
#define CONFIG_CAN_HI311X_MODULE 1
#define CONFIG_USB_F_PHONET_MODULE 1
#define CONFIG_SENSORS_TMP108_MODULE 1
#define CONFIG_PERF_EVENTS_AMD_BRS 1
#define CONFIG_USB_CDNSP_GADGET 1
#define CONFIG_PER_VMA_LOCK 1
#define CONFIG_ND_PFN_MODULE 1
#define CONFIG_NFT_REDIR_MODULE 1
#define CONFIG_I2C_CBUS_GPIO_MODULE 1
#define CONFIG_SND_SOC_PCM186X_I2C_MODULE 1
#define CONFIG_USB_GSPCA_SONIXB_MODULE 1
#define CONFIG_DQL 1
#define CONFIG_RSI_DEBUGFS 1
#define CONFIG_USB_CONFIGFS_F_UAC1_LEGACY 1
#define CONFIG_IR_TOY_MODULE 1
#define CONFIG_TCG_TIS_I2C_MODULE 1
#define CONFIG_PINCTRL_AMDISP_MODULE 1
#define CONFIG_SECCOMP_FILTER 1
#define CONFIG_SPI_PXA2XX_MODULE 1
#define CONFIG_GPIO_PCI_IDIO_16_MODULE 1
#define CONFIG_MEGARAID_NEWGEN 1
#define CONFIG_TASKS_RCU 1
#define CONFIG_BNXT_SRIOV 1
#define CONFIG_GCC_VERSION 160201
#define CONFIG_6LOWPAN_NHC_IPV6_MODULE 1
#define CONFIG_HAVE_ARCH_JUMP_LABEL_RELATIVE 1
#define CONFIG_SND_SOC_SOF_AMD_COMMON_MODULE 1
#define CONFIG_WEXT_PRIV 1
#define CONFIG_TULIP_MMIO 1
#define CONFIG_SND_SOC_CS42L84_MODULE 1
#define CONFIG_NET_VENDOR_RENESAS 1
#define CONFIG_SND_SOC_CS4234_MODULE 1
#define CONFIG_SND_SOC_INTEL_CML_LP_DA7219_MAX98357A_MACH_MODULE 1
#define CONFIG_SERIAL_MAX310X_MODULE 1
#define CONFIG_SYSCTL 1
#define CONFIG_USB_CDNSP_HOST 1
#define CONFIG_THERMAL_GOV_USER_SPACE 1
#define CONFIG_SENSORS_CGBC_MODULE 1
#define CONFIG_NVMEM 1
#define CONFIG_CRYPTO_LIB_SHA1 1
#define CONFIG_ZONE_DEVICE 1
#define CONFIG_SND_HDA_CODEC_HDMI_SIMPLE_MODULE 1
#define CONFIG_VIDEO_EM28XX_ALSA_MODULE 1
#define CONFIG_VLAN_8021Q_GVRP 1
#define CONFIG_INTEL_PMT_CRASHLOG_MODULE 1
#define CONFIG_VIDEO_OS05B10_MODULE 1
#define CONFIG_GPIO_WM8350_MODULE 1
#define CONFIG_IP_NF_IPTABLES_LEGACY_MODULE 1
#define CONFIG_USB_ISP1760_MODULE 1
#define CONFIG_HID_DRAGONRISE_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_STRING_MODULE 1
#define CONFIG_SND_AU8830_MODULE 1
#define CONFIG_SSB_POSSIBLE 1
#define CONFIG_VIDEO_IMX274_MODULE 1
#define CONFIG_SENSORS_PT5161L_MODULE 1
#define CONFIG_NET_VENDOR_XILINX 1
#define CONFIG_AIC79XX_REG_PRETTY_PRINT 1
#define CONFIG_TIGON3_MODULE 1
#define CONFIG_MAXLINEAR_GPHY_MODULE 1
#define CONFIG_XEN_SCRUB_PAGES_DEFAULT 1
#define CONFIG_INTEL_SOC_DTS_THERMAL_MODULE 1
#define CONFIG_SENSORS_MAX31785_MODULE 1
#define CONFIG_CEC_CROS_EC_MODULE 1
#define CONFIG_NLS_UTF8_MODULE 1
#define CONFIG_VIDEO_OV02C10_MODULE 1
#define CONFIG_WLAN_VENDOR_REALTEK 1
#define CONFIG_USB_LGM_PHY_MODULE 1
#define CONFIG_B43_PCI_AUTOSELECT 1
#define CONFIG_USB_GSPCA_STK1135_MODULE 1
#define CONFIG_GPIO_GENERIC_MODULE 1
#define CONFIG_SURFACE_GPE_MODULE 1
#define CONFIG_SCHED_CLASS_EXT 1
#define CONFIG_SMI330_I2C_MODULE 1
#define CONFIG_BACKLIGHT_LP855X_MODULE 1
#define CONFIG_PM_SLEEP_SMP 1
#define CONFIG_ARCH_MAY_HAVE_PC_FDC 1
#define CONFIG_FIXED_PHY_MODULE 1
#define CONFIG_CRYPTO_NULL_MODULE 1
#define CONFIG_POSIX_MQUEUE_SYSCTL 1
#define CONFIG_HOTPLUG_PCI_ACPI 1
#define CONFIG_AD7091R5_MODULE 1
#define CONFIG_INTERRUPT_CNT_MODULE 1
#define CONFIG_MULTIPLEXER 1
#define CONFIG_HIBERNATION 1
#define CONFIG_SIEMENS_SIMATIC_IPC_WDT_MODULE 1
#define CONFIG_IP_VS_DH_MODULE 1
#define CONFIG_INPUT_QNAP_MCU_MODULE 1
#define CONFIG_HAPPYMEAL_MODULE 1
#define CONFIG_OUTPUT_FORMAT "elf64-x86-64"
#define CONFIG_VIDEO_TW686X_MODULE 1
#define CONFIG_KEYBOARD_ADP5520_MODULE 1
#define CONFIG_AD_SIGMA_DELTA_MODULE 1
#define CONFIG_SND_SOC_PCM512x_MODULE 1
#define CONFIG_RTW89_8851BE_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_OSF_MODULE 1
#define CONFIG_SND_HDA_CODEC_CS8409_MODULE 1
#define CONFIG_IPMI_SI_MODULE 1
#define CONFIG_IWL4965_MODULE 1
#define CONFIG_REGULATOR_BQ257XX_MODULE 1
#define CONFIG_SERIAL_8250_MEN_MCB_MODULE 1
#define CONFIG_RTC_DRV_DS3232_HWMON 1
#define CONFIG_HID_FT260_MODULE 1
#define CONFIG_TWL4030_WATCHDOG_MODULE 1
#define CONFIG_NET_9P_XEN_MODULE 1
#define CONFIG_PHY_INTEL_LGM_EMMC_MODULE 1
#define CONFIG_SERIAL_CORE_CONSOLE 1
#define CONFIG_NET_VENDOR_CISCO 1
#define CONFIG_HP206C_MODULE 1
#define CONFIG_AK8974_MODULE 1
#define CONFIG_VIDEO_OV8858_MODULE 1
#define CONFIG_XXHASH 1
#define CONFIG_NET_L3_MASTER_DEV 1
#define CONFIG_TASK_XACCT 1
#define CONFIG_GENERIC_CLOCKEVENTS_COUPLED_INLINE 1
#define CONFIG_NET_SOCK_MSG 1
#define CONFIG_SPI_MXIC_MODULE 1
#define CONFIG_SENSORS_HDAPS_MODULE 1
#define CONFIG_MODIFY_LDT_SYSCALL 1
#define CONFIG_SENSORS_LTC2992_MODULE 1
#define CONFIG_SENSORS_ADM9240_MODULE 1
#define CONFIG_CRYPTO_LIB_DES_MODULE 1
#define CONFIG_MLX90635_MODULE 1
#define CONFIG_SND_SOC_CS42L42_MODULE 1
#define CONFIG_SND_SEQUENCER_OSS_MODULE 1
#define CONFIG_AIC7XXX_DEBUG_ENABLE 1
#define CONFIG_PARPORT_1284 1
#define CONFIG_INPUT_MAX77693_HAPTIC_MODULE 1
#define CONFIG_SND_MTS64_MODULE 1
#define CONFIG_I2C_SLAVE_TESTUNIT_MODULE 1
#define CONFIG_MOXA_SMARTIO_MODULE 1
#define CONFIG_CRYPTO_ECDH 1
#define CONFIG_MMCONF_FAM10H 1
#define CONFIG_ATA_PIIX_MODULE 1
#define CONFIG_X86_ANDROID_TABLETS_MODULE 1
#define CONFIG_RTC_DRV_DS2404_MODULE 1
#define CONFIG_RTC_DRV_MAX31335_MODULE 1
#define CONFIG_LEDS_ADP5520_MODULE 1
#define CONFIG_HAVE_ARCH_NODE_DEV_GROUP 1
#define CONFIG_ARCH_CONFIGURES_CPU_MITIGATIONS 1
#define CONFIG_DRM_NOUVEAU_BACKLIGHT 1
#define CONFIG_DVB_DYNAMIC_MINORS 1
#define CONFIG_HID_PICOLCD_MODULE 1
#define CONFIG_CHT_WC_PMIC_OPREGION 1
#define CONFIG_IA32_FEAT_CTL 1
#define CONFIG_SND_SOC_CS42L51_I2C_MODULE 1
#define CONFIG_IRQ_DOMAIN_HIERARCHY 1
#define CONFIG_IIO_ST_LSM9DS0_MODULE 1
#define CONFIG_SPI_CADENCE_MODULE 1
#define CONFIG_SND_JACK 1
#define CONFIG_I2C_AMD_ASF_MODULE 1
#define CONFIG_SND_SOC_UDA1380_MODULE 1
#define CONFIG_SND_SOC_SOF_HDA_LINK 1
#define CONFIG_IWLDVM_MODULE 1
#define CONFIG_NET_ACT_BPF_MODULE 1
#define CONFIG_HID_ASUS_MODULE 1
#define CONFIG_HID_LETSKETCH_MODULE 1
#define CONFIG_CAN_CTUCANFD_MODULE 1
#define CONFIG_FXLS8962AF_SPI_MODULE 1
#define CONFIG_DVB_USB_DIB0700_MODULE 1
#define CONFIG_SENSORS_TMP401_MODULE 1
#define CONFIG_CONTEXT_TRACKING_USER 1
#define CONFIG_CRYPTO_LIB_POLY1305 1
#define CONFIG_SND_SOC_CS_AMP_LIB_MODULE 1
#define CONFIG_I2C_SCMI_MODULE 1
#define CONFIG_MTD_NAND_CORE_MODULE 1
#define CONFIG_NET_DSA_LANTIQ_COMMON_MODULE 1
#define CONFIG_CC_HAS_IBT 1
#define CONFIG_NET_DSA_XRS700X_I2C_MODULE 1
#define CONFIG_INPUT_DA7280_HAPTICS_MODULE 1
#define CONFIG_ACPI_NFIT_MODULE 1
#define CONFIG_PINCTRL_LYNXPOINT_MODULE 1
#define CONFIG_GENERIC_IRQ_PROBE 1
#define CONFIG_CRYPTO_ECRDSA_MODULE 1
#define CONFIG_TCP_CONG_VENO_MODULE 1
#define CONFIG_CRYPTO_LIB_NH_ARCH 1
#define CONFIG_ARCH_HAS_EXECMEM_ROX 1
#define CONFIG_9P_FS_MODULE 1
#define CONFIG_MHZ19B_MODULE 1
#define CONFIG_USB_GSPCA_MODULE 1
#define CONFIG_SQUASHFS_LZO 1
#define CONFIG_MOUSE_PS2_SMBUS 1
#define CONFIG_FRAMEBUFFER_CONSOLE_DETECT_PRIMARY 1
#define CONFIG_NET_SCH_TAPRIO_MODULE 1
#define CONFIG_SND_SOC_PCM1789_MODULE 1
#define CONFIG_SENSORS_W83795_MODULE 1
#define CONFIG_SENSORS_LTC3815_MODULE 1
#define CONFIG_CRYPTO_KRB5ENC_MODULE 1
#define CONFIG_FRAME_WARN 2048
#define CONFIG_SERIAL_MAX3100_MODULE 1
#define CONFIG_DYNAMIC_FTRACE 1
#define CONFIG_SND_FIREWIRE_DIGI00X_MODULE 1
#define CONFIG_SND_SOC_SIGMADSP_REGMAP_MODULE 1
#define CONFIG_AYANEO_EC_MODULE 1
#define CONFIG_NLS_MAC_CENTEURO_MODULE 1
#define CONFIG_VIDEO_DW9768_MODULE 1
#define CONFIG_LD_VERSION 24700
#define CONFIG_NET_CLS_U32_MODULE 1
#define CONFIG_SENSORS_MP2869_MODULE 1
#define CONFIG_XEN_BACKEND 1
#define CONFIG_VT_CONSOLE 1
#define CONFIG_INET_AH_MODULE 1
#define CONFIG_I2C 1
#define CONFIG_CHARGER_BQ24257_MODULE 1
#define CONFIG_HOTPLUG_PCI_SHPC 1
#define CONFIG_NET_SCH_ETS_MODULE 1
#define CONFIG_BATTERY_RT5033_MODULE 1
#define CONFIG_INPUT_DA9052_ONKEY_MODULE 1
#define CONFIG_X86_CPUID 1
#define CONFIG_INTEL_TH_MODULE 1
#define CONFIG_SND_SOC_MODULE 1
#define CONFIG_VIDEO_V4L2_TPG_MODULE 1
#define CONFIG_SND_SOC_NAU8540_MODULE 1
#define CONFIG_ADXL313_I2C_MODULE 1
#define CONFIG_USB_MUSB_HDRC_MODULE 1
#define CONFIG_SENSORS_EMC2103_MODULE 1
#define CONFIG_SCSI_MVUMI_MODULE 1
#define CONFIG_PCIE_PME 1
#define CONFIG_LEDS_LM3642_MODULE 1
#define CONFIG_MD_RAID10_MODULE 1
#define CONFIG_LEDS_CLASS 1
#define CONFIG_SND_SOC_PCM179X_I2C_MODULE 1
#define CONFIG_PINCTRL_ICELAKE_MODULE 1
#define CONFIG_MEDIA_RADIO_SUPPORT 1
#define CONFIG_LSI_ET1011C_PHY_MODULE 1
#define CONFIG_NET_VENDOR_ADI 1
#define CONFIG_LTC2688_MODULE 1
#define CONFIG_LEDS_TRIGGER_PANIC 1
#define CONFIG_BT_HCIUART_AG6XX 1
#define CONFIG_PM_SLEEP 1
#define CONFIG_NET_SCH_CODEL_MODULE 1
#define CONFIG_MODULE_SIG_ALL 1
#define CONFIG_CRC64_ARCH 1
#define CONFIG_INTEL_TELEMETRY_MODULE 1
#define CONFIG_SENSORS_ADM1029_MODULE 1
#define CONFIG_VIDEO_DW9807_VCM_MODULE 1
#define CONFIG_SND_SOC_RT298_MODULE 1
#define CONFIG_DRM_BRIDGE 1
#define CONFIG_REED_SOLOMON_DEC8 1
#define CONFIG_VIDEO_SAA7134_RC 1
#define CONFIG_USB_GSPCA_SPCA506_MODULE 1
#define CONFIG_COMMON_CLK_PALMAS_MODULE 1
#define CONFIG_ACPI_NUMA 1
#define CONFIG_AD74413R_MODULE 1
#define CONFIG_SENSORS_ADT7410_MODULE 1
#define CONFIG_IWLWIFI_DEBUG 1
#define CONFIG_HID_MAGICMOUSE_MODULE 1
#define CONFIG_EFI_DXE_MEM_ATTRIBUTES 1
#define CONFIG_HID_APPLETB_KBD_MODULE 1
#define CONFIG_NET_SCH_FQ_MODULE 1
#define CONFIG_VIDEO_BT848_MODULE 1
#define CONFIG_RT2800USB_RT53XX 1
#define CONFIG_DETECT_HUNG_TASK 1
#define CONFIG_VIDEO_M52790_MODULE 1
#define CONFIG_SYSTEM_DATA_VERIFICATION 1
#define CONFIG_USB_G_MULTI_CDC 1
#define CONFIG_VIRTIO_IOMMU_MODULE 1
#define CONFIG_FUJITSU_LAPTOP_MODULE 1
#define CONFIG_DRM_I915_MAX_REQUEST_BUSYWAIT 8000
#define CONFIG_TOUCHSCREEN_WM831X_MODULE 1
#define CONFIG_HIBERNATION_SNAPSHOT_DEV 1
#define CONFIG_X86_INTEL_MEMORY_PROTECTION_KEYS 1
#define CONFIG_HID_ZEROPLUS_MODULE 1
#define CONFIG_SND_HDA_DSP_LOADER 1
#define CONFIG_MFD_MT6397_MODULE 1
#define CONFIG_NET_PTP_CLASSIFY 1
#define CONFIG_CC_HAS_RETURN_THUNK 1
#define CONFIG_60XX_WDT_MODULE 1
#define CONFIG_SND_SOC_RT711_SDCA_SDW_MODULE 1
#define CONFIG_VMAP_STACK 1
#define CONFIG_ICE_MODULE 1
#define CONFIG_PM 1
#define CONFIG_AD5064_MODULE 1
#define CONFIG_DST_CACHE 1
#define CONFIG_CRYPTO_DEV_VIRTIO_MODULE 1
#define CONFIG_CRYPTO_DEV_PADLOCK_MODULE 1
#define CONFIG_TASKS_TRACE_RCU_NO_MB 1
#define CONFIG_CRYPTO_DEV_CCP_CRYPTO_MODULE 1
#define CONFIG_CRYPTO_SHA512 1
#define CONFIG_MEMORY_FAILURE 1
#define CONFIG_SND_SOC_RT1019_MODULE 1
#define CONFIG_LIST_HARDENED 1
#define CONFIG_IIO_ST_PRESS_I2C_MODULE 1
#define CONFIG_SENSORS_F71882FG_MODULE 1
#define CONFIG_ADXL367_I2C_MODULE 1
#define CONFIG_IRQ_POLL 1
#define CONFIG_XE_VFIO_PCI_MODULE 1
#define CONFIG_SND_SOC_AMD_PS_MODULE 1
#define CONFIG_CHARGER_MAX14577_MODULE 1
#define CONFIG_ATH10K_SPECTRAL 1
#define CONFIG_NET_VENDOR_GOOGLE 1
#define CONFIG_ARCH_SPARSEMEM_ENABLE 1
#define CONFIG_SCSI_AIC7XXX_MODULE 1
#define CONFIG_SND_SOC_SOF_INTEL_LNL_MODULE 1
#define CONFIG_ARCH_ENABLE_THP_MIGRATION 1
#define CONFIG_ACPI_THERMAL_LIB 1
#define CONFIG_USB_EHCI_ROOT_HUB_TT 1
#define CONFIG_USB_NET_AX88179_178A_MODULE 1
#define CONFIG_NLS_CODEPAGE_775_MODULE 1
#define CONFIG_CMA_SYSFS 1
#define CONFIG_MARVELL_PHY_MODULE 1
#define CONFIG_HID_PRIMAX_MODULE 1
#define CONFIG_NLS 1
#define CONFIG_USB_S2255_MODULE 1
#define CONFIG_TOUCHSCREEN_TPS6507X_MODULE 1
#define CONFIG_IP_SET_HASH_NETPORTNET_MODULE 1
#define CONFIG_GENERIC_IRQ_RESERVATION_MODE 1
#define CONFIG_OID_REGISTRY 1
#define CONFIG_IIO_KX022A_MODULE 1
#define CONFIG_SSB_PCMCIAHOST_POSSIBLE 1
#define CONFIG_MEDIATEK_GE_PHY_MODULE 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_RT5640_MODULE 1
#define CONFIG_INTEL_SKL_INT3472_MODULE 1
#define CONFIG_USER_STACKTRACE_SUPPORT 1
#define CONFIG_SND_CTXFI_MODULE 1
#define CONFIG_CARL9170_DEBUGFS 1
#define CONFIG_BT_NXPUART_MODULE 1
#define CONFIG_SENSORS_MAX77705_MODULE 1
#define CONFIG_SPI_OFFLOAD_TRIGGER_PWM_MODULE 1
#define CONFIG_THUNDER_NIC_PF_MODULE 1
#define CONFIG_SCHED_TRACER 1
#define CONFIG_MLXREG_HOTPLUG_MODULE 1
#define CONFIG_B43_PHY_G 1
#define CONFIG_INPUT_CMA3000_I2C_MODULE 1
#define CONFIG_BNXT_FLOWER_OFFLOAD 1
#define CONFIG_TOUCHSCREEN_WACOM_I2C_MODULE 1
#define CONFIG_AD7793_MODULE 1
#define CONFIG_ACPI_ALS_MODULE 1
#define CONFIG_LPC_ICH_MODULE 1
#define CONFIG_VIDEO_OG01A1B_MODULE 1
#define CONFIG_GENERIC_IRQ_MIGRATION 1
#define CONFIG_SQUASHFS_ZLIB 1
#define CONFIG_MLX4_CORE_MODULE 1
#define CONFIG_MLX5_DPLL_MODULE 1
#define CONFIG_NET_VENDOR_WIZNET 1
#define CONFIG_EDAC_AMD64_MODULE 1
#define CONFIG_USB_AUDIO_MODULE 1
#define CONFIG_CAN_CAN327_MODULE 1
#define CONFIG_SPEAKUP_SYNTH_APOLLO_MODULE 1
#define CONFIG_SPEAKUP_SYNTH_DECTLK_MODULE 1
#define CONFIG_SND_SOC_AMD_ACP_PDM_MODULE 1
#define CONFIG_SPI_OFFLOAD_TRIGGER_ADI_UTIL_SD_MODULE 1
#define CONFIG_DVB_HORUS3A_MODULE 1
#define CONFIG_XFRM_IPTFS_MODULE 1
#define CONFIG_SENSORS_LM87_MODULE 1
#define CONFIG_BACKLIGHT_PWM_MODULE 1
#define CONFIG_APDS9300_MODULE 1
#define CONFIG_RPCSEC_GSS_KRB5_ENCTYPES_CAMELLIA 1
#define CONFIG_USB_VIDEO_CLASS_INPUT_EVDEV 1
#define CONFIG_REGULATOR_LM363X_MODULE 1
#define CONFIG_MITIGATION_PAGE_TABLE_ISOLATION 1
#define CONFIG_DVB_STV0297_MODULE 1
#define CONFIG_IPMI_IPMB_MODULE 1
#define CONFIG_NET_DSA_TAG_BRCM_PREPEND_MODULE 1
#define CONFIG_SENSORS_MAX6621_MODULE 1
#define CONFIG_SENSORS_LTC4215_MODULE 1
#define CONFIG_NETFILTER_FAMILY_BRIDGE 1
#define CONFIG_CC_NO_ARRAY_BOUNDS 1
#define CONFIG_6LOWPAN_GHC_EXT_HDR_ROUTE_MODULE 1
#define CONFIG_AMD_NODE 1
#define CONFIG_MLX90632_MODULE 1
#define CONFIG_FIB_RULES 1
#define CONFIG_NFT_XFRM_MODULE 1
#define CONFIG_CONTEXT_TRACKING_IDLE 1
#define CONFIG_AD7779_MODULE 1
#define CONFIG_BLK_DEBUG_FS 1
#define CONFIG_JBD2 1
#define CONFIG_VIDEO_IMX208_MODULE 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_DMIC_MODULE 1
#define CONFIG_FONT_SUPPORT 1
#define CONFIG_NXP_CBTX_PHY_MODULE 1
#define CONFIG_SENSORS_LTC4222_MODULE 1
#define CONFIG_USB_CDNS3_HOST 1
#define CONFIG_GENERIC_IRQ_EFFECTIVE_AFF_MASK 1
#define CONFIG_SND_SOC_WM8776_MODULE 1
#define CONFIG_WIRELESS 1
#define CONFIG_THERMAL_GOV_FAIR_SHARE 1
#define CONFIG_BLK_DEV_BSGLIB 1
#define CONFIG_USB_NET_SR9800_MODULE 1
#define CONFIG_SND_SOC_STA32X_MODULE 1
#define CONFIG_MFD_WM8350_I2C 1
#define CONFIG_9P_FS_SECURITY 1
#define CONFIG_PC87413_WDT_MODULE 1
#define CONFIG_NET_SCH_FQ_PIE_MODULE 1
#define CONFIG_MLXSW_SPECTRUM_MODULE 1
#define CONFIG_SATA_SIL24_MODULE 1
#define CONFIG_MAX1363_MODULE 1
#define CONFIG_SCSI_DH_ALUA_MODULE 1
#define CONFIG_VIDEO_IMX283_MODULE 1
#define CONFIG_SENSORS_MCP3021_MODULE 1
#define CONFIG_SND_SOC_ES8389_MODULE 1
#define CONFIG_SND_CS46XX_MODULE 1
#define CONFIG_NETFILTER 1
#define CONFIG_VIRTIO_PCI_ADMIN_LEGACY 1
#define CONFIG_GPU_BUDDY 1
#define CONFIG_LIBERTAS_THINFIRM_USB_MODULE 1
#define CONFIG_MEDIA_TUNER_MT2063_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_HL_MODULE 1
#define CONFIG_SIOX_BUS_GPIO_MODULE 1
#define CONFIG_CC_HAS_COUNTED_BY_PTR 1
#define CONFIG_IEEE802154_NL802154_EXPERIMENTAL 1
#define CONFIG_DVB_STV6111_MODULE 1
#define CONFIG_TOUCHSCREEN_STMFTS_MODULE 1
#define CONFIG_NVME_RDMA_MODULE 1
#define CONFIG_REGMAP_SPI 1
#define CONFIG_NET_ACT_GATE_MODULE 1
#define CONFIG_OPTEE_STATIC_PROTMEM_POOL 1
#define CONFIG_ADIS16080_MODULE 1
#define CONFIG_CXL_PCI_MODULE 1
#define CONFIG_SND_VIRMIDI_MODULE 1
#define CONFIG_GOOGLE_COREBOOT_TABLE_MODULE 1
#define CONFIG_MMA9553_MODULE 1
#define CONFIG_USB_GSPCA_SN9C2028_MODULE 1
#define CONFIG_NET_IPGRE_MODULE 1
#define CONFIG_INFINIBAND_IRDMA_MODULE 1
#define CONFIG_SND_USB_AUDIO_USE_MEDIA_CONTROLLER 1
#define CONFIG_BSD_DISKLABEL 1
#define CONFIG_USB_STORAGE_SDDR09_MODULE 1
#define CONFIG_VIDEO_OV9650_MODULE 1
#define CONFIG_INTEL_IOMMU_SCALABLE_MODE_DEFAULT_ON 1
#define CONFIG_DRM_PANEL_RASPBERRYPI_TOUCHSCREEN_MODULE 1
#define CONFIG_AD5446_MODULE 1
#define CONFIG_BLK_WBT_MQ 1
#define CONFIG_CHROMEOS_ACPI_MODULE 1
#define CONFIG_SND_SOC_PCM186X_SPI_MODULE 1
#define CONFIG_DVB_CXD2841ER_MODULE 1
#define CONFIG_INTEL_VSEC_MODULE 1
#define CONFIG_FUNCTION_GRAPH_RETVAL 1
#define CONFIG_CRYPTO_LIB_MD5 1
#define CONFIG_USB_SPEEDTOUCH_MODULE 1
#define CONFIG_SND_SOC_SDW_UTILS_MODULE 1
#define CONFIG_DRM_DISPLAY_DP_HELPER 1
#define CONFIG_INTEL_MEI_HDCP_MODULE 1
#define CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE 1
#define CONFIG_SND_SOC_ES8311_MODULE 1
#define CONFIG_SND_SOC_LPASS_RX_MACRO_MODULE 1
#define CONFIG_VIDEO_TVP5150_MODULE 1
#define CONFIG_INTEL_IPS_MODULE 1
#define CONFIG_MFD_WM8350 1
#define CONFIG_ENA_ETHERNET_MODULE 1
#define CONFIG_HFSPLUS_FS_MODULE 1
#define CONFIG_MFD_MAX77541_MODULE 1
#define CONFIG_CRYPTO_SKCIPHER 1
#define CONFIG_USB_CONFIGFS_F_TCM 1
#define CONFIG_MLX5_EN_TLS 1
#define CONFIG_NET_DSA_VITESSE_VSC73XX_MODULE 1
#define CONFIG_SND_SOC_RT5575_SPI 1
#define CONFIG_SENSORS_LM75_MODULE 1
#define CONFIG_USB_SERIAL_MOS7840_MODULE 1
#define CONFIG_ATH11K_SPECTRAL 1
#define CONFIG_INTEL_SPEED_SELECT_TPMI_MODULE 1
#define CONFIG_IR_SONY_DECODER_MODULE 1
#define CONFIG_LENOVO_WMI_HELPERS_MODULE 1
#define CONFIG_SERIO_ARC_PS2_MODULE 1
#define CONFIG_HID_ITE_MODULE 1
#define CONFIG_HAVE_FUNCTION_GRAPH_FREGS 1
#define CONFIG_CRYPTO_MLDSA_MODULE 1
#define CONFIG_VIDEO_IMX355_MODULE 1
#define CONFIG_X86_AMD_PSTATE 1
#define CONFIG_SND_SOC_SOF_INTEL_NVL_MODULE 1
#define CONFIG_SND_SOC_TLV320AIC23_I2C_MODULE 1
#define CONFIG_PCP_BATCH_SCALE_MAX 5
#define CONFIG_NETFILTER_XT_MATCH_NFACCT_MODULE 1
#define CONFIG_PATA_RDC_MODULE 1
#define CONFIG_SLAB_FREELIST_HARDENED 1
#define CONFIG_PM_GENERIC_DOMAINS 1
#define CONFIG_INPUT_IBM_PANEL_MODULE 1
#define CONFIG_CRYPTO_LRW_MODULE 1
#define CONFIG_DEFAULT_HUNG_TASK_TIMEOUT 120
#define CONFIG_XFS_ONLINE_SCRUB 1
#define CONFIG_SERIO_LIBPS2 1
#define CONFIG_MMA8452_MODULE 1
#define CONFIG_USB_GSPCA_SPCA505_MODULE 1
#define CONFIG_TAP_MODULE 1
#define CONFIG_TRANSPARENT_HUGEPAGE_ALWAYS 1
#define CONFIG_CAN_CC770_PLATFORM_MODULE 1
#define CONFIG_HAVE_PREEMPT_DYNAMIC 1
#define CONFIG_USB_DEFAULT_PERSIST 1
#define CONFIG_SND_SOC_MAX98520_MODULE 1
#define CONFIG_SENSORS_ADT7411_MODULE 1
#define CONFIG_TCP_CONG_CUBIC 1
#define CONFIG_USB_G_DBGP_MODULE 1
#define CONFIG_HID_THINGM_MODULE 1
#define CONFIG_ATM_BR2684_MODULE 1
#define CONFIG_ZRAM_MEMORY_TRACKING 1
#define CONFIG_ACPI_MRRM 1
#define CONFIG_XDP_SOCKETS 1
#define CONFIG_CRYPTO_ECHAINIV_MODULE 1
#define CONFIG_REGULATOR_ISL6271A_MODULE 1
#define CONFIG_TINYDRM_HX8357D_MODULE 1
#define CONFIG_MEGARAID_MAILBOX_MODULE 1
#define CONFIG_SEV_GUEST_MODULE 1
#define CONFIG_RTW89_8922A_MODULE 1
#define CONFIG_ARCH_HAS_UBSAN 1
#define CONFIG_AD7291_MODULE 1
#define CONFIG_YT2_1380_MODULE 1
#define CONFIG_MFD_WCD934X_MODULE 1
#define CONFIG_INPUT_DA9055_ONKEY_MODULE 1
#define CONFIG_HID_PICOLCD_LEDS 1
#define CONFIG_DVB_DIB7000P_MODULE 1
#define CONFIG_CW1200_MODULE 1
#define CONFIG_LCD_ILI922X_MODULE 1
#define CONFIG_JFFS2_SUMMARY 1
#define CONFIG_VIDEO_CCS_PLL_MODULE 1
#define CONFIG_IP_SET_BITMAP_IP_MODULE 1
#define CONFIG_VMAP_PFN 1
#define CONFIG_SENSORS_TPS25990_MODULE 1
#define CONFIG_HAVE_SOFTIRQ_ON_OWN_STACK 1
#define CONFIG_AIC79XX_DEBUG_ENABLE 1
#define CONFIG_SND_SOC_WM8510_MODULE 1
#define CONFIG_VIRT_CPU_ACCOUNTING_GEN 1
#define CONFIG_SERIAL_8250_KEBA_MODULE 1
#define CONFIG_LP8788_ADC_MODULE 1
#define CONFIG_SMI240_MODULE 1
#define CONFIG_BPF_JIT 1
#define CONFIG_TRACE_GPU_MEM 1
#define CONFIG_CRYPTO_LIB_SHA3 1
#define CONFIG_MOUSE_PS2_TOUCHKIT 1
#define CONFIG_HPET_TIMER 1
#define CONFIG_ARCH_HAS_MEM_ENCRYPT 1
#define CONFIG_SUNRPC_DEBUG 1
#define CONFIG_HID_MALTRON_MODULE 1
#define CONFIG_MFD_TWL4030_AUDIO 1
#define CONFIG_CRYPTO_CAST5_MODULE 1
#define CONFIG_GPIB_AGILENT_82357A_MODULE 1
#define CONFIG_PARPORT_NOT_PC 1
#define CONFIG_NET_TEAM_MODE_ACTIVEBACKUP_MODULE 1
#define CONFIG_MT7921E_MODULE 1
#define CONFIG_DELL_WMI_AIO_MODULE 1
#define CONFIG_DVB_AS102_MODULE 1
#define CONFIG_HID_PANTHERLORD_MODULE 1
#define CONFIG_HAVE_CLK_PREPARE 1
#define CONFIG_USB_CONFIGFS_MASS_STORAGE 1
#define CONFIG_WM8350_POWER_MODULE 1
#define CONFIG_SENSORS_IRPS5401_MODULE 1
#define CONFIG_SND_SOC_SOF_HDA_MLINK_MODULE 1
#define CONFIG_SENSORS_SURFACE_TEMP_MODULE 1
#define CONFIG_WM831X_BACKUP_MODULE 1
#define CONFIG_CRYPTO_CAST5_AVX_X86_64_MODULE 1
#define CONFIG_IR_ENE_MODULE 1
#define CONFIG_SURFACE_PLATFORM_PROFILE_MODULE 1
#define CONFIG_DVB_AV7110_OSD 1
#define CONFIG_LEDS_APU_MODULE 1
#define CONFIG_SERIAL_NONSTANDARD 1
#define CONFIG_XEN_UNPOPULATED_ALLOC 1
#define CONFIG_BACKLIGHT_DA9052_MODULE 1
#define CONFIG_PTP_1588_CLOCK_MOCK_MODULE 1
#define CONFIG_HAVE_RUST 1
#define CONFIG_BE2NET_HWMON 1
#define CONFIG_BLK_DEV_BSG_COMMON 1
#define CONFIG_CFG80211_CRDA_SUPPORT 1
#define CONFIG_NVRAM 1
#define CONFIG_SND_SOC_RT5514_MODULE 1
#define CONFIG_IP_ADVANCED_ROUTER 1
#define CONFIG_HMM_MIRROR 1
#define CONFIG_JOYSTICK_IFORCE_MODULE 1
#define CONFIG_SND_ICE1712_MODULE 1
#define CONFIG_SENSORS_MAX20730_MODULE 1
#define CONFIG_SND_ALI5451_MODULE 1
#define CONFIG_IP_VS_OVF_MODULE 1
#define CONFIG_CRYPTO_GENIV_MODULE 1
#define CONFIG_REGULATOR_ACT8865_MODULE 1
#define CONFIG_TRACER_SNAPSHOT 1
#define CONFIG_VIDEO_EM28XX_RC_MODULE 1
#define CONFIG_CHARGER_MAX8903_MODULE 1
#define CONFIG_SPI_LJCA_MODULE 1
#define CONFIG_MMU_GATHER_MERGE_VMAS 1
#define CONFIG_USB_C67X00_HCD_MODULE 1
#define CONFIG_AUDIT_ARCH 1
#define CONFIG_FTRACE 1
#define CONFIG_RTL8192EE_MODULE 1
#define CONFIG_USB_DWC3_ULPI 1
#define CONFIG_ATH9K_HTC_DEBUGFS 1
#define CONFIG_TI_ADC161S626_MODULE 1
#define CONFIG_SND_SOC_HDMI_CODEC_MODULE 1
#define CONFIG_DNS_RESOLVER_MODULE 1
#define CONFIG_SUNRPC_GSS_MODULE 1
#define CONFIG_PAGE_BLOCK_MAX_ORDER 10
#define CONFIG_VIDEOMODE_HELPERS 1
#define CONFIG_SQUASHFS_LZ4 1
#define CONFIG_ZL3073X_SPI_MODULE 1
#define CONFIG_EDAC_SUPPORT 1
#define CONFIG_USB_PRINTER_MODULE 1
#define CONFIG_FW_CFG_SYSFS_MODULE 1
#define CONFIG_BACKLIGHT_WM831X_MODULE 1
#define CONFIG_B44_PCICORE_AUTOSELECT 1
#define CONFIG_NETFILTER_XT_TARGET_NETMAP_MODULE 1
#define CONFIG_VDPA_SIM_NET_MODULE 1
#define CONFIG_ACPI_IPMI_MODULE 1
#define CONFIG_SERIAL_8250_LPSS_MODULE 1
#define CONFIG_SPI_MASTER 1
#define CONFIG_PPS_GENERATOR_TIO_MODULE 1
#define CONFIG_SND_INTEL_SOUNDWIRE_ACPI_MODULE 1
#define CONFIG_F2FS_FS_LZ4HC 1
#define CONFIG_USB_GSPCA_SE401_MODULE 1
#define CONFIG_STRIP_ASM_SYMS 1
#define CONFIG_LENOVO_YMC_MODULE 1
#define CONFIG_SENSORS_SIS5595_MODULE 1
#define CONFIG_PWM_GPIO_MODULE 1
#define CONFIG_MDIO_MVUSB_MODULE 1
#define CONFIG_EFI_PARTITION 1
#define CONFIG_SENSORS_MAX6620_MODULE 1
#define CONFIG_MTD_SPI_NOR_MODULE 1
#define CONFIG_SND_AC97_POWER_SAVE 1
#define CONFIG_HAVE_PREEMPT_DYNAMIC_CALL 1
#define CONFIG_CAN_F81601_MODULE 1
#define CONFIG_HAVE_GENERIC_TIF_BITS 1
#define CONFIG_SND_SOC_PCM1681_MODULE 1
#define CONFIG_INTEL_BYTCRC_PWRSRC_MODULE 1
#define CONFIG_SENSORS_LTC2990_MODULE 1
#define CONFIG_MDIO_GPIO_MODULE 1
#define CONFIG_MARVELL_10G_PHY_MODULE 1
#define CONFIG_DA9052_WATCHDOG_MODULE 1
#define CONFIG_SND_SOC_CS530X_I2C_MODULE 1
#define CONFIG_ST_UVIS25_MODULE 1
#define CONFIG_MACB_PCI_MODULE 1
#define CONFIG_VIDEO_SAA7127_MODULE 1
#define CONFIG_MAX11205_MODULE 1
#define CONFIG_MT792x_USB_MODULE 1
#define CONFIG_IP_NF_MATCH_TTL_MODULE 1
#define CONFIG_MMC_TIFM_SD_MODULE 1
#define CONFIG_SND_SOC_SSM2305_MODULE 1
#define CONFIG_FHANDLE 1
#define CONFIG_SND_USB_HIFACE_MODULE 1
#define CONFIG_XFS_SUPPORT_ASCII_CI 1
#define CONFIG_NETFILTER_XT_MATCH_CGROUP_MODULE 1
#define CONFIG_USB_SERIAL_SSU100_MODULE 1
#define CONFIG_SENSORS_G762_MODULE 1
#define CONFIG_SND_SOC_AMD_ACP3x_MODULE 1
#define CONFIG_ARCH_MHP_MEMMAP_ON_MEMORY_ENABLE 1
#define CONFIG_FPGA_DFL_FME_BRIDGE_MODULE 1
#define CONFIG_USB_SERIAL_F81232_MODULE 1
#define CONFIG_NVME_TARGET_FCLOOP_MODULE 1
#define CONFIG_USB_GSPCA_SPCA561_MODULE 1
#define CONFIG_SND_DARLA24_MODULE 1
#define CONFIG_SYS_HYPERVISOR 1
#define CONFIG_SURFACE_AGGREGATOR_MODULE 1
#define CONFIG_SGL_ALLOC 1
#define CONFIG_TYPEC_HD3SS3220_MODULE 1
#define CONFIG_LEDS_BD2802_MODULE 1
#define CONFIG_GENERIC_PCI_IOMAP 1
#define CONFIG_AMD_WBRF 1
#define CONFIG_GPIO_AMDPT_MODULE 1
#define CONFIG_CRYPTO_USER_API_RNG_MODULE 1
#define CONFIG_DVB_STV6110_MODULE 1
#define CONFIG_MLXFW_MODULE 1
#define CONFIG_NF_CT_PROTO_GRE 1
#define CONFIG_BT_HCIBFUSB_MODULE 1
#define CONFIG_SOUND_MODULE 1
#define CONFIG_TOSHIBA_WMI_MODULE 1
#define CONFIG_LOCALVERSION_AUTO 1
#define CONFIG_C2PORT_MODULE 1
#define CONFIG_SENSORS_W83793_MODULE 1
#define CONFIG_INTEL_TDX_HOST 1
#define CONFIG_ZEN_INTERACTIVE 1
#define CONFIG_NET_DSA_TAG_TRAILER_MODULE 1
#define CONFIG_CRAMFS_MODULE 1
#define CONFIG_USB_DWC3_DUAL_ROLE 1
#define CONFIG_SND_AD1889_MODULE 1
#define CONFIG_NLS_MAC_TURKISH_MODULE 1
#define CONFIG_GENERIC_ALLOCATOR 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_RT5682_MODULE 1
#define CONFIG_SND_SOC_SI476X_MODULE 1
#define CONFIG_DVB_TDA1004X_MODULE 1
#define CONFIG_EFI_SBAT_FILE ""
#define CONFIG_HAVE_ARCH_KGDB 1
#define CONFIG_CAN_C_CAN_PLATFORM_MODULE 1
#define CONFIG_HID_HYPERV_MOUSE_MODULE 1
#define CONFIG_KEYBOARD_TWL4030_MODULE 1
#define CONFIG_MTD_NAND_ECC 1
#define CONFIG_SND_USB_USX2Y_MODULE 1
#define CONFIG_NET_INGRESS 1
#define CONFIG_WQ_POWER_EFFICIENT_DEFAULT 1
#define CONFIG_CRYPTO_AEAD2_MODULE 1
#define CONFIG_INFINIBAND_VIRT_DMA 1
#define CONFIG_VIDEO_HI846_MODULE 1
#define CONFIG_MANA_INFINIBAND_MODULE 1
#define CONFIG_GPIO_CRYSTAL_COVE 1
#define CONFIG_DM_PERSISTENT_DATA_MODULE 1
#define CONFIG_TOSHIBA_HAPS_MODULE 1
#define CONFIG_NET_ACT_MPLS_MODULE 1
#define CONFIG_FUNCTION_GRAPH_RETADDR 1
#define CONFIG_VIDEO_TW5864_MODULE 1
#define CONFIG_GENERIC_BUG_RELATIVE_POINTERS 1
#define CONFIG_SND_YMFPCI_MODULE 1
#define CONFIG_CRYPTO_LIB_AESGCM 1
#define CONFIG_KVM_GENERIC_MEMORY_ATTRIBUTES 1
#define CONFIG_ARCH_STACKWALK 1
#define CONFIG_BNXT_MODULE 1
#define CONFIG_SPI 1
#define CONFIG_CHARGER_BQ25890_MODULE 1
#define CONFIG_SND_ATIIXP_MODEM_MODULE 1
#define CONFIG_P54_PCI_MODULE 1
#define CONFIG_NODES_SHIFT 10
#define CONFIG_LCD_PLATFORM_MODULE 1
#define CONFIG_USB_HIDDEV 1
#define CONFIG_CEC_CH7322_MODULE 1
#define CONFIG_RPMSG_QCOM_GLINK_MODULE 1
#define CONFIG_MITIGATION_CALL_DEPTH_TRACKING 1
#define CONFIG_GPIO_GRANITERAPIDS_MODULE 1
#define CONFIG_SENSORS_IT87_MODULE 1
#define CONFIG_TCM_FILEIO_MODULE 1
#define CONFIG_HID_U2FZERO_MODULE 1
#define CONFIG_BACKLIGHT_KTD253_MODULE 1
#define CONFIG_TOUCHSCREEN_ZFORCE_MODULE 1
#define CONFIG_WIZNET_W5100_MODULE 1
#define CONFIG_HFS_FS_MODULE 1
#define CONFIG_HAVE_ARCH_MMAP_RND_BITS 1
#define CONFIG_LEDS_SIEMENS_SIMATIC_IPC_APOLLOLAKE_MODULE 1
#define CONFIG_SND_FM801_MODULE 1
#define CONFIG_CC_OPTIMIZE_FOR_PERFORMANCE_O3 1
#define CONFIG_HAVE_PERF_REGS 1
#define CONFIG_USB_NET2280_MODULE 1
#define CONFIG_HW_RANDOM_XIPHERA_MODULE 1
#define CONFIG_GENERIC_PENDING_IRQ 1
#define CONFIG_QCOM_EMAC_MODULE 1
#define CONFIG_LENOVO_WMI_CAPDATA_MODULE 1
#define CONFIG_RTW89_USB_MODULE 1
#define CONFIG_CXL_FEATURES 1
#define CONFIG_SKFP_MODULE 1
#define CONFIG_APPLE_PROPERTIES 1
#define CONFIG_CRYPTO_DF80090A 1
#define CONFIG_MOTORCOMM_PHY_MODULE 1
#define CONFIG_VIDEO_AD5820_MODULE 1
#define CONFIG_PPS_GENERATOR_MODULE 1
#define CONFIG_VIDEO_MT9T112_MODULE 1
#define CONFIG_RESET_TI_SYSCON_MODULE 1
#define CONFIG_DVB_STB0899_MODULE 1
#define CONFIG_AD7292_MODULE 1
#define CONFIG_SND_SOC_SOF_DEBUG_PROBES_MODULE 1
#define CONFIG_SND_SOC_WM8731_I2C_MODULE 1
#define CONFIG_SND_SOC_CS35L41_SPI_MODULE 1
#define CONFIG_PAGE_SIZE_LESS_THAN_256KB 1
#define CONFIG_IPV6_SIT_6RD 1
#define CONFIG_FUSE_DAX 1
#define CONFIG_LIVEUPDATE_MEMFD 1
#define CONFIG_HAS_IOPORT 1
#define CONFIG_REGULATOR_RT5759_MODULE 1
#define CONFIG_NET_9P_USBG_MODULE 1
#define CONFIG_HAVE_JUMP_LABEL_HACK 1
#define CONFIG_STRICT_MODULE_RWX 1
#define CONFIG_MCP4531_MODULE 1
#define CONFIG_IXGBEVF_MODULE 1
#define CONFIG_SENSORS_XDPE122_REGULATOR 1
#define CONFIG_CXL_BUS_MODULE 1
#define CONFIG_MAC802154_MODULE 1
#define CONFIG_USB_NET_SR9700_MODULE 1
#define CONFIG_PCS_MTK_LYNXI_MODULE 1
#define CONFIG_FXOS8700_MODULE 1
#define CONFIG_AD7944_MODULE 1
#define CONFIG_LIBERTAS_SPI_MODULE 1
#define CONFIG_PCI 1
#define CONFIG_SENSORS_PMBUS_MODULE 1
#define CONFIG_USB_OHCI_HCD_PCI 1
#define CONFIG_SND_OPL3_LIB_SEQ_MODULE 1
#define CONFIG_USB_GSPCA_CPIA1_MODULE 1
#define CONFIG_CLANG_VERSION 0
#define CONFIG_DEV_DAX_MODULE 1
#define CONFIG_REGULATOR_ARIZONA_MICSUPP_MODULE 1
#define CONFIG_CEC_NOTIFIER 1
#define CONFIG_BRIDGE_EBT_MARK_MODULE 1
#define CONFIG_BATTERY_UG3105_MODULE 1
#define CONFIG_IT8712F_WDT_MODULE 1
#define CONFIG_HSC030PA_SPI_MODULE 1
#define CONFIG_B43_MODULE 1
#define CONFIG_DM_CACHE_MODULE 1
#define CONFIG_NETFILTER_XTABLES_COMPAT 1
#define CONFIG_GPIB_NEC7210_MODULE 1
#define CONFIG_ATH6KL_TRACING 1
#define CONFIG_B43_SSB 1
#define CONFIG_SCD30_I2C_MODULE 1
#define CONFIG_SBP_TARGET_MODULE 1
#define CONFIG_BMI270_SPI_MODULE 1
#define CONFIG_DVB_HELENE_MODULE 1
#define CONFIG_SECURITY_APPARMOR_INTROSPECT_POLICY 1
#define CONFIG_HAVE_ARCH_WITHIN_STACK_FRAMES 1
#define CONFIG_ARCH_HAS_ELF_RANDOMIZE 1
#define CONFIG_NFS_V4_1_IMPLEMENTATION_ID_DOMAIN "kernel.org"
#define CONFIG_SCSI 1
#define CONFIG_X86_REQUIRED_FEATURE_PAE 1
#define CONFIG_DVB_ZL10036_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_IPRANGE_MODULE 1
#define CONFIG_NF_CONNTRACK_TIMESTAMP 1
#define CONFIG_BOOT_VESA_SUPPORT 1
#define CONFIG_SENSORS_SHT4x_MODULE 1
#define CONFIG_SND_SOC_MAX9867_MODULE 1
#define CONFIG_INPUT_LEDS 1
#define CONFIG_USB_RTL8153_ECM_MODULE 1
#define CONFIG_IIO_CROS_EC_SENSORS_CORE_MODULE 1
#define CONFIG_SND_SOC_WCD_COMMON_MODULE 1
#define CONFIG_USB_CHIPIDEA_GENERIC_MODULE 1
#define CONFIG_SQUASHFS_DECOMP_MULTI 1
#define CONFIG_MAGIC_SYSRQ 1
#define CONFIG_GENERIC_CALIBRATE_DELAY 1
#define CONFIG_CRYPTO_KDF800108_CTR 1
#define CONFIG_REGULATOR_RT5739_MODULE 1
#define CONFIG_NET_VENDOR_SOLARFLARE 1
#define CONFIG_MAGIC_SYSRQ_SERIAL_SEQUENCE ""
#define CONFIG_BT_BNEP_MC_FILTER 1
#define CONFIG_SENSORS_MAX34440_MODULE 1
#define CONFIG_CRC7_MODULE 1
#define CONFIG_MEDIA_ANALOG_TV_SUPPORT 1
#define CONFIG_HAVE_KVM_IRQCHIP 1
#define CONFIG_SND_DEBUG 1
#define CONFIG_LD_ORPHAN_WARN_LEVEL "warn"
#define CONFIG_USB_OHCI_HCD_PLATFORM_MODULE 1
#define CONFIG_PCI_MESON_MODULE 1
#define CONFIG_AIX_PARTITION 1
#define CONFIG_RTW88_8703B_MODULE 1
#define CONFIG_DVB_TDA10071_MODULE 1
#define CONFIG_I2C_MUX_REG_MODULE 1
#define CONFIG_FONTS 1
#define CONFIG_MEDIA_TUNER_FC2580_MODULE 1
#define CONFIG_XEN_BALLOON 1
#define CONFIG_TOUCHSCREEN_USB_JASTEC 1
#define CONFIG_SFC_SIENA_MODULE 1
#define CONFIG_CC_HAS_ASM_GOTO_OUTPUT 1
#define CONFIG_64BIT 1
#define CONFIG_I2C_MUX_LTC4306_MODULE 1
#define CONFIG_INFINIBAND_USNIC_MODULE 1
#define CONFIG_SENSORS_WM8350_MODULE 1
#define CONFIG_USB_CONFIGFS_ECM_SUBSET 1
#define CONFIG_DVB_IX2505V_MODULE 1
#define CONFIG_USB_OHCI_LITTLE_ENDIAN 1
#define CONFIG_ISO9660_FS_MODULE 1
#define CONFIG_UNIX_DIAG_MODULE 1
#define CONFIG_TCG_TIS_SPI_CR50 1
#define CONFIG_QTNFMAC_MODULE 1
#define CONFIG_PHY_PACKAGE_MODULE 1
#define CONFIG_NFS_SWAP 1
#define CONFIG_SND_HDA_GENERIC_LEDS 1
#define CONFIG_DVB_VES1820_MODULE 1
#define CONFIG_SENSORS_LM85_MODULE 1
#define CONFIG_SND_SOC_CHV3_I2S_MODULE 1
#define CONFIG_AD5758_MODULE 1
#define CONFIG_APDS9306_MODULE 1
#define CONFIG_SND_SOC_SOF_HDA_MODULE 1
#define CONFIG_DMA_OPS_HELPERS 1
#define CONFIG_VIDEOBUF2_DVB_MODULE 1
#define CONFIG_DVB_STV0299_MODULE 1
#define CONFIG_I2C_I801_MUX 1
#define CONFIG_IP_SCTP_MODULE 1
#define CONFIG_XEN_PV 1
#define CONFIG_IP_VS_PROTO_SCTP 1
#define CONFIG_MFD_MADERA_SPI_MODULE 1
#define CONFIG_BATTERY_BQ27XXX_MODULE 1
#define CONFIG_SENSORS_ATK0110_MODULE 1
#define CONFIG_IP_VS_TWOS_MODULE 1
#define CONFIG_SENSORS_LTC2991_MODULE 1
#define CONFIG_GENERIC_CLOCKEVENTS_COUPLED 1
#define CONFIG_USB_GADGET_STORAGE_NUM_BUFFERS 2
#define CONFIG_RADIO_MAXIRADIO_MODULE 1
#define CONFIG_PM_DEBUG 1
#define CONFIG_VIDEOBUF2_DMA_SG_MODULE 1
#define CONFIG_NET_DSA_SMSC_LAN9303_MDIO_MODULE 1
#define CONFIG_DPTF_PCH_FIVR_MODULE 1
#define CONFIG_HAVE_STATIC_CALL_INLINE 1
#define CONFIG_MMC_SDHCI_XENON_MODULE 1
#define CONFIG_USB_F_UAC1_MODULE 1
#define CONFIG_NET_VENDOR_TI 1
#define CONFIG_RAVE_SP_CORE_MODULE 1
#define CONFIG_BLK_CGROUP 1
#define CONFIG_HARDLOCKUP_CHECK_TIMESTAMP 1
#define CONFIG_BNX2X_SRIOV 1
#define CONFIG_SND_HDA_CODEC_REALTEK_LIB_MODULE 1
#define CONFIG_AGP_SIS_MODULE 1
#define CONFIG_SIEMENS_SIMATIC_IPC_MODULE 1
#define CONFIG_HAVE_ARCH_KFENCE 1
#define CONFIG_RUSTC_HAS_FILE_WITH_NUL 1
#define CONFIG_HYPERV_NET_MODULE 1
#define CONFIG_AL3010_MODULE 1
#define CONFIG_HID_CORSAIR_MODULE 1
#define CONFIG_IPV6_VTI_MODULE 1
#define CONFIG_RTL8XXXU_UNTESTED 1
#define CONFIG_MICROCHIP_PHY_RDS_PTP_MODULE 1
#define CONFIG_PERSISTENT_HUGE_ZERO_FOLIO 1
#define CONFIG_U_SERIAL_CONSOLE 1
#define CONFIG_HID_NTI_MODULE 1
#define CONFIG_DECOMPRESS_ZSTD 1
#define CONFIG_SND_SOC_WM8770_MODULE 1
#define CONFIG_NF_LOG_ARP_MODULE 1
#define CONFIG_SND_SOC_AW8738_MODULE 1
#define CONFIG_EBC_C384_WDT_MODULE 1
#define CONFIG_MTD_MAP_BANK_WIDTH_4 1
#define CONFIG_NF_NAT_AMANDA_MODULE 1
#define CONFIG_SND_UTIMER 1
#define CONFIG_OLD_SIGSUSPEND3 1
#define CONFIG_CROS_EC_WATCHDOG_MODULE 1
#define CONFIG_MAX11410_MODULE 1
#define CONFIG_NET_TEAM_MODULE 1
#define CONFIG_LEDS_MAX77705_MODULE 1
#define CONFIG_SSB_PCIHOST_POSSIBLE 1
#define CONFIG_REGULATOR_MAX1586_MODULE 1
#define CONFIG_SND_HDA_CODEC_ANALOG_MODULE 1
#define CONFIG_CXL_MCE 1
#define CONFIG_XPS 1
#define CONFIG_W83977F_WDT_MODULE 1
#define CONFIG_6LOWPAN_GHC_EXT_HDR_FRAG_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_STATISTIC_MODULE 1
#define CONFIG_ZRAM_BACKEND_LZ4 1
#define CONFIG_KVM_IOAPIC 1
#define CONFIG_SPI_ALTERA_MODULE 1
#define CONFIG_VIRTIO_VDPA_MODULE 1
#define CONFIG_REGULATOR_MT6397_MODULE 1
#define CONFIG_COMPAT_32BIT_TIME 1
#define CONFIG_MMA9551_MODULE 1
#define CONFIG_POWER_RESET_RESTART 1
#define CONFIG_SENSORS_SCH5627_MODULE 1
#define CONFIG_HOTPLUG_CPU 1
#define CONFIG_NFS_FSCACHE 1
#define CONFIG_INTEL_ATOMISP2_PDX86 1
#define CONFIG_PAGE_POOL_STATS 1
#define CONFIG_WANT_DEV_COREDUMP 1
#define CONFIG_NET_IPGRE_DEMUX_MODULE 1
#define CONFIG_USB_LIBCOMPOSITE_MODULE 1
#define CONFIG_SENSORS_MPQ7932_MODULE 1
#define CONFIG_HAVE_KVM_ARCH_GMEM_POPULATE 1
#define CONFIG_SND_SOC_INTEL_BYT_CHT_DA7213_MACH_MODULE 1
#define CONFIG_JOYSTICK_GF2K_MODULE 1
#define CONFIG_DVB_PT1_MODULE 1
#define CONFIG_MISC_ALCOR_PCI_MODULE 1
#define CONFIG_UNWIND_USER 1
#define CONFIG_RANDOMIZE_BASE 1
#define CONFIG_BHYVE_GUEST 1
#define CONFIG_INTEGRITY_TRUSTED_KEYRING 1
#define CONFIG_NET_VENDOR_PENSANDO 1
#define CONFIG_VIDEO_HI847_MODULE 1
#define CONFIG_SERIAL_8250_DFL_MODULE 1
#define CONFIG_CRYPTO_SM4_AESNI_AVX2_X86_64_MODULE 1
#define CONFIG_F2FS_FS_ZSTD 1
#define CONFIG_SENSORS_SCH5636_MODULE 1
#define CONFIG_BLK_DEV_NVME_MODULE 1
#define CONFIG_MFD_CS47L24 1
#define CONFIG_BT_HCIUART_AML 1
#define CONFIG_NET_DSA_VITESSE_VSC73XX_PLATFORM_MODULE 1
#define CONFIG_SPI_BUTTERFLY_MODULE 1
#define CONFIG_PHONET_MODULE 1
#define CONFIG_SENSORS_LM73_MODULE 1
#define CONFIG_AMDTEE_MODULE 1
#define CONFIG_EFI_HANDOVER_PROTOCOL 1
#define CONFIG_DVB_USB_VP7045_MODULE 1
#define CONFIG_ARCH_HAS_SET_MEMORY 1
#define CONFIG_SND_SOC_SDCA_MODULE 1
#define CONFIG_DVB_USB_DTT200U_MODULE 1
#define CONFIG_PSTORE_BLK_MAX_REASON 2
#define CONFIG_HID_CHERRY_MODULE 1
#define CONFIG_MAC80211_MESH 1
#define CONFIG_BLK_WBT 1
#define CONFIG_REGMAP_W1_MODULE 1
#define CONFIG_SATA_SIS_MODULE 1
#define CONFIG_TASKS_RUDE_RCU 1
#define CONFIG_AS21XXX_PHY_MODULE 1
#define CONFIG_MTD_UBI_WL_THRESHOLD 4096
#define CONFIG_REGMAP_SOUNDWIRE_MBQ_MODULE 1
#define CONFIG_USB_SERIAL_WWAN_MODULE 1
#define CONFIG_IP_SET_HASH_NETPORT_MODULE 1
#define CONFIG_SND_SOC_SDCA_HID 1
#define CONFIG_YENTA_ENE_TUNE 1
#define CONFIG_SERIO_PS2MULT_MODULE 1
#define CONFIG_MFD_TPS65090 1
#define CONFIG_NET_ACT_SAMPLE_MODULE 1
#define CONFIG_SND_SOC_AK4613_MODULE 1
#define CONFIG_FXLS8962AF_I2C_MODULE 1
#define CONFIG_EROFS_FS_ZIP_LZMA_DEFAULT_MAX_STREAMS 16
#define CONFIG_XEN_BALLOON_MEMORY_HOTPLUG 1
#define CONFIG_USB_ARMLINUX 1
#define CONFIG_ZEROPLUS_FF 1
#define CONFIG_HID_KEYTOUCH_MODULE 1
#define CONFIG_RTW89_8852CE_MODULE 1
#define CONFIG_SND_SOC_PCM512x_SPI_MODULE 1
#define CONFIG_REGULATOR_PWM_MODULE 1
#define CONFIG_SND_SOC_AC97_CODEC_MODULE 1
#define CONFIG_INPUT_ATC260X_ONKEY_MODULE 1
#define CONFIG_INFINEON_TLV493D_MODULE 1
#define CONFIG_SMSC_PHY_MODULE 1
#define CONFIG_GPIO_XRA1403_MODULE 1
#define CONFIG_BLK_INLINE_ENCRYPTION 1
#define CONFIG_SND_SOC_DMIC_MODULE 1
#define CONFIG_AD7293_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_ADDRTYPE_MODULE 1
#define CONFIG_SENSORS_LTC4260_MODULE 1
#define CONFIG_CC_CAN_LINK 1
#define CONFIG_BT_MTKSDIO_MODULE 1
#define CONFIG_USB_FUNCTIONFS_GENERIC 1
#define CONFIG_FUNCTION_PADDING_CFI 11
#define CONFIG_B53_MODULE 1
#define CONFIG_X86_REROUTE_FOR_BROKEN_BOOT_IRQS 1
#define CONFIG_JOYSTICK_IFORCE_USB_MODULE 1
#define CONFIG_MT7925_COMMON_MODULE 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_MAX98927_MODULE 1
#define CONFIG_CHARGER_MAX77976_MODULE 1
#define CONFIG_NF_LOG_IPV6_MODULE 1
#define CONFIG_CC_HAS_AUTO_VAR_INIT_ZERO_BARE 1
#define CONFIG_MMC_VUB300_MODULE 1
#define CONFIG_IPMI_PLAT_DATA 1
#define CONFIG_SND_AMD_ACP_CONFIG_MODULE 1
#define CONFIG_RTC_DRV_S35390A_MODULE 1
#define CONFIG_KERNFS 1
#define CONFIG_DRM_MGAG200_MODULE 1
#define CONFIG_PARAVIRT_SPINLOCKS 1
#define CONFIG_SND_SOC_TLV320AIC32X4_MODULE 1
#define CONFIG_DM_MULTIPATH_HST_MODULE 1
#define CONFIG_6LOWPAN_NHC_UDP_MODULE 1
#define CONFIG_SERIO_SERPORT_MODULE 1
#define CONFIG_ACPI_APEI_MEMORY_FAILURE 1
#define CONFIG_TOUCHSCREEN_GUNZE_MODULE 1
#define CONFIG_INPUT_SOC_BUTTON_ARRAY_MODULE 1
#define CONFIG_RD_XZ 1
#define CONFIG_HAVE_PAGE_SIZE_4KB 1
#define CONFIG_DRM_AMDGPU_CIK 1
#define CONFIG_VIDEO_TW68_MODULE 1
#define CONFIG_VIDEO_V4L2_I2C 1
#define CONFIG_ARCH_WANTS_DYNAMIC_TASK_STRUCT 1
#define CONFIG_IIO_ADIS_LIB_MODULE 1
#define CONFIG_UIO_PDRV_GENIRQ_MODULE 1
#define CONFIG_DEFAULT_FQ_CODEL 1
#define CONFIG_AMD_HSMP_PLAT_MODULE 1
#define CONFIG_MSDOS_FS_MODULE 1
#define CONFIG_ADMFM2000_MODULE 1
#define CONFIG_USB_ULPI_BUS_MODULE 1
#define CONFIG_PERF_EVENTS_INTEL_RAPL_MODULE 1
#define CONFIG_DM_EBS_MODULE 1
#define CONFIG_SECURITY_TOMOYO_POLICY_LOADER "/usr/bin/tomoyo-init"
#define CONFIG_ARCH_PKEY_BITS 4
#define CONFIG_EFI_RUNTIME_MAP 1
#define CONFIG_JOYSTICK_WARRIOR_MODULE 1
#define CONFIG_CRYPTO_AEGIS128_AESNI_SSE2_MODULE 1
#define CONFIG_STM_SOURCE_CONSOLE_MODULE 1
#define CONFIG_TOUCHSCREEN_DMI 1
#define CONFIG_PCIEAER 1
#define CONFIG_IP_VS_SH_TAB_BITS 8
#define CONFIG_BE2NET_SKYHAWK 1
#define CONFIG_SND_MTPAV_MODULE 1
#define CONFIG_DVB_S5H1411_MODULE 1
#define CONFIG_ATH6KL_SDIO_MODULE 1
#define CONFIG_HAVE_SCHED_AVG_IRQ 1
#define CONFIG_TI_ADS124S08_MODULE 1
#define CONFIG_CRC_ITU_T_MODULE 1
#define CONFIG_TOUCHSCREEN_INEXIO_MODULE 1
#define CONFIG_PFCP_MODULE 1
#define CONFIG_SCSI_SRP_ATTRS_MODULE 1
#define CONFIG_BALLOON 1
#define CONFIG_SND_ECHO3G_MODULE 1
#define CONFIG_KEYBOARD_QT1050_MODULE 1
#define CONFIG_PCI_MMCONFIG 1
#define CONFIG_SSB_SDIOHOST_POSSIBLE 1
#define CONFIG_RTC_DRV_RX6110_MODULE 1
#define CONFIG_DEVFREQ_GOV_PERFORMANCE_MODULE 1
#define CONFIG_SENSORS_UCD9200_MODULE 1
#define CONFIG_AMD_HSMP_MODULE 1
#define CONFIG_SENSORS_RM3100_MODULE 1
#define CONFIG_INFINIBAND_RTRS_MODULE 1
#define CONFIG_MFD_MADERA_MODULE 1
#define CONFIG_IP_FIB_TRIE_STATS 1
#define CONFIG_RPMSG_NS_MODULE 1
#define CONFIG_KEYBOARD_MPR121_MODULE 1
#define CONFIG_PROC_PAGE_MONITOR 1
#define CONFIG_FUN_ETH_MODULE 1
#define CONFIG_HAVE_ARCH_SECCOMP_FILTER 1
#define CONFIG_NET_DSA_TAG_OCELOT_MODULE 1
#define CONFIG_HAVE_SINGLE_FTRACE_DIRECT_OPS 1
#define CONFIG_SPEAKUP_SYNTH_DUMMY_MODULE 1
#define CONFIG_DEBUG_BUGVERBOSE 1
#define CONFIG_RUSTC_HAS_FILE_AS_C_STR 1
#define CONFIG_PLAYSTATION_FF 1
#define CONFIG_SND_SOC_MAX98373_SDW_MODULE 1
#define CONFIG_SENSORS_MP2888_MODULE 1
#define CONFIG_ARCH_HAS_CPU_ATTACK_VECTORS 1
#define CONFIG_ATH9K_COMMON_DEBUG 1
#define CONFIG_EXT4_USE_FOR_EXT2 1
#define CONFIG_USB_PEGASUS_MODULE 1
#define CONFIG_PTP_1588_CLOCK_IDTCM_MODULE 1
#define CONFIG_UIO_PCI_GENERIC_MODULE 1
#define CONFIG_I2C_SIS630_MODULE 1
#define CONFIG_SLAB_FREELIST_RANDOM 1
#define CONFIG_TCG_NSC_MODULE 1
#define CONFIG_FXAS21002C_SPI_MODULE 1
#define CONFIG_ARCH_SUSPEND_POSSIBLE 1
#define CONFIG_USB_IDMOUSE_MODULE 1
#define CONFIG_X86_AMD_PLATFORM_DEVICE 1
#define CONFIG_KPROBES 1
#define CONFIG_TOUCHSCREEN_IQS7211_MODULE 1
#define CONFIG_RT_MUTEXES 1
#define CONFIG_UPROBE_EVENTS 1
#define CONFIG_USB_F_UAC2_MODULE 1
#define CONFIG_PCI_DOE 1
#define CONFIG_BLK_CGROUP_IOLATENCY 1
#define CONFIG_CEC_PIN 1
#define CONFIG_MFD_WM8997 1
#define CONFIG_BPF_KPROBE_OVERRIDE 1
#define CONFIG_INTEL_MEI_PXP_MODULE 1
#define CONFIG_GENERIC_VDSO_OVERFLOW_PROTECT 1
#define CONFIG_NET_VENDOR_XIRCOM 1
#define CONFIG_CHELSIO_T4VF_MODULE 1
#define CONFIG_NET_IFE_MODULE 1
#define CONFIG_HVC_XEN 1
#define CONFIG_CHARGER_AXP20X_MODULE 1
#define CONFIG_RD_LZ4 1
#define CONFIG_SND_HDA_SCODEC_CS35L56_SPI_MODULE 1
#define CONFIG_USB_SERIAL_EDGEPORT_MODULE 1
#define CONFIG_SPI_MICROCHIP_CORE_SPI_MODULE 1
#define CONFIG_PLFXLC_MODULE 1
#define CONFIG_SECURITY_TOMOYO 1
#define CONFIG_IPMI_SSIF_MODULE 1
#define CONFIG_IEEE802154_AT86RF230_MODULE 1
#define CONFIG_NET_DSA_XRS700X_MDIO_MODULE 1
#define CONFIG_SENSORS_LIS3_I2C_MODULE 1
#define CONFIG_DVB_MXL692_MODULE 1
#define CONFIG_VIDEO_CX231XX_ALSA_MODULE 1
#define CONFIG_MFD_SY7636A_MODULE 1
#define CONFIG_IOMMU_PT 1
#define CONFIG_DEFAULT_HOSTNAME "archlinux"
#define CONFIG_VFIO_PCI_INTX 1
#define CONFIG_MLX5_MACSEC 1
#define CONFIG_GENERIC_NET_UTILS 1
#define CONFIG_REGULATOR_TPS65132_MODULE 1
#define CONFIG_PINCTRL_SUNRISEPOINT_MODULE 1
#define CONFIG_USB_CONN_GPIO_MODULE 1
#define CONFIG_KVM_AMD_SEV 1
#define CONFIG_LMP91000_MODULE 1
#define CONFIG_DM_ERA_MODULE 1
#define CONFIG_RTW88_8812AU_MODULE 1
#define CONFIG_RTC_DRV_RX8010_MODULE 1
#define CONFIG_GENERIC_ISA_DMA 1
#define CONFIG_IP_VS_WRR_MODULE 1
#define CONFIG_SYSFB 1
#define CONFIG_LEDS_TRIGGER_ONESHOT_MODULE 1
#define CONFIG_NVDIMM_PFN 1
#define CONFIG_SECURITY_SELINUX 1
#define CONFIG_BLK_DEV_DRBD_MODULE 1
#define CONFIG_INPUT_JOYSTICK 1
#define CONFIG_BLK_DEV_DM_BUILTIN 1
#define CONFIG_DRM_DISPLAY_DSC_HELPER 1
#define CONFIG_MSI_EC_MODULE 1
#define CONFIG_SMARTJOYPLUS_FF 1
#define CONFIG_HSU_DMA_MODULE 1
#define CONFIG_IP5XXX_POWER_MODULE 1
#define CONFIG_VMWARE_VMCI_MODULE 1
#define CONFIG_SCSI_LOWLEVEL 1
#define CONFIG_SENSORS_LM63_MODULE 1
#define CONFIG_AMILO_RFKILL_MODULE 1
#define CONFIG_SND_SOC_WCD937X_SDW_MODULE 1
#define CONFIG_INTERVAL_TREE 1
#define CONFIG_GPIO_TWL6040_MODULE 1
#define CONFIG_ADIN1110_MODULE 1
#define CONFIG_RTC_DRV_PCF8563_MODULE 1
#define CONFIG_FUSION_FC_MODULE 1
#define CONFIG_CLK_TWL_MODULE 1
#define CONFIG_W1_SLAVE_DS2805_MODULE 1
#define CONFIG_SPARSEMEM 1
#define CONFIG_CXL_PMU_MODULE 1
#define CONFIG_BCACHE_MODULE 1
#define CONFIG_CRYPTO_DEV_ATMEL_SHA204A_MODULE 1
#define CONFIG_INPUT_IQS7222_MODULE 1
#define CONFIG_HVC_DRIVER 1
#define CONFIG_BLK_CGROUP_IOCOST 1
#define CONFIG_NLS_MAC_GAELIC_MODULE 1
#define CONFIG_NFP_NET_IPSEC 1
#define CONFIG_MFD_INTEL_LPSS_MODULE 1
#define CONFIG_NET_VENDOR_BROADCOM 1
#define CONFIG_SPEAKUP_SYNTH_SPKOUT_MODULE 1
#define CONFIG_RTC_SYSTOHC_DEVICE "rtc0"
#define CONFIG_DEV_DAX_HMEM_DEVICES 1
#define CONFIG_RTC_DRV_RX4581_MODULE 1
#define CONFIG_INPUT_GPIO_VIBRA_MODULE 1
#define CONFIG_OSNOISE_TRACER 1
#define CONFIG_RTC_INTF_PROC 1
#define CONFIG_USB_CHIPIDEA_NPCM_MODULE 1
#define CONFIG_RC_LOOPBACK_MODULE 1
#define CONFIG_AUTOFS_FS 1
#define CONFIG_AD5791_MODULE 1
#define CONFIG_DVB_CX24123_MODULE 1
#define CONFIG_SND_HDA_CODEC_ALC861_MODULE 1
#define CONFIG_LD_CAN_USE_KEEP_IN_OVERLAY 1
#define CONFIG_SND_FIREWORKS_MODULE 1
#define CONFIG_CHARGER_ISP1704_MODULE 1
#define CONFIG_I2C_SIMTEC_MODULE 1
#define CONFIG_IPV6_MROUTE_MULTIPLE_TABLES 1
#define CONFIG_FUNCTION_PROFILER 1
#define CONFIG_ACQUIRE_WDT_MODULE 1
#define CONFIG_BT_BREDR 1
#define CONFIG_SND_SOC_AUDIO_IIO_AUX_MODULE 1
#define CONFIG_TYPEC_DP_ALTMODE_MODULE 1
#define CONFIG_KVM_GUEST_MEMFD 1
#define CONFIG_XFRM_ESPINTCP 1
#define CONFIG_LEDS_LP3952_MODULE 1
#define CONFIG_ARCH_WANTS_NO_INSTR 1
#define CONFIG_NET_DSA_QCA8K_MODULE 1
#define CONFIG_USB_HID 1
#define CONFIG_SMSC911X_MODULE 1
#define CONFIG_SFC_MCDI_MON 1
#define CONFIG_MITIGATION_SRSO 1
#define CONFIG_SND_ES1968_RADIO 1
#define CONFIG_USB_HSO_MODULE 1
#define CONFIG_NFT_BRIDGE_REJECT_MODULE 1
#define CONFIG_GPIO_PCIE_IDIO_24_MODULE 1
#define CONFIG_SND_HDA_RECONFIG 1
#define CONFIG_ENS160_MODULE 1
#define CONFIG_AD9467_MODULE 1
#define CONFIG_PARMAN_MODULE 1
#define CONFIG_IIO_BUFFER_CB_MODULE 1
#define CONFIG_CRYPTO_SKCIPHER2 1
#define CONFIG_MTD_MODULE 1
#define CONFIG_SENSORS_LTC4261_MODULE 1
#define CONFIG_SND_SOC_CS42L83_MODULE 1
#define CONFIG_IT87_WDT_MODULE 1
#define CONFIG_GPIO_NCT6694_MODULE 1
#define CONFIG_CHARGER_TWL4030_MODULE 1
#define CONFIG_SND_HDA_SCODEC_TAS2781_MODULE 1
#define CONFIG_PCI_MSI 1
#define CONFIG_SRF08_MODULE 1
#define CONFIG_UBIFS_ATIME_SUPPORT 1
#define CONFIG_SND_SOC_MAX98373_MODULE 1
#define CONFIG_RMI4_CORE_MODULE 1
#define CONFIG_PATA_PDC2027X_MODULE 1
#define CONFIG_HAVE_GENERIC_VDSO 1
#define CONFIG_MFD_LM3533_MODULE 1
#define CONFIG_INTEL_SOC_PMIC_BXTWC_MODULE 1
#define CONFIG_SND_HDA_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_PANJIT 1
#define CONFIG_VIDEO_DW9719_MODULE 1
#define CONFIG_SND_SOC_RT5682_I2C_MODULE 1
#define CONFIG_WLAN_VENDOR_PURELIFI 1
#define CONFIG_NF_TABLES_ARP 1
#define CONFIG_TMPFS_POSIX_ACL 1
#define CONFIG_PCMCIA_XIRCOM_MODULE 1
#define CONFIG_VIDEO_OV08D10_MODULE 1
#define CONFIG_PCIE_DW_PLAT_HOST 1
#define CONFIG_MODULES_TREE_LOOKUP 1
#define CONFIG_GOOGLE_CBMEM_MODULE 1
#define CONFIG_CGROUP_DMEM 1
#define CONFIG_SENSORS_ADP1050_REGULATOR 1
#define CONFIG_FW_LOADER_PAGED_BUF 1
#define CONFIG_AIC79XX_DEBUG_MASK 0
#define CONFIG_IRQ_MSI_LIB 1
#define CONFIG_NILFS2_FS_MODULE 1
#define CONFIG_IP_VS_PE_SIP_MODULE 1
#define CONFIG_USB_SERIAL_KOBIL_SCT_MODULE 1
#define CONFIG_BATMAN_ADV_MODULE 1
#define CONFIG_NXP_C45_TJA11XX_PHY_MODULE 1
#define CONFIG_SATA_INIC162X_MODULE 1
#define CONFIG_SND_SOC_RTQ9128_MODULE 1
#define CONFIG_SND_SOC_SOF_AMD_ACP63_MODULE 1
#define CONFIG_X86_VMX_FEATURE_NAMES 1
#define CONFIG_NVMEM_RMEM_MODULE 1
#define CONFIG_USB_NET_CDC_EEM_MODULE 1
#define CONFIG_BMI160_I2C_MODULE 1
#define CONFIG_YOGABOOK_MODULE 1
#define CONFIG_SND_VIA82XX_MODEM_MODULE 1
#define CONFIG_MEDIA_TUNER_E4000_MODULE 1
#define CONFIG_RTC_DRV_DS1286_MODULE 1
#define CONFIG_INTEGRITY_SIGNATURE 1
#define CONFIG_STM_SOURCE_FTRACE_MODULE 1
#define CONFIG_RTL8723AE_MODULE 1
#define CONFIG_REGULATOR_MP8859_MODULE 1
#define CONFIG_SND_HDA_CODEC_HDMI_TEGRA_MODULE 1
#define CONFIG_DRM_CLIENT_DEFAULT_FBDEV 1
#define CONFIG_SND_AU8820_MODULE 1
#define CONFIG_SENSORS_TDA38640_REGULATOR 1
#define CONFIG_CPU_FREQ_GOV_USERSPACE 1
#define CONFIG_CHELSIO_T4_FCOE 1
#define CONFIG_BACKLIGHT_LM3533_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_ETT_TC45USB 1
#define CONFIG_SWITCHTEC_DMA_MODULE 1
#define CONFIG_SND_SOC_ADAU1372_SPI_MODULE 1
#define CONFIG_RTW88_DEBUGFS 1
#define CONFIG_INPUT_TWL6040_VIBRA_MODULE 1
#define CONFIG_SND_SOC_WSA883X_MODULE 1
#define CONFIG_SCSI_SYM53C8XX_DEFAULT_TAGS 16
#define CONFIG_IXGBE_DCA 1
#define CONFIG_BLK_DEV_NULL_BLK_MODULE 1
#define CONFIG_IP_VS_PROTO_AH_ESP 1
#define CONFIG_JOLIET 1
#define CONFIG_ACPI_THERMAL_REL_MODULE 1
#define CONFIG_DEVFREQ_THERMAL 1
#define CONFIG_V4L_MEM2MEM_DRIVERS 1
#define CONFIG_INTEL_TH_STH_MODULE 1
#define CONFIG_X86_DIRECT_GBPAGES 1
#define CONFIG_JOYSTICK_IFORCE_232_MODULE 1
#define CONFIG_INFINIBAND_OCRDMA_MODULE 1
#define CONFIG_ACPI_TOSHIBA_MODULE 1
#define CONFIG_EROFS_FS_ZIP 1
#define CONFIG_DVB_S5H1409_MODULE 1
#define CONFIG_SENSORS_LM83_MODULE 1
#define CONFIG_SQUASHFS_DECOMP_MULTI_PERCPU 1
#define CONFIG_B43LEGACY_PIO 1
#define CONFIG_HAVE_DYNAMIC_FTRACE_WITH_DIRECT_CALLS 1
#define CONFIG_ARCH_HAS_PREEMPT_LAZY 1
#define CONFIG_SERIAL_8250_DW_MODULE 1
#define CONFIG_SFC_FALCON_MODULE 1
#define CONFIG_MFD_AAT2870_CORE 1
#define CONFIG_SENSORS_MAX16601_MODULE 1
#define CONFIG_SPI_DW_MMIO_MODULE 1
#define CONFIG_MD_RAID456_MODULE 1
#define CONFIG_I6300ESB_WDT_MODULE 1
#define CONFIG_PATA_PDC_OLD_MODULE 1
#define CONFIG_MMC_WBSD_MODULE 1
#define CONFIG_HW_RANDOM_TPM 1
#define CONFIG_COMPAT_FOR_U64_ALIGNMENT 1
#define CONFIG_ILLEGAL_POINTER_VALUE 0xdead000000000000
#define CONFIG_HI8435_MODULE 1
#define CONFIG_IWLEGACY_DEBUG 1
#define CONFIG_HID_LENOVO_GO_MODULE 1
#define CONFIG_INPUT_MATRIXKMAP_MODULE 1
#define CONFIG_CEPH_LIB_PRETTYDEBUG 1
#define CONFIG_IP_NF_MATCH_AH_MODULE 1
#define CONFIG_GROUP_SCHED_WEIGHT 1
#define CONFIG_MEDIA_TUNER_SIMPLE_MODULE 1
#define CONFIG_UPROBES 1
#define CONFIG_TOUCHSCREEN_CYTTSP_CORE_MODULE 1
#define CONFIG_VP_VDPA_MODULE 1
#define CONFIG_DW_XDATA_PCIE_MODULE 1
#define CONFIG_RTC_DRV_MAX8907_MODULE 1
#define CONFIG_AD525X_DPOT_MODULE 1
#define CONFIG_ADIS16400_MODULE 1
#define CONFIG_ARCH_CORRECT_STACKTRACE_ON_KRETPROBE 1
#define CONFIG_NFT_NAT_MODULE 1
#define CONFIG_ZSWAP_COMPRESSOR_DEFAULT "zstd"
#define CONFIG_VIDEO_CS53L32A_MODULE 1
#define CONFIG_MAX31827_MODULE 1
#define CONFIG_SND_SOC_SOF_LUNARLAKE_MODULE 1
#define CONFIG_VFIO_MDEV_MODULE 1
#define CONFIG_NXP_TJA11XX_PHY_MODULE 1
#define CONFIG_REGULATOR_MAX8998_MODULE 1
#define CONFIG_NF_CONNTRACK_ZONES 1
#define CONFIG_LEGACY_VSYSCALL_XONLY 1
#define CONFIG_DRM_CLIENT 1
#define CONFIG_SCSI_AM53C974_MODULE 1
#define CONFIG_MFD_SMPRO_MODULE 1
#define CONFIG_USB_UHCI_HCD 1
#define CONFIG_SENSORS_VIA686A_MODULE 1
#define CONFIG_MT76x0E_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_MULTIPORT_MODULE 1
#define CONFIG_EROFS_FS_PCPU_KTHREAD 1
#define CONFIG_IIO_KX022A_I2C_MODULE 1
#define CONFIG_GENERIC_PHY 1
#define CONFIG_FCOE_MODULE 1
#define CONFIG_HYPERV_IOMMU 1
#define CONFIG_XILINX_SDFEC_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_LIMIT_MODULE 1
#define CONFIG_IPV6_MROUTE 1
#define CONFIG_USB_RAINSHADOW_CEC_MODULE 1
#define CONFIG_INET6_TUNNEL_MODULE 1
#define CONFIG_OCFS2_FS_STATS 1
#define CONFIG_GUEST_PERF_EVENTS 1
#define CONFIG_SCSI_ADVANSYS_MODULE 1
#define CONFIG_CRYPTO_SERPENT_AVX2_X86_64_MODULE 1
#define CONFIG_MCP4728_MODULE 1
#define CONFIG_XEN_FBDEV_FRONTEND_MODULE 1
#define CONFIG_MPL3115_MODULE 1
#define CONFIG_DVB_BT8XX_MODULE 1
#define CONFIG_NET_DSA_TAG_MXL_862XX_MODULE 1
#define CONFIG_VIDEO_ET8EK8_MODULE 1
#define CONFIG_MT7925U_MODULE 1
#define CONFIG_IWL3945_MODULE 1
#define CONFIG_USB_EHCI_FSL_MODULE 1
#define CONFIG_DUMMY_CONSOLE 1
#define CONFIG_MFD_TI_LMU_MODULE 1
#define CONFIG_RTL_CARDS_MODULE 1
#define CONFIG_JOYSTICK_TURBOGRAFX_MODULE 1
#define CONFIG_VFIO_PCI_IGD 1
#define CONFIG_PANTHERLORD_FF 1
#define CONFIG_DVB_TUNER_DIB0090_MODULE 1
#define CONFIG_USB_F_TCM_MODULE 1
#define CONFIG_HAVE_ARCH_TRACEHOOK 1
#define CONFIG_IXGBE_HWMON 1
#define CONFIG_X86_INTEL_PSTATE 1
#define CONFIG_ACPI_FPDT 1
#define CONFIG_CRYPTO_DEV_AMLOGIC_GXL_MODULE 1
#define CONFIG_DVB_PT3_MODULE 1
#define CONFIG_NET_DSA_SMSC_LAN9303_MODULE 1
#define CONFIG_USB_SERIAL_XR_MODULE 1
#define CONFIG_IPE_PROP_FS_VERITY_BUILTIN_SIG 1
#define CONFIG_IP_SET_MODULE 1
#define CONFIG_SND_SOC_CS530X_MODULE 1
#define CONFIG_IP_SET_BITMAP_PORT_MODULE 1
#define CONFIG_ACPI_APEI 1
#define CONFIG_TCP_CONG_NV_MODULE 1
#define CONFIG_SND_SOC_AMD_ACP_MODULE 1
#define CONFIG_AD8801_MODULE 1
#define CONFIG_VIDEO_CCS_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_TCPMSS_MODULE 1
#define CONFIG_RTC_DRV_WILCO_EC_MODULE 1
#define CONFIG_SLHC_MODULE 1
#define CONFIG_VIDEO_WM8775_MODULE 1
#define CONFIG_SLUB_DEBUG 1
#define CONFIG_SND_SOC_SRC4XXX_MODULE 1
#define CONFIG_PPS_CLIENT_LDISC_MODULE 1
#define CONFIG_USB_GSPCA_SQ905_MODULE 1
#define CONFIG_EDAC_SCRUB 1
#define CONFIG_CCS811_MODULE 1
#define CONFIG_W1_MASTER_MATROX_MODULE 1
#define CONFIG_BACKLIGHT_MAX8925_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_GENERAL_TOUCH 1
#define CONFIG_SND_SOC_CS35L41_I2C_MODULE 1
#define CONFIG_DVB_CX24120_MODULE 1
#define CONFIG_PINCTRL_MCP23S08_MODULE 1
#define CONFIG_NET_DSA_TAG_RZN1_A5PSW_MODULE 1
#define CONFIG_ATH10K_SDIO_MODULE 1
#define CONFIG_EFI_CAPSULE_LOADER_MODULE 1
#define CONFIG_DVB_USB_DIBUSB_MB_MODULE 1
#define CONFIG_BRIDGE_CFM 1
#define CONFIG_SND_SOC_INTEL_SST_TOPLEVEL 1
#define CONFIG_BAREUDP_MODULE 1
#define CONFIG_PATA_HPT37X_MODULE 1
#define CONFIG_LEDS_BLINKM_MODULE 1
#define CONFIG_SFC_MODULE 1
#define CONFIG_RADIO_TEA575X_MODULE 1
#define CONFIG_MMC_RICOH_MMC 1
#define CONFIG_CRYPTO_SHA256 1
#define CONFIG_DRM_XE_TIMESLICE_MAX 10000000
#define CONFIG_MCTP_FLOWS 1
#define CONFIG_ATH10K_MODULE 1
#define CONFIG_SND_CTL_LED_MODULE 1
#define CONFIG_NUMA_BALANCING 1
#define CONFIG_VIRTIO_MMIO_CMDLINE_DEVICES 1
#define CONFIG_HAVE_BUILDTIME_MCOUNT_SORT 1
#define CONFIG_FWCTL_MODULE 1
#define CONFIG_USB_GSPCA_KONICA_MODULE 1
#define CONFIG_NET_EMATCH_CMP_MODULE 1
#define CONFIG_QUOTACTL 1
#define CONFIG_BRIDGE_NF_EBTABLES_MODULE 1
#define CONFIG_EXFAT_DEFAULT_IOCHARSET "utf8"
#define CONFIG_VIDEOBUF2_V4L2_MODULE 1
#define CONFIG_NET_VENDOR_ARC 1
#define CONFIG_WIL6210_DEBUGFS 1
#define CONFIG_BT_HCIUART_BCM 1
#define CONFIG_NET_VENDOR_NVIDIA 1
#define CONFIG_UNIX 1
#define CONFIG_CEC_SECO_MODULE 1
#define CONFIG_MEDIA_TUNER_M88RS6000T_MODULE 1
#define CONFIG_IRQ_WORK 1
#define CONFIG_IPV6_RPL_LWTUNNEL 1
#define CONFIG_SND_SOC_WSA884X_MODULE 1
#define CONFIG_SATA_DWC_MODULE 1
#define CONFIG_NETFILTER_XT_MATCH_COMMENT_MODULE 1
#define CONFIG_INPUT_APANEL_MODULE 1
#define CONFIG_EROFS_FS_XATTR 1
#define CONFIG_SMSC37B787_WDT_MODULE 1
#define CONFIG_CRYPTO_LIB_SHA256_ARCH 1
#define CONFIG_CRYPTO_LIB_CURVE25519_GENERIC 1
#define CONFIG_TRACING_MAP 1
#define CONFIG_NLS_MAC_CROATIAN_MODULE 1
#define CONFIG_SCSI_HPSA_MODULE 1
#define CONFIG_APPLE_GMUX_MODULE 1
#define CONFIG_HYPERVISOR_GUEST 1
#define CONFIG_BT_HCIBT3C_MODULE 1
#define CONFIG_XEN_HAVE_VPMU 1
#define CONFIG_PWM_LP3943_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_TPROXY_MODULE 1
#define CONFIG_DUMMY_CONSOLE_COLUMNS 80
#define CONFIG_MENF21BMC_WATCHDOG_MODULE 1
#define CONFIG_SUNGEM_MODULE 1
#define CONFIG_NF_LOG_IPV4_MODULE 1
#define CONFIG_TLS_MODULE 1
#define CONFIG_PCI_HYPERV_INTERFACE_MODULE 1
#define CONFIG_NET_DEVMEM 1
#define CONFIG_ATH9K_PCI 1
#define CONFIG_B43LEGACY_LEDS 1
#define CONFIG_SND_INTEL8X0_MODULE 1
#define CONFIG_TCP_CONG_HTCP_MODULE 1
#define CONFIG_SERIAL_8250_NI_MODULE 1
#define CONFIG_CAN_SJA1000_PLATFORM_MODULE 1
#define CONFIG_SND_LAYLA24_MODULE 1
#define CONFIG_HID_PICOLCD_BACKLIGHT 1
#define CONFIG_STACKTRACE 1
#define CONFIG_AD7280_MODULE 1
#define CONFIG_WCN36XX_MODULE 1
#define CONFIG_SND_DICE_MODULE 1
#define CONFIG_DVB_USB_CINERGY_T2_MODULE 1
#define CONFIG_BT_HCIBTUSB_AUTOSUSPEND 1
#define CONFIG_TYPHOON_MODULE 1
#define CONFIG_8139TOO_8129 1
#define CONFIG_X86_NEED_RELOCS 1
#define CONFIG_PINCTRL_SX150X 1
#define CONFIG_6LOWPAN_NHC_HOP_MODULE 1
#define CONFIG_HAVE_ARCH_TRANSPARENT_HUGEPAGE_PUD 1
#define CONFIG_NET_IEEE8021Q_HELPERS 1
#define CONFIG_COMPAT_32 1
#define CONFIG_TUN_MODULE 1
#define CONFIG_SCSI_IPR_DUMP 1
#define CONFIG_SCA3000_MODULE 1
#define CONFIG_CAN_CC770_MODULE 1
#define CONFIG_INTEL_TPMI_POWER_DOMAINS_MODULE 1
#define CONFIG_NET_CLS_BASIC_MODULE 1
#define CONFIG_TCP_CONG_LP_MODULE 1
#define CONFIG_ADF4350_MODULE 1
#define CONFIG_CAN_M_CAN_TCAN4X5X_MODULE 1
#define CONFIG_DVB_USB_TECHNISAT_USB2_MODULE 1
#define CONFIG_CLKEVT_I8253 1
#define CONFIG_SATA_QSTOR_MODULE 1
#define CONFIG_ARCH_USE_SYM_ANNOTATIONS 1
#define CONFIG_XEN_VIRTIO 1
#define CONFIG_RTC_DRV_RV3029_HWMON 1
#define CONFIG_DRM_CLIENT_LOG 1
#define CONFIG_SENSORS_IBMPEX_MODULE 1
#define CONFIG_MAC80211_DEBUGFS 1
#define CONFIG_USB_G_NOKIA_MODULE 1
#define CONFIG_SOUNDWIRE_CADENCE_MODULE 1
#define CONFIG_B43LEGACY_DEBUG 1
#define CONFIG_IXGBE_DCB 1
#define CONFIG_MOUSE_BCM5974_MODULE 1
#define CONFIG_ATH5K_MODULE 1
#define CONFIG_SENSORS_MAX6639_MODULE 1
#define CONFIG_SENSORS_MAX31790_MODULE 1
#define CONFIG_SERIAL_ALTERA_UART_MAXPORTS 4
#define CONFIG_CRYPTO_XCBC_MODULE 1
#define CONFIG_GPIO_WM831X_MODULE 1
#define CONFIG_MFD_MADERA_I2C_MODULE 1
#define CONFIG_AR5523_MODULE 1
#define CONFIG_MLX4_CORE_GEN2 1
#define CONFIG_CROS_EC_DEBUGFS_MODULE 1
#define CONFIG_CHROMEOS_TBMC_MODULE 1
#define CONFIG_HW_RANDOM 1
#define CONFIG_GPIO_FXL6408_MODULE 1
#define CONFIG_CPU_IDLE_GOV_HALTPOLL 1
#define CONFIG_IP_NF_TARGET_MASQUERADE_MODULE 1
#define CONFIG_RCU_NEED_SEGCBLIST 1
#define CONFIG_SND_SOC_WM8940_MODULE 1
#define CONFIG_SENSORS_LM80_MODULE 1
#define CONFIG_NET_DSA_TAG_BRCM_LEGACY_FCS_MODULE 1
#define CONFIG_SENSORS_INA233_MODULE 1
#define CONFIG_USB_NET_CX82310_ETH_MODULE 1
#define CONFIG_AD5755_MODULE 1
#define CONFIG_BT_QCA_MODULE 1
#define CONFIG_RTC_DRV_RV8803_MODULE 1
#define CONFIG_LEDS_MAX5970_MODULE 1
#define CONFIG_SLIP_SMART 1
#define CONFIG_NEED_DMA_MAP_STATE 1
#define CONFIG_BT_MTKUART_MODULE 1
#define CONFIG_TCM_FC_MODULE 1
#define CONFIG_UBIFS_FS_MODULE 1
#define CONFIG_NFC_FDP_MODULE 1
#define CONFIG_RCU_EXP_CPU_STALL_TIMEOUT 0
#define CONFIG_KEYBOARD_MTK_PMIC_MODULE 1
#define CONFIG_MOUSE_PS2_LIFEBOOK 1
#define CONFIG_ZL3073X_MODULE 1
#define CONFIG_MODULE_SIG_KEY "certs/signing_key.pem"
#define CONFIG_ARCH_MMAP_RND_BITS_MIN 28
#define CONFIG_ARCH_WANT_OPTIMIZE_DAX_VMEMMAP 1
#define CONFIG_ISA_BUS_API 1
#define CONFIG_USB_SERIAL_SYMBOL_MODULE 1
#define CONFIG_OPENVSWITCH_VXLAN_MODULE 1
#define CONFIG_VFIO_PCI_DMABUF 1
#define CONFIG_CRYPTO_BLAKE2B 1
#define CONFIG_DEBUG_SHIRQ 1
#define CONFIG_NVDIMM_DAX 1
#define CONFIG_AMD_HFI 1
#define CONFIG_SENSORS_PLI1209BC_MODULE 1
#define CONFIG_GFS2_FS_MODULE 1
#define CONFIG_INFINIBAND_ADDR_TRANS_CONFIGFS 1
#define CONFIG_UIO_DFL_MODULE 1
#define CONFIG_ATA_FORCE 1
#define CONFIG_NET_VENDOR_DEC 1
#define CONFIG_IP_SET_HASH_IPMAC_MODULE 1
#define CONFIG_SND_SOC_MAX98373_I2C_MODULE 1
#define CONFIG_SND_ES1968_INPUT 1
#define CONFIG_SND_HDA_CODEC_CA0132_DSP 1
#define CONFIG_SENSORS_DS1621_MODULE 1
#define CONFIG_RT2800USB_UNKNOWN 1
#define CONFIG_SYSVIPC 1
#define CONFIG_LOCKDEP_SUPPORT 1
#define CONFIG_PHY_QCOM_USB_HS_MODULE 1
#define CONFIG_NFT_FIB_IPV6_MODULE 1
#define CONFIG_MEDIA_TUNER_TDA18250_MODULE 1
#define CONFIG_MEDIA_TUNER_QM1D1B0004_MODULE 1
#define CONFIG_IIO_ST_GYRO_3AXIS_MODULE 1
#define CONFIG_BT_HCIUART_LL 1
#define CONFIG_AD5933_MODULE 1
#define CONFIG_TCP_SIGPOOL 1
#define CONFIG_PINCTRL_CEDARFORK_MODULE 1
#define CONFIG_RT2X00_LIB_PCI_MODULE 1
#define CONFIG_FIREWIRE_NOSY_MODULE 1
#define CONFIG_LTC2632_MODULE 1
#define CONFIG_FSCACHE 1
#define CONFIG_SND_SOC_TAS5086_MODULE 1
#define CONFIG_MFD_SM501_MODULE 1
#define CONFIG_DM_INTEGRITY_MODULE 1
#define CONFIG_USB_CONFIGFS_MODULE 1
#define CONFIG_USB_F_ECM_MODULE 1
#define CONFIG_INFINIBAND_VMWARE_PVRDMA_MODULE 1
#define CONFIG_X86_PKG_TEMP_THERMAL_MODULE 1
#define CONFIG_SND_SOC_SOF_INTEL_APL_MODULE 1
#define CONFIG_MEDIA_SUPPORT_FILTER 1
#define CONFIG_BATTERY_CHAGALL_MODULE 1
#define CONFIG_CRYPTO 1
#define CONFIG_NF_TABLES_BRIDGE_MODULE 1
#define CONFIG_ARCH_HAS_ELFCORE_COMPAT 1
#define CONFIG_DELL_SMO8800_MODULE 1
#define CONFIG_PARAVIRT 1
#define CONFIG_HID_ELECOM_MODULE 1
#define CONFIG_FPGA_M10_BMC_SEC_UPDATE_MODULE 1
#define CONFIG_HAVE_ARCH_SECCOMP 1
#define CONFIG_AD4134_MODULE 1
#define CONFIG_PATA_PARPORT_FRIQ_MODULE 1
#define CONFIG_DVB_TUNER_CX24113_MODULE 1
#define CONFIG_IOMMU_IOPF 1
#define CONFIG_HID_MCP2221_MODULE 1
#define CONFIG_VFIO_GROUP 1
#define CONFIG_VIDEO_OV9640_MODULE 1
#define CONFIG_SND_SOC_MT6351_MODULE 1
#define CONFIG_TI_ADC081C_MODULE 1
#define CONFIG_USB_ISP1760_DUAL_ROLE 1
#define CONFIG_SENSORS_LM70_MODULE 1
#define CONFIG_BATTERY_88PM860X_MODULE 1
#define CONFIG_VIDEO_VIVID_MAX_DEVS 64
#define CONFIG_NFC_MICROREAD_MEI_MODULE 1
#define CONFIG_BLK_CGROUP_FC_APPID 1
#define CONFIG_PROC_FS 1
#define CONFIG_SPI_CS42L43_MODULE 1
#define CONFIG_USB_ALI_M5632 1
#define CONFIG_RSI_SDIO_MODULE 1
#define CONFIG_HAVE_UACCESS_VALIDATION 1
#define CONFIG_VIDEO_OV2740_MODULE 1
#define CONFIG_SND_CTL_FAST_LOOKUP 1
#define CONFIG_DVB_USB_DIBUSB_MC_MODULE 1
#define CONFIG_TXGBE_MODULE 1
#define CONFIG_ARCH_USE_MEMREMAP_PROT 1
#define CONFIG_BMA220_MODULE 1
#define CONFIG_SENSORS_MAX16064_MODULE 1
#define CONFIG_CROS_EC_LPC_MODULE 1
#define CONFIG_SND_SOC_CS35L56_SDW_MODULE 1
#define CONFIG_DEBUG_INFO_COMPRESSED_NONE 1
#define CONFIG_CRYPTO_DEV_ATMEL_ECC_MODULE 1
#define CONFIG_PM_DEVFREQ 1
#define CONFIG_DRM_CLIENT_SELECTION 1
#define CONFIG_SENSORS_F71805F_MODULE 1
#define CONFIG_NET_VENDOR_TEHUTI 1
#define CONFIG_NF_CT_PROTO_SCTP 1
#define CONFIG_BLK_DEV_PMEM_MODULE 1
#define CONFIG_USB_GSPCA_SPCA508_MODULE 1
#define CONFIG_SX_COMMON_MODULE 1
#define CONFIG_SND_SOC_CS53L30_MODULE 1
#define CONFIG_PINCTRL_CS47L85 1
#define CONFIG_MITIGATION_UNRET_ENTRY 1
#define CONFIG_BPF_EVENTS 1
#define CONFIG_GENERIC_ENTRY 1
#define CONFIG_MEDIA_PLATFORM_SUPPORT 1
#define CONFIG_X86_DISABLED_FEATURE_CENTAUR_MCR 1
#define CONFIG_TMPFS_QUOTA 1
#define CONFIG_VIDEO_VISL_MODULE 1
#define CONFIG_POSIX_TIMERS 1
#define CONFIG_HID_BELKIN_MODULE 1
#define CONFIG_ARCH_HAS_CPU_FINALIZE_INIT 1
#define CONFIG_DVB_ISL6421_MODULE 1
#define CONFIG_UIO_CIF_MODULE 1
#define CONFIG_SND_OXYGEN_MODULE 1
#define CONFIG_I2C_ATR_MODULE 1
#define CONFIG_MITIGATION_ITS 1
#define CONFIG_PROC_CPU_RESCTRL 1
#define CONFIG_USB_SERIAL_KLSI_MODULE 1
#define CONFIG_ADVANTECH_WDT_MODULE 1
#define CONFIG_LEDS_TI_LMU_COMMON_MODULE 1
#define CONFIG_BME680_MODULE 1
#define CONFIG_PCS_LYNX_MODULE 1
#define CONFIG_HAVE_FTRACE_REGS_HAVING_PT_REGS 1
#define CONFIG_RPMSG_VIRTIO_MODULE 1
#define CONFIG_TOUCHSCREEN_AD7879_SPI_MODULE 1
#define CONFIG_NOP_USB_XCEIV_MODULE 1
#define CONFIG_GENERIC_TRACER 1
#define CONFIG_NET_DSA_MT7530_MDIO_MODULE 1
#define CONFIG_ATA_GENERIC_MODULE 1
#define CONFIG_I2C_I801_MODULE 1
#define CONFIG_CPU_SUP_ZHAOXIN 1
#define CONFIG_KS8842_MODULE 1
#define CONFIG_SQUASHFS_XZ 1
#define CONFIG_INTEL_PLR_TPMI_MODULE 1
#define CONFIG_SCSI_SMARTPQI_MODULE 1
#define CONFIG_CC_HAS_COUNTED_BY 1
#define CONFIG_PPP_ASYNC_MODULE 1
#define CONFIG_DVB_MAX_ADAPTERS 16
#define CONFIG_INPUT_PCAP_MODULE 1
#define CONFIG_NET_VENDOR_SIS 1
#define CONFIG_BCMA_BLOCKIO 1
#define CONFIG_V4L2_MEM2MEM_DEV_MODULE 1
#define CONFIG_KERNEL_ZSTD 1
#define CONFIG_SND_SOC_CS530X_SPI_MODULE 1
#define CONFIG_LEDS_REGULATOR_MODULE 1
#define CONFIG_SENSEAIR_SUNRISE_CO2_MODULE 1
#define CONFIG_NOUVEAU_DEBUG_DEFAULT 3
#define CONFIG_RTC_DRV_RS5C372_MODULE 1
#define CONFIG_XFRM_AH_MODULE 1
#define CONFIG_DVB_DIB8000_MODULE 1
#define CONFIG_EFI_BOOTLOADER_CONTROL_MODULE 1
#define CONFIG_INET_DIAG_MODULE 1
#define CONFIG_OVERLAY_FS_INDEX 1
#define CONFIG_JOYSTICK_A3D_MODULE 1
#define CONFIG_SMB_SERVER_SMBDIRECT 1
#define CONFIG_INPUT_88PM80X_ONKEY_MODULE 1
#define CONFIG_FS_IOMAP 1
#define CONFIG_DRM_PANEL_AUO_A030JTN01_MODULE 1
#define CONFIG_FB_IOMEM_HELPERS 1
#define CONFIG_USB_R8A66597_MODULE 1
#define CONFIG_NATIONAL_PHY_MODULE 1
#define CONFIG_SENSORS_MLXREG_FAN_MODULE 1
#define CONFIG_SENSORS_STEF48H28_MODULE 1
#define CONFIG_DRM_QXL_MODULE 1
#define CONFIG_INPUT_VIVALDIFMAP 1
#define CONFIG_CHARGER_CROS_USBPD_MODULE 1
#define CONFIG_SCSI_IMM_MODULE 1
#define CONFIG_USB_GSPCA_DTCS033_MODULE 1
#define CONFIG_IP_VS_PROTO_TCP 1
#define CONFIG_8139TOO_TUNE_TWISTER 1
#define CONFIG_USB_GL860_MODULE 1
#define CONFIG_ALLOW_DEV_COREDUMP 1
#define CONFIG_ASN1 1
#define CONFIG_NF_NAT_PPTP_MODULE 1
#define CONFIG_STAGING_MEDIA 1
#define CONFIG_SND_SOC_INTEL_AVS_MACH_ES8336_MODULE 1
#define CONFIG_RAID_ATTRS_MODULE 1
#define CONFIG_MMC_CQHCI_MODULE 1
#define CONFIG_SND_ASIHPI_MODULE 1
#define CONFIG_AD5624R_SPI_MODULE 1
#define CONFIG_DEVTMPFS_MOUNT 1
#define CONFIG_REGULATOR_BD9571MWV_MODULE 1
#define CONFIG_NFC_ST21NFCA_I2C_MODULE 1
#define CONFIG_FIREWIRE_NET_MODULE 1
#define CONFIG_ARCH_HAS_DMA_OPS 1
#define CONFIG_HID_LOGITECH_DJ_MODULE 1
#define CONFIG_SND_PCMCIA 1
#define CONFIG_LEDS_MT6370_FLASH_MODULE 1
#define CONFIG_USB_SERIAL_EDGEPORT_TI_MODULE 1
#define CONFIG_CONSOLE_LOGLEVEL_QUIET 1
#define CONFIG_AD5592R_BASE_MODULE 1
#define CONFIG_ACPI_PCC 1
#define CONFIG_SERIO_GPIO_PS2_MODULE 1
#define CONFIG_NETFILTER_XT_TARGET_NFLOG_MODULE 1
#define CONFIG_CRYPTO_DEV_IAA_CRYPTO_MODULE 1
#define CONFIG_SCSI_EFCT_MODULE 1
#define CONFIG_USB_ETH_MODULE 1
#define CONFIG_XILINX_PR_DECOUPLER_MODULE 1
#define CONFIG_INET_TUNNEL_MODULE 1
#define CONFIG_SND_SOC_NAU8822_MODULE 1
#define CONFIG_MLX5_EN_PSP 1
#define CONFIG_XEN_SYS_HYPERVISOR 1
#define CONFIG_W1_MASTER_AMD_AXI_MODULE 1
#define CONFIG_VIDEO_WM8739_MODULE 1
#define CONFIG_ATH10K_DEBUG 1
#define CONFIG_HTE 1
#define CONFIG_SONYPI_COMPAT 1
#define CONFIG_IEEE802154_CA8210_MODULE 1
#define CONFIG_LZO_DECOMPRESS 1
#define CONFIG_DM_UNSTRIPED_MODULE 1
#define CONFIG_VIRTIO_VSOCKETS_MODULE 1
#define CONFIG_NUMA_MEMBLKS 1
#define CONFIG_JUMP_LABEL 1
#define CONFIG_GENERIC_SMP_IDLE_THREAD 1
#define CONFIG_DRM_PANIC_SCREEN_QR_CODE_URL "https://panic.archlinux.org/panic_report#"
#define CONFIG_USB_ARCH_HAS_HCD 1
#define CONFIG_GPIO_TPS65086_MODULE 1
#define CONFIG_REED_SOLOMON_ENC8 1
#define CONFIG_NET_EMATCH_STACK 32
#define CONFIG_NF_NAT_FTP_MODULE 1
#define CONFIG_CRYPTO_AEGIS128_MODULE 1
#define CONFIG_XEN_PVCALLS_FRONTEND_MODULE 1
#define CONFIG_DPOT_DAC_MODULE 1
#define CONFIG_LDM_PARTITION 1
#define CONFIG_INPUT_WM831X_ON_MODULE 1
#define CONFIG_EEPROM_EE1004_MODULE 1
#define CONFIG_IAVF_MODULE 1
#define CONFIG_TOUCHSCREEN_AD7879_I2C_MODULE 1
#define CONFIG_VIDEO_UDA1342_MODULE 1
#define CONFIG_ARCH_MMAP_RND_COMPAT_BITS_MIN 8
#define CONFIG_NET_EMATCH_CANID_MODULE 1
#define CONFIG_RTC_HCTOSYS 1
#define CONFIG_DRM_PIXPAPER_MODULE 1
#define CONFIG_EXTRA_FIRMWARE ""
#define CONFIG_IP_MULTICAST 1
#define CONFIG_SCSI_PPA_MODULE 1
#define CONFIG_DVB_BUDGET_MODULE 1
#define CONFIG_MFD_WM8994_MODULE 1
#define CONFIG_SERIAL_MULTI_INSTANTIATE_MODULE 1
#define CONFIG_NFC_ST_NCI_MODULE 1
#define CONFIG_PNPACPI 1
#define CONFIG_ASYMMETRIC_PUBLIC_KEY_SUBTYPE 1
#define CONFIG_LEDS_TPS6105X_MODULE 1
#define CONFIG_DVB_STV0288_MODULE 1
#define CONFIG_X86_MEM_ENCRYPT 1
#define CONFIG_SCSI_UFSHCD_PCI_MODULE 1
#define CONFIG_SENSORS_MAX6650_MODULE 1
#define CONFIG_LOCKUP_DETECTOR 1
#define CONFIG_FUSE_FS 1
#define CONFIG_DMAR_TABLE 1
#define CONFIG_USB_STV06XX_MODULE 1
#define CONFIG_INTEL_ATOMISP2_LED_MODULE 1
#define CONFIG_ABP2030PA_I2C_MODULE 1
#define CONFIG_NFC_PN533_USB_MODULE 1
#define CONFIG_QCOM_SCM_MODULE 1
#define CONFIG_IO_URING_BPF 1
#define CONFIG_SENSORS_LIS3LV02D_MODULE 1
#define CONFIG_TOUCHSCREEN_ADS7846_MODULE 1
#define CONFIG_MFD_MC13XXX_I2C_MODULE 1
#define CONFIG_SERIAL_8250_DWLIB 1
#define CONFIG_ZRAM_BACKEND_ZSTD 1
#define CONFIG_MFD_TPS65912_MODULE 1
#define CONFIG_USB_F_ACM_MODULE 1
#define CONFIG_KSZ884X_PCI_MODULE 1
#define CONFIG_RTW88_CORE_MODULE 1
#define CONFIG_PSTORE_RAM_MODULE 1
#define CONFIG_EFI_CUSTOM_SSDT_OVERLAYS 1
#define CONFIG_MEDIA_TUNER_TUA9001_MODULE 1
#define CONFIG_SENSORS_ISL28022_MODULE 1
#define CONFIG_X86_PAT 1
#define CONFIG_BT_HCIUART_NOKIA_MODULE 1
#define CONFIG_NOP_TRACER 1
#define CONFIG_PTP_1588_CLOCK_INES_MODULE 1
#define CONFIG_HAVE_KVM_DIRTY_RING_ACQ_REL 1
#define CONFIG_MICREL_PHY_MODULE 1
#define CONFIG_ARCH_HAS_CPU_CACHE_INVALIDATE_MEMREGION 1
#define CONFIG_BMA400_MODULE 1
#define CONFIG_DRM_VRAM_HELPER_MODULE 1
#define CONFIG_LZ4_COMPRESS_MODULE 1
#define CONFIG_TOUCHSCREEN_USB_ETURBO 1
#define CONFIG_NETFILTER_XT_MATCH_SOCKET_MODULE 1
#define CONFIG_ARCH_HAS_FORCE_DMA_UNENCRYPTED 1
#define CONFIG_SMB_SERVER_KERBEROS5 1
#define CONFIG_IP_VS_LBLCR_MODULE 1
#define CONFIG_REGULATOR_AW37503_MODULE 1
#define CONFIG_BTREE 1
#define CONFIG_PNFS_FLEXFILE_LAYOUT_MODULE 1
#define CONFIG_AMD_QDMA_MODULE 1
#define CONFIG_GENERIC_PINMUX_FUNCTIONS 1
#define CONFIG_GPIO_MOCKUP_MODULE 1
#define CONFIG_IRSD200_MODULE 1
#define CONFIG_SND_SOC_AW88081_MODULE 1
#define CONFIG_EDAC_X38_MODULE 1
#define CONFIG_VETH_MODULE 1
#define CONFIG_USB_GSPCA_CONEX_MODULE 1
#define CONFIG_LEDS_MT6370_RGB_MODULE 1
#define CONFIG_TLAN_MODULE 1
#define CONFIG_IP_VS_NFCT 1
#define CONFIG_NSM_MODULE 1
#define CONFIG_INTEL_SPEED_SELECT_INTERFACE_MODULE 1
#define CONFIG_SND_SOC_RT_SDW_COMMON_MODULE 1
#define CONFIG_MAX5522_MODULE 1
#define CONFIG_AD7303_MODULE 1
#define CONFIG_DVB_CXD2099_MODULE 1
#define CONFIG_SDIO_UART_MODULE 1
#define CONFIG_SSB_B43_PCI_BRIDGE 1
#define CONFIG_NET_SCH_PIE_MODULE 1
#define CONFIG_UCLAMP_TASK_GROUP 1
#define CONFIG_USB_SERIAL_MOS7720_MODULE 1
#define CONFIG_NET_VENDOR_LITEX 1
#define CONFIG_RTW88_8822CE_MODULE 1
#define CONFIG_DVB_PLATFORM_DRIVERS 1
#define CONFIG_AD4000_MODULE 1
#define CONFIG_VIDEO_V4L2_SUBDEV_API 1
#define CONFIG_CEPH_LIB_USE_DNS_RESOLVER 1
#define CONFIG_GPIO_TANGIER_MODULE 1
#define CONFIG_SCSI_SAS_ATA 1
#define CONFIG_INV_MPU6050_I2C_MODULE 1
#define CONFIG_IKHEADERS_MODULE 1
#define CONFIG_SENSORS_MAX31722_MODULE 1
#define CONFIG_MICROCODE 1
#define CONFIG_NVME_TARGET_FC_MODULE 1
#define CONFIG_SENSORS_MAX16065_MODULE 1
#define CONFIG_DRM_XE_GPUSVM 1
#define CONFIG_VHOST_RING_MODULE 1
#define CONFIG_VIRTIO_BALLOON_MODULE 1
#define CONFIG_BCMA_HOST_PCI_POSSIBLE 1
#define CONFIG_CPU_ISOLATION 1
#define CONFIG_GENERIC_CMOS_UPDATE 1
#define CONFIG_SERIAL_8250_PCI 1
#define CONFIG_NET_VENDOR_QLOGIC 1
#define CONFIG_USB_GSPCA_SONIXJ_MODULE 1
#define CONFIG_SND_SOC_WM8904_MODULE 1
#define CONFIG_EXTCON_PALMAS_MODULE 1
#define CONFIG_GPIO_XILINX_MODULE 1
#define CONFIG_LWTUNNEL_BPF 1
#define CONFIG_CRYPTO_LIB_NH_MODULE 1
#define CONFIG_NET_ACT_CTINFO_MODULE 1
#define CONFIG_DLM_MODULE 1
#define CONFIG_SERIO 1
#define CONFIG_CHR_DEV_SCH_MODULE 1
#define CONFIG_SC92031_MODULE 1
#define CONFIG_MCP47FEB02_MODULE 1
#define CONFIG_USB_GSPCA_OV519_MODULE 1
#define CONFIG_NET_VRF_MODULE 1
#define CONFIG_DRM_GEM_SHMEM_HELPER 1
#define CONFIG_ARCH_SUPPORTS_ATOMIC_RMW 1
#define CONFIG_CROS_EC_UCSI_MODULE 1
#define CONFIG_HARDLOCKUP_DETECTOR_PERF 1
#define CONFIG_DVB_TDA826X_MODULE 1
#define CONFIG_FTRACE_MCOUNT_USE_CC 1
#define CONFIG_BT_INTEL_PCIE_MODULE 1
#define CONFIG_CRYPTO_LIB_AES 1
#define CONFIG_CRYPTO_TWOFISH_X86_64_3WAY_MODULE 1
#define CONFIG_TYPEC_MUX_WCD939X_USBSS_MODULE 1
#define CONFIG_HYPERV_VSOCKETS_MODULE 1
#define CONFIG_BPF_LIRC_MODE2 1
#define CONFIG_BMI160_SPI_MODULE 1
#define CONFIG_SND_GINA24_MODULE 1
#define CONFIG_CROS_USBPD_LOGGER_MODULE 1
#define CONFIG_DM_VERITY_FEC 1
#define CONFIG_MLX5_VDPA_NET_MODULE 1
#define CONFIG_REGULATOR_SY7636A_MODULE 1
#define CONFIG_NF_LOG_SYSLOG_MODULE 1
#define CONFIG_LTRF216A_MODULE 1
#define CONFIG_USB_OHCI_HCD 1
#define CONFIG_PATA_LEGACY_MODULE 1
#define CONFIG_VFIO_VIRQFD 1
#define CONFIG_HSA_AMD_P2P 1
#define CONFIG_BMA400_I2C_MODULE 1
#define CONFIG_FB_IOMEM_FOPS 1
#define CONFIG_FW_CACHE 1
#define CONFIG_AGP_VIA_MODULE 1
#define CONFIG_REGMAP_I2C 1
#define CONFIG_STMMAC_PLATFORM_MODULE 1
#define CONFIG_IP_NF_TARGET_REDIRECT_MODULE 1
#define CONFIG_RCU_FANOUT_LEAF 16
#define CONFIG_MTD_MTDRAM_MODULE 1
#define CONFIG_HID_TOPRE_MODULE 1
#define CONFIG_SENSORS_ABITUGURU3_MODULE 1
#define CONFIG_SCSI_MPT2SAS_MODULE 1
#define CONFIG_SND_SOC_WM8731_SPI_MODULE 1
#define CONFIG_HINIC3_MODULE 1
#define CONFIG_MMC_SDHCI_MODULE 1
#define CONFIG_IOMMUFD_DRIVER 1
#define CONFIG_PRINTK 1
#define CONFIG_LEDS_TRIGGER_DISK 1
#define CONFIG_FIREWIRE_MODULE 1
#define CONFIG_F2FS_CHECK_FS 1
#define CONFIG_DM_SWITCH_MODULE 1
#define CONFIG_VIDEO_EM28XX_DVB_MODULE 1
#define CONFIG_DRM_I915_FORCE_PROBE "*"
#define CONFIG_NETLABEL 1
#define CONFIG_PINCTRL_CS42L43_MODULE 1
#define CONFIG_I2C_KEBA_MODULE 1
#define CONFIG_ARCH_SUPPORTS_KEXEC_HANDOVER 1
#define CONFIG_SND_SOC_MAX9860_MODULE 1
#define CONFIG_DRM_NOUVEAU_SVM 1
#define CONFIG_PCI_STUB 1
#define CONFIG_LEDS_CHT_WCOVE_MODULE 1
#define CONFIG_CRYPTO_RMD160_MODULE 1
#define CONFIG_INTEL_TH_MSU_MODULE 1
#define CONFIG_RTC_DRV_88PM80X_MODULE 1
#define CONFIG_HAVE_STATIC_CALL 1
#define CONFIG_USB_NET_CDC_NCM_MODULE 1
#define CONFIG_DAMON_STAT 1
#define CONFIG_AGP_INTEL_MODULE 1
#define CONFIG_CC_VERSION_TEXT "gcc (GCC) 16.2.1 20260810"
#define CONFIG_TOUCHSCREEN_BU21013_MODULE 1
#define CONFIG_EQUALIZER_MODULE 1
#define CONFIG_INTEL_ISH_FIRMWARE_DOWNLOADER_MODULE 1
#define CONFIG_VIDEO_IVTV_MODULE 1
#define CONFIG_DVB_BUDGET_AV_MODULE 1
#define CONFIG_IP6_NF_MATCH_SRH_MODULE 1
#define CONFIG_SND_SOC_NAU8821_MODULE 1
#define CONFIG_BINFMT_ELF 1
#define CONFIG_BLK_DEV_RNBD 1
#define CONFIG_HIGH_RES_TIMERS 1
#define CONFIG_I2C_SMBUS_MODULE 1
#define CONFIG_DEBUG_FS_ALLOW_ALL 1
#define CONFIG_NULL_TTY_MODULE 1
#define CONFIG_ALS31300_MODULE 1
#define CONFIG_QED_RDMA 1
#define CONFIG_HAVE_SAMPLE_FTRACE_DIRECT_MULTI 1
#define CONFIG_TI_TMAG5273_MODULE 1
#define CONFIG_WIREGUARD_MODULE 1
#define CONFIG_GOOGLE_MEMCONSOLE_COREBOOT_MODULE 1
#define CONFIG_RTW89_8852BU_MODULE 1
#define CONFIG_MEMFD_CREATE 1
#define CONFIG_FPGA_MGR_MICROCHIP_SPI_MODULE 1
#define CONFIG_HDMI_LPE_AUDIO_MODULE 1
#define CONFIG_SND_SOC_RT715_SDCA_SDW_MODULE 1
#define CONFIG_FXLS8962AF_MODULE 1
#define CONFIG_USB_HSIC_USB3503_MODULE 1
#define CONFIG_GPIO_DA9055_MODULE 1
#define CONFIG_SENSORS_HMC5843_I2C_MODULE 1
#define CONFIG_DA9055_WATCHDOG_MODULE 1
#define CONFIG_WIZNET_W5100_SPI_MODULE 1
#define CONFIG_DRM_AMD_DC_SI 1
